@@ -9,7 +9,7 @@
   *  option) any later version.                                              *
   \**************************************************************************/
 
-  /* $Id: admin.php 15977 2005-05-15 13:34:30Z skwashd $ */
+  /* $Id: admin.php 1906 2008-11-28 22:47:27Z sigurd $ */
 
 	$phpgw_info['flags'] = array(
 		'currentapp'  => 'addressbook', 
@@ -23,7 +23,7 @@
 
 	include('../header.inc.php');
 
-	$phpgw->config->read_repository();
+	$phpgw->config->read();
 
 	if ($submit)
 	{
@@ -37,7 +37,7 @@
 		}
 
 		$phpgw->config->save_repository(True);
-		Header('Location: ' . $phpgw->link('/admin/index.php'));
+		$phpgw->redirect_link('/admin/index.php');
 	}
 
 	$phpgw->common->phpgw_header();
