@@ -10,7 +10,7 @@
   *  option) any later version.                                              *
   \**************************************************************************/
 
-  /* $Id: class.boXport.inc.php 15977 2005-05-15 13:34:30Z skwashd $ */
+  /* $Id: class.boXport.inc.php 690 2008-02-02 10:11:33Z dave $ */
 
 	class boXport
 	{
@@ -271,7 +271,7 @@
 				// Here, buffer becomes a string suitable for printing
 				$buffer = $contacts->export_end_file($buffer);
 
-				$tsvfilename = $GLOBALS['phpgw_info']['server']['temp_dir'] . SEP . $tsvfilename;
+				$tsvfilename = "{$GLOBALS['phpgw_info']['server']['temp_dir']}/{$tsvfilename}";
 
 			}
 			else // this is the openoffice section
