@@ -17,7 +17,7 @@
   *  option) any later version.                                              *
   \**************************************************************************/
 
-/* $Id: class.boaddressbook.inc.php 18358 2007-11-27 04:43:37Z skwashd $ */
+/* $Id: class.boaddressbook.inc.php 4862 2010-02-19 13:54:57Z sigurd $ */
 
 	class boaddressbook
 	{
@@ -260,12 +260,13 @@
 		* @param string $orderby The field which you want order
 		* @param string $sort ASC | DESC depending what you want
 		* @param mixed $criteria All criterias what you want
-		* @param mixed $criteria_token same like $criteria but builded<br />with sql_criteria class, more powerfull
+		* @param mixed $criteria_token same like $criteria but builded<br />with phpgwapi_sql_criteria class, more powerfull
 		* @return array with records
 		*/
 		function get_persons($fields, $start='', $limit='', $orderby='', $sort='', $criteria='', $token_criteria='')
 		{
 			$entries =  $this->so->get_persons($fields, $start, $limit, $orderby, $sort, $criteria, $token_criteria);
+			$persons = array();
 			if(is_array($entries))
 			{
 				foreach($entries as $data)
@@ -273,10 +274,6 @@
 					$persons[$data['contact_id']] = $data;
 				}
 			}
-			else
-			{
-				$persons = array();
-			}
 			$this->total = $this->so->contacts->total_records;
 			return $persons;
 		}
@@ -369,7 +366,7 @@
 		* @param string $orderby The field which you want order
 		* @param string $sort ASC | DESC depending what you want
 		* @param array $criteria All criterias what you want
-		* @param mixed $criteria_token same like $criteria but builded<br />with sql_criteria class, more powerfull
+		* @param mixed $criteria_token same like $criteria but builded<br />with phpgwapi_sql_criteria class, more powerfull
 		* @return array with records
 		*/
 		function get_orgs($fields, $start='', $limit='', $orderby='', $sort='', $criteria='', $token_criteria='')
@@ -518,9 +515,9 @@
 		function criteria_contacts($access, $category, $field, $pattern, $show_fields)
 		{
 			$fields = array();
-			if($pattern)
+			if ($pattern)
 			{
-				switch($field)
+				switch ($field)
 				{
 					case 'person':
 						$fields = array
@@ -528,31 +525,22 @@
 							'per_full_name',
 							'per_prefix',
 							'per_suffix',
-							'per_birthday',
-							'per_pubkey',
-							'per_title',
-							'per_department',
-							'per_initials',
-							'per_sound',
-							'per_active'
+							'per_initials'
 						);
 						break;
-					case 'person_first':
-						$fields = array('per_first_name');
-						break;
-					case 'person_last':
-						$fields = array('per_last_name');
-						break;
+
 					case 'org':
-						$fields = array('org_name');
+						$fields = array ('org_name' );
 						break;
+
 					case 'comms':
-						foreach($this->comm_descr as $data)
+						$fields['comm_media'] = array();
+						foreach ( $this->comm_descr as $data )
 						{
-							$comms[] = $data['comm_description'];
+							$fields['comm_media'][] = $data ['comm_description'];
 						}
-						$fields['comm_media'] = $comms;
 						break;
+
 					case 'location':
 						$fields = array
 						(
@@ -565,17 +553,17 @@
 							'addr_country'
 						);
 						break;
+
 					case 'other':
-						$fields = array('other_value');
+						$fields = array ('other_value');
 						break;
+
 					case 'note':
-						$fields = array('note_text');
+						$fields = array ('note_text');
 						break;
-					/*
-					not needed 
-					default:
-						$fields = array();
-					*/
+
+					default :
+						$fields = array ();
 				}
 			}
 			return $this->so->criteria_contacts($GLOBALS['phpgw_info']['user']['account_id'], $access, $category, $fields, $pattern, $show_fields);
@@ -736,7 +724,7 @@
 			else
 			{
 				$uploadedfile = $_FILES['uploadedfile']['tmp_name'];
-				$uploaddir = $GLOBALS['phpgw_info']['server']['temp_dir'] . SEP;
+				$uploaddir = $GLOBALS['phpgw_info']['server']['temp_dir'] . '/';
 
 				srand((double)microtime()*1000000);
 				$random_number = rand(100000000,999999999);
@@ -762,8 +750,7 @@
 				/* Delete the temp file. */
 				unlink($filename);
 				unlink($filename . '.info');
-				Header('Location: ' . $GLOBALS['phpgw']->link('/index.php',array('menuaction' => 'addressbook.uiaddressbook.view_person', 'ab_id' => $ab_id)));
-				exit();
+				$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction' => 'addressbook.uiaddressbook.view_person', 'ab_id' => $ab_id));
 			}
 		}
 
@@ -780,7 +767,7 @@
 		//used
 		function save_preferences($prefs,$other,$qfields,$fcat_id)
 		{
-			$GLOBALS['phpgw']->preferences->read_repository();
+			$GLOBALS['phpgw']->preferences->read();
 			if (is_array($prefs))
 			{
 				/* _debug_array($prefs);exit; */
@@ -824,7 +811,7 @@
 
 			$GLOBALS['phpgw']->preferences->save_repository(True);
 			/* _debug_array($prefs);exit; */
-			Header('Location: ' . $GLOBALS['phpgw']->link('/preferences/index.php'));
+			$GLOBALS['phpgw']->redirect_link('/preferences/index.php');
 		}
 
 		//used
@@ -967,4 +954,3 @@
 			$this->negative_responses=$negative_apps;			
 		}
 	}
-?>
