@@ -17,7 +17,7 @@
   *  option) any later version.                                              *
   \**************************************************************************/
 
-/* $Id: class.soaddressbook.inc.php 17521 2006-10-31 10:40:42Z sigurdne $ */
+/* $Id: class.soaddressbook.inc.php 4870 2010-02-22 07:38:23Z sigurd $ */
 
 	class soaddressbook
 	{
@@ -469,7 +469,7 @@
 			}
 			
 			$comm_preferred = $fields['tab_comms']['preferred'];
-			
+
 			//FIXME this is a hack cos i am sick of fixing broken written by lazy developers! skwashd 20060908
 			@$this->upgrade_comms($fields['edit_comms']['insert'], 
 					     $fields['edit_comms']['delete'], 
@@ -500,15 +500,18 @@
                         }
 
 			/* Update the first and last name in accounts */
-			$account_id = $this->contacts->get_account_id($person_id);
-			if($account_id)
+			if($fields['tab_person_data'])
 			{
-				$account = CreateObject('phpgwapi.accounts',$account_id,'u');
-				$account_data = $account->read_repository();
-				$account_data['account_firstname'] = $fields['tab_person_data']['per_first_name'];
-				$account_data['account_lastname'] = $fields['tab_person_data']['per_last_name'];
-				$account->update_data($account_data);
-				$account->save_repository();
+				$account_id = $this->contacts->get_account_id($person_id);
+				if($account_id)
+				{
+					$account = CreateObject('phpgwapi.accounts',$account_id,'u');
+					$account_data = $account->read();
+					$account_data->firstname = $fields['tab_person_data']['per_first_name'];
+					$account_data->lastname = $fields['tab_person_data']['per_last_name'];
+					$account->update_data($account_data);
+					$account->save_repository();
+				}
 			}
 			
 			$this->contacts->finalize_edit($person_id);
@@ -886,8 +889,8 @@
 			{
 				$data = array();
 			}
-			
 			$this->edit_comms_by_contact($contact_id, array('comm_preferred'=>'N'), PHPGW_SQL_RUN_SQL);
+
 			foreach($data as $key => $value)
 			{
 				if(array_key_exists($value['comm_description'], $del_comms))
@@ -906,7 +909,7 @@
 						$preferred = 'N';
 					}
 					
-					$this->edit_comms($value['key_comm_id'], 
+					$this->edit_comms($value['key_comm_id'],
 							  array('comm_data' => $edit_comms[$value['comm_description']],
 								'comm_preferred' => $preferred), 
 							  PHPGW_SQL_RUN_SQL);
@@ -1092,26 +1095,16 @@
 		*/
 		function read_preferences($contact_type)
 		{
-			$prefs =& $GLOBALS['phpgw']->preferences->data['addressbook'];
-
-			if($contact_type==$this->tab_main_persons)
+			$prefs = $GLOBALS['phpgw']->preferences->read();
+			$prefs = isset($prefs['addressbook']) ? $prefs['addressbook'] : array();
+			if(isset($prefs['person_columns']) && $contact_type==$this->tab_main_persons)
 			{
-				if ( isset($prefs['person_columns'])
-					&& strlen($prefs['person_columns']) )
-				{
-					return unserialize($prefs['person_columns']);
-				}
+				
+				return $prefs['person_columns'];
 			}
-			elseif($contact_type==$this->tab_main_organizations)
+			elseif(isset($prefs['org_columns']) && $contact_type==$this->tab_main_organizations)
 			{
-				if ( isset($prefs['org_columns'])
-					&& strlen($prefs['org_columns']) )
-				{
-					return unserialize($prefs['org_columns']);
-				}
-			}
-			return array();//whoops
+				return $prefs['org_columns'];
+			}	
 		}
-
 	}
-?>
