@@ -10,7 +10,7 @@
   *  option) any later version.                                              *
   \**************************************************************************/
 
-  /* $Id: class.uiXport.inc.php 18358 2007-11-27 04:43:37Z skwashd $ */
+  /* $Id: class.uiXport.inc.php 3266 2009-07-26 10:05:32Z sigurd $ */
 
 	class uiXport
 	{
@@ -73,7 +73,8 @@
 
 		function import()
 		{
-			if ($_REQUEST['convert']) //&& ($_FILES['tsvfile']['error'] == UPLOAD_ERR_OK))
+			$conv_type_a = $GLOBALS['phpgw']->session->appsession('conv_type_values_i', 'addressbook');
+			if ($_REQUEST['convert'] && is_array($conv_type_a) && in_array($_REQUEST['conv_type'], $conv_type_a)) //&& ($_FILES['tsvfile']['error'] == UPLOAD_ERR_OK))
 			{
 				$buffer = $this->bo->import($_FILES['tsvfile']['tmp_name'],$_REQUEST['conv_type'],$_REQUEST['private'],$_REQUEST['fcat_id']);
 
@@ -115,11 +116,11 @@
 
 				$this->template->set_file(array('import' => 'import.tpl'));
 
-				$dir_handle = opendir(PHPGW_APP_INC . SEP . 'import');
+				$dir_handle = opendir(PHPGW_APP_INC . '/import');
 				$i=0; $myfilearray = '';
 				while ($file = readdir($dir_handle))
 				{
-					if ((substr($file, 0, 1) != '.') && is_file(PHPGW_APP_INC . SEP . 'import' . SEP . $file) )
+					if ((substr($file, 0, 1) != '.') && is_file(PHPGW_APP_INC . "/import/{$file}") )
 					{
 						$myfilearray[$i] = $file;
 						$i++;
@@ -133,6 +134,7 @@
 					$conv .= '<OPTION VALUE="' . $myfilearray[$i].'">' . $fname . '</OPTION>';
 				}
 
+				$GLOBALS['phpgw']->session->appsession('conv_type_values_i', 'addressbook', $myfilearray);
 				$this->template->set_var('lang_cancel',lang('Cancel'));
 				$this->template->set_var('lang_cat',lang('Select Category'));
 				$this->template->set_var('cancel_url',$GLOBALS['phpgw']->link('/index.php',array('menuaction'=>'addressbook.uiaddressbook.index')));
@@ -174,8 +176,9 @@
 			//echo "<pre>Export_vars: "; print_r($export_vars); echo "</pre>\n";
 			
 			//$entries = $this->bo->$get_data_function($fields, $this->limit, $this->start, $this->order, $this->sort, '', $criteria);
-			
-			if ($_REQUEST['convert'])
+
+			$conv_type_a = $GLOBALS['phpgw']->session->appsession('conv_type_values_e', 'addressbook');
+			if ($_REQUEST['convert'] && is_array($conv_type_a) && in_array($_REQUEST['conv_type'], $conv_type_a))
 			{
 				if ($_REQUEST['conv_type'] == 'none')
 				{
@@ -232,11 +235,11 @@
 				
 				$this->template->set_file(array('export' => 'export.tpl'));
 
-				$dir_handle = opendir(PHPGW_APP_INC. SEP . 'export');
+				$dir_handle = opendir(PHPGW_APP_INC. '/export');
 				$i=0; $myfilearray = '';
 				while ($file = readdir($dir_handle))
 				{
-					if ((substr($file, 0, 1) != '.') && is_file(PHPGW_APP_INC . SEP . 'export' . SEP . $file) )
+					if ((substr($file, 0, 1) != '.') && is_file(PHPGW_APP_INC . "/export/{$file}") )
 					{
 						$myfilearray[$i] = $file;
 						$i++;
@@ -250,6 +253,7 @@
 					$conv .= '        <option value="'.$myfilearray[$i].'">'.$fname.'</option>'."\n";
 				}
 
+				$GLOBALS['phpgw']->session->appsession('conv_type_values_e', 'addressbook', $myfilearray);
 				$this->template->set_var('lang_cancel',lang('Cancel'));
 				$this->template->set_var('lang_cat',lang('Select Category'));
 				$this->template->set_var('cat_link',$this->cat_option($this->cat_id,False,False));
