@@ -11,7 +11,7 @@
  *  option) any later version.                                              *
  \**************************************************************************/
 
-/* $Id: class.uifields.inc.php 18358 2007-11-27 04:43:37Z skwashd $ */
+/* $Id: class.uifields.inc.php 3149 2009-06-20 15:40:33Z sigurd $ */
 
 	class uifields
 	{
@@ -42,6 +42,7 @@
 				$GLOBALS['phpgw']->common->phpgw_exit();
 			}
 
+			$GLOBALS['phpgw']->template->set_root(PHPGW_APP_TPL);
 			$GLOBALS['phpgw']->template->set_file(array
 			(
 				'field_list_t' => 'listfields.tpl',
@@ -142,6 +143,7 @@
 				$GLOBALS['phpgw']->common->phpgw_exit();
 			}
 
+			$GLOBALS['phpgw']->template->set_root(PHPGW_APP_TPL);
 			$GLOBALS['phpgw']->template->set_file(array('form' => 'field_form.tpl'));
 			$GLOBALS['phpgw']->template->set_block('form','add','addhandle');
 			$GLOBALS['phpgw']->template->set_block('form','edit','edithandle');
@@ -241,6 +243,7 @@
 				$GLOBALS['phpgw']->redirect_link('/index.php', array('menuaction' => 'addressbook.uifields.index', 'sort' => $sort, 'query' => $query, 'start' => $start) );
 			}
 
+			$GLOBALS['phpgw']->template->set_root(PHPGW_APP_TPL);
 			$GLOBALS['phpgw']->template->set_file(array('form' => 'field_form.tpl'));
 			$GLOBALS['phpgw']->template->set_block('form','add','addhandle');
 			$GLOBALS['phpgw']->template->set_block('form','edit','edithandle');
@@ -374,6 +377,7 @@
 					. '<input type="hidden" name="start" value="' . $start .'">' . "\n"
 					. '<input type="hidden" name="field" value="' . $field .'">' . "\n";
 
+				$GLOBALS['phpgw']->template->set_root(PHPGW_APP_TPL);
 				$GLOBALS['phpgw']->template->set_file(array('field_delete' => 'delete_common.tpl'));
 				$GLOBALS['phpgw']->template->set_var('messages',lang('Are you sure you want to delete this field?'));
 
@@ -402,7 +406,7 @@
 			$i = 0;
 			$fields = array();
 
-			$this->config->read_repository();
+			$this->config->read();
 
 			$all_custom_fields = array();
 			if($apply=='person')
@@ -465,16 +469,16 @@
 
 		function get_apply($key)
 		{
-			if((is_array($this->per_custom_fields) && is_array($this->org_custom_fields)) && 
+			if(isset($this->per_custom_fields) && (is_array($this->per_custom_fields) && isset($this->org_custom_fields) && is_array($this->org_custom_fields)) && 
 					array_key_exists($key, $this->per_custom_fields) && array_key_exists($key, $this->org_custom_fields))
 			{
 				return 'both';
 			}
-			elseif(is_array($this->per_custom_fields) && array_key_exists($key, $this->per_custom_fields))
+			elseif(isset($this->per_custom_fields) && is_array($this->per_custom_fields) && array_key_exists($key, $this->per_custom_fields))
 			{
 				return 'person';
 			}
-			elseif(is_array($this->org_custom_fields) && array_key_exists($key, $this->org_custom_fields))
+			elseif(isset($this->org_custom_fields) && is_array($this->org_custom_fields) && array_key_exists($key, $this->org_custom_fields))
 			{
 				return 'org';
 			}
@@ -483,7 +487,7 @@
 		function save_custom_field($old='',$new='',$apply_for='')
 		{
 			$edit_contacts = False;
-			$this->config->read_repository();
+			$this->config->read();
 
 			switch($apply_for)
 			{
@@ -593,4 +597,3 @@
 			}
 		}
 	}
-?>
