@@ -9,7 +9,7 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: class.solog.inc.php 17183 2006-09-19 15:16:42Z skwashd $ */
+	/* $Id: class.solog.inc.php 4696 2010-02-01 22:48:22Z sigurd $ */
 
 	class solog
 	{
@@ -53,10 +53,10 @@
 		{
 			$where = $this->test_account_id($account_id);
 
-			$this->db->query("SELECT COUNT(*) FROM phpgw_log $where", __LINE__, __FILE__);
+			$this->db->query("SELECT COUNT(*) as cnt FROM phpgw_log $where", __LINE__, __FILE__);
 			$this->db->next_record();
 
-			return $this->db->f(0);
+			return $this->db->f('cnt');
 		}
 		
 		function purge_log($account_id)
