@@ -8,7 +8,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package admin
 	* @subpackage custom fields and functions
- 	* @version $Id: class.ui_custom.inc.php 18358 2007-11-27 04:43:37Z skwashd $
+ 	* @version $Id: class.ui_custom.inc.php 1916 2008-12-02 12:35:08Z sigurd $
 	*/
 
 	/**
@@ -16,7 +16,7 @@
 	 * @package property
 	 */
 
-	class ui_custom
+	class admin_ui_custom
 	{
 		var $grants;
 		var $start;
@@ -24,7 +24,7 @@
 		var $sort;
 		var $order;
 		var $sub;
-		var $currentapp;
+		var $local_menu_selection = false;
 
 		var $public_functions = array
 		(
@@ -35,7 +35,7 @@
 			'edit_custom_function'	=> True
 		);
 
-		function ui_custom()
+		public function __construct()
 		{
 			$this->bo					= CreateObject('admin.bo_custom',True);
 
@@ -48,11 +48,16 @@
 			$this->allrows				= $this->bo->allrows;
 
 			$GLOBALS['phpgw_info']['flags']['xslt_app'] = True;
-			$this->currentapp			= $GLOBALS['phpgw_info']['flags']['currentapp'];
 			$this->nextmatchs			= CreateObject('phpgwapi.nextmatchs');
 			$this->account				= $GLOBALS['phpgw_info']['user']['account_id'];
 			$this->bolocation			= CreateObject('preferences.boadmin_acl');
 			$this->bolocation->acl_app 	= $this->appname;
+
+			if(!$GLOBALS['phpgw_info']['flags']['menu_selection'] = phpgw::get_var('menu_selection'))
+			{
+				$GLOBALS['phpgw_info']['flags']['menu_selection'] = "admin::{$this->appname}";
+				$this->local_menu_selection = true;
+			}
 		}
 
 		function save_sessiondata()
@@ -78,6 +83,11 @@
 			$id			= phpgw::get_var('id', 'int');
 			$resort		= phpgw::get_var('resort');
 
+			if($this->local_menu_selection)
+			{
+				$GLOBALS['phpgw_info']['flags']['menu_selection'] .= '::list_atrribs';
+			}
+
 			$GLOBALS['phpgw']->xslttpl->add_file(array(
 								'custom',
 								'nextmatchs',
@@ -101,10 +111,10 @@
 						'input_text'			=> $entry['input_text'],
 						'sorting'				=> $entry['attrib_sort'],
 						'search'				=> $entry['search'],
-						'link_up'				=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.ui_custom.list_attribute', 'resort'=>'up', 'appname'=> $appname, 'location'=> $location, 'id'=> $entry['id'], 'allrows'=> $this->allrows)),
-						'link_down'				=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.ui_custom.list_attribute', 'resort'=>'down', 'appname'=> $appname, 'location'=> $location, 'id'=> $entry['id'], 'allrows'=> $this->allrows)),
-						'link_edit'				=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.ui_custom.edit_attrib', 'appname'=> $appname, 'location'=> $location, 'id'=> $entry['id'])),
-						'link_delete'			=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.ui_custom.delete', 'appname'=> $appname, 'location'=> $location, 'attrib_id'=> $entry['id'])),
+						'link_up'				=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'admin.ui_custom.list_attribute', 'resort'=>'up', 'appname'=> $appname, 'location'=> $location, 'id'=> $entry['id'], 'allrows'=> $this->allrows, 'menu_selection' => $GLOBALS['phpgw_info']['flags']['menu_selection'])),
+						'link_down'				=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'admin.ui_custom.list_attribute', 'resort'=>'down', 'appname'=> $appname, 'location'=> $location, 'id'=> $entry['id'], 'allrows'=> $this->allrows, 'menu_selection' => $GLOBALS['phpgw_info']['flags']['menu_selection'])),
+						'link_edit'				=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'admin.ui_custom.edit_attrib', 'appname'=> $appname, 'location'=> $location, 'id'=> $entry['id'], 'menu_selection' => $GLOBALS['phpgw_info']['flags']['menu_selection'])),
+						'link_delete'			=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'admin.ui_custom.delete', 'appname'=> $appname, 'location'=> $location, 'attrib_id'=> $entry['id'], 'menu_selection' => $GLOBALS['phpgw_info']['flags']['menu_selection'])),
 						'lang_up_text'			=> lang('shift up'),
 						'lang_down_text'		=> lang('shift down'),
 						'lang_edit_text'		=> lang('edit the attrib'),
@@ -133,30 +143,34 @@
 											'sort'	=> $this->sort,
 											'var'	=> 'column_name',
 											'order'	=> $this->order,
-											'extra'	=> array('menuaction'	=> $this->currentapp.'.ui_custom.list_attribute',
+											'extra'	=> array('menuaction'	=> 'admin.ui_custom.list_attribute',
 														'appname'	=> $appname,
 														'location'	=> $location,
-														'allrows'	=> $this->allrows)
+														'allrows'	=> $this->allrows,
+														'menu_selection' => $GLOBALS['phpgw_info']['flags']['menu_selection']
+														 )
 										)),
 				'sort_sorting'		=> $this->nextmatchs->show_sort_order(array
 										(
 											'sort'	=> $this->sort,
 											'var'	=> 'attrib_sort',
 											'order'	=> $this->order,
-											'extra'	=> array('menuaction'	=> $this->currentapp.'.ui_custom.list_attribute',
+											'extra'	=> array('menuaction'	=> 'admin.ui_custom.list_attribute',
 														'appname'	=> $appname,
 														'location'	=> $location,
-														'allrows'	=> $this->allrows)
+														'allrows'	=> $this->allrows,
+														'menu_selection' => $GLOBALS['phpgw_info']['flags']['menu_selection']
+														)
 										)),
 				'lang_name'		=> lang('Name'),
 			);
 
-			
+
 			$table_add[] = array
 			(
 				'lang_add'				=> lang('add'),
 				'lang_add_attribtext'	=> lang('add an attrib'),
-				'add_action'			=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.ui_custom.edit_attrib', 'appname'=> $appname, 'location'=> $location)),
+				'add_action'			=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'admin.ui_custom.edit_attrib', 'appname'=> $appname, 'location'=> $location, 'menu_selection' => $GLOBALS['phpgw_info']['flags']['menu_selection'])),
 				'lang_done'				=> lang('done'),
 				'lang_done_attribtext'	=> lang('Return to admin'),
 				'done_action'			=> $GLOBALS['phpgw']->link('/admin/index.php'),
@@ -173,12 +187,13 @@
 
 			$link_data = array
 			(
-				'menuaction'	=> $this->currentapp.'.ui_custom.list_attribute',
+				'menuaction'	=> 'admin.ui_custom.list_attribute',
 				'sort'			=> $this->sort,
 				'order'			=> $this->order,
 				'query'			=> $this->query,
 				'appname'		=> $appname,
-				'location'		=> $location
+				'location'		=> $location,
+				'menu_selection' => $GLOBALS['phpgw_info']['flags']['menu_selection']
 			);
 
 			$data = array
@@ -211,7 +226,7 @@
 
 			$function_msg	= lang('list custom attribute');
 
-			$GLOBALS['phpgw_info']['flags']['app_header'] = lang($this->currentapp) . ' - ' .lang('attribute') . ': ' . $function_msg;
+			$GLOBALS['phpgw_info']['flags']['app_header'] = lang('admin') . ' - ' .lang('attribute') . ': ' . $function_msg;
 			$GLOBALS['phpgw']->xslttpl->set_var('phpgw',array('list_attribute' => $data));
 			$this->save_sessiondata();
 		}
@@ -236,7 +251,7 @@
 					$values['location'] = '';
 				}
 			}
-			
+
 			if (isset($values['save']) && $values['save'])
 			{
 				if($id)
@@ -251,12 +266,21 @@
 				{
 					$receipt['error'][] = array('msg'=>lang('location not selected!'));
 				}
+				else
+				{
+					$location = $values['location'];
+				}
 
 				if (!$values['column_name'])
 				{
 					$receipt['error'][] = array('msg'=>lang('Column name not entered!'));
 				}
 
+				if(!preg_match('/^[a-z0-9_]+$/i',$values['column_name']))
+				{
+					$receipt['error'][] = array('msg'=>lang('Column name %1 contains illegal character', $values['column_name']));
+				}
+
 				if (!$values['input_text'])
 				{
 					$receipt['error'][] = array('msg'=>lang('Input text not entered!'));
@@ -301,7 +325,7 @@
 					{
 						$id=$receipt['id'];
 					}
-					$GLOBALS['phpgw']->redirect_link('/index.php', array('menuaction' => 'admin.ui_custom.edit_attrib', 'appname' => $values['appname'], 'location' => $values['location'], 'id' => $id));
+				//	$GLOBALS['phpgw']->redirect_link('/index.php', array('menuaction' => 'admin.ui_custom.edit_attrib', 'appname' => $values['appname'], 'location' => $values['location'], 'id' => $id, 'menu_selection' => $GLOBALS['phpgw_info']['flags']['menu_selection']));
 
 				}
 				else
@@ -324,10 +348,11 @@
 
 			$link_data = array
 			(
-				'menuaction'	=> $this->currentapp.'.ui_custom.edit_attrib',
+				'menuaction'	=> 'admin.ui_custom.edit_attrib',
 				'appname'		=> $appname,
 				'location'		=> $values['location'],
-				'id'			=> $id
+				'id'			=> $id,
+				'menu_selection' => $GLOBALS['phpgw_info']['flags']['menu_selection']
 			);
 
 			$multiple_choice = '';
@@ -357,7 +382,7 @@
 
 				'msgbox_data'						=> $GLOBALS['phpgw']->common->msgbox($msgbox_data),
 				'form_action'						=> $GLOBALS['phpgw']->link('/index.php',$link_data),
-				'done_action'						=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.ui_custom.list_attribute', 'appname'=> $appname, 'location'=>$location)),
+				'done_action'						=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'admin.ui_custom.list_attribute', 'appname'=> $appname, 'location'=>$location, 'menu_selection' => $GLOBALS['phpgw_info']['flags']['menu_selection'])),
 				'lang_id'							=> lang('Attribute ID'),
 				'lang_entity_type'					=> lang('Entity type'),
 				'lang_no_entity_type'				=> lang('No entity type'),
@@ -422,7 +447,7 @@
 				'lang_location_statustext'			=> lang('Select submodule'),
 				'select_name_location'				=> 'values[location]',
 
-				'location_list'						=> $this->bolocation->select_location('select',(isset($values['location'])?$values['location']:''),False,True),
+				'location_list'						=> $this->bolocation->select_location('select', $location, false, true),
 
 				'value_disabled'					=> isset($values['disabled']) ? $values['disabled'] : '',
 				'lang_disabled'						=> lang('disabled'),
@@ -431,18 +456,23 @@
 				'value_helpmsg'						=> isset($values['helpmsg']) ? $values['helpmsg'] : '',
 				'lang_helpmsg'						=> lang('help message'),
 				'lang_helpmsg_statustext'			=> lang('Enables help message for this attribute'),
-				'value_location'					=> isset($values['location']) ? $values['location'] : ''
+				'value_location'					=> $location
 			);
 //_debug_array($values);
 
 			$appname	= lang('appname');
 
-			$GLOBALS['phpgw_info']['flags']['app_header'] = lang($this->currentapp) . ' - ' . $appname . ': ' . $function_msg;
+			$GLOBALS['phpgw_info']['flags']['app_header'] = lang('admin') . ' - ' . $appname . ': ' . $function_msg;
 			$GLOBALS['phpgw']->xslttpl->set_var('phpgw',array('edit_attrib' => $data));
 		}
 
 		function list_custom_function()
 		{
+			if($this->local_menu_selection)
+			{
+				$GLOBALS['phpgw_info']['flags']['menu_selection'] .= '::list_functions';
+			}
+
 			$appname	= $this->appname;
 			$location	= $this->location;
 			$id			= phpgw::get_var('id', 'int');
@@ -470,10 +500,42 @@
 						'descr'						=> $entry['descr'],
 						'sorting'					=> $entry['sorting'],
 						'active'					=> $entry['active']?'X':'',
-						'link_up'					=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.ui_custom.list_custom_function', 'resort'=> 'up', 'appname'=> $appname, 'location'=> $location, 'id'=> $entry['id'], 'allrows'=> $this->allrows)),
-						'link_down'					=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.ui_custom.list_custom_function', 'resort'=> 'up', 'appname'=> $appname, 'location'=> $location, 'id'=> $entry['id'], 'allrows'=> $this->allrows)),
-						'link_edit'					=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.ui_custom.edit_custom_function', 'appname'=> $appname, 'location'=> $location, 'id'=> $entry['id'])),
-						'link_delete'				=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.ui_custom.delete', 'appname'=> $appname, 'location'=> $location, 'custom_function_id'=> $entry['id'])),
+						'link_up'					=> $GLOBALS['phpgw']->link('/index.php',array
+														(
+															'menuaction'		=> 'admin.ui_custom.list_custom_function',
+															'resort'			=> 'up',
+															'appname'			=> $appname,
+															'location'			=> $location,
+															'id'				=> $entry['id'],
+															'allrows'			=> $this->allrows,
+															'menu_selection'	=> $GLOBALS['phpgw_info']['flags']['menu_selection']
+														)),
+						'link_down'					=> $GLOBALS['phpgw']->link('/index.php',array
+														(
+															'menuaction'		=> 'admin.ui_custom.list_custom_function',
+															'resort'			=> 'down',
+															'appname'			=> $appname,
+															'location'			=> $location,
+															'id'				=> $entry['id'],
+															'allrows'			=> $this->allrows,
+															'menu_selection'	=> $GLOBALS['phpgw_info']['flags']['menu_selection']
+														)),
+						'link_edit'					=> $GLOBALS['phpgw']->link('/index.php',array
+														(
+															'menuaction'		=> 'admin.ui_custom.edit_custom_function',
+															'appname'			=> $appname,
+															'location'			=> $location,
+															'id'				=> $entry['id'],
+															'menu_selection'	=> $GLOBALS['phpgw_info']['flags']['menu_selection']
+															)),
+						'link_delete'				=> $GLOBALS['phpgw']->link('/index.php',array
+														(
+															'menuaction'		=> 'admin.ui_custom.delete',
+															'appname'			=> $appname,
+															'location'			=> $location,
+															'custom_function_id'=> $entry['id'],
+															'menu_selection'	=> $GLOBALS['phpgw_info']['flags']['menu_selection']
+														)),
 						'lang_up_text'				=> lang('shift up'),
 						'lang_down_text'			=> lang('shift down'),
 						'lang_edit_text'			=> lang('edit the custom_function'),
@@ -500,20 +562,24 @@
 											'sort'	=> $this->sort,
 											'var'	=> 'column_name',
 											'order'	=> $this->order,
-											'extra'	=> array('menuaction'	=> $this->currentapp.'.ui_custom.list_custom_function',
+											'extra'	=> array('menuaction'	=> 'admin.ui_custom.list_custom_function',
 														'appname'	=> $appname,
 														'location'	=> $location,
-														'allrows'	=> $this->allrows)
+														'allrows'	=> $this->allrows,
+														'menu_selection' => $GLOBALS['phpgw_info']['flags']['menu_selection']
+														)
 										)),
 				'sort_sorting'		=> $this->nextmatchs->show_sort_order(array
 										(
 											'sort'	=> $this->sort,
 											'var'	=> 'custom_function_sort',
 											'order'	=> $this->order,
-											'extra'	=> array('menuaction'	=> $this->currentapp.'.ui_custom.list_custom_function',
+											'extra'	=> array('menuaction'	=> 'admin.ui_custom.list_custom_function',
 														'appname'	=> $appname,
 														'location'	=> $location,
-														'allrows'	=> $this->allrows)
+														'allrows'	=> $this->allrows,
+														'menu_selection' => $GLOBALS['phpgw_info']['flags']['menu_selection']
+														)
 										)),
 				'lang_name'			=> lang('Name'),
 			);
@@ -522,7 +588,7 @@
 			(
 				'lang_add'						=> lang('add'),
 				'lang_add_custom_functiontext'	=> lang('add a custom_function'),
-				'add_action'					=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.ui_custom.edit_custom_function', 'appname'=> $appname, 'location'=> $location)),
+				'add_action'					=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'admin.ui_custom.edit_custom_function', 'appname'=> $appname, 'location'=> $location, 'menu_selection' => $GLOBALS['phpgw_info']['flags']['menu_selection'])),
 				'lang_done'						=> lang('done'),
 				'lang_done_custom_functiontext'	=> lang('Return to admin'),
 				'done_action'					=> $GLOBALS['phpgw']->link('/admin/index.php'),
@@ -539,12 +605,13 @@
 
 			$link_data = array
 			(
-				'menuaction'	=> $this->currentapp.'.ui_custom.list_custom_function',
+				'menuaction'	=> 'admin.ui_custom.list_custom_function',
 				'sort'			=> $this->sort,
 				'order'			=> $this->order,
 				'query'			=> $this->query,
 				'appname'		=> $appname,
-				'location'		=> $location
+				'location'		=> $location,
+				'menu_selection' => $GLOBALS['phpgw_info']['flags']['menu_selection']
 			);
 
 			$data = array
@@ -576,14 +643,14 @@
 
 			$function_msg	= lang('list custom function');
 
-			$GLOBALS['phpgw_info']['flags']['app_header'] = lang($this->currentapp) . ' - ' .lang('custom function') . ': ' . $function_msg;	
+			$GLOBALS['phpgw_info']['flags']['app_header'] = lang('admin') . ' - ' .lang('custom function') . ': ' . $function_msg;
 			$GLOBALS['phpgw']->xslttpl->set_var('phpgw',array('list_custom_function' => $data));
 			$this->save_sessiondata();
 		}
 
 		function edit_custom_function()
 		{
-			$GLOBALS['phpgw_info']['flags']['menu_selection'] .= '::list_functions';
+	//		$GLOBALS['phpgw_info']['flags']['menu_selection'] .= '::list_functions';
 			$appname	= $this->appname;
 			$location	= $this->location;
 			$id			= phpgw::get_var('id', 'int');
@@ -620,7 +687,7 @@
 				{
 				 	$receipt['error'][] = array('msg' => lang('location or appname is missing'));
 				}
-	
+
 				if (!isset($receipt['error']) || !$receipt['error'])
 				{
 					$receipt = $this->bo->save_custom_function($values,$action);
@@ -652,10 +719,11 @@
 
 			$link_data = array
 			(
-				'menuaction'	=> $this->currentapp.'.ui_custom.edit_custom_function',
+				'menuaction'	=> 'admin.ui_custom.edit_custom_function',
 				'appname'		=> $appname,
 				'location'		=> $location,
-				'id'			=> $id
+				'id'			=> $id,
+				'menu_selection' => $GLOBALS['phpgw_info']['flags']['menu_selection']
 			);
 
 
@@ -672,7 +740,7 @@
 
 				'msgbox_data'						=> $GLOBALS['phpgw']->common->msgbox($msgbox_data),
 				'form_action'						=> $GLOBALS['phpgw']->link('/index.php',$link_data),
-				'done_action'						=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.ui_custom.list_custom_function', 'appname'=> $appname, 'location'=> $location)),
+				'done_action'						=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'admin.ui_custom.list_custom_function', 'appname'=> $appname, 'location'=> $location, 'menu_selection' => $GLOBALS['phpgw_info']['flags']['menu_selection'])),
 				'lang_id'							=> lang('Custom function ID'),
 				'lang_entity_type'					=> lang('Entity type'),
 				'lang_no_entity_type'				=> lang('No entity type'),
@@ -698,7 +766,7 @@
 			);
 
 
-			$GLOBALS['phpgw_info']['flags']['app_header'] = lang($this->currentapp) . ' - ' . lang('custom function') . ': ' . $function_msg;
+			$GLOBALS['phpgw_info']['flags']['app_header'] = lang('admin') . ' - ' . lang('custom function') . ': ' . $function_msg;
 			$GLOBALS['phpgw']->xslttpl->set_var('phpgw',array('edit_custom_function' => $data));
 		}
 
@@ -708,46 +776,50 @@
 			$location				= phpgw::get_var('location');
 			$attrib_id				= phpgw::get_var('attrib_id', 'int');
 			$custom_function_id		= phpgw::get_var('custom_function_id', 'int');
-			$confirm				= phpgw::get_var('confirm', 'bool', 'POST');
 
-			if ( $attrib_id )
+			$function = 'list_attribute';
+			if ( $custom_function_id )
 			{
-				$function='list_attribute';
+				$function = 'list_custom_function';
 			}
-			else if($custom_function_id)
+
+			$redirect_args = array
+			(
+				'menuaction'	=> "admin.ui_custom.{$function}",
+				'location'		=> $location,
+				'appname'		=> $appname,
+				'attrib_id'		=> $attrib_id,
+				//FIXME this hack won't be merged upstream
+				'menu_selection' => $GLOBALS['phpgw_info']['flags']['menu_selection']
+			);
+
+			if ( phpgw::get_var('confirm', 'bool', 'POST') )
 			{
-				$function='list_custom_function';
+				$this->bo->delete($location, $appname, $attrib_id, $custom_function_id);
+				$GLOBALS['phpgw']->redirect_link('/index.php', $redirect_args);
 			}
 
+			if ( phpgw::get_var('cancel', 'bool', 'POST') )
+			{
+				$GLOBALS['phpgw']->redirect_link('/index.php', $redirect_args);
+			}
+
+			$GLOBALS['phpgw']->xslttpl->add_file(array('confirm_delete'));
+
 			$link_data = array
 			(
-				'menuaction'	=> $this->currentapp.'.ui_custom.'.$function,
-				'location'		=> $location,
-				'appname'		=> $appname,
-				'attrib_id'		=> $attrib_id
-			);
-
-			$delete_data = array
-			(
-				'menuaction'			=> $this->currentapp.'.ui_custom.delete',
+				'menuaction'			=> 'admin.ui_custom.delete',
 				'location'				=> $location,
 				'appname'				=> $appname,
 				'attrib_id'				=> $attrib_id,
-				'custom_function_id' 	=> $custom_function_id
+				'custom_function_id' 	=> $custom_function_id,
+				//FIXME this hack won't be merged upstream
+				'menu_selection'		=> $GLOBALS['phpgw_info']['flags']['menu_selection']
 			);
 
-			if ( $confirm )
-			{
-				$this->bo->delete($location,$appname,$attrib_id,$custom_function_id);
-				$GLOBALS['phpgw']->redirect_link('/index.php', $link_data);
-			}
-
-			$GLOBALS['phpgw']->xslttpl->add_file(array('app_delete'));
-
 			$data = array
 			(
-				'done_action'				=> $GLOBALS['phpgw']->link('/index.php',$link_data),
-				'delete_action'				=> $GLOBALS['phpgw']->link('/index.php',$delete_data),
+				'form_action'				=> $GLOBALS['phpgw']->link('/index.php', $link_data),
 				'lang_confirm_msg'			=> lang('do you really want to delete this entry'),
 				'lang_yes'					=> lang('yes'),
 				'lang_yes_standardtext'		=> lang('Delete the entry'),
@@ -758,8 +830,7 @@
 			$appname	= lang('Custom fields');
 			$function_msg	= lang('delete entity type');
 
-			$GLOBALS['phpgw_info']['flags']['app_header'] = lang($this->currentapp) . ' - ' . $appname . ': ' . $function_msg;
+			$GLOBALS['phpgw_info']['flags']['app_header'] = lang('admin') . ' - ' . $appname . ': ' . $function_msg;
 			$GLOBALS['phpgw']->xslttpl->set_var('phpgw',array('delete' => $data));
 		}
 	}
-?>
