@@ -20,34 +20,36 @@
 	* Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA            *
 	\**************************************************************************/
 
-	/* $Id: class.uiasyncservice.inc.php 18358 2007-11-27 04:43:37Z skwashd $ */
+	/* $Id: class.uiasyncservice.inc.php 2589 2009-04-14 13:39:36Z sigurd $ */
 
-	class uiasyncservice
+	class admin_uiasyncservice
 	{
-		var $public_functions = array(
-			'index' => True,
-		);
-		function uiasyncservice()
+		public $public_functions = array('index' => True);
+
+		public function __construct()
 		{
-			if (!is_object($GLOBALS['phpgw']->asyncservice))
+			if ( !isset($GLOBALS['phpgw']->asyncservice)
+				|| !is_object($GLOBALS['phpgw']->asyncservice) )
 			{
 				$GLOBALS['phpgw']->asyncservice = CreateObject('phpgwapi.asyncservice');
 			}
 		}
 
-		function index()
+		public function index()
 		{
 			if ($GLOBALS['phpgw']->acl->check('asyncservice_access',1,'admin'))
 			{
 				$GLOBALS['phpgw']->redirect_link('/index.php');
 			}
+
+			$GLOBALS['phpgw_info']['flags']['current_selection'] = 'admin::admin::async';
+
 			$GLOBALS['phpgw_info']['flags']['app_header'] = lang('Admin').' - '.lang('Asynchronous timed services');
-			$GLOBALS['phpgw']->common->phpgw_header();
-			echo parse_navbar();
+			$GLOBALS['phpgw']->common->phpgw_header(true);
 
 			$async = clone($GLOBALS['phpgw']->asyncservice);	// use an own instance, as we might set debug=True
 
-			$async->debug = !!$_POST['debug'];
+			$async->debug = phpgw::get_var('debug', 'bool', 'POST');
 
 			$units = array
 			(
@@ -83,7 +85,7 @@
 				if ( $test )
 				{
 					$prefs = $GLOBALS['phpgw']->preferences->create_email_preferences();
-					if (!$async->set_timer($times,'test','admin.uiasyncservice.test',$prefs['email']['address']))
+					if (!$async->set_timer($times,'test','admin.uiasyncservice.test',array('to' => $prefs['email']['address'])))
 					{
 						echo '<p><b>'.lang("Error setting timer, wrong syntax or maybe there's one already running !!!")."</b></p>\n";
 					}
@@ -102,6 +104,29 @@
 					{
 						echo '<p><b>'.lang('Error: %1 not found or other error !!!',$async->crontab)."</b></p>\n";
 					}
+					else
+					{
+						$asyncservice = 'cron';
+					}
+				}
+
+				if ( $asyncservice )
+				{
+					if (!isset($GLOBALS['phpgw_info']['server']['asyncservice'])
+						|| $asyncservice != $GLOBALS['phpgw_info']['server']['asyncservice'] )
+					{
+						$config = CreateObject('phpgwapi.config','phpgwapi');
+						$config->read();
+						$config->value('asyncservice', $asyncservice);
+						$config->save_repository();
+						unset($config);
+						$GLOBALS['phpgw_info']['server']['asyncservice'] = $asyncservice;
+					}
+
+					if(($asyncservice == 'off' || $asyncservice == 'fallback') && !$install)
+					{
+						$async->uninstall();
+					}
 				}
 			}
 			else
@@ -115,15 +140,6 @@
 			$lr_date = $last_run['end'] ? $GLOBALS['phpgw']->common->show_date($last_run['end']) : lang('never');
 			echo '<p><b>'.lang('Async services last executed').'</b>: '.$lr_date.' ('.$last_run['run_by'].")</p>\n<hr>\n";
 
-			if ( $asyncservice != $GLOBALS['phpgw_info']['server']['asyncservice'] )
-			{
-				$config = CreateObject('phpgwapi.config','phpgwapi');
-				$config->read_repository();
-				$config->value('asyncservice', $asyncservice);
-				$config->save_repository();
-				unset($config);
-				$GLOBALS['phpgw_info']['server']['asyncservice'] = $asyncservice;
-			}
 			if (!$async->only_fallback)
 			{
 				$installed = $async->installed();
@@ -132,7 +148,7 @@
 					$async_use['cron'] = lang('crontab only (recomended)');
 				}
 			}
-			$async_use['']    = lang('fallback (after each pageview)');
+			$async_use['fallback']    = lang('fallback (after each pageview)');
 			$async_use['off'] = lang('disabled (not recomended)');
 			echo '<p><b>'.lang('Run Asynchronous services').'</b>'.
 				' <select name="asyncservice" onChange="this.form.submit();">';
@@ -177,7 +193,7 @@
 			echo ' <td colspan="8"><input type="checkbox" name="debug" value="1"' . ($debug ? ' checked' : '')."> \n".
 				lang('Enable debug-messages')."</td>\n</tr></table>\n";
 
-			if ( $send ])
+			if ( $send )
 			{
 				$next = $async->next_run($times,True);
 
@@ -211,13 +227,15 @@
 			
 		}
 		
-		function test($to)
+		public function test($data)
 		{
+			$to = $data['to'];
+			$from = $GLOBALS['phpgw']->preferences->values['email'];
 			if (!is_object($GLOBALS['phpgw']->send))
 			{
 				$GLOBALS['phpgw']->send = CreateObject('phpgwapi.send');
 			}
-			$returncode = $GLOBALS['phpgw']->send->msg('email',$to,$subject='Asynchronous timed services','Greatings from cron ;-)');
+			$returncode = $GLOBALS['phpgw']->send->msg('email', $to, $subject='Asynchronous timed services', 'Greatings from cron ;-)', '', '', '', $from);
 
 			if (!$returncode)	// not nice, but better than failing silently
 			{
