@@ -9,10 +9,10 @@
 	*  Free Software Foundation; either version 2 of the License, or (at your  *
 	*  option) any later version.                                              *
 	\**************************************************************************/
-	/* $Id: class.uicategories.inc.php 18358 2007-11-27 04:43:37Z skwashd $ */
+	/* $Id: class.uicategories.inc.php 5147 2010-04-08 13:34:46Z sigurd $ */
 	/* $Source$ */
 
-	class uicategories
+	class admin_uicategories
 	{
 		var $bo;
 		var $nextmatchs;
@@ -25,17 +25,24 @@
 		var $cat_id;
 		var $debug = False;
 
-		var $public_functions = array
+		public $public_functions = array
 		(
 			'index'  => True,
 			'edit'   => True,
 			'delete' => True
 		);
 
-		function uicategories()
+		public function __construct()
 		{
 			$GLOBALS['phpgw_info']['flags']['xslt_app'] = True;
 
+			$appname = phpgw::get_var('appname', 'string', 'REQUEST', 'admin');
+
+			if(!$GLOBALS['phpgw_info']['flags']['menu_selection'] = phpgw::get_var('menu_selection'))
+			{
+				$GLOBALS['phpgw_info']['flags']['menu_selection'] = "admin::{$appname}::categories";
+			}
+
 			$this->bo			= CreateObject('admin.bocategories');
 			$this->nextmatchs	= CreateObject('phpgwapi.nextmatchs');
 
@@ -44,6 +51,7 @@
 			$this->sort			= $this->bo->sort;
 			$this->order		= $this->bo->order;
 			$this->cat_id		= $this->bo->cat_id;
+			$this->allrows		= $this->bo->allrows;
 			if($this->debug) { $this->_debug_sqsof(); }
 		}
 
@@ -80,6 +88,7 @@
 		function index()
 		{
 			$appname = phpgw::get_var('appname');
+			$location = phpgw::get_var('location');
 			$global_cats  = phpgw::get_var('global_cats');
 
 			$GLOBALS['phpgw']->xslttpl->add_file('cats');
@@ -88,12 +97,15 @@
 			(
 				'menuaction'  => 'admin.uicategories.index',
 				'appname'     => $appname,
-				'global_cats' => $global_cats
+				'location'     => $location,
+				'global_cats' => $global_cats,
+				'menu_selection' => $GLOBALS['phpgw_info']['flags']['menu_selection']
 			);
 
 			if ( phpgw::get_var('add', 'bool') )
 			{
 				$link_data['menuaction'] = 'admin.uicategories.edit';
+				$link_data['menu_selection'] = $GLOBALS['phpgw_info']['flags']['menu_selection'];
 				$GLOBALS['phpgw']->redirect_link('/index.php', $link_data);
 			}
 
@@ -125,7 +137,8 @@
 											'sort'	=> $this->sort,
 											'var'	=> 'cat_name',
 											'order'	=> $this->order,
-											'extra'	=> $link_data
+											'extra'	=> $link_data,
+											'menu_selection' => $GLOBALS['phpgw_info']['flags']['menu_selection']
 										)),
 				'lang_add_sub'			=> lang('add sub'),
 				'lang_name'				=> lang('name'),
@@ -138,7 +151,8 @@
 												'sort'	=> $this->sort,
 												'var'	=> 'cat_description',
 												'order'	=> $this->order,
-												'extra'	=> $link_data
+												'extra'	=> $link_data,
+												'menu_selection' => $GLOBALS['phpgw_info']['flags']['menu_selection']
 											))
 			);
 
@@ -185,6 +199,7 @@
 				{
 					$link_data['cat_id']		= $cat['id'];
 					$link_data['menuaction']	= 'admin.uicategories.edit';
+					$link_data['menu_selection'] = $GLOBALS['phpgw_info']['flags']['menu_selection'];
 					$edit_url			= $GLOBALS['phpgw']->link('/index.php',$link_data);
 					$lang_edit			= lang('edit');
 
@@ -202,6 +217,7 @@
 
 				$link_data['menuaction'] = 'admin.uicategories.edit';
 				$link_data['parent'] = $cat['id'];
+				$link_data['menu_selection'] = $GLOBALS['phpgw_info']['flags']['menu_selection'];
 				unset($link_data['cat_id']);
 				$add_sub_url = $GLOBALS['phpgw']->link('/index.php',$link_data);
 
@@ -234,14 +250,14 @@
 				'lang_done_statustext'	=> lang('return to admin mainscreen')
 			);
 
-			$link_data['menuaction'] = 'admin.uicategories.index';
-
 			$nm = array
 			(
-				'start_record'	=> $this->start,
+				'start'			=> $this->start,
  				'num_records'	=> count($categories),
  				'all_records'	=> $this->bo->cats->total_records,
-				'link_data'		=> $link_data
+				'link_data'		=> $link_data,
+				'allow_all_rows'=> true,
+				'allrows'		=> $this->allrows
 			);
 
 			$data = array
@@ -250,7 +266,7 @@
 				'search_data'	=> $this->nextmatchs->xslt_search(array('query' => $this->query,'link_data' => $link_data)),
 				'cat_header'	=> $cat_header,
 				'cat_data'		=> $content,
-				'cat_add'		=> $cat_add 
+				'cat_add'		=> $cat_add
 			);
 
 			$this->save_sessiondata();
@@ -260,8 +276,9 @@
 		function edit()
 		{
 			$appname		= phpgw::get_var('appname');
+			$location		= phpgw::get_var('location');
 			$global_cats	= phpgw::get_var('global_cats');
-			$parent			= phpgw::get_var('parent', 'int', 'GET');
+			$parent			= phpgw::get_var('parent', 'int', 'GET', 0);
 			$values			= phpgw::get_var('values', 'string', 'POST');
 
 			$message = '';
@@ -269,7 +286,9 @@
 			(
 				'menuaction'  => 'admin.uicategories.index',
 				'appname'     => $appname,
-				'global_cats' => $global_cats
+				'location'     => $location,
+				'global_cats' => $global_cats,
+				'menu_selection' => $GLOBALS['phpgw_info']['flags']['menu_selection']
 			);
 
 			if ( isset($values['cancel']) && $values['cancel'] )
@@ -313,14 +332,14 @@
 					'id'			=> 0,
 					'name'			=> '',
 					'description'	=> '',
-					'parent'		=> 0
+					'parent'		=> $parent
 				));
 			}
 			$parent = $cats[0]['parent'];
 
 			if ( $appname )
 			{
-				$GLOBALS['phpgw_info']['flags']['app_header'] = lang($appname) . ' ' . lang('global categories') . ': ' . ($this->cat_id?lang('edit category'):lang('add category'));
+				$GLOBALS['phpgw_info']['flags']['app_header'] = lang($appname) . ' ' . $location?"::{$location}":'' . lang('global categories') . ': ' . ($this->cat_id?lang('edit category'):lang('add category'));
 			}
 			else
 			{
@@ -331,7 +350,7 @@
 
 			if ( $appname )
 			{
-				$GLOBALS['phpgw']->template->set_var('title_categories',lang('Edit global category for %1',lang($appname)));
+				$GLOBALS['phpgw']->template->set_var('title_categories',lang('Edit global category for %1',lang($appname) . $location?"::{$location}":''));
 			}
 			else
 			{
@@ -373,13 +392,16 @@
 		function delete()
 		{
 			$appname = phpgw::get_var('appname');
+			$location= phpgw::get_var('location');
 			$global_cats  = phpgw::get_var('global_cats');
 
 			$link_data = array
 			(
 				'menuaction'  => 'admin.uicategories.index',
 				'appname'     => $appname,
-				'global_cats' => $global_cats
+				'location'     => $location,
+				'global_cats' => $global_cats,
+				'menu_selection' => $GLOBALS['phpgw_info']['flags']['menu_selection']
 			);
 
 			if ( phpgw::get_var('cancel', 'bool') || !$this->cat_id )
@@ -387,7 +409,7 @@
 				$GLOBALS['phpgw']->redirect_link('/index.php', $link_data);
 			}
 
-			if ( phpgw::get_var('confirm', bool) )
+			if ( phpgw::get_var('confirm', 'bool') )
 			{
 				$subs = phpgw::get_var('subs');
 				if ( $subs )
@@ -415,9 +437,9 @@
 				}
 			}
 
-			$GLOBALS['phpgw']->xslttpl->add_file(array('app_delete'));
+			$GLOBALS['phpgw']->xslttpl->add_file(array('confirm_delete'));
 
-			$GLOBALS['phpgw_info']['flags']['app_header'] = ( $appname ? lang($appname) . ' ' : '' ) . lang('global categories') . ': ' . lang('delete category');
+			$GLOBALS['phpgw_info']['flags']['app_header'] = ( $appname ? lang($appname) . ' ' : '' ) .($location?"::{$location}":'') . lang('global categories') . ': ' . lang('delete category');
 
 			$type = $appname ? 'noglobalapp' : 'noglobal';
 
@@ -462,13 +484,20 @@
 				}
 			}
 
-			$link_data['menuaction']	= 'admin.uicategories.delete';
-			$link_data['cat_id']		= $this->cat_id;
+			$link_data = array
+			(
+				'menuaction'	=> 'admin.uicategories.delete',
+				'cat_id'		=> $this->cat_id,
+				'appname'      => $appname,
+				'location'     => $location,
+				'global_cats' => $global_cats,
+				'menu_selection' => $GLOBALS['phpgw_info']['flags']['menu_selection']
+			);
+			$link_data['menu_selection'] = $GLOBALS['phpgw_info']['flags']['menu_selection'];
 
 			$data = array
 			(
-				'delete_action'			=> $GLOBALS['phpgw']->link('/index.php', $link_data),
-				'done_action'			=> $GLOBALS['phpgw']->link('/index.php', $link_data),
+				'form_action'			=> $GLOBALS['phpgw']->link('/index.php', $link_data),
 				'show_done'				=> $show_done,
 				'msgbox_data'			=> $msgbox_error,
 				'lang_delete'			=> lang('delete'),
