@@ -9,17 +9,18 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: class.uiloglevels.inc.php 18358 2007-11-27 04:43:37Z skwashd $ */
+	/* $Id: class.uiloglevels.inc.php 4543 2010-01-20 19:53:06Z sigurd $ */
 
-	class uiloglevels
+	class admin_uiloglevels
 	{
-		var $template;
-		var $select_template;
-		var $public_functions = array(
+		private $template;
+		private $select_template;
+		public $public_functions = array
+		(
 			'edit_log_levels' => True
 		);
 
-		function uiloglevels()
+		public function __construct()
 		{
 			
 			if ($GLOBALS['phpgw']->acl->check('error_log_access',1,'admin'))
@@ -27,20 +28,22 @@
 				$GLOBALS['phpgw']->redirect_link('/index.php');
 			}
 
+			$GLOBALS['phpgw_info']['flags']['menu_selection'] = 'admin::admin::log_levels';
+
 			$this->template   = $GLOBALS['phpgw']->template;
-			$this->template->set_file(
-				Array(
-					'loglevels' => 'loglevels.tpl',
-					'log_level_select' => 'log_level_select.tpl'
-				)
-			);
+			$this->template->set_file(array
+			(
+				'loglevels' => 'loglevels.tpl',
+				'log_level_select' => 'log_level_select.tpl'
+			));
+
   			// foo removes the module template.  I don't understand Templates enough to
   			// know why I needed it.  Trial and error.
 			$this->template->set_block('loglevels','module', 'foo'); 
 			$this->template->set_block('loglevels','module_add', 'foo'); 
 		}
 
-		function edit_log_levels()
+		public function edit_log_levels()
 		{
 			if ($GLOBALS['phpgw']->acl->check('error_log_access',1,'admin'))
 			{
@@ -96,18 +99,19 @@
 		}
 		
 		
-		function add_modules_list() 
+		private function add_modules_list() 
 		{
 			$apps_with_logging = $GLOBALS['phpgw_info']['server']['log_levels']['module'];
 			$sorted_apps = array();
 			$app_add_list = array();
-			foreach ($GLOBALS['phpgw_info']['apps'] as $app => $app_data)
+			foreach ( $GLOBALS['phpgw_info']['apps'] as $app => $app_data )
 			{
 				$sorted_apps[$app] = $app_data['title']; 
-			}	
+			}
+
+			asort($sorted_apps);
 			
 			$add_options = '';
-			asort($sorted_apps);
 			$tr_class = 'row_on';
 		    foreach ( $sorted_apps as $app => $title) 
 		    {
@@ -134,7 +138,7 @@
 		    	}
 		    	else 
 		    	{
-					$add_options = $add_options . '<option value="' . $app . '">' . $title . '</option>';
+					$add_options .= "<option value=\"{$app}\">{$title}</option>\n";
 		    	}
 		    }	
 				
@@ -160,26 +164,29 @@
 			
 		}
 		
-		function add_users_list() 
+		private function add_users_list() 
 		{
 			$add_options = '';
 			$tr_class = 'row_on';
 			$accounts = $GLOBALS['phpgw']->accounts->get_list('accounts');
-			foreach($accounts as $account)
+			foreach ( $accounts as $account )
 			{
-				$account_lid = $account['account_lid'];
+				$account_lid = $account->lid;
+				$name = (string) $account;
 		    	if ( isset($GLOBALS['phpgw_info']['server']['log_levels']['user'][$account_lid]) ) 
 		    	{
 					$var = array
 					(
 						'tr_class' 		=> $tr_class,
-						'module_name'   => $account_lid,
+						'module_name'   => (string) $account,
 						'module_option' => $this->create_select_box('user', $account_lid, $GLOBALS['phpgw_info']['server']['log_levels']['user'][$account_lid]),
 						'remove_url' => $GLOBALS['phpgw']->link('/index.php', array('menuaction' => 'admin.uiloglevels.edit_log_levels', 'level_type' => 'user', 'level_key' => $account_lid) ),
 						'lang_remove'   => lang('remove')
 					);
+
 					$this->template->set_var($var);
-					$this->template->fp('user_list','module',True);
+					$this->template->fp('user_list', 'module', true);
+
 					if ($tr_class == 'row_on')
 					{
 						$tr_class = 'row_off';
@@ -191,7 +198,7 @@
 		    	}
 		    	else 
 		    	{
-					$add_options .= '<option value="' . $account_lid . '">' . $account_lid . '</option>';
+					$add_options .= "<option value=\"{$account_lid}\">{$name}</option>\n";
 		    	}
 		    }	
 				
@@ -215,9 +222,9 @@
 			}
 		}		
 		
-		function create_select_box($level_type, $level_key, $current_level)
+		private function create_select_box($level_type, $level_key, $current_level)
 		{
-			$select_name = $level_type . '_' . $level_key . '_select';
+			$select_name = "{$level_type}_{$level_key}_select";
 
 			$var = array
 			(
@@ -231,12 +238,16 @@
 				'lang_info'		=> lang('info'),
 				'lang_notice'	=> lang('notice'),
 				'lang_debug'	=> lang('debug'),
+				'lang_strict'	=> 'strict',
+				'lang_deprecated'	=> 'deprecated',
 				'F_selected'	=> '',
 				'E_selected'	=> '',
 				'N_selected'	=> '',
 				'W_selected'	=> '',
 				'I_selected'	=> '',
-				'D_selected'	=> ''
+				'D_selected'	=> '',
+				'S_selected'	=> '',
+				'DP_selected'	=> ''
 			);
 			
 			if ( $current_level ) 
@@ -252,7 +263,7 @@
 			return $this->template->fp('select', 'log_level_select', True);	
 		}
 		
-		function update_level($level_type, $level_key, $new_level)
+		private function update_level($level_type, $level_key, $new_level)
 		{
 			if ( $new_level )
 			{
@@ -276,7 +287,7 @@
 			// save it...  It would be nice if phpgwapi.config had an method for just saving one setting.
 
 			$c = CreateObject('phpgwapi.config','phpgwapi');
-			$c->read_repository();
+			$c->read();
 			$c->value('log_levels', $GLOBALS['phpgw_info']['server']['log_levels']);
 			$c->save_repository();
 		}
