@@ -1,49 +1,104 @@
 <?php
-	/**************************************************************************\
-	* phpGroupWare - Administration                                            *
-	* http://www.phpgroupware.org                                              *
-	* Written by coreteam <phpgroupware-developers@gnu.org>                    *
-	* --------------------------------------------                             *
-	*  This program is free software; you can redistribute it and/or modify it *
-	*  under the terms of the GNU General Public License as published by the   *
-	*  Free Software Foundation; either version 2 of the License, or (at your  *
-	*  option) any later version.                                              *
-	\**************************************************************************/
-	/* $Id: class.uimainscreen.inc.php 18358 2007-11-27 04:43:37Z skwashd $ */
+	/**
+	 * phpGroupWare Administration Misc Page Renderers
+	 *
+	 * @author Dave Hall <skwashd@phpgroupware.org>
+	 * @author coreteam <phpgroupware-developers@gnu.org>
+	 * @author Various Others <unknown>
+	 * @copyright Copyright (C) 2003-2008 Free Software Foundation, Inc. http://www.fsf.org/
+	 * @license http://www.gnu.org/licenses/gpl.html GNU General Public License
+	 * @package phpgroupware
+	 * @subpackage phpgwapi
+	 * @category gui
+	 * @version $Id: class.uimainscreen.inc.php 1781 2008-11-02 19:51:19Z sigurd $
+	 */
 
-	class uimainscreen
+	/*
+	   This program is free software: you can redistribute it and/or modify
+	   it under the terms of the GNU General Public License as published by
+	   the Free Software Foundation, either version 2 of the License, or
+	   (at your option) any later version.
+
+	   This program is distributed in the hope that it will be useful,
+	   but WITHOUT ANY WARRANTY; without even the implied warranty of
+	   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+	   GNU General Public License for more details.
+
+	   You should have received a copy of the GNU General Public License
+	   along with this program.  If not, see <http://www.gnu.org/licenses/>.
+	 */
+
+	/**
+	 *  Miscellaneous Admin Pages renderer 
+	 *
+	 * @author Dave Hall <skwashd@phpgroupware.org>
+	 * @author coreteam <phpgroupware-developers@gnu.org>
+	 * @author Various Others <unknown>
+	 * @copyright Copyright (C) 2003-2008 Free Software Foundation, Inc. http://www.fsf.org/
+	 * @license http://www.gnu.org/licenses/gpl.html GNU General Public License
+	 * @package phpgroupware
+	 * @subpackage phpgwapi
+	 */
+	class admin_uimainscreen
 	{
-		var $public_functions = array
+		/**
+		 * @var array $public_functions the publicly callable methods
+		 */
+		public $public_functions = array
 		(
-			'index'		=> True,
-			'mainscreen'	=> True
+			'index'			=> true,
+			'mainscreen'	=> true
 		);
 
-		function uimainscreen()
+		/**
+		 * Constucttor
+		 */
+		public function __construct()
 		{
 			$menuaction = phpgw::get_var('menuaction', 'location');
-			$GLOBALS['phpgw_info']['flags']['xslt_app'] = $menuaction == 'admin.uimainscreen.mainscreen';
+			$GLOBALS['phpgw_info']['flags']['xslt_app'] = false;
 			$GLOBALS['phpgw']->nextmatchs = CreateObject('phpgwapi.nextmatchs');
+			$GLOBALS['phpgw_info']['flags']['menu_selection'] = 'admin';
 		}
 
+		/**
+		 * Render the admin menu
+		 *
+		 * @return void
+		 */
 		function mainscreen()
 		{
-			function display_section($appname,$file,$file2='')
-			{
-				$GLOBALS['phpgw']->common->display_mainscreen($appname,$file2 ? $file2 : $file);
-			}
+			$menu		= createObject('phpgwapi.menu');
+			$navbar		= $menu->get('navbar');
+			$navigation = $menu->get('admin');
 
-			$GLOBALS['phpgw']->hooks->process('admin');
-			$GLOBALS['phpgw']->xslttpl->set_var('phpgw', array('list' => $GLOBALS['phpgw']->common->output));
+			$treemenu = '';
+			foreach ( $GLOBALS['phpgw_info']['user']['apps'] as $app => $app_info )
+			{
+				if(!in_array($app, array('logout', 'about', 'preferences')) && isset($navbar[$app]))
+				{
+					$treemenu .= $menu->render_menu($app, $navigation[$app], $navbar[$app], true);
+				}
+			}
+			$GLOBALS['phpgw']->common->phpgw_header(true);
+			echo $treemenu;
 		}
 
-		function index()
+		/**
+		 * Render the welcome screen editor
+		 *
+		 * @return void
+		 */
+		public function index()
 		{
 			if ( phpgw::get_var('cancel', 'bool', 'POST') )
 			{
-				$GLOBALS['phpgw']->redirect_link('/admin/index.php');
+				$GLOBALS['phpgw']->redirect_link('/index.php', array('menuaction' => 'admin.uimainscreen.mainscreen'));
 			}
 
+			$GLOBALS['phpgw_info']['flags']['menu_selection'] .= '::admin::mainscreen';
+
+			$GLOBALS['phpgw']->template->set_root(PHPGW_APP_TPL);
 			$GLOBALS['phpgw']->template->set_file(array('message' => 'mainscreen_message.tpl'));
 			$GLOBALS['phpgw']->template->set_block('message','form','form');
 			$GLOBALS['phpgw']->template->set_block('message','row','row');
@@ -146,4 +201,3 @@
 			$GLOBALS['phpgw']->template->pfp('out','form');
 		}
 	}
-?>
