@@ -10,26 +10,38 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: hook_after_navbar.inc.php 16400 2006-02-14 08:48:21Z skwashd $ */
+	/* $Id: hook_after_navbar.inc.php 5980 2010-06-08 12:10:40Z sigurd $ */
 
 	/* Check currentapp and API upgrade status */
 
-	if ($GLOBALS['phpgw_info']['flags']['currentapp'] != 'home' &&
-		$GLOBALS['phpgw_info']['flags']['currentapp'] != 'welcome' &&
-		(isset($GLOBALS['phpgw_info']['server']['checkappversions']) &&
-		$GLOBALS['phpgw_info']['server']['checkappversions']))
+	if ($GLOBALS['phpgw_info']['flags']['currentapp'] != 'home'
+		&& $GLOBALS['phpgw_info']['flags']['currentapp'] != 'welcome'
+		&& $GLOBALS['phpgw_info']['flags']['currentapp'] != 'about'
+//		&& (isset($GLOBALS['phpgw_info']['server']['checkappversions']) &&	$GLOBALS['phpgw_info']['server']['checkappversions'])
+		)
 	{
 		if ((isset($GLOBALS['phpgw_info']['user']['apps']['admin']) &&
 			$GLOBALS['phpgw_info']['user']['apps']['admin']) ||
 			$GLOBALS['phpgw_info']['server']['checkappversions'] == 'All')
 		{
+			$require_upgrade = false;
 			$_current = array();
 			$app_name = $GLOBALS['phpgw_info']['flags']['currentapp'];
 			$GLOBALS['phpgw']->db->query("SELECT app_name,app_version FROM phpgw_applications WHERE app_name='$app_name' OR app_name='phpgwapi'",__LINE__,__FILE__);
+			$app_info = array();
 			while($GLOBALS['phpgw']->db->next_record())
 			{
-				$_db_version  = $GLOBALS['phpgw']->db->f('app_version');
-				$app_name     = $GLOBALS['phpgw']->db->f('app_name');
+				$app_info[] = array
+				(
+					'db_version'	=> $GLOBALS['phpgw']->db->f('app_version'),
+					'app_name'		=> $GLOBALS['phpgw']->db->f('app_name')
+				); 
+			}
+			
+			foreach($app_info as $app)
+			{
+				$_db_version  = $app['db_version'];
+				$app_name	  = $app['app_name'];
 				$_versionfile = $GLOBALS['phpgw']->common->get_app_dir($app_name) . '/setup/setup.inc.php';
 				if(file_exists($_versionfile))
 				{
@@ -46,14 +58,15 @@
 						$_current[$app_name] = True;
 						if($app_name == 'phpgwapi')
 						{
-							$api_str = '<br>' . lang('The API is current');
+							$api_str = lang('The API is current');
 						}
 					}
 					else
 					{
 						if($app_name == 'phpgwapi')
 						{
-							$api_str = '<br>' . lang('The API requires an upgrade');
+							$api_str = lang('The API requires an upgrade');
+							$require_upgrade = true;
 						}
 					}
 					unset($test);
@@ -63,20 +76,37 @@
 				unset($_db_version);
 				unset($_versionfile);
 			}
-			if(!@isset($_current[$GLOBALS['phpgw_info']['flags']['currentapp']]))
+			if(!isset($_current[$GLOBALS['phpgw_info']['flags']['currentapp']]))
 			{
-				echo '<center>';
-				echo $api_str;
-				echo '<br>' . lang('This application requires an upgrade') . ':' . "\n";
-				echo '<br>' . lang('Please run setup to become current') . '.' . "\n";
-				echo '</center>';
+				$app_str  = '<br>' . lang('This application requires an upgrade') . ':' . "\n";
+				$app_str .= '<br>' . lang('Please run setup to become current') . '.' . "\n";
+				$require_upgrade = true;
 			}
 			else
 			{
-				echo '<center>';
+				$app_str  =  '<br>' . lang('This application is current') . "\n";
+			}
+		
+			if($require_upgrade)
+			{
+				echo '<div class="error">';
 				echo $api_str;
-				echo '<br>' . lang('This application is current') . "\n";
-				echo '</center>';
+				echo $app_str;
+				echo '</div>';
 			}
 		}
 	}
+	
+	if( phpgw::get_var('phpgw_return_as') != 'json' && $receipt = phpgwapi_cache::session_get('phpgwapi', 'phpgw_messages'))
+	{
+		phpgwapi_cache::session_clear('phpgwapi', 'phpgw_messages');
+		$msgbox_data = $GLOBALS['phpgw']->common->msgbox_data($receipt);
+		$msgbox_data = $GLOBALS['phpgw']->common->msgbox($msgbox_data);
+		foreach($msgbox_data as & $message)
+		{
+			echo "<div class='{$message['msgbox_class']}'>";
+//			echo "<img src='{$message['msgbox_img']}' alt='{$message['msgbox_img_alt']}' title='{$message['msgbox_img_alt']}'/>";
+			echo $message['msgbox_text'];
+			echo '</div>';
+		}
+	}
