@@ -12,7 +12,7 @@
   *  option) any later version.                                              *
   \**************************************************************************/
 
-  /* $Id: class.socalendar_sql.inc.php 18358 2007-11-27 04:43:37Z skwashd $ */
+  /* $Id: class.socalendar_sql.inc.php 4696 2010-02-01 22:48:22Z sigurd $ */
 
 phpgw::import_class('phpgwapi.datetime');
 
@@ -22,6 +22,7 @@ class calendar_socalendar_ extends calendar_socalendar__
 	
 	var $cal_event;
 	var $today = array('raw','day','month','year','full','dow','dm','bd');
+	protected $global_lock = false;
 
 	function __construct()
 	{
@@ -82,19 +83,32 @@ class calendar_socalendar_ extends calendar_socalendar__
     
 	function delete_calendar($calendar='')
 	{
-		$this->stream->query('SELECT cal_id FROM phpgw_cal WHERE owner='.intval($calendar),__LINE__,__FILE__);
-		if($this->stream->num_rows())
+		$calendar = (int) $calendar;
+		//TODO transaction needed here 
+
+		$this->stream->query("SELECT cal_id FROM phpgw_cal WHERE owner = {$calendar}",__LINE__,__FILE__);
+		while($this->stream->next_record())
 		{
-			while($this->stream->next_record())
-			{
-				$this->delete_event(intval($this->stream->f('cal_id')));
-			}
-			$this->expunge();
+			$this->delete_event( (int) $this->stream->f('cal_id'));
 		}
-		$this->stream->lock(array('phpgw_cal_user'));
-		$this->stream->query('DELETE FROM phpgw_cal_user WHERE cal_login='.intval($calendar),__LINE__,__FILE__);
-		$this->stream->unlock();
-			
+//		$this->stream->lock(array('phpgw_cal_user'));
+		if ( $this->stream->Transaction )
+		{
+			$this->global_lock = true;
+		}
+		else
+		{
+			$this->stream->transaction_begin();
+		}
+		$this->expunge();
+		$this->stream->query("DELETE FROM phpgw_cal_user WHERE cal_login = {$calendar}",__LINE__,__FILE__);
+		if ( !$this->global_lock )
+		{
+			$this->stream->transaction_commit();
+		}
+
+//		$this->stream->unlock();
+		// end transaction
 		return $calendar;
 	}
 
@@ -225,12 +239,12 @@ class calendar_socalendar_ extends calendar_socalendar__
 			// Use http://www.php.net/manual/en/function.mcal-fetch-event.php as the reference
 			$this->add_attribute('owner',intval($this->stream->f('owner')));
 			$this->add_attribute('id',intval($this->stream->f('cal_id')));
-			$this->add_attribute('uid', "phpgw://{$_SERVER['SERVER_NAME']}/calendar/" . intval($this->stream->f('cal_id')));
-			$this->set_class(intval($this->stream->f('is_public')));
+			$this->add_attribute('uid', "phpgw://{$_SERVER['SERVER_NAME']}/calendar/" . (int) $this->stream->f('cal_id'));
+			$this->set_class( !!$this->stream->f('is_public'));
 			$this->set_category($this->stream->f('category'));
-			$this->set_title(stripslashes($GLOBALS['phpgw']->strip_html($this->stream->f('title'))));
-			$this->set_description(stripslashes($GLOBALS['phpgw']->strip_html($this->stream->f('description'))));
-			$this->add_attribute('location',stripslashes($GLOBALS['phpgw']->strip_html($this->stream->f('location'))));
+			$this->set_title($GLOBALS['phpgw']->strip_html($this->stream->f('title', true)));
+			$this->set_description($GLOBALS['phpgw']->strip_html($this->stream->f('description', true)));
+			$this->add_attribute('location',$GLOBALS['phpgw']->strip_html($this->stream->f('location', true)));
 			$this->add_attribute('reference',intval($this->stream->f('reference')));
 			
 			// This is the preferred method once everything is normalized...
@@ -244,7 +258,7 @@ class calendar_socalendar_ extends calendar_socalendar__
 			$datetime = phpgwapi_datetime::localdates($this->stream->f('mdatetime'));
 			$this->set_date('modtime',$datetime['year'],$datetime['month'],$datetime['day'],$datetime['hour'],$datetime['minute'],$datetime['second']);
 
-			$datetime = phpgw_datetime::localdates($this->stream->f('edatetime'));
+			$datetime = phpgwapi_datetime::localdates($this->stream->f('edatetime'));
 			$this->set_end($datetime['year'],$datetime['month'],$datetime['day'],$datetime['hour'],$datetime['minute'],$datetime['second']);
 
 		//Legacy Support
@@ -400,10 +414,11 @@ class calendar_socalendar_ extends calendar_socalendar__
 		}
 		$member_groups = $GLOBALS['phpgw']->accounts->membership($this->user);
 		@reset($member_groups);
-		while($member_groups != False && list($key,$group_info) = each($member_groups))
+		foreach ($member_groups as $key => $group_info)
 		{
-			$member[] = $group_info['account_id'];
+			$member[] = $group_info->id;		
 		}
+
 		@reset($member);
 //		$user_where .= ','.implode(',',$member);
 		$user_where .= ')) ';
@@ -483,7 +498,7 @@ class calendar_socalendar_ extends calendar_socalendar__
 			return 1;
 		}
 		$this_event = $this->event;
-		$locks = array(
+/*		$locks = array(
 			'phpgw_cal',
 			'phpgw_cal_user',
 			'phpgw_cal_repeats',
@@ -491,6 +506,16 @@ class calendar_socalendar_ extends calendar_socalendar__
 // OLD-ALARM			'phpgw_cal_alarm'
 		);
 		$this->stream->lock($locks);
+*/
+		if ( $this->stream->Transaction )
+		{
+			$this->global_lock = true;
+		}
+		else
+		{
+			$this->stream->transaction_begin();
+		}
+
 		foreach($this->deleted_events as $cal_id)
 		{
 			foreach ($locks as $table)
@@ -498,7 +523,11 @@ class calendar_socalendar_ extends calendar_socalendar__
 				$this->stream->query('DELETE FROM '.$table.' WHERE cal_id='.$cal_id,__LINE__,__FILE__);
 			}
 		}
-		$this->stream->unlock();
+//		$this->stream->unlock();
+		if ( !$this->global_lock )
+		{
+			$this->stream->transaction_commit();
+		}
 
 		foreach($this->deleted_events as $cal_id)
 		{
@@ -630,7 +659,8 @@ class calendar_socalendar_ extends calendar_socalendar__
 // OLD-ALARM			'phpgw_cal_alarm'
 		);
 		$this->stream->lock($locks);
-		if($event['id'] == 0)
+		if ( !isset($event['id'])
+			|| !$event['id'] )
 		{
 			$this->stream->query('INSERT INTO phpgw_cal(title, owner, priority, is_public, category) '
 				. "VALUES('".$this->stream->db_addslashes($event['title'])
@@ -666,7 +696,7 @@ class calendar_socalendar_ extends calendar_socalendar__
 				. "title='".$this->stream->db_addslashes($event['title'])."', "
 				. "description='".$this->stream->db_addslashes($event['description'])."', "
 				. "location='".$this->stream->db_addslashes($event['location'])."', "
-				. ($event['groups']?"groups='".(count($event['groups'])>1?implode(',',$event['groups']):','.$event['groups'][0].',')."', ":'')
+				. (isset($event['groups']) ? "groups='".(count($event['groups']) > 1 ? implode(',',$event['groups']) : ','.$event['groups'][0].',')."', ":'')
 				. 'reference='.$event['reference'].' '
 				. 'WHERE cal_id='.$event['id'];
 		
@@ -696,9 +726,9 @@ class calendar_socalendar_ extends calendar_socalendar__
 				$end = 0;
 			}
 
-			$this->stream->query('SELECT count(cal_id) FROM phpgw_cal_repeats WHERE cal_id='.$event['id'],__LINE__,__FILE__);
+			$this->stream->query('SELECT count(cal_id) as cnt FROM phpgw_cal_repeats WHERE cal_id='.$event['id'],__LINE__,__FILE__);
 			$this->stream->next_record();
-			$num_rows = $this->stream->f(0);
+			$num_rows = $this->stream->f('cnt');
 			if($num_rows == 0)
 			{
 				$this->stream->query('INSERT INTO phpgw_cal_repeats(cal_id,recur_type,recur_enddate,recur_data,recur_interval) '
@@ -758,7 +788,8 @@ class calendar_socalendar_ extends calendar_socalendar__
 
 		$this->stream->unlock();
 
-		if (is_array($event['alarm']))
+		if ( isset($event['alarm'])
+			&& is_array($event['alarm']) )
 		{
 			foreach ($event['alarm'] as $alarm)	// this are all new alarms
 			{
@@ -862,10 +893,11 @@ class calendar_socalendar_ extends calendar_socalendar__
 
 		$member_groups = $GLOBALS['phpgw']->accounts->membership($this->user);
 		@reset($member_groups);
-		while($member_groups != False && list($key,$group_info) = each($member_groups))
+		foreach ($member_groups as $key => $group_info)
 		{
-			$member[] = intval($group_info['account_id']);
+			$member[] = $group_info->id;		
 		}
+
 		@reset($member);
 
 		if($this->debug)
@@ -885,18 +917,5 @@ class calendar_socalendar_ extends calendar_socalendar__
 		}
 		return $this->get_event_ids($repeats,$user_where.$wheremod.$extra.$order_by);
 	}
-
-/* OLD-ALARM
-	function add_alarm($eventid,$alarm,$owner)
-	{
-		$this->stream->query('INSERT INTO phpgw_cal_alarm(cal_id,cal_owner,cal_time,cal_text,alarm_enabled) VALUES('.$eventid.','.$owner.','.$alarm['time'].",'".$alarm['text']."',1)",__LINE__,__FILE__);
-		$this->stream->query('SELECT LAST_INSERT_ID()');
-		$this->stream->next_record();
-		return($this->stream->f(0));
-	}
-	function delete_alarm($alarmid)
-	{
-		$this->stream->query('DELETE FROM phpgw_cal_alarm WHERE alarm_id='.$alarmid,__LINE__,__FILE__);
-	}
-*/
 }
+
