@@ -8,13 +8,13 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package demo
 	* @subpackage demo
- 	* @version $Id: class.uidemo.inc.php 18358 2007-11-27 04:43:37Z skwashd $
+ 	* @version $Id: class.uidemo.inc.php 1781 2008-11-02 19:51:19Z sigurd $
 	*/
 
 	/*
 	   This program is free software: you can redistribute it and/or modify
 	   it under the terms of the GNU General Public License as published by
-	   the Free Software Foundation, either version 3 of the License, or
+	   the Free Software Foundation, either version 2 of the License, or
 	   (at your option) any later version.
 
 	   This program is distributed in the hope that it will be useful,
@@ -37,87 +37,82 @@
 		* @var ??? $grants ???
 		*/
 		private $grants;
-		
+
 		/**
 		* @var ??? $start ???
 		*/
 		private $start;
-		
+
 		/**
 		* @var ??? $query ???
 		*/
 		private $query;
-		
+
 		/**
 		* @var ??? $sort ???
 		*/
 		private $sort;
-		
+
 		/**
 		* @var ??? $order ???
 		*/
 		private $order;
-		
+
 		/**
 		* @var object $cats categories object
 		*/
 		private $cats;
-		
+
 		/**
 		* @var object $nextmatches paging handler
 		*/
 		private $nextmatches;
-		
+
 		/**
 		* @var int $account reference to the current user id
 		*/
 		private $account;
-		
+
 		/**
 		* @var object $bo business logic
 		*/
 		private $bo;
-		
-		/**
-		* @var object $menu application menu handler
-		*/
-		private $menu;
-		
+
 		/**
 		* @var object $acl reference to global access control list manager
 		*/
 		private $acl;
-		
+
 		/**
 		* @var string $acl_location the access control location
 		*/
 		private $acl_location;
-		
+
 		/**
 		* @var bool $acl_read does the current user have read access to the current location
 		*/
 		private $acl_read;
-		
+
 		/**
 		* @var bool $acl_add does the current user have add access to the current location
 		*/
 		private $acl_add;
-		
+
 		/**
 		* @var bool $acl_edit does the current user have edit access to the current location
 		*/
 		private $acl_edit;
-		
+
 		/**
 		* @var bool $allrows display all rows of result set?
 		*/
 		private $allrows;
-		
+
 		/**
 		* @var int $cat_id the currently selected category
 		*/
 		private $cat_id;
-		
+
 		/**
 		* @var bool $filter the current filter
 		*/
@@ -143,14 +138,12 @@
 			$this->nextmatches		= CreateObject('phpgwapi.nextmatchs');
 			$this->account			=& $GLOBALS['phpgw_info']['user']['account_id'];
 			$this->bo				= CreateObject('demo.bodemo',true);
-			$this->menu				= CreateObject('demo.menu');
-			$this->menu->set_sub('demo');
 			$this->acl 				=& $GLOBALS['phpgw']->acl;
 			$this->acl_location 	= $this->bo->get_acl_location();
-			$this->acl_read 		= $this->acl->check($this->acl_location, PHPGW_ACL_READ);
-			$this->acl_add 			= $this->acl->check($this->acl_location, PHPGW_ACL_ADD);
-			$this->acl_edit 		= $this->acl->check($this->acl_location, PHPGW_ACL_EDIT);
-			$this->acl_delete 		= $this->acl->check($this->acl_location, PHPGW_ACL_DELETE);
+			$this->acl_read 		= $this->acl->check($this->acl_location, PHPGW_ACL_READ, 'demo');
+			$this->acl_add 			= $this->acl->check($this->acl_location, PHPGW_ACL_ADD, 'demo');
+			$this->acl_edit 		= $this->acl->check($this->acl_location, PHPGW_ACL_EDIT, 'demo');
+			$this->acl_delete 		= $this->acl->check($this->acl_location, PHPGW_ACL_DELETE, 'demo');
 
 			$this->start			= $this->bo->start;
 			$this->query			= $this->bo->query;
@@ -159,6 +152,7 @@
 			$this->allrows			= $this->bo->allrows;
 			$this->cat_id			= $this->bo->cat_id;
 			$this->filter			= $this->bo->filter;
+			$GLOBALS['phpgw_info']['flags']['menu_selection'] = 'demo';
 		}
 
 		private function save_sessiondata()
@@ -176,17 +170,16 @@
 		public function index()
 		{
 			$output	= self::get_output();
-		
-			$this->menu->set_sub($output);
-			$links = $this->menu->links();
+
+			$GLOBALS['phpgw_info']['flags']['menu_selection'] .= "::{$output}";
 
 			if(!$this->acl_read)
 			{
-				$this->no_access($links);
+				$this->no_access();
 				return;
 			}
 
-			$GLOBALS['phpgw']->xslttpl->add_file(array('demo','nextmatchs','menu',
+			$GLOBALS['phpgw']->xslttpl->add_file(array('demo','nextmatchs',
 										'search_field'));
 
 			$demo_info = $this->bo->read();
@@ -296,7 +289,6 @@
 			$data = array
 			(
 				'msgbox_data'							=> $GLOBALS['phpgw']->common->msgbox($msgbox_data),
-				'links'									=> $links,
 				'cat_filter'							=> $this->cats->formatted_xslt_list(array('select_name' => 'cat_id','selected' => $this->cat_id,'globals' => true,'link_data' => $link_data)),
 				'filter_data'							=> $this->nextmatches->xslt_filter(array('filter' => $this->filter,'link_data' => $link_data)),
 				'allow_allrows'							=> true,
@@ -319,7 +311,7 @@
 			$function_msg= lang('list demo values');
 
 			$GLOBALS['phpgw_info']['flags']['app_header'] = lang('demo') . ": {$function_msg}";
-			
+
 			$GLOBALS['phpgw']->xslttpl->set_var('phpgw',array("list_{$output}" => $data));
 			$this->save_sessiondata();
 		}
@@ -327,16 +319,15 @@
 		public function index2()
 		{
 			$output	= self::get_output();
-			
-			$this->menu->set_sub('alternative');
-			$links = $this->menu->links();
+
+			$GLOBALS['phpgw_info']['flags']['menu_selection'] .= '::alternative';
 			if(!$this->acl_read)
 			{
-				$this->no_access($links);
+				$this->no_access();
 				return;
 			}
 
-			$GLOBALS['phpgw']->xslttpl->add_file(array('demo','nextmatchs','menu',
+			$GLOBALS['phpgw']->xslttpl->add_file(array('demo','nextmatchs',
 										'search_field'));
 
 			$demo_info = $this->bo->read2();
@@ -474,7 +465,6 @@
 			$data = array
 			(
 				'msgbox_data'							=> $GLOBALS['phpgw']->common->msgbox($msgbox_data),
-				'links'									=> $links,
 				'cat_filter'							=> $this->cats->formatted_xslt_list(array('select_name' => 'cat_id','selected' => $this->cat_id,'globals' => true,'link_data' => $link_data)),
 				'filter_data'							=> $this->nextmatches->xslt_filter(array('filter' => $this->filter,'link_data' => $link_data)),
 				'allow_allrows'							=> true,
@@ -498,7 +488,7 @@
 			$function_msg= lang('list demo values');
 
 			$GLOBALS['phpgw_info']['flags']['app_header'] = lang('demo'). ": {$function_msg}";
-			
+
 			$GLOBALS['phpgw']->xslttpl->set_var('phpgw',array("list2_{$output}" => $data));
 			$this->save_sessiondata();
 		}
@@ -535,7 +525,7 @@
 			{
 				if(!$this->acl_edit)
 				{
-					$this->no_access($links);
+					$this->no_access();
 					return;
 				}
 
@@ -782,7 +772,7 @@
 
 		public function no_access($links = '')
 		{
-			$GLOBALS['phpgw']->xslttpl->add_file(array('no_access','menu'));
+			$GLOBALS['phpgw']->xslttpl->add_file(array('no_access'));
 
 			$receipt['error'][]=array('msg'=>lang('NO ACCESS'));
 
