@@ -7,7 +7,7 @@
 	* @copyright Copyright (C) 2003-2005 Free Software Foundation, Inc. http://www.fsf.org/
 	* @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 	* @package email
-	* @version $Id: class.bocompose.inc.php,v 1.16 2006/12/18 11:02:13 sigurdne Exp $
+	* @version $Id: class.bocompose.inc.php 4237 2009-11-27 23:17:21Z sigurd $
 	* @internal Based on AngleMail http://www.anglemail.org/
 	*/
 
@@ -524,13 +524,13 @@
 								$part_string = base64_decode($part_string);
 							}
 							
-							$fpart = fopen($GLOBALS['phpgw']->msg->att_files_dir . SEP . $newfilename,'wb');
+							$fpart = fopen("{$GLOBALS['phpgw']->msg->att_files_dir}/{$newfilename}",'wb');
 							fputs($fpart, $part_string);
 							fclose($fpart);
 							unset($fpart);
 							unset($part_string);
 				
-							$finfo = fopen($GLOBALS['phpgw']->msg->att_files_dir . SEP . $newfilename . '.info','wb');
+							$finfo = fopen("{$GLOBALS['phpgw']->msg->att_files_dir}/{$newfilename}" . '.info','wb');
 							fputs($finfo, strtolower($mimemajors[$part->type] . '/' . $part->subtype) ."\n" 
 								. $filename . "\n");
 							fclose($finfo);
