@@ -7,7 +7,7 @@
 	* @copyright Copyright (C) 2003-2005 Free Software Foundation, Inc. http://www.fsf.org/
 	* @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 	* @package email
-	* @version $Id: class.boindex.inc.php,v 1.39 2006/12/17 11:21:02 sigurdne Exp $
+	* @version $Id: class.boindex.inc.php 4237 2009-11-27 23:17:21Z sigurd $
 	* @internal Based on AngleMail http://www.anglemail.org/
 	*/
 
@@ -198,7 +198,7 @@
 				//'stats_backcolor' => $GLOBALS['phpgw_info']['theme']['em_folder'],
 				//'stats_backcolor_class' => 'th',
 				'stats_backcolor_class' => 'email_folder',
-				'stats_font' => $GLOBALS['phpgw_info']['theme']['font'],
+				'stats_font' => '',
 				'stats_font_size' => '2',
 				'stats_foldername_size' => '3',
 				//'stats_color' => $GLOBALS['phpgw_info']['theme']['em_folder_text'],
