@@ -7,7 +7,7 @@
 	* @copyright Copyright (C) 2003-2005 Free Software Foundation, Inc. http://www.fsf.org/
 	* @license http://www.gnu.org/licenses/lgpl.html GNU Lesser General Public License
 	* @package email
-	* @version $Id: class.html_widgets.inc.php,v 1.14 2007/02/11 06:42:17 skwashd Exp $
+	* @version $Id: class.html_widgets.inc.php 4237 2009-11-27 23:17:21Z sigurd $
 	* @internal Based on AngleMail http://www.anglemail.org/
 	*/
 
@@ -909,9 +909,9 @@
 			$row2_rowcolor_key = 'row_on';
 			$this->tpl->set_var('row1_rowcolor_key',$row1_rowcolor_key);
 			$this->tpl->set_var('row2_rowcolor_key',$row2_rowcolor_key);
-			$this->tpl->set_var('toolbar_row1_bgcolor',$GLOBALS['phpgw_info']['theme'][$row1_rowcolor_key]);
-			$this->tpl->set_var('toolbar_row2_bgcolor',$GLOBALS['phpgw_info']['theme'][$row2_rowcolor_key]);
-			$this->tpl->set_var('toolbar_font',$GLOBALS['phpgw_info']['theme']['font']);
+			$this->tpl->set_var('toolbar_row1_bgcolor','');
+			$this->tpl->set_var('toolbar_row2_bgcolor','');
+			$this->tpl->set_var('toolbar_font','');
 			$this->tpl->set_var('toolbar_font_size','2');
 			$this->tpl->set_var('report_this_font_size','1');
 			
@@ -1806,7 +1806,8 @@
 			$GLOBALS['phpgw']->common->phpgw_header(True);
 			$GLOBALS['phpgw']->template->set_root(PHPGW_APP_TPL);
 
-			$GLOBALS['phpgw']->template->set_file(array(
+			$GLOBALS['phpgw']->template->set_file(array
+			(
 				'T_error_report' => 'error_report.tpl'
 			));
 			$GLOBALS['phpgw']->template->set_var('error_report_text', $this->prop_error_report_text());
@@ -1816,11 +1817,9 @@
 			// do we exit the script here?
 			if ($do_exit)
 			{
-				// kill this script, we re outa here...
 				if (is_object($GLOBALS['phpgw']->msg))
 				{
 					$GLOBALS['phpgw']->msg->end_request();
-					$GLOBALS['phpgw']->msg = '';
 					unset($GLOBALS['phpgw']->msg);
 				}
 				$GLOBALS['phpgw']->common->phpgw_exit();
@@ -1834,6 +1833,9 @@
 		*/
 		function get_geek_bar()
 		{
+			//disabling "geekbar"
+			return '';
+
 			$row_on = $GLOBALS['phpgw_info']['theme']['row_on'];
 			$this_server_type = $GLOBALS['phpgw']->msg->get_pref_value('mail_server_type');
 			if (extension_loaded('imap') && function_exists('imap_open'))
