@@ -7,7 +7,7 @@
 	* @copyright Copyright (C) 2003-2005 Free Software Foundation, Inc. http://www.fsf.org/
 	* @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 	* @package email
-	* @version $Id: class.uiindex.inc.php,v 1.31 2006/12/18 14:44:38 sigurdne Exp $
+	* @version $Id: class.uiindex.inc.php 4237 2009-11-27 23:17:21Z sigurd $
 	* @internal Based on AngleMail http://www.anglemail.org/
 	*/
 
@@ -32,19 +32,15 @@
 
 		function uiindex()
 		{
-			if(!isset($GLOBALS['phpgw']->js) || !is_object($GLOBALS['phpgw']->js))
-			{
-				$GLOBALS['phpgw']->js = CreateObject('phpgwapi.javascript');
-			}
 			$GLOBALS['phpgw']->js->validate_file('core','base','phpgwapi');
 			
-			$folder = get_var('folder',array('POST','GET'));
+			$folder = phpgw::get_var('folder');
 			if($folder)
 			{
 				$_GET['fldball[folder]']=$folder;
 			}
 			
-			$acctnum = get_var('acctnum',array('POST','GET'));
+			$acctnum = phpgw::get_var('acctnum');
 			if($acctnum)
 			{
 				$_GET['fldball[acctnum]']=$folder;
@@ -75,6 +71,8 @@
 			$this->bo = CreateObject('email.boindex');
 			$this->bo->index_data();
 			
+			$this->index_old_tpl();
+			return;
 			if ($GLOBALS['phpgw']->msg->phpgw_before_xslt)
 			{
 				$this->index_old_tpl();
@@ -96,19 +94,8 @@
 			// we point to the global template for this version of phpgw templatings
 			$this->tpl =& $GLOBALS['phpgw']->template;
 			
-			// NOW we can out the header, because "index_data()" filled this global
-			//	$GLOBALS['phpgw_info']['flags']['email_refresh_uri']
-			// which is needed to preserve folder and sort settings during the auto-refresh-ing
-			// currently (Dec 6, 2001) that logic is in phpgwapi/inc/templates/idsociety/head.inc.php
-			unset($GLOBALS['phpgw_info']['flags']['noheader']);
-			unset($GLOBALS['phpgw_info']['flags']['nonavbar']);
-			$GLOBALS['phpgw_info']['flags']['noappheader'] = True;
-			$GLOBALS['phpgw_info']['flags']['noappfooter'] = True;
 			$GLOBALS['phpgw']->common->phpgw_header(true);
 			$this->tpl->set_root(PHPGW_APP_TPL);
-			// HOWEVER still this class must NOT invoke $GLOBALS['phpgw']->common->phpgw_header()
-			// even though we had to output the header (go figure... :)
-			// later: What does that mean ?
 			
 			$this->bo->xi['my_layout'] = $GLOBALS['phpgw']->msg->get_pref_value('layout');
 			$this->bo->xi['my_browser'] = $GLOBALS['phpgw']->msg->browser;
@@ -309,7 +296,7 @@
 						}
 						$tpl_vars = Array(
 							// new checkbox value, new fake_uri method of embedding coumpound data in a single HTML element
-							'mlist_embedded_uri' => $this->bo->xi['msg_list_dsp'][$i]['uri'],
+							'mlist_embedded_uri' => http_build_query($this->bo->xi['msg_list_dsp'][$i]['uri']),
 							'mlist_backcolor'	=> $this->bo->xi['msg_list_dsp'][$i]['back_color'],
 							'mlist_backcolor_class'	=> $this->bo->xi['msg_list_dsp'][$i]['back_color_class'],
 							'mlist_subject'		=> $this->bo->xi['msg_list_dsp'][$i]['subject'],
@@ -593,9 +580,6 @@ EOD;
 		*/
 		function mlist()
 		{
-			//raw HTTP_POST_VARS dump
-			//echo 'HTTP_POST_VARS print_r dump:<b><pre>'."\r\n"; print_r($GLOBALS['HTTP_POST_VARS']); echo '</pre><br /><br />'."\r\n";
-			
 			$this->bo = CreateObject("email.boindex");
 			$this->bo->mlist_data();
 			
@@ -603,16 +587,8 @@ EOD;
 			// NOW we can out the header, because "index_data()" filled this global
 			//	$GLOBALS['phpgw_info']['flags']['email_refresh_uri']
 			// which is needed to preserve folder and sort settings during the auto-refresh-ing
-			// currently (Dec 6, 2001) that logic is in phpgwapi/inc/templates/idsociety/head.inc.php
-			unset($GLOBALS['phpgw_info']['flags']['noheader']);
-			unset($GLOBALS['phpgw_info']['flags']['nonavbar']);
-			$GLOBALS['phpgw_info']['flags']['noappheader'] = True;
-			$GLOBALS['phpgw_info']['flags']['noappfooter'] = True;
-			$GLOBALS['phpgw']->common->phpgw_header();
+			$GLOBALS['phpgw']->common->phpgw_header(true);
 			$GLOBALS['phpgw']->template->set_root(PHPGW_APP_TPL);
-			// NOTE: as of Dec 10, 2001 a call from menuaction defaults to NOT modular
-			// HOWEVER still this class must NOT invoke $GLOBALS['phpgw']->common->phpgw_header()
-			// even though we had to output the header and navbar, (go figure... :)
 
 			// MUCH of this data may not be necessary nor used for mlists 
 			$this->bo->xi['my_layout'] = $GLOBALS['phpgw']->msg->prefs['layout'];
