@@ -1,7 +1,7 @@
 <?php
 	/**************************************************************************\
-	* phpGroupWare - FeLaMiMail                                              *
-	* http://www.phpgroupware.org                                              *
+	* eGroupWare - FeLaMiMail                                                  *
+	* http://www.egroupware.org                                                *
 	* http://www.phpgw.de                                                      *
 	* http://www.linux-at-work.de                                              *
 	* Written by Lars Kneschke [lkneschke@linux-at-work.de]                    *
@@ -11,16 +11,20 @@
 	*  Free Software Foundation; either version 2 of the License, or (at your  *
 	*  option) any later version.                                              *
 	\**************************************************************************/
-	/* $Id: index.php 17722 2006-12-18 20:03:33Z sigurdne $ */
+	/* $Id: index.php 4237 2009-11-27 23:17:21Z sigurd $ */
 
-	$phpgw_info['flags'] = array
+	// this is to get css inclusion working
+	$_GET['menuaction']	= 'felamimail.uifelamimail.viewMainScreen';
+
+	$GLOBALS['phpgw_info']['flags'] = array
 	(
 		'currentapp' => 'felamimail',
 		'noheader'   => True,
-		'nonavbar'   => True
+		'nonavbar'   => True,
+		'include_xajax' => True,
 	);
+								
 	include('../header.inc.php');
 
-	$obj = CreateObject('felamimail.uifelamimail');
-	$obj->viewMainScreen();
+	execmethod('felamimail.uifelamimail.viewMainScreen');
 ?>
