@@ -8,7 +8,7 @@
 	* @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 	* @package phpgroupware
 	* @subpackage help
-	* @version $Id: help.php 17968 2007-02-20 13:40:04Z sigurdne $
+	* @version $Id: help.php 3359 2009-08-10 15:44:19Z sigurd $
 	*/
 
 	/**
@@ -16,7 +16,7 @@
 	*/
 	$GLOBALS['phpgw_info'] = array();
 
-	$app = $HTTP_GET_VARS['app'];
+	$app = $_GET['app'];
 
 	if (!$app)
 	{
