@@ -8,7 +8,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package hrm
 	* @subpackage user
- 	* @version $Id: class.bojob.inc.php 18358 2007-11-27 04:43:37Z skwashd $
+ 	* @version $Id: class.bojob.inc.php 1013 2008-05-20 06:44:35Z sigurd $
 	*/
 
 	/**
@@ -32,11 +32,11 @@
 
 		var $public_functions = array
 		(
-			'read'			=> True,
-			'read_single'		=> True,
-			'save'			=> True,
-			'delete'		=> True,
-			'check_perms'		=> True
+			'read'			=> true,
+			'read_single'		=> true,
+			'save'			=> true,
+			'delete'		=> true,
+			'check_perms'		=> true
 		);
 
 		var $soap_functions = array(
@@ -58,7 +58,7 @@
 			)
 		);
 
-		public function __construct($session=False)
+		public function __construct($session=false)
 		{
 		//	$this->currentapp	= $GLOBALS['phpgw_info']['flags']['currentapp'];
 			$this->so 		= CreateObject('hrm.sojob');
@@ -67,7 +67,7 @@
 			if ($session)
 			{
 				$this->read_sessiondata();
-				$this->use_session = True;
+				$this->use_session = true;
 			}
 
 			$this->start	= phpgw::get_var('start', 'int');
@@ -391,7 +391,7 @@
 			$qualification_list = $this->so->select_qualification_list($job_id,$quali_id);
 			return $qualification_list;
 		}
-		
+
 		function resort_value($data)
 		{
 			$this->so->resort_value($data);
