@@ -8,7 +8,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package hrm
 	* @subpackage job
- 	* @version $Id: class.sojob.inc.php 18358 2007-11-27 04:43:37Z skwashd $
+ 	* @version $Id: class.sojob.inc.php 4558 2010-01-21 14:15:38Z sigurd $
 	*/
 
 	/**
@@ -26,15 +26,11 @@
 
 		public function __construct()
 		{
-		//	$this->currentapp	= $GLOBALS['phpgw_info']['flags']['currentapp'];
 			$this->account	= $GLOBALS['phpgw_info']['user']['account_id'];
-			$this->bocommon		= CreateObject('hrm.bocommon');
-			$this->db           	= $this->bocommon->new_db();
-			$this->db2           	= $this->bocommon->new_db();
-
-			$this->left_join		= $this->bocommon->left_join;
-			$this->join			= $this->bocommon->join;
-			$this->like			= $this->bocommon->like;
+			$this->db 			= & $GLOBALS['phpgw']->db;
+			$this->like 		= & $this->db->like;
+			$this->join 		= & $this->db->join;
+			$this->left_join	= & $this->db->left_join;
 		}
 
 		function read($data)
@@ -186,7 +182,7 @@
 				}
 
 			}
-			
+
 			return $jobs;
 		}
 
@@ -265,7 +261,7 @@
 			}
 
 			$groupmethod = ' GROUP BY phpgw_hrm_quali.category';
-			
+
 			$sql = "SELECT phpgw_hrm_quali.id as quali_id, phpgw_hrm_quali.remark as remark,phpgw_hrm_quali_category.descr as category,phpgw_hrm_quali_type.name,phpgw_hrm_quali_type.descr from phpgw_hrm_quali"
 				. " $this->join phpgw_hrm_quali_type ON phpgw_hrm_quali.quali_type_id = phpgw_hrm_quali_type.id"
 				. " $this->join phpgw_hrm_quali_category ON phpgw_hrm_quali.category = phpgw_hrm_quali_category.id"
@@ -434,8 +430,8 @@
 
 			$sql = "SELECT * FROM $table $filtermethod $querymethod";
 
-			$this->db2->query($sql,__LINE__,__FILE__);
-			$this->total_records = $this->db2->num_rows();
+			$this->db->query($sql,__LINE__,__FILE__);
+			$this->total_records = $this->db->num_rows();
 
 			if(!$allrows)
 			{
@@ -462,39 +458,28 @@
 
 		function read_task($data)
 		{
-			if(is_array($data))
-			{
-				if ($data['start'])
-				{
-					$start=$data['start'];
-				}
-				else
-				{
-					$start=0;
-				}
-				$query		= (isset($data['query'])?$data['query']:'');
-				$sort		= (isset($data['sort'])?$data['sort']:'DESC');
-				$order		= (isset($data['order'])?$data['order']:'');
-				$allrows	= (isset($data['allrows'])?$data['allrows']:'');
-			}
-
-			$job_id = $data['job_id'];
-			$filter_id = $data['filter_id'];
+			$start		= isset($data['start']) && $data['start'] ? $data['start']:0;
+			$query		= isset($data['query']) ? $data['query'] : '';
+			$sort		= isset($data['sort']) && $data['sort']? $data['sort'] : 'DESC';
+			$order		= isset($data['order']) ? $data['order'] : '';
+			$allrows	= isset($data['allrows']) ? $data['allrows'] : '';
+			$job_id 	= $data['job_id'];
+			$filter_id = isset($data['filter_id']) ? $data['filter_id'] : '';
 
 			if ($order)
 			{
-				$ordermethod = " order by $order $sort";
-
+				$ordermethod = " ORDER BY $order $sort";
 			}
 			else
 			{
-				$ordermethod = ' order by value_sort asc';
+				$ordermethod = ' ORDER BY value_sort asc';
 			}
 
 			$sql = "SELECT * from phpgw_hrm_task  WHERE job_id=" . intval($job_id);
 
 			$parent_select = ' AND task_level =0';
 
+			$querymethod = '';
 			if($filter_id)
 			{
 				$querymethod = " AND id != $filter_id";
@@ -502,13 +487,10 @@
 
 			if($query)
 			{
-				$query = preg_replace("/'/",'',$query);
-				$query = preg_replace('/"/','',$query);
-
-				$querymethod .= " AND name $this->like '%$query%'";
+				$query = $this->db->db_addslashes($query);
+				$querymethod .= " AND name {$this->like} '%{$query}%'";
 			}
 
-
 			$this->db->query($sql . $parent_select . $querymethod . $ordermethod,__LINE__,__FILE__);
 			$this->total_records = $this->db->num_rows();
 
@@ -547,7 +529,7 @@
 					$subtasks[$j]['name']        = $this->db->f('name');
 					$subtasks[$j]['descr'] = $this->db->f('descr');
 					$subtasks[$j]['value_sort'] = $value_sort;
-					
+
 					$j++;
 					$value_sort ++;
 				}
@@ -587,6 +569,8 @@
 
 		function add_job($values)
 		{
+			$receipt = array();
+			$this->db->transaction_begin();
 			$table = 'phpgw_hrm_job';
 
 			if($values['parent_id'])
@@ -612,17 +596,17 @@
 				$this->account
 				);
 
-			$insert_values	= $this->bocommon->validate_db_insert($insert_values);
-
+			$insert_values	= $this->db->validate_insert($insert_values);
 
 			$this->db->query("INSERT INTO $table (name,descr,job_parent,job_level,entry_date,owner) "
 				. "VALUES ($insert_values)",__LINE__,__FILE__);
 
-			$receipt['message'][]=array('msg'=>lang('job has been saved'));
-
 			$receipt['id'] = $this->db->get_last_insert_id($table,'id');
-
-			$this->db->transaction_commit();
+			
+			if($this->db->transaction_commit())
+			{
+				$receipt['message'][]=array('msg'=>lang('job has been saved'));
+			}
 			return $receipt;
 		}
 
@@ -672,7 +656,7 @@
 			$value_set['job_parent']		= intval($values['parent_id']);
 			$value_set['job_level']		= $level;
 
-			$value_set	= $this->bocommon->validate_db_update($value_set);
+			$value_set	= $this->db->validate_update($value_set);
 
 			$this->db->query("UPDATE $table set $value_set WHERE id=" . $values['id'],__LINE__,__FILE__);
 
@@ -818,6 +802,7 @@
 
 		function add_task($values)
 		{
+			$this->db->transaction_begin();
 			$table = 'phpgw_hrm_task';
 
 			$this->db->query("SELECT max(value_sort) as value_sort FROM $table WHERE job_id = " . (int)$values['job_id'],__LINE__,__FILE__);
@@ -827,7 +812,8 @@
 
 			if($values['parent_id'])
 			{
-				$this->db->query("SELECT task_level, max(value_sort) as value_sort FROM $table  where id=" . intval($values['parent_id']),__LINE__,__FILE__);
+				$values['parent_id'] = (int)$values['parent_id'];
+				$this->db->query("SELECT task_level FROM {$table} WHERE id={$values['parent_id']}",__LINE__,__FILE__);
 				$this->db->next_record();
 				$level	= (int)$this->db->f('task_level') +1;
 			}
@@ -850,7 +836,7 @@
 				$value_sort
 				);
 
-			$insert_values	= $this->bocommon->validate_db_insert($insert_values);
+			$insert_values	= $this->db->validate_insert($insert_values);
 
 
 			$this->db->query("INSERT INTO $table (job_id,name,descr,task_parent,task_level,entry_date,owner,value_sort) "
@@ -911,7 +897,7 @@
 			$value_set['task_parent']		= intval($values['parent_id']);
 			$value_set['task_level']		= $level;
 
-			$value_set	= $this->bocommon->validate_db_update($value_set);
+			$value_set	= $this->db->validate_update($value_set);
 
 			$this->db->query("UPDATE $table set $value_set WHERE id=" . $values['id'],__LINE__,__FILE__);
 
@@ -1035,7 +1021,7 @@
 			$values['descr'] = $this->db->db_addslashes($values['descr']);
 			$values['name'] = $this->db->db_addslashes($values['name']);
 
-			$values['quali_type_id'] = $this->bocommon->next_id('phpgw_hrm_quali_type');
+			$values['quali_type_id'] = $this->db->next_id('phpgw_hrm_quali_type');
 
 			$insert_values=array(
 				$values['quali_type_id'],
@@ -1045,7 +1031,7 @@
 				$this->account
 				);
 
-			$insert_values	= $this->bocommon->validate_db_insert($insert_values);
+			$insert_values	= $this->db->validate_insert($insert_values);
 			$this->db->query("INSERT INTO phpgw_hrm_quali_type (id,name,descr,entry_date,type_owner) "
 				. "VALUES ($insert_values)",__LINE__,__FILE__);
 
@@ -1063,7 +1049,7 @@
 			$value_set['descr'] = $this->db->db_addslashes($values['descr']);
 			$value_set['name'] = $this->db->db_addslashes($values['name']);
 
-			$value_set	= $this->bocommon->validate_db_update($value_set);
+			$value_set	= $this->db->validate_update($value_set);
 
 			$this->db->query("UPDATE phpgw_hrm_quali_type set $value_set WHERE id=" . $values['quali_type_id'],__LINE__,__FILE__);
 
@@ -1085,17 +1071,17 @@
 			 {
 			 	if ($values['name'] == stripslashes($this->db->f('name')) && $values['descr'] == stripslashes($this->db->f('descr')))
 			 	{
-			 		return True;
+			 		return true;
 			 	}
 			 }
 
-			 return False;
+			 return false;
 		}
 
 		function add_qualification($values)
 		{
 			$value['remark'] = $this->db->db_addslashes($values['remark']);
-			
+
 			$this->db->query("SELECT  max(value_sort) as value_sort FROM phpgw_hrm_quali WHERE job_id = " . (int)$values['job_id'],__LINE__,__FILE__);
 			$this->db->next_record();
 			$value_sort	= (int)$this->db->f('value_sort') +1;
@@ -1114,13 +1100,13 @@
 				$value_sort
 				);
 
-			$insert_values	= $this->bocommon->validate_db_insert($insert_values);
+			$insert_values	= $this->db->validate_insert($insert_values);
 
 			$this->db->query("INSERT INTO phpgw_hrm_quali (job_id,quali_type_id,category,skill_id,experience_id,entry_date,quali_owner,remark,value_sort) "
 				. "VALUES ($insert_values)",__LINE__,__FILE__);
 
 			$quali_id = $this->db->get_last_insert_id('phpgw_hrm_quali','id');
-			
+
 			if(is_array($values['alternative_qualification']))
 			{
 				$this->db->query("UPDATE phpgw_hrm_quali set is_parent = 1 WHERE id= $quali_id",__LINE__,__FILE__);
@@ -1154,7 +1140,7 @@
 			$value_set['experience_id']		= $values['experience_id'];
 			$value_set['remark'] 			= $this->db->db_addslashes($values['remark']);
 
-			$value_set	= $this->bocommon->validate_db_update($value_set);
+			$value_set	= $this->db->validate_update($value_set);
 
 			$table='phpgw_hrm_quali';
 
@@ -1221,7 +1207,7 @@
 			$this->db->query('DELETE FROM phpgw_hrm_quali WHERE id='  . intval($id) . ' AND job_id='  . intval($job_id),__LINE__,__FILE__);
 			$this->db->transaction_commit();
 		}
-		
+
 		function resort_value($data)
 		{
 			if(is_array($data))
@@ -1247,6 +1233,7 @@
 				return;
 			}
 
+			$this->db->transaction_begin();
 			$sql = "SELECT value_sort FROM $table where job_id=$job_id AND id=$id";
 			$this->db->query($sql,__LINE__,__FILE__);
 			$this->db->next_record();
@@ -1280,6 +1267,6 @@
 					return;
 					break;
 			}
+			$this->db->transaction_commit();
 		}
-		
 	}
