@@ -8,7 +8,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package hrm
 	* @subpackage job
- 	* @version $Id: class.uijob.inc.php 18358 2007-11-27 04:43:37Z skwashd $
+ 	* @version $Id: class.uijob.inc.php 1047 2008-05-26 19:51:20Z sigurd $
 	*/
 
 	/**
@@ -38,28 +38,28 @@
 
 		var $public_functions = array
 		(
-			'index'  			=> True,
-			'view_qualification'		=> True,
-			'view_job'   			=> True,
-			'edit_job'			=> True,
-			'delete_job'			=> True,
-			'reset_job_type_hierarchy'	=> True,
-			'edit_qualification'		=> True,
-			'delete_qualification'		=> True,
-			'qualification'			=> True,
-			'task'				=> True,
-			'edit_task'			=> True,
-			'view_task'			=> True,
-			'delete_task'			=> True,
-			'lookup_qualification'		=> True,
-			'edit_qualification_type'	=> True,
-			'hierarchy'			=> True,
-			'print_pdf'			=> True
+			'index'  			=> true,
+			'view_qualification'		=> true,
+			'view_job'   			=> true,
+			'edit_job'			=> true,
+			'delete_job'			=> true,
+			'reset_job_type_hierarchy'	=> true,
+			'edit_qualification'		=> true,
+			'delete_qualification'		=> true,
+			'qualification'			=> true,
+			'task'				=> true,
+			'edit_task'			=> true,
+			'view_task'			=> true,
+			'delete_task'			=> true,
+			'lookup_qualification'		=> true,
+			'edit_qualification_type'	=> true,
+			'hierarchy'			=> true,
+			'print_pdf'			=> true
 		);
 
 		public function __construct()
 		{
-			$GLOBALS['phpgw_info']['flags']['xslt_app'] = True;
+			$GLOBALS['phpgw_info']['flags']['xslt_app'] = true;
 		//	$this->currentapp			= 'hrm';
 			$this->nextmatchs			= CreateObject('phpgwapi.nextmatchs');
 			$this->account				= $GLOBALS['phpgw_info']['user']['account_id'];
@@ -67,14 +67,13 @@
 			$this->bocommon				= CreateObject('hrm.bocommon');
 			$this->bocategory			= CreateObject('hrm.bocategory');
 			$this->acl				= CreateObject('phpgwapi.acl');
-			$this->menu				= CreateObject('hrm.menu');
-			$this->menu->sub			='job';
 
 			$this->start				= $this->bo->start;
 			$this->query				= $this->bo->query;
 			$this->sort				= $this->bo->sort;
 			$this->order				= $this->bo->order;
 			$this->allrows				= $this->bo->allrows;
+			$GLOBALS['phpgw_info']['flags']['menu_selection'] = 'hrm::job';
 		}
 
 		function save_sessiondata()
@@ -93,18 +92,15 @@
 
 		function index()
 		{
-			$links = $this->menu->links('job_type');
 
-			if(!$this->acl->check('.job', PHPGW_ACL_READ))
+			if(!$this->acl->check('.job', PHPGW_ACL_READ, 'hrm'))
 			{
-				$this->bocommon->no_access($links);
+				$this->bocommon->no_access();
 				return;
 			}
 
-			if ( !isset($GLOBALS['phpgw']->js) || !is_object($GLOBALS['phpgw']->js) )
-			{
-				$GLOBALS['phpgw']->js = createObject('phpgwapi.javascript');
-			}
+			$GLOBALS['phpgw_info']['flags']['menu_selection'] .= '::job_type';
+
 			$GLOBALS['phpgw']->js->validate_file('base', 'check', 'hrm');
 
 			$GLOBALS['phpgw']->xslttpl->add_file(array('job','nextmatchs','menu',
@@ -218,8 +214,8 @@
 			$data = array
 			(
 				'msgbox_data'					=> $GLOBALS['phpgw']->common->msgbox($msgbox_data),
-				'links'							=> $links,
-				'allow_allrows'					=> True,
+				'menu'							=> execMethod('hrm.menu.links'),
+				'allow_allrows'					=> true,
 				'allrows'						=> $this->allrows,
 				'start_record'					=> $this->start,
 				'record_limit'					=> $record_limit,
@@ -249,22 +245,23 @@
 		}
 
 		function print_pdf()
-		{
-			if(!$this->acl->check('.job', PHPGW_ACL_READ))
+                                                                  {
+			if(!$this->acl->check('.job', PHPGW_ACL_READ, 'hrm'))
 			{
-				$this->bocommon->no_access($links);
+				$this->bocommon->no_access();
 				return;
 			}
-			$GLOBALS['phpgw_info']['flags'][noheader] = True;
-			$GLOBALS['phpgw_info']['flags'][nofooter] = True;
-			$GLOBALS['phpgw_info']['flags']['xslt_app'] = False;
-			
+
+			$GLOBALS['phpgw_info']['flags']['noheader'] = true;
+			$GLOBALS['phpgw_info']['flags']['nofooter'] = true;
+			$GLOBALS['phpgw_info']['flags']['xslt_app'] = false;
+
 			$pdf	= CreateObject('phpgwapi.pdf');
 			$dateformat = $GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat'];
 			$date = $GLOBALS['phpgw']->common->show_date('',$dateformat);
-			
+
 			$values	= phpgw::get_var('values');
-			
+
 			// don't want any warnings turning up in the pdf code if the server is set to 'anal' mode.
 			//error_reporting(7);
 			//error_reporting(E_ALL);
@@ -279,7 +276,7 @@
 
 //			$pdf->line(20,760,578,760);
 //			$pdf->line(200,40,200,822);
-			
+
 			$pdf->addText(220,770,16,'Stillings beskrivelse');
 			$pdf->addText(300,34,6,$date);
 
@@ -293,7 +290,7 @@
 			$pdf->ezSetDy(-50);
 
 			$i = 0;
-		
+
 			while (is_array($values) && list(,$job_id) = each($values['select']))
 			{
 				if($i > 0)
@@ -304,7 +301,7 @@
 				$qualification = $this->bo->read_qualification($job_id);
 				$task = $this->bo->read_task($job_id);
 				$i++;
-			
+
 				$pdf->ezSetY(720);
 				$pdf->ezText($job_info['name'],14);
 				$pdf->ezSetDy(-10);
@@ -323,9 +320,9 @@
 						$pdf->ezText($j . ' ' . $entry['name'],12,array('left' => 10));
 					}
 					$j++;
-				}	
+				}
 				$pdf->ezSetDy(-10);
-				
+
 				$pdf->ezText(lang('qualification') . ':',12);
 				$pdf->ezSetDy(-5);
 				$j = 1;
@@ -341,21 +338,23 @@
 						$pdf->ezText($j . ' ' . $entry['name'],12,array('left' => 10));
 					}
 					$j++;
-				}	
+				}
 			}
-			
+
 			$document = $pdf->ezOutput();
-			$pdf->print_pdf($document,'job');  
+			$pdf->print_pdf($document,'job');
 		}
 
 		function qualification()
 		{
-			if(!$this->acl->check('.job', PHPGW_ACL_READ))
+			if(!$this->acl->check('.job', PHPGW_ACL_READ, 'hrm'))
 			{
-				$this->bocommon->no_access($links);
+				$this->bocommon->no_access();
 				return;
 			}
 
+			$GLOBALS['phpgw_info']['flags']['menu_selection'] .= '::job_type';
+
 			$job_id	= phpgw::get_var('job_id', 'int');
 			$id	= phpgw::get_var('id', 'int');
 			$resort	= phpgw::get_var('resort');
@@ -364,7 +363,7 @@
 			{
 				$this->bo->resort_value(array('resort'=>$resort,'job_id' => $job_id,'id' => $id,'type'=>'qualification'));
 			}
-			
+
 			$receipt = $GLOBALS['phpgw']->session->appsession('session_data','hrm_quali_receipt');
 			$GLOBALS['phpgw']->session->appsession('session_data','hrm_quali_receipt','');
 
@@ -501,12 +500,14 @@
 
 		function task()
 		{
-			if(!$this->acl->check('.job', PHPGW_ACL_READ))
+			if(!$this->acl->check('.job', PHPGW_ACL_READ, 'hrm'))
 			{
-				$this->bocommon->no_access($links);
+				$this->bocommon->no_access();
 				return;
 			}
 
+			$GLOBALS['phpgw_info']['flags']['menu_selection'] .= '::job_type';
+
 			$job_id	= phpgw::get_var('job_id', 'int');
 			$id	= phpgw::get_var('id', 'int');
 			$resort	= phpgw::get_var('resort');
@@ -650,19 +651,21 @@
 			$parent_id	= phpgw::get_var('parent_id', 'int');
 			$values		= phpgw::get_var('values');
 
+			$GLOBALS['phpgw_info']['flags']['menu_selection'] .= '::job_type';
+
 			if(!$id)
 			{
-				if(!$this->acl->check('.job', PHPGW_ACL_ADD))
+				if(!$this->acl->check('.job', PHPGW_ACL_ADD, 'hrm'))
 				{
-					$this->bocommon->no_access($links);
+					$this->bocommon->no_access();
 					return;
 				}
 			}
 			else
 			{
-				if(!$this->acl->check('.job', PHPGW_ACL_EDIT))
+				if(!$this->acl->check('.job', PHPGW_ACL_EDIT, 'hrm'))
 				{
-					$this->bocommon->no_access($links);
+					$this->bocommon->no_access();
 					return;
 				}
 			}
@@ -727,7 +730,7 @@
 			(
 				'menuaction'	=> 'hrm.uijob.edit_task',
 				'id'		=> $id,
-				'job_id'	=> $job_id				
+				'job_id'	=> $job_id
 			);
 
 			$msgbox_data = $this->bocommon->msgbox_data($receipt);
@@ -774,12 +777,14 @@
 			$job_id		= phpgw::get_var('job_id', 'int');
 			$parent_id	= phpgw::get_var('parent_id', 'int');
 
-			if(!$this->acl->check('.job', PHPGW_ACL_READ))
+			if(!$this->acl->check('.job', PHPGW_ACL_READ, 'hrm'))
 			{
-				$this->bocommon->no_access($links);
+				$this->bocommon->no_access();
 				return;
 			}
 
+			$GLOBALS['phpgw_info']['flags']['menu_selection'] .= '::job_type';
+
 			$GLOBALS['phpgw']->xslttpl->add_file(array('job'));
 
 			if ($id)
@@ -835,14 +840,15 @@
 
 		function lookup_qualification()
 		{
-			if(!$this->acl->check('.job', PHPGW_ACL_ADD))
+			if(!$this->acl->check('.job', PHPGW_ACL_ADD, 'hrm'))
 			{
-				$this->bocommon->no_access($links);
+				$this->bocommon->no_access();
 				return;
 			}
 
+			$GLOBALS['phpgw_info']['flags']['menu_selection'] .= '::job_type';
 
-			$GLOBALS['phpgw_info']['flags']['noframework'] = True;
+			$GLOBALS['phpgw_info']['flags']['noframework'] = true;
 			$GLOBALS['phpgw_info']['flags']['headonly']=true;
 
 			$receipt = $GLOBALS['phpgw']->session->appsession('session_data','hrm_quali_tp_receipt');
@@ -854,7 +860,7 @@
 
 			$dateformat = $GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat'];
 
-			if($this->acl->check('.job', PHPGW_ACL_EDIT))
+			if($this->acl->check('.job', PHPGW_ACL_EDIT, 'hrm'))
 			{
 				$allowed_edit = true;
 			}
@@ -957,7 +963,7 @@
 
 			$data = array
 			(
-				'allow_allrows'					=> True,
+				'allow_allrows'					=> true,
 				'allrows'					=> $this->allrows,
 				'start_record'					=> $this->start,
 				'record_limit'					=> $record_limit,
@@ -1008,7 +1014,7 @@
 
 		function edit_qualification_type()
 		{
-			$GLOBALS['phpgw_info']['flags']['noframework'] = True;
+			$GLOBALS['phpgw_info']['flags']['noframework'] = true;
 			$GLOBALS['phpgw_info']['flags']['headonly']=true;
 
 			$quali_type_id	= phpgw::get_var('quali_type_id', 'int');
@@ -1085,7 +1091,7 @@
 				'lang_name'				=> lang('name'),
 				'lang_descr'				=> lang('descr'),
 				'lang_descr_status_text'		=> lang('Enter a description'),
-				
+
 				'msgbox_data'				=> $GLOBALS['phpgw']->common->msgbox($msgbox_data),
 				'form_action'				=> $GLOBALS['phpgw']->link('/index.php',$link_data),
 				'lang_id'				=> lang('qualification type ID'),
@@ -1114,21 +1120,22 @@
 
 			if(!$id)
 			{
-				if(!$this->acl->check('.job', PHPGW_ACL_ADD))
+				if(!$this->acl->check('.job', PHPGW_ACL_ADD, 'hrm'))
 				{
-					$this->bocommon->no_access($links);
+					$this->bocommon->no_access();
 					return;
 				}
 			}
 			else
 			{
-				if(!$this->acl->check('.job', PHPGW_ACL_EDIT))
+				if(!$this->acl->check('.job', PHPGW_ACL_EDIT, 'hrm'))
 				{
-					$this->bocommon->no_access($links);
+					$this->bocommon->no_access();
 					return;
 				}
 			}
 
+			$GLOBALS['phpgw_info']['flags']['menu_selection'] .= '::job_type';
 
 			$GLOBALS['phpgw']->xslttpl->add_file(array('job'));
 
@@ -1238,12 +1245,13 @@
 			$id		= phpgw::get_var('id', 'int');
 			$parent_id	= phpgw::get_var('parent_id', 'int');
 
-			if(!$this->acl->check('.job', PHPGW_ACL_READ))
+			if(!$this->acl->check('.job', PHPGW_ACL_READ, 'hrm'))
 			{
-				$this->bocommon->no_access($links);
+				$this->bocommon->no_access();
 				return;
 			}
 
+			$GLOBALS['phpgw_info']['flags']['menu_selection'] .= '::job_type';
 
 			$GLOBALS['phpgw']->xslttpl->add_file(array('job'));
 
@@ -1310,21 +1318,23 @@
 
 			if(!$quali_id)
 			{
-				if(!$this->acl->check('.job', PHPGW_ACL_ADD))
+				if(!$this->acl->check('.job', PHPGW_ACL_ADD, 'hrm'))
 				{
-					$this->bocommon->no_access($links);
+					$this->bocommon->no_access();
 					return;
 				}
 			}
 			else
 			{
-				if(!$this->acl->check('.job', PHPGW_ACL_EDIT))
+				if(!$this->acl->check('.job', PHPGW_ACL_EDIT, 'hrm'))
 				{
-					$this->bocommon->no_access($links);
+					$this->bocommon->no_access();
 					return;
 				}
 			}
 
+			$GLOBALS['phpgw_info']['flags']['menu_selection'] .= '::job_type';
+
 			$values		= phpgw::get_var('values');
 
 			$GLOBALS['phpgw']->xslttpl->add_file(array('job'));
@@ -1472,12 +1482,14 @@
 			$quali_id	= phpgw::get_var('quali_id', 'int');
 			$job_id	= phpgw::get_var('job_id', 'int');
 
-			if(!$this->acl->check('.job', PHPGW_ACL_READ))
+			if(!$this->acl->check('.job', PHPGW_ACL_READ, 'hrm'))
 			{
-				$this->bocommon->no_access($links);
+				$this->bocommon->no_access();
 				return;
 			}
 
+			$GLOBALS['phpgw_info']['flags']['menu_selection'] .= '::job_type';
+
 			$GLOBALS['phpgw']->xslttpl->add_file(array('job'));
 
 			$values = $this->bo->read_single_qualification($quali_id);
@@ -1541,12 +1553,14 @@
 
 		function delete_job()
 		{
-			if(!$this->acl->check('.job', PHPGW_ACL_DELETE))
+			if(!$this->acl->check('.job', PHPGW_ACL_DELETE, 'hrm'))
 			{
-				$this->bocommon->no_access($links);
+				$this->bocommon->no_access();
 				return;
 			}
 
+			$GLOBALS['phpgw_info']['flags']['menu_selection'] .= '::job_type';
+
 			$job_id	= phpgw::get_var('job_id', 'int');
 			$confirm		= phpgw::get_var('confirm', 'bool', 'POST');
 			$link_data = array
@@ -1582,12 +1596,14 @@
 
 		function delete_task()
 		{
-			if(!$this->acl->check('.job', PHPGW_ACL_DELETE))
+			if(!$this->acl->check('.job', PHPGW_ACL_DELETE, 'hrm'))
 			{
-				$this->bocommon->no_access($links);
+				$this->bocommon->no_access();
 				return;
 			}
 
+			$GLOBALS['phpgw_info']['flags']['menu_selection'] .= '::job_type';
+
 			$id		= phpgw::get_var('id', 'int');
 			$job_id	= phpgw::get_var('job_id', 'int');
 			$confirm		= phpgw::get_var('confirm', 'bool', 'POST');
@@ -1626,12 +1642,14 @@
 
 		function delete_qualification()
 		{
-			if(!$this->acl->check('.job', PHPGW_ACL_DELETE))
+			if(!$this->acl->check('.job', PHPGW_ACL_DELETE, 'hrm'))
 			{
-				$this->bocommon->no_access($links);
+				$this->bocommon->no_access();
 				return;
 			}
 
+			$GLOBALS['phpgw_info']['flags']['menu_selection'] .= '::job_type';
+
 			$quali_id	= phpgw::get_var('quali_id', 'int');
 			$job_id		= phpgw::get_var('job_id', 'int');
 			$confirm	= phpgw::get_var('confirm', 'bool', 'POST');
@@ -1670,12 +1688,14 @@
 
 		function reset_job_type_hierarchy()
 		{
-			if(!$this->acl->check('.job', PHPGW_ACL_DELETE))
+			if(!$this->acl->check('.job', PHPGW_ACL_DELETE, 'hrm'))
 			{
-				$this->bocommon->no_access($links);
+				$this->bocommon->no_access();
 				return;
 			}
 
+			$GLOBALS['phpgw_info']['flags']['menu_selection'] .= '::job_type';
+
 			$confirm		= phpgw::get_var('confirm', 'bool', 'POST');
 			$link_data = array
 			(
@@ -1706,9 +1726,10 @@
 			$GLOBALS['phpgw_info']['flags']['app_header'] = lang('hrm') . ' - ' . $appname . ': ' . $function_msg;
 			$GLOBALS['phpgw']->xslttpl->set_var('phpgw',array('delete' => $data));
 		}
-		
+
 		function hierarchy()
 		{
+			$GLOBALS['phpgw_info']['flags']['menu_selection'] .= '::organisation';
 			$GLOBALS['phpgw_info']['flags']['xslt_app'] = false;
 			$GLOBALS['phpgw']->common->phpgw_header(true);
 			echo '<div class="msg">FIXME: Implement something here!</div>';
