@@ -8,7 +8,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package hrm
 	* @subpackage user
- 	* @version $Id: class.uiuser.inc.php 18358 2007-11-27 04:43:37Z skwashd $
+ 	* @version $Id: class.uiuser.inc.php 4416 2009-12-25 17:33:44Z sigurd $
 	*/
 
 	/**
@@ -41,17 +41,16 @@
 			$GLOBALS['phpgw_info']['flags']['xslt_app'] = true;
 			$this->nextmatchs			= CreateObject('phpgwapi.nextmatchs');
 			$this->account				= $GLOBALS['phpgw_info']['user']['account_id'];
-			$this->bo					= CreateObject('hrm.bouser',False);
+			$this->bo					= CreateObject('hrm.bouser',false);
 			$this->bocommon				= CreateObject('hrm.bocommon');
 			$this->bocategory			= CreateObject('hrm.bocategory');
-			$this->menu					= CreateObject('hrm.menu');
-			$this->menu->sub			='user';
 			$this->grants 				= $this->bo->grants;
 			$this->start				= $this->bo->start;
 			$this->query				= $this->bo->query;
 			$this->sort					= $this->bo->sort;
 			$this->order				= $this->bo->order;
 			$this->allrows				= $this->bo->allrows;
+			$GLOBALS['phpgw_info']['flags']['menu_selection'] = 'hrm::user';
 		}
 
 		function save_sessiondata()
@@ -69,11 +68,9 @@
 
 		function index()
 		{
-			$GLOBALS['phpgw']->xslttpl->add_file(array('user','nextmatchs','menu',
+			$GLOBALS['phpgw']->xslttpl->add_file(array('user','nextmatchs',
 										'search_field'));
 
-			$links = $this->menu->links();
-
 			$account_info = $this->bo->read();
 
 			$content = array();
@@ -156,8 +153,8 @@
 
 			$data = array
 			(
-				'links'								=> $links,
-				'allow_allrows'						=> True,
+				'menu'								=> execMethod('hrm.menu.links'),
+				'allow_allrows'						=> true,
 				'allrows'							=> $this->allrows,
 				'start_record'						=> $this->start,
 				'record_limit'						=> $record_limit,
@@ -181,115 +178,10 @@
 			$this->save_sessiondata();
 		}
 
-		// FIXME this really belongs in the bo layer
-		function get_user_data($user_id)
-		{
-			$account = CreateObject('phpgwapi.accounts',$user_id,'u');
-			$account_info = $account->read_repository();
-			$membership = $account->membership($user_id);
-			$contacts = CreateObject('phpgwapi.contacts');
-
-			$qcols = array
-			(
-				'n_given'    => 'n_given',
-				'n_family'   => 'n_family',
-				'tel_work'   => 'tel_work',
-				'tel_home'   => 'tel_home',
-				'tel_cell'   => 'tel_cell',
-				'title'      => 'title',
-				'email'      => 'email',
-				'email_home' => 'email_home',
-			);
-
-			$fields = $contacts->are_users($account_info['person_id'], $qcols);
-
-			$this->boaddressbook  = CreateObject('addressbook.boaddressbook');
-			$comms = $this->boaddressbook->get_comm_contact_data($fields[0]['contact_id']);
-
-			if(is_array($comms) && isset($comms[$fields[0]['contact_id']]) )
-			{
-				$fields[0]['tel_work'] = $comms[$fields[0]['contact_id']]['work phone'];			
-				$fields[0]['tel_home'] = $comms[$fields[0]['contact_id']]['home phone'];
-				$fields[0]['tel_cell'] = $comms[$fields[0]['contact_id']]['mobile (cell) phone'];
-				$fields[0]['email_home'] = $comms[$fields[0]['contact_id']]['home email'];
-			}
-		
-			if(!$account_info['person_id'])
-			{
-				$sfields = rawurlencode(serialize($fields[0]));
-				$contact_link   = $GLOBALS['phpgw']->link('/index.php', 
-					array
-					(
-						'menuaction'	=> 'addressbook.uiaddressbook.add_person',
-						'entry'			=> $sfields,
-					)
-				);
-			}
-			else
-			{
-				$contact_link   = $GLOBALS['phpgw']->link('/index.php',
-					array
-					(
-						'menuaction'	=> 'addressbook.uiaddressbook.view_person',
-						'ab_id'		=> $fields[0]['contact_id']
-					)
-				);
-			}
-
-			$prefs_user = $this->bocommon->create_preferences('email',$user_id);
-
-			$email_work = '';
-			if($fields[0]['email'] || $prefs_user['address'])
-			{
-				if(isset($prefs_user['address']) && $prefs_user['address'])
-				{
-					$email_work = $prefs_user['address'];
-				}
-				else
-				{
-					$email_work = $fields[0]['email'];
-				}
-			}
-
-			$email_home = '';
-			if($fields[0]['email_home'])
-			{
-				$email_home = $fields[0]['email_home'];
-			}
-
-			$qcols_extra = array
-			(
-				array('name' =>lang('first name'), 'type' => 'link', 'link_value' =>$contact_link),
-				array('name' =>lang('last name'), 'type' => 'text'),
-				array('name' =>lang('work phone'), 'type' => 'text'),
-				array('name' =>lang('home phone'), 'type' => 'text'),
-				array('name' =>lang('cellular phone'), 'type' => 'text'),
-				array('name' =>lang('title'), 'type' => 'text'),
-				array('name' =>lang('work email'), 'type' => 'mail', 'link_value' => $email_work),
-				array('name' =>lang('home email'), 'type' => 'mail', 'link_value' => $email_home),
-			);
-
-			if(is_array($fields))
-			{
-				$qcols = array_keys($qcols);
-				$j=0;
-				for ($i=0;$i<count($qcols);$i++)
-				{
-					$user_values[$j]['value'] = $fields[0][$qcols[$i]];
-					$user_values[$j]['name'] = $qcols_extra[$i]['name'];
-					$user_values[$j]['type'] = $qcols_extra[$i]['type'];
-					$user_values[$j]['link_value'] = isset($qcols_extra[$i]['link_value']) ? $qcols_extra[$i]['link_value'] : '';
-					$j++;
-				}
-			}
-			
-			return $user_values;
-		}
-
 		function training()
 		{
 			$user_id	= phpgw::get_var('user_id', 'int');
-  
+
 			if (!$this->grants[$user_id])
 			{
 				$this->bocommon->no_access($links);
@@ -305,7 +197,7 @@
 
 			if ($user_id)
 			{
-				$user_values = $this->get_user_data($user_id);
+				$user_values = $this->bo->get_user_data($user_id);
 				$training = $this->bo->read_training($user_id);
 			}
 //_debug_array($training);
@@ -336,11 +228,12 @@
 					$text_delete		= lang('delete');
 					$lang_delete_text	= lang('delete training item');
 				}
-				
+
 				$content[] = array
 				(
 					'title'			=> $entry['title'],
 					'place'			=> $entry['place'],
+					'credits'		=> $entry['credits'],
 					'start_date'		=> $entry['start_date'],
 					'end_date'		=> $entry['end_date'],
 					'category'		=> $entry['category'],
@@ -354,7 +247,7 @@
 					'text_edit'		=> $text_edit,
 					'text_delete'		=> $text_delete
 				);
-				
+
 				unset ($link_edit);
 				unset ($text_edit);
 				unset ($lang_edit_edit);
@@ -376,6 +269,17 @@
 												//		'cat_id'	=> $this->cat_id,
 														'allrows' 	=> $this->allrows)
 										)),
+				'sort_credits'		=> $this->nextmatchs->show_sort_order(array
+										(
+											'sort'	=> $this->sort,
+											'var'	=> 'phpgw_hrm_training.credits',
+											'order'	=> $this->order,
+											'extra'	=> array('menuaction'	=> 'hrm.uiuser.training',
+														'user_id'	=> $user_id,
+														'query'		=> $this->query,
+												//		'cat_id'	=> $this->cat_id,
+														'allrows' 	=> $this->allrows)
+										)),
 				'sort_start_date'	=> $this->nextmatchs->show_sort_order(array
 										(
 											'sort'	=> $this->sort,
@@ -400,6 +304,7 @@
 														'allrows' 	=> $this->allrows)
 										)),
 				'lang_category'		=> lang('category'),
+				'lang_credits'		=> lang('credits'),
 				'lang_title'		=> lang('training'),
 				'lang_start_date'	=> lang('start date'),
 				'lang_end_date'		=> lang('end date'),
@@ -420,7 +325,7 @@
 				$add_action	= $GLOBALS['phpgw']->link('/index.php', array('menuaction'=> 'hrm.uiuser.edit', 'user_id'=> $user_id));
 				$lang_add	= lang('add');
 			}
-			
+
 			$table_add[] = array
 			(
 				'lang_add'					=> $lang_add,
@@ -495,7 +400,7 @@
 				{
 					$this->bocommon->no_access($links);
 					return;
-				}	
+				}
 			}
 
 			$GLOBALS['phpgw']->xslttpl->add_file(array('user'));
@@ -625,6 +530,7 @@
 				'value_title'					=> isset($values['title']) ? $values['title'] : '',
 				'value_start_date'				=> isset($values['start_date']) ? $values['start_date'] : '',
 				'value_end_date'				=> isset($values['end_date']) ? $values['end_date'] : '',
+				'value_credits'					=> isset($values['credits']) ? $values['credits'] : 0,
 				'value_entry_date'				=> isset($values['entry_date']) ? $values['entry_date'] : '',
 				'value_reference'				=> isset($values['reference']) ? $values['reference'] : '',
 				'value_new_place_name'			=> isset($values['new_place_name']) ? $values['new_place_name'] : '',
@@ -700,7 +606,7 @@
 			$user_id	= phpgw::get_var('user_id', 'int');
 
 			if(!$this->bocommon->check_perms($this->grants[$user_id], PHPGW_ACL_READ))
-			{				
+			{
 				$this->bocommon->no_access($links);
 				return;
 			}
@@ -723,6 +629,7 @@
 				'value_title'				=> $values['title'],
 				'value_start_date'			=> $values['start_date'],
 				'value_end_date'			=> $values['end_date'],
+				'value_credits'				=> isset($values['credits']) ? $values['credits'] : 0,
 				'value_entry_date'			=> $values['entry_date'],
 				'value_reference'			=> $values['reference'],
 
@@ -839,7 +746,7 @@
 
 			if($user_id)
 			{
-				$user_values = $this->get_user_data($user_id);
+				$user_values = $this->bo->get_user_data($user_id);
 				$training = $this->bo->read_training($user_id);
 			}
 			else
@@ -847,7 +754,7 @@
 				echo 'Nothing';
 				return;
 			}
-			
+
 //	_debug_array($user_values);
 
 //	_debug_array($training);
@@ -870,7 +777,7 @@
 
 
 //	_debug_array($content);
-			
+
 			$date = $GLOBALS['phpgw']->common->show_date('',$dateformat);
 
 			// don't want any warnings turning up in the pdf code if the server is set to 'anal' mode.
@@ -887,7 +794,7 @@
 //			$pdf->line(20,40,578,40);
 			$pdf->line(20,760,578,760);
 			$pdf->line(200,40,200,822);
-			
+
 			$pdf->addText(220,770,16,'CV');
 			$pdf->addText(300,34,6,$date);
 
@@ -909,7 +816,7 @@
 									'value'=>array('justification'=>'left','width'=>200))
 							)
 						);
-		
+
 			$table_header = array(
 				'start_date'=>array('justification'=>'left','width'=>70),
 				'sep'=>array('justification'=>'center','width'=>15),
@@ -960,7 +867,7 @@
 					'spacer'		=> '',
 					'what'			=> $entry['title'] . ', ' . $entry['place']
 				);
-				
+
 				$pdf->ezTable($content,'','',
 							array('xPos'=>50,'xOrientation'=>'right','width'=>500,0,'shaded'=>0,'fontSize' => 10,'showLines'=> 0,'titleFontSize' => 12,'outerLineThickness'=>2,'showHeadings'=>0
 							,'cols'=>$table_header
@@ -970,6 +877,6 @@
 				unset($content);
 			}
 			$document = $pdf->ezOutput();
-			$pdf->print_pdf($document,'cv_'.$GLOBALS['phpgw']->accounts->id2name($user_id));  
+			$pdf->print_pdf($document,'cv_'.$GLOBALS['phpgw']->accounts->id2name($user_id));
 		}
 	}
