@@ -2,13 +2,29 @@
 	/**
 	* phpGroupWare
 	*
-	* phpgroupware base
-	* @copyright Copyright (C) 2000-2005 Free Software Foundation, Inc. http://www.fsf.org/
+	* @author Dave Hall <skwashd@phpgroupware.org>
+	* @author Others <unknown>
+	* @copyright Copyright (C) 2000-2008 Free Software Foundation, Inc. http://www.fsf.org/
 	* @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 	* @package phpgroupware
-	* @version $Id: index.php 17797 2006-12-28 04:09:50Z skwashd $
+	* @version $Id: index.php 6052 2010-06-13 20:29:30Z sigurd $
 	*/
 
+	/*
+	   This program is free software: you can redistribute it and/or modify
+	   it under the terms of the GNU General Public License as published by
+	   the Free Software Foundation, either version 2 of the License, or
+	   (at your option) any later version.
+
+	   This program is distributed in the hope that it will be useful,
+	   but WITHOUT ANY WARRANTY; without even the implied warranty of
+	   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+	   GNU General Public License for more details.
+
+	   You should have received a copy of the GNU General Public License
+	   along with this program.  If not, see <http://www.gnu.org/licenses/>.
+	 */
+
 	$phpgw_info = array();
 	if (!file_exists('header.inc.php'))
 	{
@@ -18,6 +34,7 @@
 
 	/**
 	* @global string $GLOBALS['sessionid']
+	* @internal FIXME this is ugly and probably not needed - skwashd jan08
 	*/
 	$GLOBALS['sessionid'] = isset($_REQUEST['sessionid'])? $_REQUEST['sessionid'] : '';
 
@@ -50,14 +67,13 @@
 	$GLOBALS['phpgw_info']['flags'] = array
 	(
 		'noheader'   => true,
-	//	'nonavbar'   => true,
 		'currentapp' => $app
 	);
 	
 	/**
 	* Include phpgroupware header
 	*/
-	include_once('header.inc.php');
+	require_once('header.inc.php');
 
 	if ($app == 'home' && ! $api_requested)
 	{
@@ -79,12 +95,23 @@
 		&& $GLOBALS[$class]->public_functions[$method] )
 
 	{
-		if ( isset($_GET['phpgw_return_as']) && $_GET['phpgw_return_as'] == 'json' )
+		if ( phpgw::get_var('X-Requested-With', 'string', 'SERVER') == 'XMLHttpRequest'
+			 // deprecated
+			|| phpgw::get_var('phpgw_return_as', 'string', 'GET') == 'json' )
 		{
-			Header('Content-Type: text/javascript');
+			// comply with RFC 4627
+			header('Content-Type: application/json'); 
 			$return_data = $GLOBALS[$class]->$method();
-			echo execMethod('phpgwapi.Services_JSON.encode', $return_data);
+			echo json_encode($return_data);
 			$GLOBALS['phpgw_info']['flags']['nofooter'] = true;
+
+			//If debug info is not triggered elsewhere.
+			if (isset($GLOBALS['phpgw_info']['user']['apps']['admin']) && DEBUG_TIMER && !phpgwapi_cache::session_get($app,'id_debug'))
+			{
+				$debug_timer_stop = perfgetmicrotime();
+				_debug_array(lang('page prepared in %1 seconds.', $debug_timer_stop - $GLOBALS['debug_timer_start'] ));
+			}
+
 			$GLOBALS['phpgw']->common->phpgw_exit();
 		}
 		else
@@ -128,4 +155,3 @@
 		$GLOBALS['phpgw']->redirect_link('/home.php');
 	}
 	$GLOBALS['phpgw']->common->phpgw_footer();
-?>
