@@ -22,7 +22,7 @@
 	* along with this program; if not, write to the Free Software       *
 	* Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.         *
 	\*******************************************************************/
-	/* $Id: class.help.inc.php 18020 2007-03-07 10:44:39Z sigurdne $ */
+	/* $Id: class.help.inc.php 690 2008-02-02 10:11:33Z dave $ */
 
 	class help
 	{
@@ -73,7 +73,7 @@
 			{
 				$this->output = array();
 			}
-			$GLOBALS['phpgw']->xslttpl->add_file($GLOBALS['phpgw']->common->get_tpl_dir('manual','base') . SEP . 'help');
+			$GLOBALS['phpgw']->xslttpl->add_file($GLOBALS['phpgw']->common->get_tpl_dir('manual','base') . '/help');
 		}
 
 		/*
@@ -109,8 +109,8 @@
 		{
 			if ($this->app_name)
 			{
-				$GLOBALS['phpgw']->xslttpl->add_file($GLOBALS['phpgw']->common->get_tpl_dir('manual','base') . SEP . 'help_data');
-		//		$GLOBALS['phpgw']->xslttpl->add_file($GLOBALS['phpgw']->common->get_tpl_dir($this->app_name,'base') . SEP . 'help_data');
+				$GLOBALS['phpgw']->xslttpl->add_file($GLOBALS['phpgw']->common->get_tpl_dir('manual','base') . '/help_data');
+		//		$GLOBALS['phpgw']->xslttpl->add_file($GLOBALS['phpgw']->common->get_tpl_dir($this->app_name,'base') . '/help_data');
 			}
 		}
 
