@@ -3,11 +3,11 @@
 	* phpGroupWare - Manual
 	*
 	* @author Sigurd Nes <sigurdne@online.no>
-	* @copyright Copyright (C) 2003,2004,2005,2006,2007 Free Software Foundation, Inc. http://www.fsf.org/
+	* @copyright Copyright (C) 2003-2010 Free Software Foundation, Inc. http://www.fsf.org/
 	* @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package manual
- 	* @version $Id: class.uimanual.inc.php 18114 2007-04-09 16:22:13Z sigurdne $
+ 	* @version $Id: class.uimanual.inc.php 5416 2010-04-25 17:14:08Z sigurd $
 	*/
 
 	/**
@@ -68,16 +68,15 @@
 
 		function help()
 		{
-			$odt2xhtml	= CreateObject('manual.odt2xhtml');
+			$GLOBALS['phpgw_info']['flags']['noframework'] = true;
+			$GLOBALS['phpgw_info']['flags']['no_reset_fonts'] = true;
 			$app = phpgw::get_var('app', 'string', 'GET');
 			$section = phpgw::get_var('section', 'string', 'GET');
 
 			if(!$section)
 			{
-				$referer = parse_url(phpgw::get_var('HTTP_REFERER', 'string', 'SERVER') );
-				parse_str($referer['query']);
-
-				if(isset($menuaction) && $menuaction)
+				$menuaction = phpgw::get_var('referer');
+				if($menuaction)
 				{
 					list($app_from_referer, $class, $method) = explode('.',$menuaction);
 					if ( strpos($class, 'ui') === 0 )
@@ -107,11 +106,34 @@
 				parse_navbar();
 			}
 				
+			$pdffile = PHPGW_SERVER_ROOT . "/{$app}/help/{$lang}/{$section}.pdf";
+			
+			if(is_file($pdffile))
+			{
+				$browser = CreateObject('phpgwapi.browser');
+				$browser->content_header("{$section}.pdf", '', filesize($pdffile));
+			    ob_clean();
+			    flush();
+				readfile($pdffile);
+				exit;
+			}
+
 			$odtfile = PHPGW_SERVER_ROOT . "/{$app}/help/{$lang}/{$section}.odt";
+			
+			// test the manual on odt2xhtml
+			//$odtfile = PHPGW_SERVER_ROOT . '/phpgwapi/inc/odt2xhtml/odt2xhtml.odt';
 
 			if(is_file($odtfile))
 			{
-				echo $odt2xhtml->oo_convert($odt2xhtml->oo_unzip($odtfile));
+				$frontend = '/'; # directory where file odt to converse
+				$root = $GLOBALS['phpgw_info']['server']['temp_dir'];
+
+				$odt2xhtml	= CreateObject('phpgwapi.odt2xhtml', $root, $frontend, $odtfile);
+				$odt2xhtml->convert2xhtml();
+				$odt2xhtml->get_elements_html();
+				$odt2xhtml->display_elements_html('css',0); 
+				$odt2xhtml->display_elements_html('body',1);
+				$odt2xhtml->delete_tmp();
 			}
 			else
 			{
@@ -123,11 +145,11 @@ HTML;
 			}
 			
 			$GLOBALS['phpgw']->common->phpgw_footer();
-
 		}
 
 		function attrib_help()
 		{
+			$GLOBALS['phpgw_info']['flags']['noframework'] = true;
 			$t =& $GLOBALS['phpgw']->template;
 			$t->set_root(PHPGW_APP_TPL);
 
@@ -138,16 +160,24 @@ HTML;
 			$location 	= phpgw::get_var('location');
 			$id			= phpgw::get_var('id', 'int');
 
-			$custom 	= createObject('phpgwapi.custom_fields');
-			
-			$attrib_data 	= $custom->get_attrib_single($appname, $location, $id);
+			$attrib_data 	= $GLOBALS['phpgw']->custom_fields->get($appname, $location, $id);
+
+			$helpmsg = nl2br(str_replace(array
+						(
+							'[',
+							']'
+						),array
+						(
+							'<',
+							'>'
+						),$attrib_data['helpmsg']));
 
 			$function_msg	= lang('Help');
 
-			$t->set_file('help','help.tpl');
-			$t->set_var('title',lang('Help') . ' - "' . $attrib_data['input_text'] . '"');
-			$t->set_var('help_msg',$attrib_data['helpmsg'] );
-			$t->set_var('lang_close',lang('close') );
+			$t->set_file('help', 'help.tpl');
+			$t->set_var('title', lang('Help') . " - \"{$attrib_data['input_text']}\"");
+			$t->set_var('help_msg', $helpmsg );
+			$t->set_var('lang_close', lang('close'));
 											
 			$GLOBALS['phpgw']->common->phpgw_header();
 			$t->pfp('out','help');
