@@ -7,7 +7,7 @@
 	* @license http://www.gnu.org/licenses/lgpl.html GNU Lesser General Public License
 	* @package phpgwapi
 	* @subpackage cron
-	* @version $Id: asyncservices.php 15874 2005-04-28 08:11:59Z powerstat $
+	* @version $Id: asyncservices.php 3604 2009-09-18 07:41:55Z sigurd $
 	*/
 
 	$path_to_phpgroupware = dirname(__FILE__) . '/../..';	// need to be adapted if this script is moved somewhere else
@@ -27,13 +27,29 @@
 
 	unset($GLOBALS['phpgw_info']['flags']['noapi']);
 
+	$GLOBALS['phpgw_info']['server']['sessions_type'] = 'db';
+
+	$_domain_info = isset($GLOBALS['phpgw_domain'][$_GET['domain']]) ? $GLOBALS['phpgw_domain'][$_GET['domain']] : '';
+	if(!$_domain_info)
+	{
+		echo "not a valid domain\n";
+		die();
+	}
+	else
+	{
+		$GLOBALS['phpgw_domain'] = array();
+		$GLOBALS['phpgw_domain'][$_GET['domain']] = $_domain_info;
+	}
+
 	$db_type = $GLOBALS['phpgw_domain'][$_GET['domain']]['db_type'];
+	if($db_type == 'postgres')
+	{
+		$db_type = 'pgsql';
+	}
 	if (!extension_loaded($db_type) && !dl($db_type.'.so'))
 	{
 		echo "Extension '$db_type' is not loaded and can't be loaded via dl('$db_type.so') !!!\n";
 	}
-	
-	$GLOBALS['phpgw_info']['server']['sessions_type'] = 'db';
 
 	/**
 	* Include API functions
