@@ -3,13 +3,28 @@
 	* Authentication based on NIS maps
 	* @author Dylan Adams <dadams@jhu.edu>
 	* @copyright Copyright (C) 2001 Dylan Adams
-	* @copyright Portions Copyright (C) 2004 Free Software Foundation, Inc http://www.fsf.org/
+	* @copyright Portions Copyright (C) 2004 - 2008 Free Software Foundation, Inc http://www.fsf.org/
 	* @license http://www.gnu.org/licenses/lgpl.html GNU Lesser General Public License
 	* @package phpgwapi
 	* @subpackage accounts
-	* @version $Id: class.auth_nis.inc.php 17062 2006-09-03 06:15:27Z skwashd $
+	* @version $Id: class.auth_nis.inc.php 1781 2008-11-02 19:51:19Z sigurd $
 	*/
 
+	/*
+	   This program is free software: you can redistribute it and/or modify
+	   it under the terms of the GNU Lesser General Public License as published by
+	   the Free Software Foundation, either version 2 of the License, or
+	   (at your option) any later version.
+
+	   This program is distributed in the hope that it will be useful,
+	   but WITHOUT ANY WARRANTY; without even the implied warranty of
+	   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+	   GNU General Public License for more details.
+
+	   You should have received a copy of the GNU Lesser General Public License
+	   along with this program.  If not, see <http://www.gnu.org/licenses/>.
+	 */
+
 	/**
 	* Authentication based on NIS maps
 	*
@@ -17,12 +32,12 @@
 	* @subpackage accounts
 	* @ignore
 	*/
-	class auth_nis extends auth_
+	class phpgwapi_auth_nis extends phpgwapi_auth_
 	{
 		
-		function auth_nis()
+		function __construct()
 		{
-			parent::auth();
+			parent::__construct();
 		}
 		
 		function authenticate($username, $passwd)
@@ -55,8 +70,6 @@
 		function change_password($old_passwd, $new_passwd, $account_id = '')
 		{
 			// can't change passwords unless server runs as root (bad idea)
-			return( False );
+			return '';
 		}
-
 	}
-?>
