@@ -8,7 +8,7 @@
  * @license http://www.fsf.org/licenses/lgpl.html GNU Lesser General Public License
  * @package phpgwapi
  * @subpackage gui
- * @version $Id: class.Template.inc.php 17222 2006-09-25 06:28:32Z skwashd $
+ * @version $Id: class.Template.inc.php 4681 2010-01-30 17:06:35Z sigurd $
  * @internal Based on phplib
  *
  */
@@ -184,26 +184,31 @@ class Template
 	 * @access    public
 	 * @return    boolean
 	 */
-	function set_root($root, $attempt = 0)
+	function set_root($root = null, $attempt = 0)
 	{
-		if ( empty($root) )
+		if ( is_null($root) )
 		{
 			$root = PHPGW_APP_TPL;
 		}
 
-		if (!is_dir($root) && $attempt == 1 )
+		if ( !is_dir($root) )
 		{
-			$this->halt("set_root: $root is not a directory.");
-			return false;
-		}
-		elseif ( !is_dir($root) )
-		{
-			$this->set_root(substr($root, 0, (0 - strlen($GLOBALS['phpgw_info']['server']['template_set']))) . 'base', 1);
+			if ( $attempt == 1 )
+			{
+				$this->halt("set_root: $root is not a directory.");
+				return false;
+			}
+			else
+			{
+				$new_root = preg_replace("/\/{$GLOBALS['phpgw_info']['server']['template_set']}\$/", '/base', $root);
+				$this->set_root($new_root, 1);
+			}
 		}
 
 		$this->root = $root;
 
-		if ($this->debug & 4) {
+		if ($this->debug & 4)
+		{
 			echo "<p><b>set_root:</b> root = $root</p>\n";
 		}
 
@@ -417,7 +422,7 @@ class Template
 			}
 		} else {
 			reset($varname);
-			while (list($k, $v) = each($varname)) {
+			while (list(, $v) = each($varname)) {
 				if (!empty($v)) {
 					if ($this->debug & 1) {
 						printf("<b>clear_var:</b> (with array) <b>%s</b><br>\n", $v);
@@ -459,7 +464,7 @@ class Template
 			}
 		} else {
 			reset($varname);
-			while (list($k, $v) = each($varname)) {
+			while (list(, $v) = each($varname)) {
 				if (!empty($v)) {
 					if ($this->debug & 1) {
 						printf("<b>unset_var:</b> (with array) <b>%s</b><br>\n", $v);
@@ -501,6 +506,10 @@ class Template
 		reset($this->varvals);
 		while (list($k, $v) = each($this->varvals)) {
 			$varvals_quoted[$k] = preg_replace(array('/\\\\/', '/\$/'), array('\\\\\\\\', '\\\\$'), $v);
+			if(is_array($varvals_quoted[$k]))
+			{
+				$varvals_quoted[$k] = implode($varvals_quoted[$k]);
+			}
 		}
 
 		$str = $this->get_var($varname);
@@ -651,7 +660,7 @@ class Template
 			echo "<p><b>get_vars:</b> constructing array of vars...</p>\n";
 		}
 		reset($this->varkeys);
-		while (list($k, $v) = each($this->varkeys)) {
+		while (list($k, ) = each($this->varkeys)) {
 			$result[$k] = $this->get_var($k);
 		}
 		return $result;
@@ -689,7 +698,7 @@ class Template
 			return $str;
 		} else {
 			reset($varname);
-			while (list($k, $v) = each($varname)) {
+			while (list(, $v) = each($varname)) {
 				if (isset($this->varvals[$v])) {
 					$str = $this->varvals[$v];
 				} else {
@@ -736,7 +745,7 @@ class Template
 		}
 
 		reset($m);
-		while (list($k, $v) = each($m)) {
+		while (list(, $v) = each($m)) {
 			if (!isset($this->varkeys[$v])) {
 				if ($this->debug & 4) {
 					echo "<p><b>get_undefined:</b> undefined: $v</p>\n";
@@ -866,8 +875,8 @@ class Template
 			}
 			else
 			{
-				$new_root = substr($root, 0, (0 - strlen($GLOBALS['phpgw_info']['server']['template_set']))) . 'base';
-				$new_filename = $this->filename(str_replace($root.'/','',$new_filename), $new_root, 1);
+				$new_root = preg_replace("/\/templates\/{$GLOBALS['phpgw_info']['server']['template_set']}\$/", '/templates/base', $root);
+				$new_filename = $this->filename($filename, $new_root, 1);
 			}
 		}
 		return $new_filename;
