@@ -4,11 +4,11 @@
 	* @author Dan Kuykendall <seek3r@phpgroupware.org>
 	* @author Joseph Engo <jengo@phpgroupware.org>
 	* @author Mark Peters <skeeter@phpgroupware.org>
-	* @copyright Copyright (C) 2000-2005 Free Software Foundation, Inc http://www.fsf.org/
+	* @copyright Copyright (C) 2000-2008 Free Software Foundation, Inc http://www.fsf.org/
 	* @license http://www.gnu.org/licenses/lgpl.html GNU Lesser General Public License
 	* @package phpgwapi
 	* @subpackage utilities
-	* @version $Id: class.common.inc.php 18358 2007-11-27 04:43:37Z skwashd $
+	* @version $Id: class.common.inc.php 5820 2010-05-27 12:18:48Z sigurd $
 	*/
 
 	/**
@@ -83,6 +83,11 @@
 
 			for($i=1;$i<6;++$i)
 			{
+				if(!isset($regs2[$i]) && !isset($regs[$i]))
+				{
+					continue;
+				}
+
 				if($debug) { echo "<br />$i: $regs[$i] - $regs2[$i]"; }
 
 				if($regs2[$i] == $regs[$i])
@@ -140,7 +145,7 @@
 		public function getInstalledLanguages()
 		{
 			$GLOBALS['phpgw']->db->query('select distinct lang from phpgw_lang');
-			while ($GLOBALS['phpgw']->db->next_record()) 
+			while ($GLOBALS['phpgw']->db->next_record())
 			{
 				$installedLanguages[$GLOBALS['phpgw']->db->f('lang')] = $GLOBALS['phpgw']->db->f('lang');
 			}
@@ -286,10 +291,13 @@
 			if ( is_null($final_called) )
 			{
 				// call the asyncservice check_run function if it is not explicitly set to cron-only
-				if (!isset($GLOBALS['phpgw_info']['server']['asyncservice']) || !$GLOBALS['phpgw_info']['server']['asyncservice'] )
+				if ( !isset($GLOBALS['phpgw_info']['server']['asyncservice'])
+					|| !$GLOBALS['phpgw_info']['server']['asyncservice'] 
+					|| $GLOBALS['phpgw_info']['server']['asyncservice'] == 'fallback')
 				{
 					ExecMethod('phpgwapi.asyncservice.check_run', 'fallback');
 				}
+				$GLOBALS['phpgw']->session->commit_session();
 				$GLOBALS['phpgw']->db->disconnect();
 				$final_called = true;
 			}
@@ -323,20 +331,31 @@
 		* @param string $text Heading error text
 		* @return string HTML table with error messages or empty string when there is no error/s
 		*/
-		public function error_list($errors, $text='Error')
+		public function error_list($errors, $text = 'Error')
 		{
-			if (! is_array($errors))
+			if ( !is_array($errors) || !count($errors) )
 			{
 				return '';
 			}
 
-			$html_error = '<h3>' . lang($text) . "</h3>\n"
-						. "<ul class=\"errors\">\n<ul>\n<li>{$errors[0]}</li>";
-			for ($i=1; $i<count($errors); ++$i)
+			$text = lang($text);
+			$html_error = <<<HTML
+				<h3>$text</h3>
+					<ul>
+
+HTML;
+			foreach ( $errors as $error )
 			{
-				$html_error .= "<li>{$errors[$i]}</li>\n";
+				$html_error .= <<<HTML
+						<li>{$error}</li>
+
+HTML;
 			}
-			return "$html_error</ul>\n";
+			$html_error .= <<<HTML
+				</ul>
+
+HTML;
+			return $html_error;
 		}
 
 		/**
@@ -446,7 +465,7 @@
 						);
 					}
 				}
-				
+
 				$this->output['app_row_icon'][] = array
 				(
 					'layout'	=> $GLOBALS['phpgw_info']['user']['preferences']['common']['template_set'],
@@ -458,51 +477,46 @@
 			}
 		}
 
-
-
 		/**
 		* Grab the owner name
 		*
 		* @param integer $accountid Account id
+		*
 		* @return string Users fullname
 		*/
-		public function grab_owner_name($accountid = '')
+		public function grab_owner_name($accountid = null)
 		{
-			$GLOBALS['phpgw']->accounts->get_account_name($accountid,$lid,$fname,$lname);
-			return $this->display_fullname($lid,$fname,$lname);
+			return (string) $GLOBALS['phpgw']->accounts->get($accountid);
 		}
 
 		/**
 		* Create tabs
 		*
-		* @param array $tabs With ($id,$tab) pairs
+		* @param array   $tabs      With ($id,$tab) pairs
 		* @param integer $selection array key of selected tab
-		* @param boolean $lang When true use translation otherwise use given label
-		* @return string HTML output string
+		* @param boolean $lang      Translate label?
+		*
+		* @return string html snippet for creating tabs in a modern browser
 		*/
 		public function create_tabs($tabs, $selection, $lang = false)
 		{
+			phpgw::import_class('phpgwapi.yui');
+			if ( $lang )
+			{
+				foreach ( $tabs as &$tab )
+				{
+					$tab = lang($tab);
+				}
+			}
+
+			$html = phpgwapi_yui::tabview_generate($tabs, $selection);
 			$output = <<<HTML
 			<div class="yui-navset">
-				<ul class="yui-nav">
-
-HTML;
-			foreach($tabs as $id => $tab)
-			{
-				$selected = $id == $selection ? ' class="selected"' : '';
-				$label = $lang ? lang($tab['label']) : $tab['label'];
-				$output .= <<<HTML
-					<li{$selected}><a href="{$tab['link']}"><em>{$label}</em></a></li>
-
-HTML;
-			}
-			$output .= <<<HTML
-				</ul>
+				{$html}
 			</div>
 
 HTML;
 			return $output;
-
 		}
 
 		/**
@@ -555,10 +569,10 @@ HTML;
 			{
 				$appname = 'phpgwapi';
 			}
- 
+
 			$incdir         = PHPGW_INCLUDE_ROOT . '/' . $appname . '/inc';
 			$incdir_default = PHPGW_SERVER_ROOT . '/' . $appname . '/inc';
- 
+
 			if (@is_dir ($incdir))
 			{
 				return $incdir;
@@ -576,7 +590,7 @@ HTML;
 		/**
 		* List themes available
 		*
-		* Themes can either be css files like in HEAD (if the template has a css-directory) or ordinary .14 themes-files
+		* Themes are CSS files stored under the template directory
 		* @return array List with available themes
 		*/
 		public static function list_themes()
@@ -617,26 +631,24 @@ HTML;
 
 			$list = array();
 
-			$d = dir(PHPGW_SERVER_ROOT . '/phpgwapi/templates');
-			while ($entry=$d->read())
+			$dirname = PHPGW_SERVER_ROOT . '/phpgwapi/templates';
+
+			$dir = new DirectoryIterator($dirname);
+			foreach ( $dir as $file )
 			{
-				if ( !in_array($entry, $ignore_list)
-					&& is_dir(PHPGW_SERVER_ROOT . "/phpgwapi/templates/{$entry}"))
+				$entry = (string) $file;
+				if ( !in_array($entry, $ignore_list) && $file->isDir() )
 				{
-					$list[$entry]['name'] = $entry;
-					$f = PHPGW_SERVER_ROOT . "/phpgwapi/templates/{$entry}/details.inc.php";
-					if (file_exists ($f))
+					$list[$entry]['title'] = $entry;
+
+					$f = "{$dirname}/{$entry}/details.inc.php";
+					if ( file_exists($f) )
 					{
-						include($f);
-						$list[$entry]['title'] = "Use {$GLOBALS['phpgw_info']['template'][$entry]['title']}interface";
-					}
-					else
-					{
-						$list[$entry]['title'] = $entry;
+						require_once $f;
+						$list[$entry]['title'] = lang ('Use %s interface', $GLOBALS['phpgw_info']['template'][$entry]['title']);
 					}
 				}
 			}
-			$d->close();
 			ksort($list);
 			return $list;
 		}
@@ -857,7 +869,7 @@ HTML;
 		/**
 		* Find an individual image
 		*
-		* @param string $module the module the image is for
+		* @param string $module the module the image is from
 		* @param string $image the image to search for
 		* @param string $ext the filename extension of the image - should usually be an empty string
 		* @param bool $use_lang use a translated verison of the image
@@ -886,7 +898,7 @@ HTML;
 
 			foreach ( $image as $img )
 			{
-				$image_found = self::find_image($module, $img.$ext); 
+				$image_found = self::find_image($module, $img.$ext);
 				if ( $image_found )
 				{
 					return $image_found;
@@ -910,7 +922,7 @@ HTML;
 			{
 				return $with_extension;
 			}
-			
+
 			$without_extension = $this->image($appname,$image);
 			if ( $without_extension )
 			{
@@ -920,98 +932,6 @@ HTML;
 			return '';
 		}
 
-		function navbar()
-		{
-			$GLOBALS['phpgw_info']['navbar']['home']['title'] = 'Home';
-			$GLOBALS['phpgw_info']['navbar']['home']['url']   = $GLOBALS['phpgw']->link('/home.php');
-			$GLOBALS['phpgw_info']['navbar']['home']['icon']  = $this->image('phpgwapi',Array('home','nonav'));
-			$GLOBALS['phpgw_info']['navbar']['home']['icon_hover']  = $this->image_on('phpgwapi',Array('home','nonav'),'-over');
-
-			list($first) = each($GLOBALS['phpgw_info']['user']['apps']);
-			if ( isset($GLOBALS['phpgw_info']['user']['apps']['admin'])
-				&& is_array($GLOBALS['phpgw_info']['user']['apps']['admin']) 
-				&& $first != 'admin')
-			{
-				$newarray['admin'] = $GLOBALS['phpgw_info']['user']['apps']['admin'];
-				foreach($GLOBALS['phpgw_info']['user']['apps'] as $index => $value)
-				{
-					if($index != 'admin')
-					{
-						$newarray[$index] = $value;
-					}
-				}
-				$GLOBALS['phpgw_info']['user']['apps'] = $newarray;
-				reset($GLOBALS['phpgw_info']['user']['apps']);
-			}
-			unset($index);
-			unset($value);
-			unset($newarray);
-			
-			foreach($GLOBALS['phpgw_info']['user']['apps'] as $app => $data)
-			{
-				if (is_long($app))
-				{
-					continue;
-				}
-
-				if ($app == 'preferences' || $GLOBALS['phpgw_info']['apps'][$app]['status'] != 2 && $GLOBALS['phpgw_info']['apps'][$app]['status'] != 3)
-				{
-					$GLOBALS['phpgw_info']['navbar'][$app]['title'] = $GLOBALS['phpgw_info']['apps'][$app]['title'];
-					$GLOBALS['phpgw_info']['navbar'][$app]['url']   = $GLOBALS['phpgw']->link('/' . $app . '/index.php');
-					$GLOBALS['phpgw_info']['navbar'][$app]['name']  = $app;
-
-					if ($app != $GLOBALS['phpgw_info']['flags']['currentapp'])
-					{
-						$GLOBALS['phpgw_info']['navbar'][$app]['icon']  = $this->image($app,Array('navbar','nonav'));
-						$GLOBALS['phpgw_info']['navbar'][$app]['icon_hover']  = $this->image_on($app,Array('navbar','nonav'),'-over');
-					}
-					else
-					{
-						$GLOBALS['phpgw_info']['navbar'][$app]['icon']  = $this->image_on($app,Array('navbar','nonav'),'-over');
-						$GLOBALS['phpgw_info']['navbar'][$app]['icon_hover']  = $this->image($app,Array('navbar','nonav'));
-					}
-
-					if($GLOBALS['phpgw_info']['navbar'][$app]['icon'] == '')
-					{
-						$GLOBALS['phpgw_info']['navbar'][$app]['icon']  = $this->image('phpgwapi','nonav');
-					}
-				}
-			}
-			if ($GLOBALS['phpgw_info']['flags']['currentapp'] == 'home' || $GLOBALS['phpgw_info']['flags']['currentapp'] == 'preferences' || $GLOBALS['phpgw_info']['flags']['currentapp'] == 'about')
-			{
-				$app = $app_title = 'phpGroupWare';
-			}
-			else
-			{
-				$app = $GLOBALS['phpgw_info']['flags']['currentapp'];
-				$app_title = lang($app);
-			}
-
-			if (isset($GLOBALS['phpgw_info']['user']['apps']['preferences']) 
-				&& $GLOBALS['phpgw_info']['user']['apps']['preferences'])	// preferences last
-			{
-				$prefs = $GLOBALS['phpgw_info']['navbar']['preferences'];
-				unset($GLOBALS['phpgw_info']['navbar']['preferences']);
-				$GLOBALS['phpgw_info']['navbar']['preferences'] = $prefs;
-			}
-
-			// We handle this here becuase its special
-			if(isset($GLOBALS['phpgw_info']['navbar']['manual']))
-			{
-				$GLOBALS['phpgw_info']['navbar']['manual']['url']   = "javascript:openwindow('" . $GLOBALS['phpgw']->link('/index.php', array('menuaction'=> 'manual.uimanual.help', 'app' => isset($GLOBALS['phpgw_info']['apps']['manual']['app']) && $GLOBALS['phpgw_info']['apps']['manual']['app'] ? $GLOBALS['phpgw_info']['apps']['manual']['app'] : $app, 'section' => isset($GLOBALS['phpgw_info']['apps']['manual']['section'])?$GLOBALS['phpgw_info']['apps']['manual']['section']:'')) . "','700','600')";
-			}
-
-			$GLOBALS['phpgw_info']['navbar']['about']['title'] = lang('About %1', $app_title);
-			$GLOBALS['phpgw_info']['navbar']['about']['url']   = $GLOBALS['phpgw']->link('/about.php', array('app' => $app) );
-			$GLOBALS['phpgw_info']['navbar']['about']['icon']  = $this->image('phpgwapi',Array('about','nonav'));
-			$GLOBALS['phpgw_info']['navbar']['about']['icon_hover']  = $this->image_on('phpgwapi',Array('about','nonav'),'-over');
-
-			$GLOBALS['phpgw_info']['navbar']['logout']['title'] = 'Logout';
-			$GLOBALS['phpgw_info']['navbar']['logout']['url']   = $GLOBALS['phpgw']->link('/logout.php');
-			$GLOBALS['phpgw_info']['navbar']['logout']['icon']  = $this->image('phpgwapi',Array('logout','nonav'));
-			$GLOBALS['phpgw_info']['navbar']['logout']['icon_hover']  = $this->image_on('phpgwapi',Array('logout','nonav'),'-over');
-		}
-
 		/**
 		* Load header.inc.php for an application
 		*/
@@ -1019,7 +939,7 @@ HTML;
 		{
 			if (file_exists(PHPGW_APP_INC . '/header.inc.php'))
 			{
-				include(PHPGW_APP_INC . '/header.inc.php');
+				require_once PHPGW_APP_INC . '/header.inc.php';
 			}
 		}
 
@@ -1028,9 +948,23 @@ HTML;
 		*/
 		public function phpgw_header($navbar = False)
 		{
-			include(PHPGW_INCLUDE_ROOT . '/phpgwapi/templates/' . $GLOBALS['phpgw_info']['server']['template_set'] . '/head.inc.php');
-			$this->navbar(False);
-			include(PHPGW_INCLUDE_ROOT . '/phpgwapi/templates/' . $GLOBALS['phpgw_info']['server']['template_set'] . '/navbar.inc.php');
+			// this prevents infinite loops caused by bad code - skwashd jan08
+			static $called = false;
+			if ( $called )
+			{
+				return;
+			}
+			$called = true;
+
+			$tpl_name = $GLOBALS['phpgw_info']['server']['template_set'];
+			if ( !is_dir(PHPGW_INCLUDE_ROOT . "/phpgwapi/templates/{$tpl_name}/")
+				|| !is_readable(PHPGW_INCLUDE_ROOT . "/phpgwapi/templates/{$tpl_name}/head.inc.php") )
+			{
+				$tpl_name = 'simple';
+			}
+
+			require_once PHPGW_INCLUDE_ROOT . "/phpgwapi/templates/{$tpl_name}/head.inc.php";
+			require_once PHPGW_INCLUDE_ROOT . "/phpgwapi/templates/{$tpl_name}/navbar.inc.php";
 			if ($navbar)
 			{
 				echo parse_navbar();
@@ -1059,10 +993,10 @@ HTML;
 					$GLOBALS['phpgw']->xslttpl->pparse();
 				}
 
-				if ( !isset($GLOBALS['phpgw_info']['flags']['nofooter']) 
+				if ( !isset($GLOBALS['phpgw_info']['flags']['nofooter'])
 					|| !$GLOBALS['phpgw_info']['flags']['nofooter'] )
 				{
-					include(PHPGW_API_INC . '/footer.inc.php');
+					require_once PHPGW_API_INC . '/footer.inc.php';
 				}
 			}
 		}
@@ -1096,7 +1030,7 @@ HTML;
 			{
 				list($app,$class,$method) = explode('.',$GLOBALS['phpgw_info']['menuaction']);
 				if ( isset($GLOBALS[$class]->public_functions)
-					&& is_array($GLOBALS[$class]->public_functions) 
+					&& is_array($GLOBALS[$class]->public_functions)
 					&& isset($GLOBALS[$class]->public_functions['css']) )
 				{
 					$app_css .= $GLOBALS[$class]->css();
@@ -1107,7 +1041,7 @@ HTML;
 			{
 				$app_css .= $GLOBALS['phpgw_info']['flags']['css'] . "\n";
 			}
-			
+
 			$all_css .= "\n<!-- NOTE: This will not be supported in the future -->\n\t\t<style type=\"text/css\">\n\t\t{$app_css}\n\t\t</style>\n";
 			return $all_css;
 		}
@@ -1120,12 +1054,12 @@ HTML;
 		{
 			return $this->get_javascript();
 		}
-		
+
 		/**
 		* Include JavaScript in template header
 		*
 		* The method is included here to make it easier to change the js support
-		* in phpgw. One change then all templates will support it (as long as they 
+		* in phpgw. One change then all templates will support it (as long as they
 		* include a call to this method).
 		*
 		* @author Dave Hall skwashd at phpgroupware.org
@@ -1138,26 +1072,38 @@ HTML;
 			{
 				$js .= $GLOBALS['phpgw']->js->get_script_links();
 			}
-			
+			if( isset($GLOBALS['phpgw']->yuical) && is_object($GLOBALS['phpgw']->yuical))
+			{
+				if($cal_script = $GLOBALS['phpgw']->yuical->get_script())
+				{
+					$GLOBALS['phpgw_info']['flags']['java_script'] .= "\n"
+						. '<script type="text/javascript">' ."\n"
+						. '//<[CDATA[' ."\n"
+						. $cal_script ."\n"
+						. '//]]' ."\n"
+						. "</script>\n";
+				}
+			}
+
 			if ( isset($GLOBALS['phpgw_info']['menuaction']) )
 			{
 				list($app, $class, $method) = explode('.',$GLOBALS['phpgw_info']['menuaction']);
-				if ( isset($GLOBALS[$class]->public_functions) 
-					&& is_array($GLOBALS[$class]->public_functions) 
+				if ( isset($GLOBALS[$class]->public_functions)
+					&& is_array($GLOBALS[$class]->public_functions)
 					&& isset($GLOBALS[$class]->public_functions['java_script'])
 					&& $GLOBALS[$class]->public_functions['java_script'] )
 				{
 					$js .= $GLOBALS[$class]->java_script();
 				}
 			}
-			
+
 			if (isset($GLOBALS['phpgw_info']['flags']['java_script']))
 			{
 				$js .= $GLOBALS['phpgw_info']['flags']['java_script'] . "\n";
 			}
 			return $js;
 		}
-		
+
 		/**
 		* Get window.on* events from javascript class
 		*
@@ -1182,7 +1128,7 @@ HTML;
 		* @param string $data hexidecimal data as a string
 		* @return string binary value of $data;
 		*/
-		public function hex2bin($data)
+		public static function hex2bin($data)
 		{
 			$len = strlen($data);
 			return pack('H' . $len, $data);
@@ -1209,58 +1155,6 @@ HTML;
 			return $GLOBALS['phpgw']->crypto->decrypt($data);
 		}
 
-		/**
-		* DES encrypt a password
-		*
-		* @param string $userpass User password
-		* @param string $random Random seed
-		* @return string DES encrypted password
-		*/
-		public function des_cryptpasswd($userpass, $random)
-		{
-			$lcrypt = '{crypt}';
-			$password = crypt($userpass, $random);
-			$ldappassword = sprintf('%s%s', $lcrypt, $password);
-			return $ldappassword;
-		}
-
-		/**
-		* MD5 encrypt password
-		*
-		* @author fechner at ponton dot de (source http://au3.php.net/manual/en/function.ldap-modify.php)
-		* @internal as there is really only 1 way to do this, it isn't copyrightable :)
-		* @param string $userpass User password
-		* @param string $random Random seed
-		* @return string MD5 encrypted password
-		*/ 
-		public function md5_cryptpasswd($userpass)
-		{
-			return '{md5}' . base64_encode(pack('H*', md5($userpass)));
-		}
-
-		/**
-		* Encrypt password based on encryption type set in setup
-		*
-		* @param string $password Password to encrypt
-		* @return Encrypted password or false
-		*/
-		public function encrypt_password($password)
-		{
-			if (strtolower($GLOBALS['phpgw_info']['server']['ldap_encryption_type']) == 'des')
-			{
-				$salt       = $this->randomstring(2);
-				$e_password = $this->des_cryptpasswd($password, $salt);
-				
-				return $e_password;
-			}
-			elseif (strtolower($GLOBALS['phpgw_info']['server']['ldap_encryption_type']) == 'md5')
-			{
-				return $this->md5_cryptpasswd($password);
-			}
-			
-			return false;
-		}
-
 		/**
 		* Find the current position of the application in the users portal_order preference
 		*
@@ -1312,12 +1206,13 @@ HTML;
 		{
 			if (!$t || (substr(php_uname(), 0, 7) == "Windows" && intval($t) <= 0))
 			{
-				$t = phpgwapi_datetime::gmtnow();
+				return ''; // return nothing if not valid input
+//				$t = phpgwapi_datetime::gmtnow();
 			}
 
 			//  + (date('I') == 1?3600:0)
 			$t += phpgwapi_datetime::user_timezone();
-			
+
 			if (! $format)
 			{
 				$format = $GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat'] . ' - ';
@@ -1360,7 +1255,7 @@ HTML;
 			{
 				return (implode(' ',$dlarr));
 			}
-		} 
+		}
 
 		/**
 		* Format the time takes settings from user preferences
@@ -1433,32 +1328,32 @@ HTML;
 				case 32:	$s .= lang('Group has been deleted');	break;
 				case 33:	$s .= lang('Group has been updated');	break;
 				case 34:	$s .= lang('Account has been deleted') . '<p>'
-						. lang('Error deleting %1 %2 directory',lang('users'),' '.lang('private').' ') 
+						. lang('Error deleting %1 %2 directory',lang('users'),' '.lang('private').' ')
 						. ',<br />' . lang('Please %1 by hand',lang('delete')) . '<br /><br />'
 						. lang('To correct this error for the future you will need to properly set the')
 						. '<br />' . lang('permissions to the files/users directory')
 						. '<br />' . lang('On *nix systems please type: %1','chmod 770 '
-						. $GLOBALS['phpgw_info']['server']['files_dir'] . '/users/'); 
+						. $GLOBALS['phpgw_info']['server']['files_dir'] . '/users/');
 					break;
 				case 35:	$s .= lang('Account has been updated') . '<p>'
 						. lang('Error renaming %1 %2 directory',lang('users'),
-						' '.lang('private').' ') 
+						' '.lang('private').' ')
 						. ',<br />' . lang('Please %1 by hand',
 						lang('rename')) . '<br /><br />'
 						. lang('To correct this error for the future you will need to properly set the')
 						. '<br>' . lang('permissions to the files/users directory')
 						. '<br>' . lang('On *nix systems please type: %1','chmod 770 '
-						. $GLOBALS['phpgw_info']['server']['files_dir'] . '/users/'); 
+						. $GLOBALS['phpgw_info']['server']['files_dir'] . '/users/');
 					break;
 				case 36:	$s .= lang('Account has been created') . '<p>'
 						. lang('Error creating %1 %2 directory',lang('users'),
-						' '.lang('private').' ') 
+						' '.lang('private').' ')
 						. ',<br />' . lang('Please %1 by hand',
 						lang('create')) . '<br /><br />'
 						. lang('To correct this error for the future you will need to properly set the')
 						. '<br />' . lang('permissions to the files/users directory')
 						. '<br />' . lang('On *nix systems please type: %1','chmod 770 '
-						. $GLOBALS['phpgw_info']['server']['files_dir'] . '/users/'); 
+						. $GLOBALS['phpgw_info']['server']['files_dir'] . '/users/');
 					break;
 				case 37:	$s .= lang('Group has been added') . '<p>'
 						. lang('Error creating %1 %2 directory',lang('groups'),' ')
@@ -1467,7 +1362,7 @@ HTML;
 						. lang('To correct this error for the future you will need to properly set the')
 						. '<br />' . lang('permissions to the files/users directory')
 						. '<br />' . lang('On *nix systems please type: %1','chmod 770 '
-						. $GLOBALS['phpgw_info']['server']['files_dir'] . '/groups/'); 
+						. $GLOBALS['phpgw_info']['server']['files_dir'] . '/groups/');
 					break;
 				case 38:	$s .= lang('Group has been deleted') . '<p>'
 						. lang('Error deleting %1 %2 directory',lang('groups'),' ')
@@ -1476,7 +1371,7 @@ HTML;
 						. lang('To correct this error for the future you will need to properly set the')
 						. '<br />' . lang('permissions to the files/users directory')
 						. '<br />' . lang('On *nix systems please type: %1','chmod 770 '
-						. $GLOBALS['phpgw_info']['server']['files_dir'] . '/groups/'); 
+						. $GLOBALS['phpgw_info']['server']['files_dir'] . '/groups/');
 					break;
 				case 39:	$s .= lang('Group has been updated') . '<p>'
 						. lang('Error renaming %1 %2 directory',lang('groups'),' ')
@@ -1485,7 +1380,7 @@ HTML;
 						. lang('To correct this error for the future you will need to properly set the')
 						. '<br />' . lang('permissions to the files/users directory')
 						. '<br />' . lang('On *nix systems please type: %1','chmod 770 '
-						. $GLOBALS['phpgw_info']['server']['files_dir'] . '/groups/'); 
+						. $GLOBALS['phpgw_info']['server']['files_dir'] . '/groups/');
 					break;
 				case 40: $s .= lang('You have not entered a title').'.';
 					break;
@@ -1503,11 +1398,11 @@ HTML;
 		/**
 		* Process error message
 		*
-		* @param string $error Error message 
+		* @param string $error Error message
 		* @param integer $line Line number of error
 		* @param string $file Filename in which the error occured
 		*/
-		public function phpgw_error($error,$line = '', $file = '') 
+		public function phpgw_error($error,$line = '', $file = '')
 		{
 			echo '<p><strong>phpGroupWare internal error:</strong><p>'.$error;
 			if ($line)
@@ -1592,36 +1487,33 @@ HTML;
 			}
 
 			$GLOBALS['phpgw']->db->query("SELECT id FROM phpgw_nextid WHERE appname='".$appname."'",__LINE__,__FILE__);
-			while( $GLOBALS['phpgw']->db->next_record() )
+			if ( $GLOBALS['phpgw']->db->next_record() )
 			{
 				$id = $GLOBALS['phpgw']->db->f('id');
 			}
 
-			if (empty($id) || !$id)
+			if ( empty($id) )
 			{
-				if($min)
+				$id = 1;
+				if ( $min )
 				{
 					$id = $min;
 				}
-				else
-				{
-					$id = 1;
-				}
-				$GLOBALS['phpgw']->db->query("INSERT INTO phpgw_nextid (appname,id) VALUES ('".$appname."',".$id.")",__LINE__,__FILE__);
+
+				$GLOBALS['phpgw']->db->query("INSERT INTO phpgw_nextid (appname,id) VALUES ('{$appname}', {$id})", __LINE__, __FILE__);
+				return $id;
 			}
-			elseif($id<$min)
+			else if ( $id < $min )
 			{
 				$id = $min;
-				$GLOBALS['phpgw']->db->query("UPDATE phpgw_nextid SET id=".$id." WHERE appname='".$appname."'",__LINE__,__FILE__);
+				$GLOBALS['phpgw']->db->query("UPDATE phpgw_nextid SET id = {$id} WHERE appname='{$appname}'", __LINE__, __FILE__);
+				return $id;
 			}
-			elseif ($max && ($id > $max))
+			else if ( $max && ($id > $max) )
 			{
-				return False;
-			}
-			else
-			{
-				return intval($id);
+				return 0;
 			}
+			return (int) $id;
 		}
 
 		/**
@@ -1637,7 +1529,7 @@ HTML;
 		}
 
 		/**
-		* Stops capturing all output and uses it in the XSLT temaplte engine by stuffing it 
+		* Stops capturing all output and uses it in the XSLT temaplte engine by stuffing it
 		* into an xml node called "body_data"
 		*
 		* @internal Note: need to be run BEFORE exit is called, as buffers get flushed automatically before
@@ -1677,7 +1569,10 @@ HTML;
 				return;
 			}
 
-			$GLOBALS['phpgw']->xslttpl->add_file($this->get_tpl_dir('phpgwapi','base') . SEP . 'msgbox');
+			if(!isset($GLOBALS['phpgw']->xslttpl->xslfiles['msgbox']))
+			{
+				$GLOBALS['phpgw']->xslttpl->add_file($this->get_tpl_dir('phpgwapi','base') . '/msgbox');
+			}
 
 		//	$prev_helper = $GLOBALS['phpgw']->translation->translator_helper;
 		//	$GLOBALS['phpgw']->translation->translator_helper = '';
@@ -1691,19 +1586,22 @@ HTML;
 					{
 						$img	= $this->image('phpgwapi','msgbox_good');
 						$alt	= lang('OK');
+						$class  = 'msg_good';
 					}
 					else
 					{
 						$img	= $this->image('phpgwapi','msgbox_bad');
 						$alt	= lang('ERROR');
+						$class  = 'error';
 					}
 
 					$data[] = array
 					(
-						'msgbox_text'				=> lang($key),
+						'msgbox_text'				=> $key,
 						'msgbox_img'				=> $img,
 						'msgbox_img_alt'			=> $alt,
-						'lang_msgbox_statustext'	=> $alt
+						'lang_msgbox_statustext'	=> $alt,
+						'msgbox_class'				=> $class
 					);
 				}
 			}
@@ -1748,31 +1646,37 @@ HTML;
 		* @param array $data
 		* @returns array for use with msgbox
 		*/
-		
+
 		public function msgbox_data($receipt)
 		{
-			$msgbox_data_error=array();
-			if (isSet($receipt['error']) AND is_array($receipt['error']))
+			$msgbox_data_error	 = array();
+			$msgbox_data_message = array();
+			if (isset($receipt['error']) && is_array($receipt['error']))
 			{
-				foreach($receipt['error'] as $errors)
+				foreach($receipt['error'] as $dummy => $error)
 				{
-					$msgbox_data_error += array($errors['msg']=> False);
+					$msgbox_data_error[$error['msg']] = false;
 				}
 			}
-
-			$msgbox_data_message=array();
-
-			if (isSet($receipt['message']) AND is_array($receipt['message']))
+			else if(isset($receipt['error']))
 			{
-				foreach($receipt['message'] as $messages)
-				{
-					$msgbox_data_message += array($messages['msg']=> True);
-				}
+				$msgbox_data_error[$receipt['error']] = false;			
 			}
 
-			$msgbox_data = $msgbox_data_error + $msgbox_data_message;
+			if (isset($receipt['message']) && is_array($receipt['message']))
+			{
+				foreach($receipt['message'] as $dummy => $message)
+				{
+					$msgbox_data_message[$message['msg']] = true;
+				}
+			}
+			else if(isset($receipt['message']))
+			{
+				$msgbox_data_message[$receipt['message']] = true;			
+			}
+
+			$msgbox_data = array_merge($msgbox_data_error, $msgbox_data_message);
 
 			return $msgbox_data;
 		}
 	}
-?>
