@@ -6,17 +6,18 @@
 	* @license http://www.gnu.org/licenses/lgpl.html GNU Lesser General Public License
 	* @package phpgwapi
 	* @subpackage contacts
-	* @version $Id: class.contact_accounts.inc.php 15562 2004-12-30 06:47:35Z skwashd $
+	* @version $Id: class.contact_accounts.inc.php 1040 2008-05-26 10:27:54Z dave $
 	*/
 
 	/**
 	* Use SQL criteria
 	*/
-	include_once(PHPGW_API_INC . '/class.sql_criteria.inc.php');
+	phpgw::import_class('phpgwapi.sql_criteria');
+
 	/**
 	* Use SQL entity
 	*/
-	include_once(PHPGW_API_INC . '/class.sql_entity.inc.php');
+	phpgw::import_class('phpgwapi.sql_entity');
 
 	/**
 	* Query statements for "account" table
@@ -24,7 +25,7 @@
 	* @package phpgwapi
 	* @subpackage contacts
 	*/
-	class contact_accounts extends sql_entity
+	class contact_accounts extends phpgwapi_sql_entity
 	{
 		var $map = array('account_id'		=> array('select'	=> '',
 								 'criteria' 	=> '',
@@ -67,7 +68,7 @@
 
 		function criteria_person_only($element)
 		{
-			$this->_add_criteria($this->put_alias(sql_criteria::not_null($this->real_field('account_person_id'))));
+			$this->_add_criteria($this->put_alias(phpgwapi_sql_criteria::not_null($this->real_field('account_person_id'))));
 		}
 
 		function criteria_account_person_id($element)
@@ -80,4 +81,3 @@
 			$this->add_field('is_user', 'count('.$this->real_field('account_id').')');
 		}
 	}
-?>
\ No newline at end of file
