@@ -6,17 +6,18 @@
 	* @license http://www.gnu.org/licenses/lgpl.html GNU Lesser General Public License
 	* @package phpgwapi
 	* @subpackage contacts
-	* @version $Id: class.contact_addr_type.inc.php 17062 2006-09-03 06:15:27Z skwashd $
+	* @version $Id: class.contact_addr_type.inc.php 1040 2008-05-26 10:27:54Z dave $
 	*/
 
 	/**
 	* Use SQL criteria
 	*/
-	include_once(PHPGW_API_INC . '/class.sql_criteria.inc.php');
+	phpgw::import_class('phpgwapi.sql_criteria');
+
 	/**
 	* Use SQL entity
 	*/
-	include_once(PHPGW_API_INC . '/class.sql_entity.inc.php');
+	phpgw::import_class('phpgwapi.sql_entity');
 
 	/**
 	* Query statements for "addr_type" table
@@ -24,7 +25,7 @@
 	* @package phpgwapi
 	* @subpackage contacts
 	*/
-		class contact_addr_type extends sql_entity
+		class contact_addr_type extends phpgwapi_sql_entity
 		{
 				var $map = array('addr_type_id'         => array('select'       => '',
 																 'criteria'     => '',
@@ -62,12 +63,11 @@
 			$field = $this->put_alias($element['real_field']);
 			if(is_array($element['value']))
 			{
-				$this->_add_criteria(sql_criteria::in($field, $element['value']));
+				$this->_add_criteria(phpgwapi_sql_criteria::in($field, $element['value']));
 			}
 			else
 			{
-				$this->_add_criteria(sql_criteria::equal($field, $element['value']));
+				$this->_add_criteria(phpgwapi_sql_criteria::equal($field, $element['value']));
 			}
 		}
 	}
-?>
