@@ -6,17 +6,18 @@
 	* @license http://www.gnu.org/licenses/lgpl.html GNU Lesser General Public License
 	* @package phpgwapi
 	* @subpackage contacts
-	* @version $Id: class.contact_central.inc.php 17062 2006-09-03 06:15:27Z skwashd $
+	* @version $Id: class.contact_central.inc.php 1040 2008-05-26 10:27:54Z dave $
 	*/
 
 	/**
 	* Use SQL criteria
 	*/
-	include_once(PHPGW_API_INC . '/class.sql_criteria.inc.php');
+	phpgw::import_class('phpgwapi.sql_criteria');
+
 	/**
 	* Use SQL entity
 	*/
-	include_once(PHPGW_API_INC . '/class.sql_entity.inc.php');
+	phpgw::import_class('phpgwapi.sql_entity');
 
 	/**
 	* Query statements for "central" table
@@ -24,7 +25,7 @@
 	* @package phpgwapi
 	* @subpackage contacts
 	*/
-	class contact_central extends sql_entity
+	class contact_central extends phpgwapi_sql_entity
 	{
 		var $map = array('contact_id'	=> array('select'	=> '',
 							 'criteria' 	=> '',
@@ -164,17 +165,16 @@
 			{
 				foreach($element['value'] as $value)
 				{
-					$data[] = sql_criteria::or_(sql_criteria::equal($field, sql::string($value)),
-									sql_criteria::has($field, ',' . $value . ','));
+					$data[] = phpgwapi_sql_criteria::or_(phpgwapi_sql_criteria::equal($field, sql::string($value)),
+									phpgwapi_sql_criteria::has($field, ',' . $value . ','));
 				}
 				
-				$criteria = sql_criteria::append_or($data);
+				$criteria = phpgwapi_sql_criteria::append_or($data);
 				$this->_add_criteria($criteria);
 			}
 			else
 			{
-				$this->_add_criteria(sql_criteria::equal($field, sql::string($element['value'])));
+				$this->_add_criteria(phpgwapi_sql_criteria::equal($field, phpgwapi_sql::string($element['value'])));
 			}
 		}
 	}
-?>
\ No newline at end of file
