@@ -6,17 +6,18 @@
 	* @license http://www.gnu.org/licenses/lgpl.html GNU Lesser General Public License
 	* @package phpgwapi
 	* @subpackage contacts
-	* @version $Id: class.contact_comm_descr.inc.php 15562 2004-12-30 06:47:35Z skwashd $
+	* @version $Id: class.contact_comm_descr.inc.php 3619 2009-09-20 19:28:19Z sigurd $
 	*/
 
 	/**
 	* Use SQL criteria
 	*/
-	include_once(PHPGW_API_INC . '/class.sql_criteria.inc.php');
+	phpgw::import_class('phpgwapi.sql_criteria');
+
 	/**
 	* Use SQL entity
 	*/
-	include_once(PHPGW_API_INC . '/class.sql_entity.inc.php');
+	phpgw::import_class('phpgwapi.sql_entity');
 
 	/**
 	* Query statements for "comm_descr" table
@@ -24,7 +25,7 @@
 	* @package phpgwapi
 	* @subpackage contacts
 	*/
-	class contact_comm_descr extends sql_entity
+	class contact_comm_descr extends phpgwapi_sql_entity
 	{
 		var $map = array('comm_descr_id'	=> array('select'	=> '',
 								 'criteria' 	=> '',
@@ -84,11 +85,10 @@
 			
 			foreach($element['value'] as $value)
 			{
-				$data[] = sql_criteria::equal($field, sql::string($value));
+				$data[] = phpgwapi_sql_criteria::equal($field, phpgwapi_sql::string($value));
 			}
 
-			$criteria = sql_criteria::append_or($data);
+			$criteria = phpgwapi_sql_criteria::append_or($data);
 			$this->_add_criteria($criteria);
 		}
 	}
-?>
\ No newline at end of file
