@@ -6,17 +6,18 @@
 	* @license http://www.gnu.org/licenses/lgpl.html GNU Lesser General Public License
 	* @package phpgwapi
 	* @subpackage contacts
-	* @version $Id: class.contact_others.inc.php 15562 2004-12-30 06:47:35Z skwashd $
+	* @version $Id: class.contact_others.inc.php 1040 2008-05-26 10:27:54Z dave $
 	*/
 
 	/**
 	* Use SQL criteria
 	*/
-	include_once(PHPGW_API_INC . '/class.sql_criteria.inc.php');
+	phpgw::import_class('phpgwapi.sql_criteria');
+
 	/**
 	* Use SQL entity
 	*/
-	include_once(PHPGW_API_INC . '/class.sql_entity.inc.php');
+	phpgw::import_class('phpgwapi.sql_entity');
 
 	/**
 	* Query statements for "others" table
@@ -24,7 +25,7 @@
 	* @package phpgwapi
 	* @subpackage contacts
 	*/
-	class contact_others extends sql_entity
+	class contact_others extends phpgwapi_sql_entity
 	{
 		var $map = array('key_other_id'		=> array('select'	=> '',
 								 'criteria' 	=> '',
@@ -129,12 +130,11 @@
 			$field = $this->put_alias($element['real_field']);
 			if(is_array($element['value']))
 			{
-				$this->_add_criteria(sql_criteria::in($field, $element['value']));
+				$this->_add_criteria(phpgwapi_sql_criteria::in($field, $element['value']));
 			}
 			else
 			{
-				$this->_add_criteria(sql_criteria::equal($field, $element['value']));
+				$this->_add_criteria(phpgwapi_sql_criteria::equal($field, $element['value']));
 			}
 		}
 	}
-?>
