@@ -6,17 +6,18 @@
 	* @license http://www.gnu.org/licenses/lgpl.html GNU Lesser General Public License
 	* @package phpgwapi
 	* @subpackage contacts
-	* @version $Id: class.contact_person.inc.php 15562 2004-12-30 06:47:35Z skwashd $
+	* @version $Id: class.contact_person.inc.php 2428 2009-02-22 20:52:15Z sigurd $
 	*/
 
 	/**
 	* Use SQL criteria
 	*/
-	include_once(PHPGW_API_INC . '/class.sql_criteria.inc.php');
+	phpgw::import_class('phpgwapi.sql_criteria');
+
 	/**
 	* Use SQL entity
 	*/
-	include_once(PHPGW_API_INC . '/class.sql_entity.inc.php');
+	phpgw::import_class('phpgwapi.sql_entity');
 
 	/**
 	* Query statements for "person" table
@@ -24,7 +25,7 @@
 	* @package phpgwapi
 	* @subpackage contacts
 	*/
-	class contact_person extends sql_entity
+	class contact_person extends phpgwapi_sql_entity
 	{
 		var $map = array('person_id'		=> array('select'	=> '',
 								 'criteria' 	=> '',
@@ -320,11 +321,10 @@
 
 		function full_name()
 		{
-
-			$this->add_field('per_full_name', sql::concat_null(array($this->real_field('per_first_name'), sql::string(' '),
-										 $this->real_field('per_middle_name'), sql::string(' '),
-										 $this->real_field('per_last_name'))));
+			$this->add_field('per_full_name', phpgwapi_sql::concat_null(array($this->real_field('per_prefix'), phpgwapi_sql::string(' '),
+										 $this->real_field('per_first_name'), phpgwapi_sql::string(' '),
+										 $this->real_field('per_middle_name'), phpgwapi_sql::string(' '),
+										 $this->real_field('per_last_name'), phpgwapi_sql::string(' '),
+										 $this->real_field('per_suffix'))));
 		}
-
 	}
-?>
