@@ -9,7 +9,7 @@
 	* @license http://www.gnu.org/licenses/lgpl.html GNU Lesser General Public License
 	* @package phpgwapi
 	* @subpackage contacts
-	* @version $Id: class.contacts_shared.inc.php 17062 2006-09-03 06:15:27Z skwashd $
+	* @version $Id: class.contacts_shared.inc.php 6153 2010-06-28 08:59:59Z sigurd $
 	*/
 
 	/**
@@ -152,7 +152,6 @@
 				$lastiteration = $lastindex - $subindex;
 				for ($iteration = 0; $iteration < $lastiteration; $iteration++)
 				{
-					$nextchar = 0;
 					if ($this->comesafter($sortarray[$iteration][$index], $sortarray[$iteration + 1][$index]))
 					{
 						$temp = $sortarray[$iteration];
@@ -172,7 +171,6 @@
 				$lastiteration = $lastindex - $subindex;
 				for ($iteration = $lastiteration; $iteration > 0; $iteration--)
 				{
-					$nextchar = 0;
 					if ($this->comesafter($sortarray[$iteration][$index], $sortarray[$iteration - 1][$index]))
 					{
 						$temp = $sortarray[$iteration];
@@ -601,4 +599,3 @@
 			return $a;
 		}
 	}
-?>
