@@ -6,7 +6,7 @@
 	* @license http://www.gnu.org/licenses/lgpl.html GNU Lesser General Public License
 	* @package phpgwapi
 	* @subpackage network
-	* @version $Id: class.crypto.inc.php 18358 2007-11-27 04:43:37Z skwashd $
+	* @version $Id: class.crypto.inc.php 3061 2009-06-14 18:18:21Z sigurd $
 	*/
 
 	/**
@@ -90,9 +90,9 @@
 
 		function cleanup()
 		{
-			if ($this->enabled)
+			if ($this->enabled && $this->td)
 			{
-				mcrypt_generic_deinit($this->td);
+				@mcrypt_generic_deinit($this->td);
 			}
 		}
 
@@ -102,7 +102,7 @@
 			return pack('H'.$len, $data);
 		}
 
-		function encrypt($data)
+		function encrypt($data, $bypass = false)
 		{
 			$_obj = false;
 			if($this->debug)
@@ -131,10 +131,13 @@
 				{
 					echo '<br>' . time() . ' crypto->encrypt() found "' . gettype($data) . '". No serialization...' . "\n";
 				}
+				//FIXME - Strings are not decrypted correctly
+				$data = serialize($data);
+				$_obj = true;
 			}
 
 			/* Disable all encryption if the admin didn't set it up */
-			if ($this->enabled)
+			if ($this->enabled && !$bypass)
 			{
 				if($_obj)
 				{
@@ -172,7 +175,7 @@
 			}
 		}
 
-		function decrypt($encrypteddata)
+		function decrypt($encrypteddata, $bypass = false)
 		{
 			if($this->debug)
 			{
@@ -186,7 +189,7 @@
 			}
 
 			/* Disable all encryption if the admin didn't set it up */
-			if ($this->enabled)
+			if ($this->enabled && !$bypass)
 			{
 				$data = $this->hex2bin($encrypteddata);
 				mcrypt_generic_init ($this->td, $this->key, $this->iv);
@@ -197,7 +200,7 @@
 					echo '<br>' . time() . ' crypto->decrypt() decrypted data: ---->>>>' . $data;
 				}
 				$test = stripslashes($data);
-				if(@unserialize($test))
+				if( $test )
 				{
 					if($this->debug)
 					{
@@ -219,7 +222,7 @@
 			}
 
 			$newdata = @unserialize($data);
-			if($newdata)
+			if($newdata || is_array($newdata)) // Check for empty array
 			{
 				if($this->debug)
 				{
@@ -239,4 +242,3 @@
 			}
 		}
 	} // class crypto
-?>
