@@ -1,16 +1,40 @@
 <?php
 	/**
 	* Datetime class that contains common date/time functions
+	*
+	* @author Dave Hall <skwashd@phpgroupware.org>
 	* @author Joseph Engo <jengo@phpgroupware.org>
 	* @author Mark Peters <skeeter@phpgroupware.org>
 	* @copyright Copyright (C) 2000,2001 Joseph Engo, Mark Peters
-	* @copyright Portions Copyright (C) 2000-2004 Free Software Foundation, Inc. http://www.fsf.org/
+	* @copyright Portions Copyright (C) 2000-2008 Free Software Foundation, Inc. http://www.fsf.org/
 	* @license http://www.gnu.org/licenses/lgpl.html GNU Lesser General Public License
 	* @package phpgwapi
 	* @subpackage utilities
-	* @version $Id: class.datetime.inc.php 18358 2007-11-27 04:43:37Z skwashd $
+	* @version $Id: class.datetime.inc.php 3808 2009-10-02 14:01:42Z sigurd $
 	*/
 
+	/*
+	   This program is free software: you can redistribute it and/or modify
+	   it under the terms of the GNU Lesser General Public License as published by
+	   the Free Software Foundation, either version 2 of the License, or
+	   (at your option) any later version.
+
+	   This program is distributed in the hope that it will be useful,
+	   but WITHOUT ANY WARRANTY; without even the implied warranty of
+	   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+	   GNU General Public License for more details.
+
+	   You should have received a copy of the GNU Lesser General Public License
+	   along with this program.  If not, see <http://www.gnu.org/licenses/>.
+	 */
+
+	/*
+	 * We set the default timezone here to prevent any notices
+	 *
+	 * Everything in phpGroupWare is based on UTC, so lets set it here
+	 */
+	date_default_timezone_set('UTC');
+
 	/**
 	* Datetime class that contains common date/time functions
 	*
@@ -125,6 +149,11 @@
 			'Su'
 		);
 
+		/**
+		* Get the current GMT time as a unixtime stamp
+		*
+		* @return int unixtime stamp
+		*/
 		public static function gmtnow()
 		{
 			static $offset = null;
@@ -143,17 +172,32 @@
 			return time() + $offset;
 		}
 
+		/**
+		* Gets the current user's UTC offset in seconds
+		*
+		* @return int offset in seconds
+		*/
 		public static function user_timezone()
 		{
 				return isset($GLOBALS['phpgw_info']['user']['preferences']['common']['tz_offset']) 
 					? (int) $GLOBALS['phpgw_info']['user']['preferences']['common']['tz_offset'] * self::SECONDS_IN_HOUR : 0;
 		}
 
+		/**
+		* Get the current user's localtime as a unix timestmap
+		*
+		* @return int unix timestmap
+		*/
 		public static function user_localtime()
 		{
 			return time() + self::user_timezone();
 		}
 		
+		/**
+		* Get the current server UTC offset using an NTP server
+		*
+		* @return int offset in hours
+		*/
 		public static function getntpoffset()
 		{
 			$error_occured = False;
@@ -187,7 +231,7 @@
 				{
 					$date = explode('-',$array[1]);
 					$time = explode(':',$array[2]);
-					$gmtnow = mktime(intval($time[0]),intval($time[1]),intval($time[2]),intval($date[1]),intval($date[2]),intval($date[0]) + 2000);
+					$gmtnow = mktime((int) $time[0], (int) $time[1], (int) $time[2], (int) $date[1], (int) $date[2], (int) $date[0] + 2000);
 					print_debug('Temporary RFC epoch',$gmtnow,'api');
 					print_debug('GMT',date('Ymd H:i:s',$gmtnow),'api');
 				}
@@ -207,6 +251,11 @@
 			}
 		}
 
+		/**
+		* Get the current server UTC offset using a NIST's time information webpage
+		*
+		* @return int offset in hours
+		*/
 		public static function gethttpoffset()
 		{
 			$error_occured = false;
@@ -243,6 +292,11 @@
 			return (int) ($server_time - $gmtnow) / self::SECONDS_IN_HOUR;
 		}
 
+		/**
+		* Get the current server UTC offset using a guess
+		*
+		* @return int offset in hours
+		*/
 		public static function getbestguess()
 		{
 			print_debug('datetime::datetime::debug: Inside getting from local server','api');
@@ -327,9 +381,9 @@
 
 			if ( substr($dta[5],0,3) != 'GMT' )
 			{
-				$tzoffset = substr($dta[5],0,1);
-				$tzhours = intval(substr($dta[5],1,2));
-				$tzmins = intval(substr($dta[5],3,2));
+				$tzoffset = substr($dta[5], 0, 1);
+				$tzhours = (int) substr($dta[5], 1, 2);
+				$tzmins = (int) substr($dta[5], 3, 2);
 				switch ($tzoffset)
 				{
 					case '-':
@@ -342,10 +396,19 @@
 						break;
 				}
 			}
+
 			return mktime($ta[0],$ta[1],$ta[2],$month[$dta[2]],$dta[1],$dta[3]);
 		}
 
-		function get_weekday_start($year,$month,$day)
+		/**
+		* Get the first day of the current week
+		*
+		* @param int $year the year to check
+		* @param int $month the month to check
+		* @param int $day the day to check
+		* @return int starting weekday
+		*/
+		function get_weekday_start($year, $month, $day)
 		{
 			$weekday = self::day_of_week($year, $month, $day);
 			switch($GLOBALS['phpgw_info']['user']['preferences']['calendar']['weekdaystarts'])
@@ -514,7 +577,7 @@
 		*/
 		function days_in_month($month, $year)
 		{
-			return date('t', mktime(13, 0, 0, (int)$month, 1, (int)$year) );
+			return cal_days_in_month(CAL_GREGORIAN, (int) $month, (int) $year);
 		}
 
 		/**
@@ -598,6 +661,18 @@
 			return (mktime(0, 0, 0, $m2, $d2, $y2, 0) - mktime(13, 0, 0, $m1, $d1, $y1, 0) ) / self::SECONDS_IN_DAY;
 		}
 
+		/**
+		* Compare 2 dates
+		*
+		* @internal see http://php.net/strcmp
+		* @param int $a_year the year of the first date
+		* @param int $a_month the month of the first date
+		* @param int $a_day the day of the first date
+		* @param int $b_year the year of the second date
+		* @param int $b_month the month of the second date
+		* @param int $b_day the day of the second date
+		* @return int comparsion result - same as php's native strcmp()
+		*/ 
 		public static function date_compare($a_year, $a_month, $a_day, $b_year, $b_month, $b_day)
 		{
 			$a_date = mktime(13, 0, 0, (int)$a_month, (int)$a_day, (int)$a_year);
@@ -613,6 +688,18 @@
 			return -1;
 		}
 
+		/**
+		* Compare 2 dates
+		*
+		* @internal see http://php.net/strcmp
+		* @param int $a_hour the hour of the first time
+		* @param int $a_minute the minutes of the first time
+		* @param int $a_second the seconds of the first time
+		* @param int $b_hour the hour of the second time
+		* @param int $b_minute the minutes of the second time
+		* @param int $b_second the seconds of the second time
+		* @return int comparsion result - same as php's native strcmp()
+		*/
 		public static function time_compare($a_hour, $a_minute, $a_second, $b_hour, $b_minute, $b_second)
 		{
 			// I use the 1970/1/2 to compare the times, as the 1. can get via TZ-offest still 
@@ -630,29 +717,52 @@
 			return -1;
 		}
 
+		/**
+		* Convert a local date and time to UTC
+		*
+		* @param int $hour the hour to convert
+		* @param int $minute the minute to convert
+		* @param int $second the second to convert
+		* @param int $month the month to convert
+		* @param int $day the day to convert
+		* @oaram int $year the year to convert
+		* @return int the localtime as a UTC unix timestamp
+		*/
 		public static function makegmttime($hour,$minute,$second,$month,$day,$year)
 		{
 			return self::gmtdate(mktime($hour, $minute, $second, $month, $day, $year));
 		}
 
+		/**
+		* Convert a unix timestamp to an array of date information
+		*
+		* @param int $localtime the current user's local time as a unix timestamp
+		* @return array date information - keys 'raw', 'day', 'month', 'year', 'full', 'dow', 'dm' & 'bd'
+		*/
 		public static function localdates($localtime)
 		{
 			$date = Array('raw', 'day', 'month', 'year', 'full', 'dow', 'dm', 'bd');
 			$date['raw'] = $localtime;
-			$date['year'] = intval($GLOBALS['phpgw']->common->show_date($date['raw'],'Y'));
-			$date['month'] = intval($GLOBALS['phpgw']->common->show_date($date['raw'],'m'));
-			$date['day'] = intval($GLOBALS['phpgw']->common->show_date($date['raw'],'d'));
-			$date['full'] = intval($GLOBALS['phpgw']->common->show_date($date['raw'],'Ymd'));
+			$date['year'] = (int) $GLOBALS['phpgw']->common->show_date($date['raw'],'Y');
+			$date['month'] = (int) $GLOBALS['phpgw']->common->show_date($date['raw'],'m');
+			$date['day'] = (int) $GLOBALS['phpgw']->common->show_date($date['raw'],'d');
+			$date['full'] = (int) $GLOBALS['phpgw']->common->show_date($date['raw'],'Ymd');
 			$date['bd'] = mktime(13, 0, 0, $date['month'], $date['day'], $date['year']);
-			$date['dm'] = intval($GLOBALS['phpgw']->common->show_date($date['raw'],'dm'));
+			$date['dm'] = (int) $GLOBALS['phpgw']->common->show_date($date['raw'],'dm');
 			$date['dow'] = self::day_of_week($date['year'],$date['month'],$date['day']);
-			$date['hour'] = intval($GLOBALS['phpgw']->common->show_date($date['raw'],'H'));
-			$date['minute'] = intval($GLOBALS['phpgw']->common->show_date($date['raw'],'i'));
-			$date['second'] = intval($GLOBALS['phpgw']->common->show_date($date['raw'],'s'));
+			$date['hour'] = (int) $GLOBALS['phpgw']->common->show_date($date['raw'],'H');
+			$date['minute'] = (int) $GLOBALS['phpgw']->common->show_date($date['raw'],'i');
+			$date['second'] = (int) $GLOBALS['phpgw']->common->show_date($date['raw'],'s');
 		
 			return $date;
 		}
 
+		/**
+		* Convert user's current local time to a UTC unix timestamp
+		*
+		* @param int $locatime the user's local time as a unix timestamp
+		* @return int UTC unix timestamp
+		*/
 		public static function gmtdate($localtime)
 		{
 			return self::localdates($localtime - self::user_timezone());
@@ -666,7 +776,7 @@
 		 * @param string $formatTarget Target date format
 		 * @return string Date in target format representation
 		 */
-		function convertDate($date, $formatSource, $formatTarget)
+		public static function convertDate($date, $formatSource, $formatTarget)
 		{
 			// get format separator character
 			$formatSourceSepChar = substr($formatSource,1,1);
@@ -688,45 +798,35 @@
 
 				if($key == 'M')
 				{
-					for($j=1; $j <=12; $j++)
-					{
-						if(date('M',mktime(0,0,0,$j,1,2000)) == $val)
-						{
-							$map_date['m'] = $j;
-						}
-					}
+					$map_date['m'] = self::convert_m_to_int($val);
 				}
 				else
 				{
-					$map_date[strtolower($key)] = intval($val);
+					$map_date[strtolower($key)] = (int) $val;
 				}
 			}
-			return date($formatTarget, mktime(0,0,0,$map_date['m'], $map_date['d'], $map_date['y']));
+			return date($formatTarget, mktime(0, 0, 0, $map_date['m'], $map_date['d'], $map_date['y']));
 		}
 
+		/**
+		* Convert a date string to an array containing date parts
+		*
+		* @param string $datestr the date string to convert - must match user's preferred date format
+		* @return array date parts: year,month and day
+		*/
 		public static function date_array($datestr)
 		{
 			$dateformat =& $GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat'];
 
-	
-	// 		FIXME : something wrong with the pattern for preg_split
-	//		$fields = preg_split('/[./-]/',$datestr);
-	//		foreach ( preg_split('/[./-]/', $dateformat) as $n => $field )
-			$fields = split('[./-]',$datestr);
-			foreach(split('[./-]',$dateformat) as $n => $field)
+			$pattern = '/[\.\/\-]/';
+			$fields = preg_split($pattern, $datestr);
+			foreach(preg_split($pattern, $dateformat) as $n => $field)
 			{
 				$date[$field] = (int) $fields[$n];
 
 				if ( $field == 'M' )
 				{
-					for($i=1; $i <=12; $i++)
-					{
-						if ( date('M', mktime(0, 0, 0, $i, 1, 2000)) == $fields[$n] )
-						{
-							$date['m'] = $i;
-							break;
-						}
-					}
+					$date['m'] = self::convert_M_to_int($fields[$n]);
 				}
 			}
 
@@ -738,9 +838,15 @@
 			);
 		}
 
+		/**
+		* Convert a date araray to a unix timestamp
+		*
+		* @param array $date the date array to convert, must contain keys day, month & year
+		* @return int unix timestamp
+		*/
 		public static function date_to_timestamp($date = array())
 		{
-			if ( !count($date) )
+			if ( !$date )
 			{
 				return 0;
 			}
@@ -749,6 +855,24 @@
 			return mktime (13, 0, 0, $date_array['month'], $date_array['day'], $date_array['year']);
 		}
 
+		/**
+		* Convert a M month string to an int
+		*
+		* @param string $str abbreviated month name string
+		* @return int the month number - 0 is returned for invalid input
+		*/
+		private static function convert_M_to_int($str)
+		{
+			for($i=1; $i <=12; ++$i)
+			{
+				if ( date('M', mktime(0, 0, 0, $i, 1, 2000)) == $str )
+				{
+					return $i;
+				}
+			}
+			return 0;
+		}
+
 		/**
 		* Get a list of translated day names
 		*
@@ -800,7 +924,7 @@
 		* @param int $dow ISO 8601 day of week number
 		* @return string local say of week name
 		*/
-		public static function nr2weekday($selected = 0)
+		public static function nr2weekday($dow = 0)
 		{
 			$dow_list = self::get_dow_fullnames();
 			if ( isset($dow_list[$dow]) )
