@@ -3,39 +3,49 @@
 	* Database abstraction class
 	* @author NetUSE AG Boris Erdmann, Kristian Koehntopp
    	* @author Dan Kuykendall, Dave Hall and others
+   	* @author Sigurd Nes
 	* @copyright Copyright (C) 1998-2000 NetUSE AG Boris Erdmann, Kristian Koehntopp
 	* @copyright Portions Copyright (C) 2001-2006 Free Software Foundation, Inc. http://www.fsf.org/
 	* @license http://www.fsf.org/licenses/lgpl.html GNU Lesser General Public License
 	* @link http://www.sanisoft.com/phplib/manual/DB_sql.php
 	* @package phpgwapi
 	* @subpackage database
-	* @version $Id: class.db.inc.php 18358 2007-11-27 04:43:37Z skwashd $
+	* @version $Id: class.db.inc.php 6219 2010-08-10 12:34:08Z sigurd $
 	*/
 
-	if (empty($GLOBALS['phpgw_info']['server']['db_type']))
+	if ( empty($GLOBALS['phpgw_info']['server']['db_type']) )
 	{
 		$GLOBALS['phpgw_info']['server']['db_type'] = 'mysql';
 	}
-	/**
-	* Include concrete database implementation
-	*/
-	require_once(PHPGW_API_INC . '/adodb/adodb.inc.php');
+
+	if ( empty($GLOBALS['phpgw_info']['server']['db_abstraction']) )
+	{
+		require_once PHPGW_API_INC . '/class.db_pdo.inc.php';
+	}
+	else
+	{
+		require_once PHPGW_API_INC . "/class.db_{$GLOBALS['phpgw_info']['server']['db_abstraction']}.inc.php";	
+	}
+
 
 	/**
 	* Database abstraction class to allow phpGroupWare to use multiple database backends
 	* 
 	* @package phpgwapi
 	* @subpackage database
-	* @abstract
 	*/
-	class phpgwapi_db
+	abstract class phpgwapi_db_
 	{
-
 		/**
-		* @var object $adodb holds the ADOdb object
+		* @var object $adodb holds the legacy ADOdb object
 		*/
 		var $adodb;
 
+		/**
+		* @var object $db holds the db object
+		*/
+		var $db;
+
 		/**
 		* @var string $Host database hostname
 		*/
@@ -46,6 +56,8 @@
 		 */
 		 var $join = ' INNER JOIN ';
 		 
+
+		 var $left_join = ' LEFT JOIN ';
 		/**
 		 * @var string $like the sql syntax to use for a case insensitive LIKE
 		 */
@@ -86,14 +98,19 @@
 		*/
 		var $auto_stripslashes = false;
 		
-		var $resultSet;
+		var $resultSet = array();
 		
+		var $fetchmode = 'ASSOC';//'BOTH';
+
+		var $Transaction  = false;
+
+		var $persistent = false;
 		/**
 		* Constructor
 		* @param string $query query to be executed (optional)
 		* @param string $db_type the database engine being used
 		*/
-		public function __construct($query = null, $db_type = null)
+		public function __construct($query = null, $db_type = null, $delay_connect = null)
 		{
 			if ( is_null($db_type) )
 			{
@@ -102,10 +119,16 @@
 
 			$this->Type = $db_type;
 
-			$this->Database = $GLOBALS['phpgw_info']['server']['db_name']; 
-			$this->Host = $GLOBALS['phpgw_info']['server']['db_host']; 
-			$this->User = $GLOBALS['phpgw_info']['server']['db_user']; 
-			$this->Password = $GLOBALS['phpgw_info']['server']['db_pass']; 
+			$_key = $GLOBALS['phpgw_info']['server']['setup_mcrypt_key'];
+			$_iv  = $GLOBALS['phpgw_info']['server']['mcrypt_iv'];
+			$crypto = createObject('phpgwapi.crypto',array($_key, $_iv));
+
+			$this->Database		= $crypto->decrypt($GLOBALS['phpgw_info']['server']['db_name']);
+			$this->Host			= $crypto->decrypt($GLOBALS['phpgw_info']['server']['db_host']);
+			$this->User			= $crypto->decrypt($GLOBALS['phpgw_info']['server']['db_user']);
+			$this->Password		= $crypto->decrypt($GLOBALS['phpgw_info']['server']['db_pass']);
+
+			$this->persistent = isset($GLOBALS['phpgw_info']['server']['db_persistent']) && $GLOBALS['phpgw_info']['server']['db_persistent'] ? true : false;
 
 			// We do it this way to allow it to be easily extended in the future
 			switch ( $this->Type )
@@ -118,7 +141,17 @@
 					//do nothing for now
 			}
 			
-			$this->new_adodb();
+			if( !$delay_connect )
+			{
+				try
+				{
+					$this->connect();
+				}
+				catch(Exception $e)
+				{
+					throw $e;
+				}
+			}
 
 			if ( !is_null($query) )
 			{
@@ -131,55 +164,31 @@
 		*/
 		public function __clone()
 		{
-			$this->new_adodb();
+
 		}
 
-		/**
-		* Create a new adodb object
-		*/
-		private function new_adodb()
-		{
-			$type = $this->Type;
-			if ( $type == 'mysql' )
-			{
-				$type = 'mysqlt';
-			}
-			$this->adodb = newADOConnection($this->Type);
-			$this->connect();
-			 // would be good if one day we just use ADODB_FETCH_ASSOC
-			$this->adodb->SetFetchMode(ADODB_FETCH_BOTH);
-		}
 
 		/**
 		* Destructor
 		*/
 		public function __destruct()
 		{
-			$this->disconnect();
+
 		}
 
 		/**
-		* Get current connection id
-		* @return int current connection id
+		* Backward compatibility for get current connection id
+		* @return bool true
 		*/
 		function link_id()
 		{
-			if(!$this->adodb->isConnected())
+			if(!$this->db)
 			{
 				$this->connect();
 			}
-			return $this->adodb->_connectionID;
+			return true;
 		}
-
-		/**
-		* Get current query id
-		* @return int id of current query
-		*/
-		public function query_id()
-		{
-			return $this->Query_ID;
-		}
-
+	
 		/**
 		* Open a connection to a database
 		*
@@ -188,38 +197,13 @@
 		* @param string $User name of database user (optional)
 		* @param string $Password password for database user (optional)
 		*/
-		public function connect($Database = null, $Host = null, $User = null, $Password = null)
-		{
-			if ( !is_null($Database) )
-			{
-				$this->Database = $Database;
-			}
+		abstract public function connect($Database = null, $Host = null, $User = null, $Password = null);
 
-			if ( !is_null($Host) )
-			{
-				$this->Host = $Host;
-			}
-
-			if ( !is_null($User) )
-			{
-				$this->User = $User;
-			}
-
-			if ( !is_null($Password) )
-			{
-				$this->Password = $Password;
-			}
-
-			return @$this->adodb->connect($this->Host, $this->User, $this->Password, $this->Database);
-		}
 
 		/**
 		* Close a connection to a database - only needed for persistent connections
 		*/
-		public function disconnect()
-		{
-			$this->adodb->close();
-		}
+		abstract public function disconnect();
 
 		/**
 		* Escape strings before sending them to the database
@@ -227,19 +211,7 @@
 		* @param string $str the string to be escaped
 		* @return string escaped sting
 		*/
-		public function db_addslashes($str)
-		{
-			if ( is_null($str) )
-			{
-				return '';
-			}
-
-			if ( !is_object($this->adodb) )  //workaround
-			{
-				return addslashes($str);
-			}
-			return substr($this->adodb->qstr($str, magic_quotes_runtime()), 1, -1);
-		}
+		abstract public function db_addslashes($str);
 
 		/**
 		* Convert a unix timestamp to a rdms specific timestamp
@@ -247,21 +219,14 @@
 		* @param int unix timestamp
 		* @return string rdms specific timestamp
 		*/
-		public function to_timestamp($epoch)
-		{
-			return substr($this->adodb->DBTimeStamp($epoch), 1, -1);
-		}
-
+		abstract public function to_timestamp($epoch);
 		/**
 		* Convert a rdms specific timestamp to a unix timestamp 
 		*
 		* @param string rdms specific timestamp
 		* @return int unix timestamp
 		*/
-		public function from_timestamp($timestamp)
-		{
-			return $this->adodb->UnixTimeStamp($timestamp);
-		}
+		abstract public function from_timestamp($timestamp);
 
 		/**
 		* Execute a query with limited result set
@@ -279,7 +244,8 @@
 		*/
 		public function free()
 		{
-			unset($this->resultSet);
+			//unset($this->resultSet);
+			$this->resultSet = array();
 			return true;
 		}
 
@@ -289,31 +255,10 @@
 		* @param string $sql the query to be executed
 		* @param mixed $line the line method was called from - use __LINE__
 		* @param string $file the file method was called from - use __FILE__
+		* @param bool $exec true for exec, false for query
 		* @return integer current query id if sucesful and null if fails
 		*/
-		public function query($sql, $line = '', $file = '')
-		{
-			if ( !$this->adodb->isConnected() )
-			{
-				$this->connect();
-			}
-
-			$this->resultSet = $this->adodb->Execute($sql);
-
-			if ( !$this->resultSet && $this->Halt_On_Error == 'yes' )
-			{
-				if($file)
-				{
-					trigger_error("$sql\n in File: $file\n on Line: $line\n". $this->adodb->ErrorMsg(), E_USER_ERROR);
-				}
-				else
-				{
-					trigger_error("$sql\n". $this->adodb->ErrorMsg(), E_USER_ERROR);
-				}
-			}
-			$this->delayPointer = true;
-			return true;
-		}
+		abstract public function query($sql, $line = '', $file = '', $exec = false, $fetch_single = false);
 
 		/**
 		* Execute a query with limited result set
@@ -325,55 +270,15 @@
 		* @param integer $num_rows number of rows to return (optional), if unset will use $GLOBALS['phpgw_info']['user']['preferences']['common']['maxmatchs']
 		* @return integer current query id if sucesful and null if fails
 		*/
-		public function limit_query($Query_String, $offset = -1, $line = '', $file = '', $num_rows = -1)
-		{
-			if ( (int) $num_rows <= 0 )
-			{
-				$num_rows = $GLOBALS['phpgw_info']['user']['preferences']['common']['maxmatchs'];
-			}
-			
-			if ( !$this->adodb->isConnected() )
-			{
-				$this->connect();
-			}
-			
-			$this->resultSet = $this->adodb->SelectLimit($Query_String, $num_rows, $offset);
-			if(!$this->resultSet && $this->Halt_On_Error == 'yes')
-			{
-				trigger_error("$Query_String\n" . $this->adodb->ErrorMsg(), E_USER_ERROR);
-			}
-			else
-			{
-				$this->delayPointer = true;
-				return true;
-			}
-		}
+
+		abstract function limit_query($Query_String, $offset, $line = '', $file = '', $num_rows = 0);
 		
 		/**
 		* Move to the next row in the results set
 		*
 		* @return bool was another row found?
 		*/
-		public function next_record()
-		{
-			if($this->resultSet && $this->resultSet->RecordCount())
-			{
-				if($this->delayPointer)
-				{
-					$this->delayPointer = false;
-					$this->Record =& $this->resultSet->fields;
-					return true;
-				}
-	
-				if(!$this->resultSet->EOF)
-				{
-					$row = $this->resultSet->MoveNext();
-					$this->Record =& $this->resultSet->fields;
-					return !!$row;
-				}
-			}
-			return false;
-		}
+		abstract public function next_record();
 
 		/**
 		* Move to position in result set
@@ -381,91 +286,38 @@
 		* @param int $pos required row (optional), default first row
 		* @return int 1 if sucessful or 0 if not found
 		*/
-		public function seek($pos = 0)
-		{
-			if($this->resultSet)
-			{
-				return $this->resultSet->Move($pos);
-			}
-			return false;
-		}
+		abstract public function seek($pos = 0);
 
 		/**
 		* Begin transaction
 		*
 		* @return integer|boolean current transaction id
 		*/
-		public function transaction_begin()
-		{
-			return $this->adodb->StartTrans();
-		}
-		
+		abstract public function transaction_begin();	
+
 		/**
 		* Complete the transaction
 		*
 		* @return boolean True if sucessful, False if fails
 		*/ 
-		public function transaction_commit()
-		{
-			return $this->adodb->CompleteTrans();
-		}
+		abstract public function transaction_commit();
 		
 		/**
 		* Rollback the current transaction
 		*
 		* @return boolean True if sucessful, False if fails
 		*/
-		public function transaction_abort()
-		{
-			$this->adodb->FailTrans();
-			return $this->adodb->HasFailedTrans();
-		}
+		abstract public function transaction_abort();
 
 		/**
-		* Find the primary key of the last insertion on the current db connection
+		* Find the value of the last insertion on the current db connection
+		* To use this function safely in Postgresql you MUST wrap it in a beginTransaction() commit() block
 		*
 		* @param string $table name of table the insert was performed on
-		* @param string $field the autoincrement primary key of the table
+		* @param string $field not needed - kept for backward compatibility
 		* @return integer the id, -1 if fails
 		*/
-		public function get_last_insert_id($table, $field)
-		{
-			// This looks like a pretty ugly hack to me, is it really needed? skwashd nov07
-			if($GLOBALS['phpgw_info']['server']['db_type'] == 'postgres')
-			{
-				$params = explode('.',$this->adodb->pgVersion);
-
-				if ($params[0] < 8 || ($params[0] == 8 && $params[1] ==0))
-				{
-					$oid = pg_getlastoid($this->adodb->_queryID);
-					if ($oid == -1)
-					{
-						return -1;
-					}
-
-					$result = @pg_Exec($this->adodb->_connectionID, "select $field from $table where oid=$oid");
-				}
-				else
-				{
-					$result = @pg_Exec($this->adodb->_connectionID, "select lastval()");
-				}
-
-				if (!$result)
-				{
-					return -1;
-				}
-
-				$Record = @pg_fetch_array($result, 0);
-
-				@pg_freeresult($result);
-				if (!is_array($Record)) /* OID not found? */
-				{
-					return -1;
-				}
-				return $Record[0];
-			}
-			return $this->adodb->Insert_ID($table, $field);
-		}
+		abstract public function get_last_insert_id($table, $field = '');
 
 		/**
 		* Lock a table
@@ -474,10 +326,7 @@
 		* @param string $mode type of lock required (optional), default write
 		* @return boolean True if sucessful, False if fails
 		*/
-		public function lock($table, $mode='write')
-		{
-			//$this->adodb->BeginTrans();
-		}
+		abstract public function lock($table, $mode='write');
 		
 		
 		/**
@@ -485,13 +334,13 @@
 		*
 		* @return boolean True if sucessful, False if fails
 		*/
-		public function unlock()
-		{
-			//$this->adodb->CommitTrans();
-		}
+		abstract public function unlock();
 		
 		/**
-		 * Prepare the VALUES component of an INSERT sql statement
+		 * Prepare the VALUES component of an INSERT sql statement by guessing data types
+		 *
+		 * It is not a good idea to rely on the data types determined by this method if 
+		 * you are inserting numeric data into varchar/text fields, such as street numbers
 		 * 
 		 * @param array $value_set array of values to insert into the database
 		 * @return string the prepared sql, empty string for invalid input
@@ -506,20 +355,20 @@
 			$insert_value = array();
 			foreach ( $values as $value )
 			{
-				if ( is_numeric($value) )
+				if($value || (is_numeric($value) && $value == 0) )
 				{
-					if ( !$value )
+					if ( is_numeric($value) )
 					{
-						$insert_value[] = 'NULL';
+						$insert_value[]	= "'$value'";
 					}
 					else
 					{
-						$insert_value[] = $value;
+						$insert_value[]	= "'" . $this->db_addslashes(stripslashes($value)) . "'"; //in case slashes are already added.
 					}
 				}
 				else
 				{
-					$insert_value[]	= "'$value'";
+					$insert_value[]	= 'NULL';
 				}
 			}
 			return implode(",", $insert_value);
@@ -541,11 +390,18 @@
 			$value_entry = array();
 			foreach ( $value_set as $field => $value )
 			{
-				if($value || $value === 0)
+				if($value || (is_numeric($value) && $value == 0) )
 				{
 					if ( is_numeric($value) )
 					{
-						$value_entry[]= "{$field}={$value}";
+						if((strlen($value) > 1 && strpos($value,'0') === 0))
+						{
+							$value_entry[]= "{$field}='{$value}'";
+						}
+						else
+						{
+							$value_entry[]= "{$field}={$value}";
+						}
 					}
 					else
 					{
@@ -565,56 +421,32 @@
 		*
 		* @return integer number of rows
 		*/
-		public function affected_rows()
-		{
-			return $this->adodb->Affected_Rows();
-		}
-		
+		abstract public function affected_rows();
+
 		/**
 		* Number of rows in current result set
 		*
 		* @return integer number of rows
 		*/
-		public function num_rows()
-		{
-			if($this->resultSet)
-			{
-				return $this->resultSet->RecordCount();
-			}
-			return 0;
-		}
-
+		abstract public function num_rows();
 		/**
 		* Number of fields in current row
 		*
 		* @return integer number of fields
 		*/
-		public function num_fields()
-		{
-			if($this->resultSet)
-			{
-				return $this->resultSet->fieldCount();
-			}
-			return 0;
-		}
+		abstract public function num_fields();
 
 		/**
 		* Short hand for num_rows()
 		* @return integer Number of rows
 		* @see num_rows()
 		*/
-		public function nf()
-		{
-			return $this->num_rows();
-		}
+		abstract public function nf();
 
 		/**
 		* Short hand for print @see num_rows
 		*/
-		public function np()
-		{
-			print $this->num_rows();
-		}
+		abstract public function np();
 
 		/**
 		* Return the value of a filed
@@ -623,24 +455,7 @@
 		* @param boolean $strip_slashes string escape chars from field(optional), default false
 		* @return string the field value
 		*/
-		public function f($name, $strip_slashes = False)
-		{
-			if($this->resultSet && get_class($this->resultSet) != 'adorecordset_empty')
-			{
-				if( isset($this->resultSet->fields[$name]) )
-				{
-					if ($strip_slashes || ($this->auto_stripslashes && ! $strip_slashes))
-					{
-						return stripslashes($this->resultSet->fields[$name]);
-					}
-					else
-					{
-						return $this->resultSet->fields[$name];
-					}
-				}
-				return '';
-			}
-		}
+		abstract public function f($name, $strip_slashes = False);
 
 		/**
 		* Print the value of a field
@@ -648,11 +463,7 @@
 		* @param string $field name of field to print
 		* @param bool $strip_slashes string escape chars from field(optional), default false
 		*/
-		public function p($field, $strip_slashes = True)
-		{
-			//echo "depi: p";
-			print $this->f($field, $strip_slashes);
-		}
+		abstract public function p($field, $strip_slashes = True);
 
 		/**
 		* Get the id for the next sequence - not implemented!
@@ -672,49 +483,7 @@
 		* @param boolean $full optional, default False summary information, True full information
 		* @return array Table meta data
 		*/  
-		public function metadata($table = '',$full = false)
-		{
-			if($this->debug)
-			{
-				//echo "depi: metadata";
-			}
-			
-			if(!$this->adodb->IsConnected())
-			{
-				$this->connect();
-			}
-			if(!($return =& $this->adodb->MetaColumns($table,$full)))
-			{
-				$return = array();
-			}
-			return $return;
-			
-			/*
-			 * Due to compatibility problems with Table we changed the behavior
-			 * of metadata();
-			 * depending on $full, metadata returns the following values:
-			 *
-			 * - full is false (default):
-			 * $result[]:
-			 *   [0]["table"]  table name
-			 *   [0]["name"]   field name
-			 *   [0]["type"]   field type
-			 *   [0]["len"]    field length
-			 *   [0]["flags"]  field flags
-			 *
-			 * - full is true
-			 * $result[]:
-			 *   ["num_fields"] number of metadata records
-			 *   [0]["table"]  table name
-			 *   [0]["name"]   field name
-			 *   [0]["type"]   field type
-			 *   [0]["len"]    field length
-			 *   [0]["flags"]  field flags
-			 *   ["meta"][field name]  index of field named "field name"
-			 *   The last one is used, if you have a field name, but no index.
-			 *   Test:  if (isset($result['meta']['myfield'])) { ...
-			 */
-		}
+		abstract public function metadata($table,$full = false);
 
 		/**
 		* Returns an associate array of foreign keys, or false if not supported.
@@ -724,18 +493,17 @@
 		* @param boolean $upper optional, default False. If $upper is true, then the table names (array keys) are upper-cased.
 		* @return array Table meta data
 		*/  
-		public function MetaForeignKeys($table = '', $owner=false, $upper=false)
-		{
-			if(!$this->adodb->IsConnected())
-			{
-				$this->connect();
-			}
-			if(!($return =& $this->adodb->MetaForeignKeys($table, $owner, $upper)))
-			{
-				$return = array();
-			}
-			return $return;
-		}
+		abstract public function MetaForeignKeys($table, $owner=false, $upper=false);
+
+		/**
+		* Returns an associate array of foreign keys, or false if not supported.
+		*
+		* @param string $table name of table to describe
+		* @param boolean $primary optional, default False.
+		* @return array Index data
+		*/  
+
+		abstract public function metaindexes($table, $primary = false);
 
 		/**
 		* Error handler
@@ -744,28 +512,14 @@
 		* @param int $line line of calling method/function (optional)
 		* @param string $file file of calling method/function (optional)
 		*/
-		public function halt($msg, $line = '', $file = '')
-		{
-			$this->adodb->RollbackTrans();
-		}
+		abstract public function halt($msg, $line = '', $file = '');
 		
 		/**
 		* Get a list of table names in the current database
 		*
 		* @return array list of the tables
 		*/
-		public function table_names()
-		{
-			if(!$this->adodb->IsConnected())
-			{
-				$this->connect();
-			}
-			if(!($return =& $this->adodb->MetaTables('TABLES')))
-			{
-				$return = array();
-			}
-			return $return;
-		}
+		abstract public function table_names();
 
 		/**
 		* Return a list of indexes in current database
@@ -784,40 +538,10 @@
 		* @param string $adminname Name of database administrator user (optional)
 		* @param string $adminpasswd Password for the database administrator user (optional)
 		* @returns bool was the new db created?
+		* @throws Exception invalid db-name
 		*/
-		public function create_database($adminname = '', $adminpasswd = '')
-		{
-			//THIS IS CALLED BY SETUP DON'T KILL IT!
-			if ( $this->adodb->IsConnected() )
-			{
-				$this->adodb->Disconnect(); //close the dead connection to be safe
-			}
+		abstract public function create_database($adminname = '', $adminpasswd = '');
 
-			$this->adodb = newADOConnection($GLOBALS['phpgw_info']['server']['db_type']);
-			$this->adodb->NConnect($this->Host, $adminname, $adminpasswd);
-			
-			if ( !$this->adodb->IsConnected() )
-			{
-				echo 'Connection FAILED<br />';
-				return False;
-			}
-
-			//create the db
-			$this->adodb->Execute("CREATE DATABASE {$this->Database}");
-		
-			//Grant rights on the db
-			switch ($GLOBALS['phpgw_info']['server']['db_type'])
-			{
-				case 'mysql':
-					$this->adodb->Execute("GRANT ALL ON {$this->Database}.*"
-							. " TO {$this->User}@{$_SERVER['SERVER_NAME']}"
-							. " IDENTIFIED BY '{$this->Password}'");
-				default:
-					//do nothing
-			}
-			$this->adodb->Disconnect();
-			return True;
-		}
 		/**
 		* Get the correct date format for DATE field for a particular RDBMS
 		*
@@ -869,40 +593,76 @@
 			}
 			return $datetime_format;
 	 	}
-				
-	 	/**
-		* Prepare SQL statement
+
+		/**
+		* Get the correct datetime format for MONEY field for a particular RDBMS
 		*
-		* @param string $query SQL query
-		* @return integer|boolean Result identifier for query_prepared_statement() or FALSE
-		* @see query_prepared_statement()
+		* @return string the formatted string
 		*/
-		public function prepare_sql_statement($query)
+		public static function money_format($amount)
 		{
-			//echo "depi";
-			if (($query == '') || (!$this->connect()))
+			if ($GLOBALS['phpgw_info']['server']['db_type']=='mssql')
 			{
-				return false;
+				return "CONVERT(MONEY,'{$amount}',0)";
+			}
+			else
+			{
+				return "'{$amount}'";
 			}
-			return false;
 		}
 
 		/**
-		 * Execute prepared SQL statement
+		 * Execute prepared SQL statement for insert
 		 *
-		 * @param resource $result_id Result identifier from prepare_sql_statement()
-		 * @param array $parameters_array Parameters for the prepared SQL statement
+		 * @param string $sql_string 
+		 * @param array $valueset  values,id and datatypes for the insert 
+		 * Use type = PDO::PARAM_STR for strings and type = PDO::PARAM_INT for integers
 		 * @return boolean TRUE on success or FALSE on failure
-		 * @see prepare_sql_statement()
 		 */
-		public function query_prepared_statement($result_id, $parameters_array)
-		{
-			if ((!$this->connect()) || (!$result_id))
-			{
-				return false;
-			}
-			return false;
-		}  
 
+		abstract public function insert($sql_string, $valueset, $line = '', $file = '');
+
+		/**
+		 * Execute prepared SQL statement for select
+		 *
+		 * @param string $sql_string 
+		 * @param array $params conditions for the select 
+		 * @return boolean TRUE on success or FALSE on failure
+		 */
+
+		abstract public function select($sql_string, $params, $line = '', $file = '');
+
+		/**
+		* Finds the next ID for a record at a table
+		*
+		* @param string $table tablename in question
+		* @param array $key conditions
+		* @return int the next id
+		*/
+
+		public function next_id($table='',$key='')
+		{
+			$where = '';
+			$condition = array();
+			if(is_array($key))
+			{
+				foreach ($key as $column => $value)
+				{
+					if($value)
+					{
+						$condition[] = $column . "='" . $value;
+					}
+				}
+
+				if( $condition )
+				{
+					$where='WHERE ' . implode("' AND ", $condition) . "'";
+				}
+			}
+
+			$this->query("SELECT max(id) as maximum FROM $table $where",__LINE__,__FILE__);
+			$this->next_record();
+			$next_id = $this->f('maximum')+1;
+			return $next_id;
+		}
 	}
-?>
