@@ -6,7 +6,7 @@
 	* @license http://www.fsf.org/licenses/lgpl.html GNU Lesser General Public License
 	* @package phpgwapi
 	* @subpackage application
-	* @version $Id: class.historylog.inc.php 17814 2006-12-28 10:28:55Z skwashd $
+	* @version $Id: class.historylog.inc.php 2462 2009-02-26 15:28:57Z sigurd $
 	*/
 
 	/**
@@ -18,7 +18,7 @@
 	class historylog
 	{
 		var $db;
-		var $appname;
+		var $location_id;
 		var $template;
 		var $nextmatchs;
 		var $types = array(
@@ -28,21 +28,22 @@
 		);
 		var $alternate_handlers = array();
 
-		function historylog($appname)
+		function historylog($appname, $location = '.')
 		{
 			if (! $appname)
 			{
 				$appname = $GLOBALS['phpgw_info']['flags']['currentapp'];
 			}
 
-			$this->appname = $appname;
+			$location_id = $GLOBALS['phpgw']->locations->get_id($appname, $location);
+			$this->location_id = (int) $location_id;
 			$this->db      =& $GLOBALS['phpgw']->db;
 		}
 
 		function delete($record_id)
 		{
 			$this->db->query("DELETE FROM phpgw_history_log WHERE history_record_id='".(int)$record_id."' and "
-				. "history_appname='" . $this->appname . "'",__LINE__,__FILE__);
+				. "location_id=" . $this->location_id ,__LINE__,__FILE__);
 		}
 
 		function add($status,$record_id,$new_value,$old_value)
@@ -50,10 +51,10 @@
 			if ($new_value != $old_value)
 			{
 				$this->db->query("INSERT INTO phpgw_history_log (history_record_id,"
-					. "history_appname,history_owner,history_status,history_new_value,history_old_value,history_timestamp) "
-					. "VALUES ('".(int)$record_id."','" . $this->appname . "','"
+					. "location_id,history_owner,history_status,history_new_value,history_old_value,history_timestamp) "
+					. "VALUES ('".(int)$record_id."'," . $this->location_id . ",'"
 					. $GLOBALS['phpgw_info']['user']['account_id'] . "','$status','"
-					. $this->db->db_addslashes($new_value) . "','" . $this->db->db_addslashes($old_value) . "','" . $this->db->to_timestamp(time())
+					. $this->db->db_addslashes($new_value) . "','" . $this->db->db_addslashes($old_value) . "','" . date($this->db->datetime_format())
 					. "')",__LINE__,__FILE__);
 			}
 		}
@@ -99,7 +100,7 @@
 			}
 
 			$this->db->query('SELECT * FROM phpgw_history_log'
-				. " WHERE history_appname='{$this->appname}' AND history_record_id = {$record_id} $filter $only_show_filter "
+				. " WHERE location_id= {$this->location_id} AND history_record_id = {$record_id} $filter $only_show_filter "
 				. $orderby, __LINE__, __FILE__);
 
 			$return_values = array();
@@ -112,8 +113,8 @@
 					'owner'      => $GLOBALS['phpgw']->accounts->id2name($this->db->f('history_owner')),
 //					'status'     => lang($this->types[$this->db->f('history_status')]),
 					'status'     => ereg_replace(' ','',$this->db->f('history_status')),
-					'new_value'  => $this->db->f('history_new_value'),
-					'old_value'  => $this->db->f('history_old_value'),
+					'new_value'  => htmlspecialchars_decode($this->db->f('history_new_value',true)),
+					'old_value'  => htmlspecialchars_decode($this->db->f('history_old_value',true)),
 					'datetime'   => $this->db->from_timestamp($this->db->f('history_timestamp'))
 				);
 			}
