@@ -7,18 +7,19 @@
 	* @license http://www.fsf.org/licenses/gpl.html GNU General Public License
 	* @package phpgwapi
 	* @subpackage application
-	* @version $Id: class.log.inc.php 18358 2007-11-27 04:43:37Z skwashd $
+	* @version $Id: class.log.inc.php 5126 2010-04-05 19:03:09Z sigurd $
 	*/
 
+	phpgw::import_class('phpgwapi.datetime');
 	/**
 	* Log
-	* 
+	*
 	* @package phpgwapi
 	* @subpackage application
 	*/
-	class log
+	class phpgwapi_log
 	{
-		
+
 		/***************************\
 		*	Instance Variables...   *
 		\***************************/
@@ -28,6 +29,7 @@
 			'debug',
 			'info',
 			'notice',
+			'strict',
 			'warn',
 			'error',
 			'fatal',
@@ -45,11 +47,13 @@
 			'W' => 3,
 			'N'	=> 4,
 			'I' => 5,
-			'D' => 6
+			'D' => 6,
+			'S'	=> 7,
+			'DP'=>8
 		);
 
-		// these are used by the admin appliation when showing the log file. 
-				
+		// these are used by the admin appliation when showing the log file.
+
 		var $log_level_names = array
 		(
 			'F' => 'fatal',
@@ -57,9 +61,20 @@
 			'W' => 'warn',
 			'N'	=> 'notice',
 			'I' => 'info',
-			'D' => 'debug'
+			'D' => 'debug',
+			'S'	=> 'strict',
+			'DP'=> 'deprecated'
 		);
+
+		/**
+		 * Constructor
+		 */
 		
+		public function __construct()
+		{
+		}
+
+
 		function checkprefs()
 		{
 			//validate defaults
@@ -70,27 +85,27 @@
 				$GLOBALS['phpgw_info']['server']['log_levels']['user'] = array();
 			}
 		}
-		
+
 		function get_level_name($level)
 		{
 			return $this->log_level_names[$level];
 		}
-		
-		function is_level($level) 
+
+		function is_level($level)
 		{
 			$this->checkprefs();
 			if ( $this->log_level_table[$GLOBALS['phpgw_info']['server']['log_levels']['global_level']] >= $this->log_level_table[$level] )
 			{
 				return true;
 			}
-			
+
 			if ( isset($GLOBALS['phpgw_info']['flags']['currentapp'])
 				 && @array_key_exists( $GLOBALS['phpgw_info']['flags']['currentapp'] , $GLOBALS['phpgw_info']['server']['log_levels']['module'])
 				 && $this->log_level_table[$GLOBALS['phpgw_info']['server']['log_levels']['module'][$GLOBALS['phpgw_info']['flags']['currentapp']]] >= $this->log_level_table[$level] )
 			{
 					return true;
 			}
-			
+
 			if ( isset($GLOBALS['phpgw_info']['user']['account_lid'])
 				 && @array_key_exists($GLOBALS['phpgw_info']['user']['account_lid'], $GLOBALS['phpgw_info']['server']['log_levels']['user'])
 				 && $this->log_level_table[$GLOBALS['phpgw_info']['server']['log_levels']['user'][$GLOBALS['phpgw_info']['user']['account_lid']]] >= $this->log_level_table[$level] )
@@ -100,8 +115,8 @@
 
 			return false;
 		}
-		
-		  
+
+
 		function log_if_level($level, $parms)
 		{
 			if ( $this->is_level($level) )
@@ -110,7 +125,7 @@
 				$err = createObject('phpgwapi.log_message',$parms);
 				$this->write_error_to_db($err);
  				$this->handle_fatal_error($err);              // this is here instead of in fatal() because I still support
- 				                                              // the old methods. 
+ 				                                              // the old methods.
  				return true;
 			}
 			else
@@ -119,18 +134,15 @@
 			}
 		}
 
-		function log()
-		{}
-
 		function make_parms($arg_array)
 		{
-			if ( count($arg_array) == 0 ) 
+			if ( count($arg_array) == 0 )
 			{
 				$parms['text'] = 'No message passed to logging function!';
 			}
-			else 
+			else
 			{
-				// if they've passed in an array of parms, 
+				// if they've passed in an array of parms,
 				// just return it.
 				if ( is_array($arg_array[0])  )
 				{
@@ -162,13 +174,25 @@
 			$arg_array = func_get_args();
 			return $this->log_if_level('I',  $this->make_parms($arg_array));
 		}
-		
+
 		function notice()
 		{
 			$arg_array = func_get_args();
 			return $this->log_if_level('N',  $this->make_parms($arg_array));
 		}
 
+		function strict()
+		{
+			$arg_array = func_get_args();
+			return $this->log_if_level('S',  $this->make_parms($arg_array));
+		}
+
+		function deprecated()
+		{
+			$arg_array = func_get_args();
+			return $this->log_if_level('DP',  $this->make_parms($arg_array));
+		}
+
 		function warn()
 		{
 			$arg_array = func_get_args();
@@ -189,41 +213,53 @@
 
 		function write_error_to_db($err)
 		{
-			if(is_object($GLOBALS['phpgw']->db))
+			if ( isset($GLOBALS['phpgw']->db)
+				&& is_object($GLOBALS['phpgw']->db))
 			{
 				$db =& $GLOBALS['phpgw']->db;
 			}
-			else // during setup
+			else if ( isset($GLOBALS['phpgw_setup']->oProc->m_odb)
+				&& is_object($GLOBALS['phpgw_setup']->oProc->m_odb) ) // during setup
 			{
 				$db =& $GLOBALS['phpgw_setup']->oProc->m_odb;
 				if(!$db->metadata('phpgw_log'))
 				{
-					echo 'Failed to log error to database. DB errno ' . $db->Errno . ': message ' . $db->Error;
+					echo 'Failed to log error to database.';
 					return;
 				}
 			}
-			$db->query("insert into phpgw_log (log_date, log_app, log_account_id, log_account_lid, log_severity, log_file, log_line, log_msg) values "
-				. "('" . $db->to_timestamp(time()) . "'"
-				. ",'" . $db->db_addslashes($GLOBALS['phpgw_info']['flags']['currentapp']) . "'"
-				. ","  . ( isset($GLOBALS['phpgw']->session->account_id) ? $GLOBALS['phpgw']->session->account_id : -1)
-				. ",'" . $db->db_addslashes(isset($GLOBALS['phpgw']->session->account_lid) ? $GLOBALS['phpgw']->session->account_lid : 'not authenticated') . "'"
-				. ",'" . $err->severity . "'"
-				. ",'" . $db->db_addslashes($err->fname) . "'"
-				. ","  . intval($err->line)
-				. ",'" . $db->db_addslashes($err->msg) . "'"
-				. ")"
-				,__LINE__,__FILE__
+			else
+			{
+				//trigger_error("Failed to log error to database: no database object available");
+				return;
+			}
+
+			$values = array
+			(
+				date($db->datetime_format()),
+				$db->db_addslashes($GLOBALS['phpgw_info']['flags']['currentapp']),
+				isset($GLOBALS['phpgw_info']['user']['id']) && $GLOBALS['phpgw_info']['user']['id'] ? $GLOBALS['phpgw_info']['user']['id'] : -1,
+				$db->db_addslashes(isset($GLOBALS['phpgw_info']['user']['lid']) && $GLOBALS['phpgw_info']['user']['lid'] ? $GLOBALS['phpgw_info']['user']['lid'] : 'not authenticated'),
+				$err->severity,
+				$err->fname ? $db->db_addslashes($err->fname) : 'dummy',
+				(int)$err->line,
+				$db->db_addslashes($err->msg),
 			);
+
+			$values	= $db->validate_insert($values);
+
+			$db->query("insert into phpgw_log (log_date, log_app, log_account_id, log_account_lid, log_severity,"
+					 . "log_file, log_line, log_msg) values ({$values})",__LINE__,__FILE__);
 			if ( isset($db->Errno) )
 			{
-				trigger_error("Failed to log error to database. DB errno " . $db->Errno . ": message " . $db->Error,  E_USER_NOTICE);
+				//trigger_error("Failed to log error to database. DB errno " . $db->Errno . ": message " . $db->Error,  E_USER_NOTICE);
 			}
 		}
 
 		// I pulled this from the old code, where it's used to display a fatal error and determinate processing..
 		// Do I still want to do this?  If so, do I want to translate the error message like it used to?
-		// 
-		function handle_fatal_error($err) 
+		//
+		function handle_fatal_error($err)
 		{
 			if ($err->severity == 'F')
 			{
@@ -236,8 +272,8 @@
 					unset($msg_array[0]);
 					if ( isset($GLOBALS['phpgw_info']['user']['apps']['admin']) )
 					{
-						$trace = '<h2>' .lang('back trace') . "</h2>\n" 
-									. '<p>' . lang('Please include the following output when you report this incident on our bug tracker - %1', 
+						$trace = '<h2>' .lang('back trace') . "</h2>\n"
+									. '<p>' . lang('Please include the following output when you report this incident on our bug tracker - %1',
 											'<a href="https://savannah.gnu.org/bugs/?group=phpgroupware" target="_blank">https://savannah.gnu.org/bugs/?group=phpgroupware</a>') . "</p>\n"
 									. '<pre>' . implode("\n", $msg_array) . '</pre>';
 					}
@@ -256,7 +292,7 @@
 			}
 		}
 
-		
+
 		// write() left in for backward compatibility
 		function write($parms)
 		{
@@ -283,6 +319,4 @@
 		{
 			return true;
 		}
-
-
 	}
