@@ -6,7 +6,7 @@
 	* @license http://www.fsf.org/licenses/gpl.html GNU General Public License
 	* @package phpgwapi
 	* @subpackage gui
-	* @version $Id: class.nextmatchs_xslt.inc.php 18358 2007-11-27 04:43:37Z skwashd $
+	* @version $Id: class.nextmatchs_xslt.inc.php 5147 2010-04-08 13:34:46Z sigurd $
 	*/
 
 	/**
@@ -15,7 +15,7 @@
 	* @package phpgwapi
 	* @subpackage gui
 	*/
-	class nextmatchs_xslt
+	class phpgwapi_nextmatchs_xslt
 	{
 		var $maxmatches;
 		var $action;
@@ -106,12 +106,14 @@
 		{
 			$GLOBALS['phpgw']->xslttpl->add_file('nextmatchs', PHPGW_TEMPLATE_DIR);
 
-			$start = isset($values['start']) ? (int) $values['start'] : 0;
+			$start = isset($values['start']) && $values['start'] ? (int) $values['start'] : 0;
+
 			$nm_data = array
 			(
 				'img_width'			=> $GLOBALS['phpgw_info']['user']['preferences']['common']['template_set'] == 'funkwerk' ? '' : '12',
 				'img_height'		=> $GLOBALS['phpgw_info']['user']['preferences']['common']['template_set'] == 'funkwerk' ? '' : '12',
-				'allow_all_rows'	=> isset($values['allow_all_rows']) ? false : 'yes',
+				'allow_all_rows'	=> isset($values['allow_all_rows']) ? true : false,
+				'allrows'			=> isset($values['allrows']) && $values['allrows'] ? true : false,
 				'start_record'		=> $start,
 				'record_limit'		=> $this->maxmatches,
 				'num_records'		=> (int) $values['num_records'],
