@@ -7,12 +7,12 @@
 	 * @license http://www.fsf.org/licenses/lgpl.html GNU Lesser General Public License
 	 * @package phpgwapi
 	 * @subpackage application
-	 * @version $Id: class.preferences.inc.php 18358 2007-11-27 04:43:37Z skwashd $
+	 * @version $Id: class.preferences.inc.php 5127 2010-04-05 20:03:23Z sigurd $
 	 */
 
 	/**
 	 * Preferences class for setting application preferences
-	 * 
+	 *
 	 * @package phpgwapi
 	 * @subpackage application
 	 * @internal the prefs are read into 4 arrays:
@@ -24,15 +24,15 @@
 	class preferences
 	{
 		/**
-		 * @var account_id 
+		 * @var account_id
 		 */
 		var $account_id;
 		/**
-		 * @var account_type 
+		 * @var account_type
 		 */
 		var $account_type;
 		/**
-		 * @var data effectiv user prefs, used by all apps 
+		 * @var data effectiv user prefs, used by all apps
 		 */
 		var $data = array();
 
@@ -42,24 +42,26 @@
 		var $debug = false;
 
 		/**
-		 * @var user set user prefs for saveing (no defaults/forced prefs merged) 
+		 * @var user set user prefs for saveing (no defaults/forced prefs merged)
 		 */
 		var $user = array();
 		/**
-		 * @var default default prefs 
+		 * @var default default prefs
 		 */
 		var $default = array();
 		/**
-		 * @var forced forced prefs 
+		 * @var forced forced prefs
 		 */
 		var $forced = array();
 		/**
-		 * @var db 
+		 * @var db
 		 */
 		var $db;
 
 		var $values,$vars;	// standard notify substitues, will be set by standard_substitues()
 
+		protected $global_lock = false;
+
 		/**
 		 * Standard constructor for setting $this->account_id
 		 *
@@ -77,9 +79,13 @@
 		*
 		* @param int $account_id the account id - 0 = current user's id
 		*/
-		public function set_account_id($account_id = 0)
+		public function set_account_id($account_id = 0, $read_repo = false)
 		{
 			$this->account_id = get_account_id($account_id);
+			if ( $read_repo )
+			{
+				$this->read_repository();
+			}
 		}
 
 		/*
@@ -156,28 +162,32 @@
 				$GLOBALS['phpgw']->translation->userlang = $GLOBALS['phpgw_info']['user']['preferences']['common']['lang'];
 			}
 			// we cant use phpgw_info/user/fullname, as it's not set when we run
-			$GLOBALS['phpgw']->accounts->get_account_name($this->account_id,$lid,$fname,$lname);
+			$user = $GLOBALS['phpgw']->accounts->get($this->account_id);
 
-			$this->values = array(	// standard notify replacements
-					'fullname'  => $GLOBALS['phpgw']->common->display_fullname('',$fname,$lname),
-					'firstname' => $fname,
-					'lastname'  => $lname,
-					'domain'    => $GLOBALS['phpgw_info']['server']['mail_suffix'],
-					'email'     => $this->email_address($this->account_id),
-					'date'      => $GLOBALS['phpgw']->common->show_date('',$GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat'])
-					);
+			// standard notify replacements
+			$this->values = array
+			(
+				'fullname'  => $user->__toString(),
+				'firstname' => $user->firstname,
+				'lastname'  => $user->lastname,
+				'domain'    => $GLOBALS['phpgw_info']['server']['mail_suffix'],
+				'email'     => $this->email_address($this->account_id),
+				'date'      => $GLOBALS['phpgw']->common->show_date('',$GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat'])
+			);
 			// do this first, as it might be already contain some substitues
 			//
 			$this->values['email'] = $this->parse_notify($this->values['email']);
 
-			$this->vars = array(	// langs have to be in common !!!
-					'fullname'  => lang('name of the user, eg. %1',$this->values['fullname']),
-					'firstname' => lang('first name of the user, eg. %1',$this->values['firstname']),
-					'lastname'  => lang('last name of the user, eg. %1',$this->values['lastname']),
-					'domain'    => lang('domain name for mail-address, eg. %1',$this->values['domain']),
-					'email'     => lang('email-address of the user, eg. %1',$this->values['email']),
-					'date'      => lang('todays date, eg. %1',$this->values['date'])
-					);
+			// langs have to be in common !!!
+			$this->vars = array
+			(
+				'fullname'  => lang('name of the user, eg. %1',$this->values['fullname']),
+				'firstname' => lang('first name of the user, eg. %1',$this->values['firstname']),
+				'lastname'  => lang('last name of the user, eg. %1',$this->values['lastname']),
+				'domain'    => lang('domain name for mail-address, eg. %1',$this->values['domain']),
+				'email'     => lang('email-address of the user, eg. %1',$this->values['email']),
+				'date'      => lang('todays date, eg. %1',$this->values['date'])
+			);
 			// do the substituetion in the effective prefs (data)
 			//
 			foreach($this->data as $app => $data)
@@ -207,7 +217,7 @@
 		 *
 		 * @param $arr array to unquote (var-param!)
 		 */
-		function unquote(&$arr)
+		public function unquote(&$arr)
 		{
 			if (!is_array($arr))
 			{
@@ -222,7 +232,7 @@
 				}
 				else
 				{
-					$arr[$key] = stripslashes($value);	
+					$arr[$key] = stripslashes($value);
 				}
 			}
 		}
@@ -233,8 +243,9 @@
 		 * the function ready all 3 prefs user/default/forced and merges them to the effective ones
 		 * private function should only be called from within this class
 		 */
-		function read_repository()
+		protected function read_repository()
 		{
+			//FIXME - ever used?
 			if($GLOBALS['phpgw']->acl->check('session_only_preferences',1,'preferences') && strlen($GLOBALS['phpgw']->session->appsession('session_prefs','initiated')))
 			{
 				$this->user		= $GLOBALS['phpgw']->session->appsession('session_prefs','user');
@@ -258,30 +269,30 @@
 			{
 				$this->db->query('SELECT * FROM phpgw_preferences WHERE preference_owner IN (-1,-2,'.intval($this->account_id).')',__LINE__,__FILE__);
 
-						$this->forced = $this->default = $this->user = array();
-						while($this->db->next_record())
-						{
-						// The following ereg is required for PostgreSQL to work
-						$app = ereg_replace(' ','',$this->db->f('preference_app'));
-						$value = unserialize($this->db->f('preference_value'));
-						$this->unquote($value);
-						if (!is_array($value))
-						{
+				$this->forced = $this->default = $this->user = array();
+				while($this->db->next_record())
+				{
+					// The following ereg is required for PostgreSQL to work
+					$app = str_replace(' ','',$this->db->f('preference_app'));
+					$value = unserialize($this->db->f('preference_value'));
+					$this->unquote($value);
+					if (!is_array($value))
+					{
 						continue;
-						}
-						switch($this->db->f('preference_owner'))
-						{
+					}
+					switch($this->db->f('preference_owner'))
+					{
 						case -1:	// forced
-						$this->forced[$app] = $value;
-						break;
+							$this->forced[$app] = $value;
+							break;
 						case -2:	// default
-						$this->default[$app] = $value;
-						break;
+							$this->default[$app] = $value;
+							break;
 						default:	// user
-						$this->user[$app] = $value;
-						break;
-						}
-						}
+							$this->user[$app] = $value;
+							break;
+					}
+				}
 
 				if ($GLOBALS['phpgw']->acl->check('session_only_preferences',1,'preferences'))
 				{
@@ -322,13 +333,31 @@
 			if (is_array($this->data))
 			{
 				reset($this->data);
+
+				// This one should cope with daylight saving time
+				// Create two timezone objects, one for UTC (GMT) and one for
+				// user pref
+				$dateTimeZone_utc = new DateTimeZone('UTC');
+				$dateTimeZone_pref = new DateTimeZone(isset($this->data['common']['timezone']) && $this->data['common']['timezone'] ? $this->data['common']['timezone'] : 'UTC');
+
+				// Create two DateTime objects that will contain the same Unix timestamp, but
+				// have different timezones attached to them.
+				$dateTime_utc = new DateTime("now", $dateTimeZone_utc);
+				$dateTime_pref = new DateTime("now", $dateTimeZone_pref);
+
+				// Calculate the GMT offset for the date/time contained in the $dateTime_utc
+				// object, but using the timezone rules as defined for Tokyo
+
+				$this->data['common']['tz_offset'] = (int)$dateTimeZone_pref->getOffset($dateTime_utc)/3600;
 			}
-			if ($this->debug && substr($GLOBALS['phpgw_info']['flags']['currentapp'],0,3) != 'log') {
+			if ($this->debug && substr($GLOBALS['phpgw_info']['flags']['currentapp'],0,3) != 'log') 
+			{
 				echo "user<pre>";    print_r($this->user); echo "</pre>\n";
 				echo "forced<pre>";  print_r($this->forced); echo "</pre>\n";
 				echo "default<pre>"; print_r($this->default); echo "</pre>\n";
-				echo "effectiv<pre>";print_r($this->data); echo "</pre>\n"; 
+				echo "effectiv<pre>";print_r($this->data); echo "</pre>\n";
 			}
+
 			return $this->data;
 		}
 
@@ -339,7 +368,7 @@
 		 * Example1: preferences->read();
 		 * @return $data array containing user preferences
 		 */
-		function read()
+		public function read()
 		{
 			if (count($this->data) == 0)
 			{
@@ -359,7 +388,7 @@
 		 * the effective prefs ($this->data) are updated to reflect the change
 		 * @return the new effective prefs (even when forced or default prefs are set !)
 		 */
-		function add($app_name,$var,$value = '##undef##',$type='user')
+		public function add($app_name,$var,$value = '##undef##',$type='user')
 		{
 			//echo "<p>add('$app_name','$var','$value')</p>\n";
 			if ($value == '##undef##')
@@ -405,7 +434,7 @@
 		 * the effektive prefs ($this->data) are updated to reflect the change
 		 * @return the new effective prefs (even when forced or default prefs are deleted!)
 		 */
-		function delete($app_name, $var = False,$type = 'user')
+		public function delete($app_name, $var = False,$type = 'user')
 		{
 			//echo "<p>delete('$app_name','$var')</p>\n";
 			$set_via = array(
@@ -468,7 +497,7 @@
 		 * @param $value value of the preference
 		 * the function works on user and data, to be able to save the pref and to have imediate effect
 		 */
-		function add_struct($app_name,$var,$value = '')
+		public function add_struct($app_name,$var,$value = '')
 		{
 			/* eval is slow and dangerous
 			   $code = '$this->data[$app_name]'.$var.' = $value;';
@@ -497,7 +526,7 @@
 		 * @param $var array keys separated by '/', eg. 'ex_accounts/1'
 		 * the function works on user and data, to be able to save the pref and to have imediate effect
 		 */
-		function delete_struct($app_name, $var = '')
+		public function delete_struct($app_name, $var = '')
 		{
 			/* eval is slow and dangerous
 			   $code_1 = '$this->data[$app_name]'.$var.' = "";';
@@ -528,7 +557,7 @@
 		 *
 		 * @param $arr array to unquote (var-param!)
 		 */
-		function quote(&$arr)
+		public function quote(&$arr)
 		{
 			if (!is_array($arr))
 			{
@@ -552,10 +581,10 @@
 		 * save the the preferences to the repository
 		 *
 		 * @param $update_session_info old param, seems not to be used
-		 * @param $type which prefs to update: user/default/forced 
+		 * @param $type which prefs to update: user/default/forced
 		 * the user prefs for saveing are in $this->user not in $this->data, which are the effectiv prefs only
 		 */
-		function save_repository($update_session_info = False,$type='user')
+		public function save_repository($update_session_info = False,$type='user')
 		{
 			// Don't get the old values back from the cache on next load
 			$GLOBALS['phpgw']->session->clear_phpgw_info_cache();
@@ -579,7 +608,15 @@
 
 			if (! $GLOBALS['phpgw']->acl->check('session_only_preferences',1,'preferences'))
 			{
-				$this->db->transaction_begin();
+				if ( $this->db->Transaction )
+				{
+					$this->global_lock = true;
+				}
+				else
+				{
+					$this->db->transaction_begin();
+				}
+
 				$this->db->query("delete from phpgw_preferences where preference_owner='$account_id'",
 						__LINE__,__FILE__);
 
@@ -590,11 +627,15 @@
 					$value = $this->db->db_addslashes(serialize($value));	// this addslashes is for the database
 					$app = $this->db->db_addslashes($app);
 
-					$this->db->query($sql = "INSERT INTO phpgw_preferences".
+					$this->db->query("INSERT INTO phpgw_preferences".
 							" (preference_owner,preference_app,preference_value)".
 							" VALUES ($account_id,'$app','$value')",__LINE__,__FILE__);
 				}
-				$this->db->transaction_commit();
+
+				if ( !$this->global_lock )
+				{
+					$this->db->transaction_commit();
+				}
 			}
 			else
 			{
@@ -611,10 +652,12 @@
 						break;
 				}
 
-				$GLOBALS['phpgw_info']['user']['preferences'] = $this->data;
+			//	$GLOBALS['phpgw_info']['user']['preferences'] = $this->data;
 				$GLOBALS['phpgw']->session->save_repositories();
 			}
 
+			$GLOBALS['phpgw_info']['user']['preferences'] = $this->data;
+
 			if (($type == 'user' || !$type) && isset($GLOBALS['phpgw_info']['server']['cache_phpgw_info']) && $GLOBALS['phpgw_info']['server']['cache_phpgw_info']  && $this->account_id == $GLOBALS['phpgw_info']['user']['account_id'])
 			{
 				$GLOBALS['phpgw']->session->delete_cache($this->account_id);
@@ -629,7 +672,7 @@
 		 *
 		 * @param $account_id numerical id of account for which to create the prefs
 		 */
-		function create_defaults($account_id)
+		public function create_defaults($account_id)
 		{
 			return; // not longer needed, as the defaults are merged in on runtime
 			$this->db->query("select * from phpgw_preferences where preference_owner='-2'",__LINE__,__FILE__);
@@ -651,10 +694,10 @@
 		/**
 		 * update the preferences array
 		 *
-		 * 
+		 *
 		 * @param $data array of preferences
 		 */
-		function update_data($data)
+		public function update_data($data)
 		{
 			if(is_array($data))
 			{
@@ -671,11 +714,11 @@
 		}
 
 		/* legacy support */
-		function change($app_name,$var,$value = "")
+		public function change($app_name,$var,$value = "")
 		{
 			return $this->add($app_name,$var,$value);
 		}
-		function commit($update_session_info = True)
+		public function commit($update_session_info = True)
 		{
 			//return $this->save_repository($update_session_info);
 		}
@@ -691,43 +734,44 @@
 		function verify_basic_settings()
 		{
 			$preferences_update = False;
-			if (!is_array($GLOBALS['phpgw_info']['user']['preferences']))
+			if ( !is_array($GLOBALS['phpgw_info']['user']['preferences']) 
+				|| isset($GLOBALS['phpgw_info']['server']['cache_phpgw_info']) )
 			{
 				$GLOBALS['phpgw_info']['user']['preferences'] = $this->read_repository();
 				$preferences_update = True;
 			}
 			/* This takes care of new users who dont have proper default prefs setup */
-			if (!isset($GLOBALS['phpgw_info']['user']['preferences']['common']['maxmatchs']) || 
+			if (!isset($GLOBALS['phpgw_info']['user']['preferences']['common']['maxmatchs']) ||
 					!$GLOBALS['phpgw_info']['user']['preferences']['common']['maxmatchs'])
 			{
 				$this->add('common','maxmatchs',15);
 				$preferences_update = True;
 			}
-			if (!isset($GLOBALS['phpgw_info']['user']['preferences']['common']['theme']) || 
+			if (!isset($GLOBALS['phpgw_info']['user']['preferences']['common']['theme']) ||
 					!$GLOBALS['phpgw_info']['user']['preferences']['common']['theme'])
 			{
 				$this->add('common','theme','default');
 				$preferences_update = True;
 			}
-			if (!isset($GLOBALS['phpgw_info']['user']['preferences']['common']['template_set']) || 
+			if (!isset($GLOBALS['phpgw_info']['user']['preferences']['common']['template_set']) ||
 					!$GLOBALS['phpgw_info']['user']['preferences']['common']['template_set'])
 			{
 				$this->add('common','template_set','verdilak');
 				$preferences_update = True;
 			}
-			if (!isset($GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat']) || 
+			if (!isset($GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat']) ||
 					!$GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat'])
 			{
 				$this->add('common','dateformat','d-M-Y');
 				$preferences_update = True;
 			}
-			if (!isset($GLOBALS['phpgw_info']['user']['preferences']['common']['timeformat']) || 
+			if (!isset($GLOBALS['phpgw_info']['user']['preferences']['common']['timeformat']) ||
 					!$GLOBALS['phpgw_info']['user']['preferences']['common']['timeformat'])
 			{
 				$this->add('common','timeformat',12);
 				$preferences_update = True;
 			}
-			if (!isset($GLOBALS['phpgw_info']['user']['preferences']['common']['lang']) || 
+			if (!isset($GLOBALS['phpgw_info']['user']['preferences']['common']['lang']) ||
 					!$GLOBALS['phpgw_info']['user']['preferences']['common']['lang'])
 			{
 				$this->add('common','lang',$GLOBALS['phpgw']->common->getPreferredLanguage());
@@ -752,8 +796,8 @@
 		 * mail server of type pop3, pop3s, imap, imaps users value from
 		 * $GLOBALS['phpgw_info']['user']['preferences']['email']['mail_port'].
 		 * if that value is not set, it generates a default port for the given $server_type.
-		 * Someday, this *MAY* be 
-		 * (a) a se4rver wide admin setting, or 
+		 * Someday, this *MAY* be
+		 * (a) a se4rver wide admin setting, or
 		 * (b)user custom preference
 		 * Until then, simply set the port number based on the mail_server_type, thereof
 		 * ONLY call this function AFTER ['email']['mail_server_type'] has been set.
@@ -798,7 +842,7 @@
 						$port_number = 993;
 						break;
 					case 'imap':
-						// IMAP normal connection, No SSL 
+						// IMAP normal connection, No SSL
 					default:
 						// UNKNOWN SERVER in Preferences, return a
 						// default value that is likely to work
@@ -839,14 +883,14 @@
 		/**
 		 * returns the custom email-address (if set) or generates a default one
 		 *
-		 * This will generate the appropriate email address used as the "From:" 
-		 email address when the user sends email, the localpert * part. The "personal" 
+		 * This will generate the appropriate email address used as the "From:"
+		 email address when the user sends email, the localpert * part. The "personal"
 		 part is generated elsewhere.
 		 In the absence of a custom ['email']['address'], this function should be used to set it.
 		 * @param $accountid - as determined in and/or passed to "create_email_preferences"
 		 * @access public
 		 */
-		function email_address($account_id='')
+		public function email_address($account_id='')
 		{
 			if ( isset($this->data['email']['address']) )
 			{
@@ -876,13 +920,13 @@
 		 * 	$GLOBALS['phpgw_info']['user']['preferences'] = $GLOBALS['phpgw']->preferences->create_email_preferences();
 		 * which fills an array based at:
 		 * 	$GLOBALS['phpgw_info']['user']['preferences']['email'][prefs_are_elements_here]
-		 * Reading the raw preference DB data and comparing to the email preference schema defined in 
-		 * /email/class.bopreferences.inc.php (see discussion there and below) to create default preference values 
-		 * for the  in the ['email'][] pref data array in cases where the user has not supplied 
+		 * Reading the raw preference DB data and comparing to the email preference schema defined in
+		 * /email/class.bopreferences.inc.php (see discussion there and below) to create default preference values
+		 * for the  in the ['email'][] pref data array in cases where the user has not supplied
 		 * a preference value for any particular preference item available to the user.
 		 * @access Public
 		 */
-		function create_email_preferences($accountid='', $acctnum=0)
+		public function create_email_preferences($accountid='', $acctnum=0)
 		{
 			print_debug('class.preferences: create_email_preferences: ENTERING<br>', 'messageonly','api');
 			// we may need function "html_quotes_decode" from the mail_msg class
@@ -967,7 +1011,7 @@
 			// the user does not directly manipulate this pref for the default email account
 			if ((string)$acctnum == '0')
 			{
-				$prefs['email']['fullname'] = $GLOBALS['phpgw_info']['user']['fullname'];
+				$prefs['email']['fullname'] = (string) $GLOBALS['phpgw']->accounts->get($account_id);
 			}
 
 
@@ -1007,11 +1051,11 @@
 
 			// --- make the schema-based pref data for this user ---
 			// user defined values and/or user specified custom email prefs are read from the
-			// prefs DB with mininal manipulation of the data. Currently the only change to 
+			// prefs DB with mininal manipulation of the data. Currently the only change to
 			// users raw data is related to reversing the encoding of "database un-friendly" chars
-			// which itself may become unnecessary if and when the database handlers can reliably 
+			// which itself may become unnecessary if and when the database handlers can reliably
 			// take care of this for us. Of course, password data requires special decoding,
-			// but the password in the array [email][paswd] should be left in encrypted form 
+			// but the password in the array [email][paswd] should be left in encrypted form
 			// and only decrypted seperately when used to login in to an email server.
 
 			// --- generating a default value if necessary ---
@@ -1042,7 +1086,7 @@
 
 				// --- is there a value in the DB for this preference item ---
 				// if the prefs DB has no value for this defined available preference, we must make one.
-				// This occurs if (a) this is user's first login, or (b) this is a custom pref which the user 
+				// This occurs if (a) this is user's first login, or (b) this is a custom pref which the user
 				// has not overriden, do a default (non-custom) value is needed.
 				if (!isset($prefs['email'][$this_avail_pref['id']]))
 				{
@@ -1082,7 +1126,7 @@
 						}
 						else
 						{
-							// opposite of boolean not_set  = string "True" which simply sets a 
+							// opposite of boolean not_set  = string "True" which simply sets a
 							// value it exists in the users session [email][] preference array
 							$prefs['email'][$this_avail_pref['id']] = 'True';
 						}
@@ -1106,7 +1150,7 @@
 					// INIT_NO_FILL
 					elseif ($set_proc[0] == 'init_no_fill')
 					{
-						// we have an available preference item that we may NOT fill with a default 
+						// we have an available preference item that we may NOT fill with a default
 						// value. Only the user may supply a value for this pref item.
 						print_debug('* handle "init_no_fill" set_proc:', serialize($set_proc),'api');
 						// we are FORBADE from filling this at this time!
@@ -1114,7 +1158,7 @@
 					// varEVAL
 					elseif ($set_proc[0] == 'varEVAL')
 					{
-						// similar to "function" but used for array references, the string in $set_proc[1] 
+						// similar to "function" but used for array references, the string in $set_proc[1]
 						// represents code which typically is an array referencing a system/api property
 						print_debug('* handle "GLOBALS" set_proc:', serialize($set_proc),'api');
 						$evaled = '';
@@ -1140,8 +1184,8 @@
 					/// here until the next OFFICIAL submit email prefs function, where it
 					// will again get this preparation before being written to the database.
 
-					// NOTE: if database de-fanging is eventually handled deeper in the 
-					// preferences class, then the following code would become depreciated 
+					// NOTE: if database de-fanging is eventually handled deeper in the
+					// preferences class, then the following code would become depreciated
 					// and should be removed in that case.
 					if (($this_avail_pref['type'] == 'user_string') &&
 							(stristr($this_avail_pref['write_props'], 'no_db_defang') == False))
@@ -1155,7 +1199,7 @@
 			}
 			// users preferences are now established to known structured values...
 
-			// SANITY CHECK 
+			// SANITY CHECK
 			// ---  [email][use_trash_folder]  ---
 			// ---  [email][use_sent_folder]  ---
 			// is it possible to use Trash and Sent folders - i.e. using IMAP server
@@ -1196,7 +1240,7 @@
 		{
 		$prefs['email']['userid'] = $this->sub_default_userid($accountid);
 		}
-		// ---  address  --- 
+		// ---  address  ---
 		if (!isset($prefs['email']['address']))
 		{
 		$prefs['email']['address'] = $this->email_address($accountid);
@@ -1286,7 +1330,7 @@
 	//	$prefs['email']['font_size_offset'] = 'normal';
 	//}
 
-	// SANITY CHECK 
+	// SANITY CHECK
 	// ---  use_trash_folder  ---
 	// ---  use_sent_folder  ---
 	// is it possible to use Trash and Sent folders - i.e. using IMAP server
@@ -1315,4 +1359,3 @@
 	return $prefs;
 	*/
 	} /* end of preferences class */
-?>
