@@ -8,7 +8,7 @@
 	* @license http://www.fsf.org/licenses/gpl.html GNU General Public License
 	* @package phpgwapi
 	* @subpackage database
-	* @version $Id: class.schema_proc.inc.php 17635 2006-12-04 15:04:58Z sigurdne $
+	* @version $Id: class.schema_proc.inc.php 4315 2009-12-08 11:33:06Z sigurd $
 	*/
 
 	/**
@@ -71,6 +71,7 @@
 			{
 				$sSequenceSQL = '';
 				$sTriggerSQL = '';
+				$this->m_oTranslator->indexes_sql = array();
 				if($this->_GetTableSQL($sTableName, $aTableDef, $sTableSQL, $sSequenceSQL, $sTriggerSQL))
 				{
 					$sTableSQL = "CREATE TABLE $sTableName (\n$sTableSQL\n)"
@@ -86,11 +87,23 @@
 					}
 					
 					$sAllTableSQL .= $sTableSQL . "\n\n";
+
+					// postgres and mssql
+					if(isset($this->m_oTranslator->indexes_sql) && is_array($this->m_oTranslator->indexes_sql) && count($this->m_oTranslator->indexes_sql)>0)
+					{
+						foreach($this->m_oTranslator->indexes_sql as $key => $sIndexSQL)
+						{
+							$ix_name = $key.'_'.$sTableName.'_idx';
+							$IndexSQL = str_replace(array('__index_name__','__table_name__'), array($ix_name,$sTableName), $sIndexSQL);
+							$sAllTableSQL .= $IndexSQL . "\n\n";
+						}
+					}
 				}
 				else
 				{
 					if($bOutputHTML)
 					{
+						print('<br>SQL:<pre>' . $sAllTableSQL . '</pre><br>');
 						print('<br>Failed generating script for <b>' . $sTableName . '</b><br>');
 						echo '<pre style="text-align: left;">'.$sTableName.' = '; print_r($aTableDef); echo "</pre>\n";
 					}
@@ -107,7 +120,7 @@
 			return True;
 		}
 
-		function ExecuteScripts($aTables, $bOutputHTML=False)
+		function ExecuteScripts($aTables, $bOutputHTML=false)
 		{
 			if(!is_array($aTables) || !IsSet($this->m_odb))
 			{
@@ -117,7 +130,7 @@
 			reset($aTables);
 			$this->m_aTables = $aTables;
 
-			while(list($sTableName, $aTableDef) = each($aTables))
+			foreach ($aTables as $sTableName => $aTableDef)
 			{
 				if($this->CreateTable($sTableName, $aTableDef))
 				{
@@ -150,7 +163,8 @@
 			$this->m_aTables = $aTables;
 
 			reset($this->m_aTables);
-			while(list($sTableName, $aTableDef) = each($this->m_aTables))
+
+			foreach ( $this->m_aTables as $sTableName => $aTableDef)
 			{
 				if($this->DropTable($sTableName))
 				{
@@ -653,7 +667,7 @@
 				$this->query($sIXSQL, __LINE__, __FILE__);
 			}
 			
-			// postgres
+			// postgres and mssql
 			if(isset($this->m_oTranslator->indexes_sql) && is_array($this->m_oTranslator->indexes_sql) && count($this->m_oTranslator->indexes_sql)>0)
 			{
 				foreach($this->m_oTranslator->indexes_sql as $key => $sIndexSQL)
