@@ -8,7 +8,7 @@
 	* @license http://www.fsf.org/licenses/gpl.html GNU General Public License
 	* @package phpgwapi
 	* @subpackage database
-	* @version $Id: class.schema_proc_mssql.inc.php 17062 2006-09-03 06:15:27Z skwashd $
+	* @version $Id: class.schema_proc_mssql.inc.php 2512 2009-03-04 12:16:25Z jonas.borgstrom $
 	*/
 
 	/**
@@ -87,6 +87,9 @@
 				case 'text':
 					$sTranslated = 'text';
 					break;
+				case 'time':
+					$sTranslated = 'time';
+					break;
 				case 'timestamp':
 					$sTranslated = 'datetime';
 					break;
@@ -110,7 +113,7 @@
 			{
 				case 'current_date':
 				case 'current_timestamp':
-				return "'GetDate()'";
+				return "GetDate()";
 			}
 
 			return "'" . $sDefault . "'";
@@ -197,8 +200,33 @@
 			return "UNIQUE($sFields)";
 		}
 
-		function GetIXSQL($sFields)
+
+		/* format:
+			CREATE [ UNIQUE ] [ CLUSTERED | NONCLUSTERED ] INDEX index_name
+			    ON { table | view } ( column [ ASC | DESC ] [ ,...n ] )
+			[ WITH < index_option > [ ,...n] ]
+			[ ON filegroup ]
+
+			< index_option > :: =
+			    { PAD_INDEX |
+			        FILLFACTOR = fillfactor |
+			        IGNORE_DUP_KEY |
+			        DROP_EXISTING |
+			    STATISTICS_NORECOMPUTE |
+			    SORT_IN_TEMPDB 
+			}
+		*/
+
+		function GetIXSQL($sFields,$sTableName = '')
 		{
+			if($sTableName)
+			{
+				return "CREATE NONCLUSTERED INDEX ". str_replace(',','_',$sFields).'_'.$sTableName.'_idx' ."  ON $sTableName ($sFields)";
+			}
+			else
+			{
+				$this->indexes_sql[str_replace(',','_',$sFields)] = "CREATE NONCLUSTERED INDEX __index_name__ ON __table_name__ ($sFields)";
+			}
 			return '';
 		}
 
@@ -210,8 +238,7 @@
 			$this->ix = array();
 			$this->uc = array();
 
-			// Field, Type, Null, Key, Default, Extra
-			$oProc->m_odb->query("exec sp_columns '$sTableName'", __LINE__, __FILE__);
+			$oProc->m_odb->query("EXEC sp_columns '$sTableName'", __LINE__, __FILE__);
 			while ($oProc->m_odb->next_record())
 			{
 				$type = $default = $null = $nullcomma = $prec = $scale = $ret = $colinfo = $scales = '';
@@ -219,20 +246,12 @@
 				{
 					$sColumns .= ',';
 				}
-				$sColumns .= $oProc->m_odb->f(0);
 
-				// The rest of this is used only for SQL->array
-				$colinfo = explode('(',$oProc->m_odb->f(1));
-				$prec = ereg_replace(')','',$colinfo[1]);
-				$scales = explode(',',$prec);
-				if ($scales[1])
-				{
-					$prec  = $scales[0];
-					$scale = $scales[1];
-				}
-				$type = $this->rTranslateType($colinfo[0], $prec, $scale);
+				$sColumns .= $oProc->m_odb->f('COLUMN_NAME');
 
-				if ($oProc->m_odb->f(2) == 'YES')
+				$type = $this->rTranslateType($oProc->m_odb->f('TYPE_NAME'),$oProc->m_odb->f('PRECISION'), $oProc->m_odb->f('SCALE'));
+
+				if ($oProc->m_odb->f('IS_NULLABLE') == 'YES')
 				{
 					$null = "'nullable' => True";
 				}
@@ -240,9 +259,10 @@
 				{
 					$null = "'nullable' => False";
 				}
-				if ($oProc->m_odb->f(4))
+
+				if ($oProc->m_odb->f('COLUMN_DEF'))
 				{
-					$default = "'default' => '".$oProc->m_odb->f(4)."'";
+					$default = "'default' => '".str_replace(array('((','))', "('", "')",'GetDate()'),array('','','','','current_timestamp'),$oProc->m_odb->f('COLUMN_DEF'))."'";
 					$nullcomma = ',';
 				}
 				else
@@ -250,25 +270,42 @@
 					$default = '';
 					$nullcomma = '';
 				}
-				if ($oProc->m_odb->f(5))
+				if ($oProc->m_odb->f('TYPE_NAME') == 'int identity')
 				{
 					$type = "'type' => 'auto'";
 				}
-				$this->sCol[] = "\t\t\t\t'" . $oProc->m_odb->f(0)."' => array(" . $type . ',' . $null . $nullcomma . $default . '),' . "\n";
-				if ($oProc->m_odb->f(3) == 'PRI')
+				$this->sCol[] = "\t\t\t\t'" . $oProc->m_odb->f('COLUMN_NAME')."' => array(" . $type . ',' . $null . $nullcomma . $default . '),' . "\n";
+			}
+
+			$this->pk = $oProc->m_odb->adodb->MetaPrimaryKeys($sTableName);
+
+			$ForeignKeys =$oProc->m_odb->MetaForeignKeys($sTableName);
+
+			foreach($ForeignKeys as $table => $keys)
+			{
+				$keystr = array();
+				foreach ($keys as $keypair)
 				{
-					$this->pk[] = $oProc->m_odb->f(0);
+					$keypair = explode('=',$keypair);
+					$keystr[] = "'" . $keypair[0] . "' => '" . $keypair[1] . "'";
 				}
-				if ($oProc->m_odb->f(3) == 'UNI')
+				$this->fk[] = "'" . $table . "' => array(" . implode(', ',$keystr)  . ')';
+			}
+
+			/*FIXME: not working as expected */
+			$oProc->m_odb->query("EXEC sp_indexes  @table_server = '{$GLOBALS['phpgw_info']['server']['db_host']}', @table_name = '$sTableName'", __LINE__, __FILE__);
+			while ($oProc->m_odb->next_record())
+			{
+				if($oProc->m_odb->f('NON_UNIQUE') == 1)
 				{
-					$this->uc[] = $oProc->m_odb->f(0);
+					$this->ix[] = $oProc->m_odb->f('COLUMN_NAME');
 				}
-				/* Hmmm, MUL could also mean unique, or not... */
-				if ($oProc->m_odb->f(3) == 'MUL')
+				else
 				{
-					$this->ix[] = $oProc->m_odb->f(0);
+					$this->uc[] = $oProc->m_odb->f('COLUMN_NAME');
 				}
 			}
+
 			/* ugly as heck, but is here to chop the trailing comma on the last element (for php3) */
 			$this->sCol[count($this->sCol) - 1] = substr($this->sCol[count($this->sCol) - 1],0,-2) . "\n";
 
@@ -337,6 +374,8 @@
 
 		function CreateTable($oProc, &$aTables, $sTableName, $aTableDef)
 		{
+			global $DEBUG;
+			unset($this->indexes_sql);
 			if ($oProc->_GetTableSQL($sTableName, $aTableDef, $sTableSQL, $sSequenceSQL, $sTriggerSQL))
 			{
 				// create sequence first since it will be needed for default
@@ -346,7 +385,28 @@
 				}
 
 				$query = "CREATE TABLE $sTableName ($sTableSQL)";
-				return !!($oProc->m_odb->query($query));
+
+				$result = !!$oProc->m_odb->query($query, __LINE__, __FILE__);
+				if($result==True)
+				{
+					if (isset($this->indexes_sql) && $DEBUG)
+					{
+						echo  '<pre>';
+						print_r($this->indexes_sql);
+						echo '</pre>';
+					}
+
+					if(isset($this->indexes_sql) && is_array($this->indexes_sql) && count($this->indexes_sql)>0)
+					{
+						foreach($this->indexes_sql as $key => $sIndexSQL)
+						{
+							$ix_name = str_replace(',','_',$key).'_'.$sTableName.'_idx';
+							$IndexSQL = str_replace(array('__index_name__','__table_name__'), array($ix_name,$sTableName), $sIndexSQL);
+							$oProc->m_odb->query($IndexSQL, __LINE__, __FILE__);
+						}
+					}			
+				}
+				return $result;
 			}
 
 			return false;
