@@ -8,7 +8,7 @@
 	* @license http://www.fsf.org/licenses/gpl.html GNU General Public License
 	* @package phpgwapi
 	* @subpackage database
-	* @version $Id: class.schema_proc_mysql.inc.php 18358 2007-11-27 04:43:37Z skwashd $
+	* @version $Id: class.schema_proc_mysql.inc.php 2592 2009-04-15 11:34:41Z sigurd $
 	*/
  
 	/**
@@ -17,7 +17,7 @@
 	* @package phpgwapi
 	* @subpackage database
 	*/
-	class schema_proc_mysql
+	class phpgwapi_schema_proc_mysql
 	{
 		var $m_sStatementTerminator;
 		/* Following added to convert sql to array */
@@ -27,7 +27,7 @@
 		var $ix = array();
 		var $uc = array();
 
-		function schema_proc_mysql()
+		function __construct()
 		{
 			$this->m_sStatementTerminator = ';';
 			/* The use of a temp_db is to allow this process to be run from other than setup*/
@@ -52,19 +52,6 @@
 				$temp_db->User     = $phpgw_domain[$ConfigDomain]['db_user'];
 				$temp_db->Password = $phpgw_domain[$ConfigDomain]['db_pass'];
 			}
-
-			$temp_db->query("SELECT version() as version",__LINE__,__FILE__);
-			$temp_db->next_record();
-			$version = $temp_db->f('version');
-			$parts   = explode('.',$version);
-			if($parts[0] == 5 || ($parts[0] == 4 && $parts[1] == 1))
-			{
-				$this->now_statement =  "now()";
-			}
-			else
-			{
-				$this->now_statement =  "'now()'";				
-			}
 		}
 
 		/* Return a type suitable for DDL */
@@ -76,6 +63,9 @@
 				case 'auto':
 					$sTranslated = 'int(11) auto_increment';
 					break;
+				case 'bool':
+					$sTranslated = 'bool';
+					break;
 				case 'blob':
 					$sTranslated = 'blob';
 					break;
@@ -126,6 +116,9 @@
 				case 'text':
 					$sTranslated = 'text';
 					break;
+				case 'time':
+					$sTranslated = 'time';
+					break;
 				case 'timestamp':
 					$sTranslated = 'timestamp';
 					break;
@@ -150,7 +143,7 @@
 			{
 				case 'current_date':
 				case 'current_timestamp':
-					return $this->now_statement;
+					return 'now()';
 
 			}
 			return "'" . $sDefault . "'";
@@ -204,6 +197,7 @@
 					$sTranslated = "'type' => 'float', 'precision' => $iPrecision";
 					break;
 				case 'datetime':
+				case 'timestamp':
 					$sTranslated = "'type' => 'timestamp'";
 					break;
 				case 'enum':
@@ -238,7 +232,7 @@
 
 		function GetUCSQL($sFields)
 		{
-			return "UNIQUE($sFields)";
+			return "UNIQUE KEY ($sFields)";
 		}
 
 		function GetIXSQL($sFields, $sTableName = '')
@@ -249,13 +243,13 @@
 			}
 			else
 			{
-				return "INDEX ($sFields)";			
+				return "KEY ($sFields)";			
 			}
 		}
 
-	   	// foreign key supports needs MySQL 3.23.44 and up with InnoDB or MySQL 5.1
-	   	// or other versions the syntax is parsed in table create commands
-	   	// see chapter 1.8.4.5
+		// foreign key supports needs MySQL 3.23.44 and up with InnoDB or MySQL 5.1
+		// or other versions the syntax is parsed in table create commands
+		// see chapter 1.8.4.5
 
 		function GetFKSQL($reftable, $sFields)
 		{
@@ -308,7 +302,7 @@
 						}
 					}
 				}
-				elseif ($scales[1])
+				else if ( isset($scales[1]) )
 				{
 					$prec  = $scales[0];
 					$scale = $scales[1];
@@ -360,7 +354,7 @@
 
 		function DropTable($oProc, &$aTables, $sTableName)
 		{
-			return !!($oProc->m_odb->query("DROP TABLE " . $sTableName, __LINE__, __FILE__));
+			return !!($oProc->m_odb->query("DROP TABLE " . $sTableName, __LINE__, __FILE__, true));
 		}
 
 		function DropColumn($oProc, &$aTables, $sTableName, $aNewTableDef, $sColumnName, $bCopyData = true)
@@ -423,6 +417,8 @@
 
 		function CreateTable($oProc, &$aTables, $sTableName, $aTableDef)
 		{
+			global $DEBUG;
+
 			if ($oProc->_GetTableSQL($sTableName, $aTableDef, $sTableSQL, $sSequenceSQL, $sTriggerSQL))
 			{
 				/* create sequence first since it will be needed for default */
@@ -431,8 +427,11 @@
 					$oProc->m_odb->query($sSequenceSQL, __LINE__, __FILE__);
 				}
 
-				$query = "CREATE TABLE $sTableName ($sTableSQL)";
-				return !!($oProc->m_odb->query($query, __LINE__, __FILE__));
+				$query = "CREATE TABLE $sTableName ($sTableSQL) ENGINE=InnoDB DEFAULT CHARSET=utf8";
+
+				if($DEBUG) { echo '<br>CREATE TABLE STATEMENT: ' ; var_dump($query); }
+
+				return !!($oProc->m_odb->query($query, __LINE__, __FILE__, true));
 			}
 
 			return false;
