@@ -12,7 +12,7 @@
 	* @license http://www.fsf.org/licenses/gpl.html GNU General Public License
 	* @package phpgwapi
 	* @subpackage database
-	* @version $Id: class.schema_proc_pgsql.inc.php 17987 2007-02-23 10:45:22Z sigurdne $
+	* @version $Id: class.schema_proc_pgsql.inc.php 2979 2009-06-09 11:05:20Z sigurd $
 	* @link http://www.greatbridge.org/project/phppgadmin
 	* @internal SQL for table properties taken from phpPgAdmin Version 2.2.1
 	*/
@@ -84,6 +84,9 @@
 				case 'text':
 					$sTranslated = 'text';
 					break;
+				case 'time':
+					$sTranslated = 'time';
+					break;
 				case 'timestamp':
 					$sTranslated = 'timestamp';
 					break;
@@ -163,6 +166,9 @@
 				case 'timestamp':
 					$sTranslated = "'type' => 'timestamp'";
 					break;
+				case 'time':
+					$sTranslated = "'type' => 'time'";
+					break;
 				case 'varchar':
 					if ($iPrecision > 0 && $iPrecision < 256)
 					{
@@ -178,6 +184,7 @@
 				case 'date':
 					$sTranslated = "'type' => '$sType'";
 					break;
+				case 'bool':
 				case 'boolean':
 					$sTranslated = "'type' => 'bool'";
 					break;
@@ -279,11 +286,11 @@
 
 				if ($sdb->f(5) == 'f')
 				{
-					$null = "'nullable' => True";
+					$null = "'nullable' => False";
 				}
 				else
 				{
-					$null = "'nullable' => False";
+					$null = "'nullable' => True";
 				}
 
 				if ($sdb->f(2) == 'numeric')
@@ -319,7 +326,7 @@
 					";
 				$sdc->query($sql_get_default, __LINE__, __FILE__);
 				$sdc->next_record();
-				if ($sdc->f(0))
+				if ($sdc->f(0) != '')
 				{
 					if (ereg('nextval',$sdc->f(0)))
 					{
@@ -329,7 +336,15 @@
 					}
 					else
 					{
-						$default = "'default' => '" . str_replace(array('::bpchar','::character varying','now()'),array('','','current_timestamp'),$sdc->f(0));
+						if(preg_match('/(now()|::timestamp(6) without time zone$|::timestamp without time zone$)/i', $sdc->f(0)))
+						{
+							$default =  "'default' =>'current_timestamp'";
+						}
+						else
+						{
+							$default = "'default' => '" . str_replace(array('::bpchar','::character varying'),array('',''),$sdc->f(0));						
+						}
+						
 						// For db-functions - add an apos
 						if(substr($default,-1)!= "'")
 						{
@@ -378,12 +393,13 @@
 				{
 					$this->pk[] = $sdc->f(2);
 				}
-				if ($sdc->f(3) == 't')
+				else if ($sdc->f(3) == 't')
 				{
 					$this->uc[] = $sdc->f(2);
 				}
 			}
 
+/*
 			$ForeignKeys = $sdc->MetaForeignKeys($sTableName);
 
 			foreach($ForeignKeys as $table => $keys)
@@ -396,18 +412,72 @@
 				}
 				$this->fk[] = $table . "' => array(" . implode(', ',$keystr)  . ')';
 			}
+*/
 
-			$MetaIndexes = $sdc->adodb->MetaIndexes($sTableName);
+			$sql_f_keys = "SELECT
+				pc.conname,
+				pg_catalog.pg_get_constraintdef(pc.oid, true) AS consrc,
+				pc.contype,
+				CASE WHEN pc.contype='u' OR pc.contype='p' THEN (
+					SELECT
+						indisclustered
+					FROM
+						pg_catalog.pg_depend pd,
+						pg_catalog.pg_class pl,
+						pg_catalog.pg_index pi
+					WHERE
+						pd.refclassid=pc.tableoid
+						AND pd.refobjid=pc.oid
+						AND pd.objid=pl.oid
+						AND pl.oid=pi.indexrelid
+				) ELSE
+					NULL
+				END AS indisclustered
+			FROM
+				pg_catalog.pg_constraint pc
+			WHERE
+				pc.conrelid = (SELECT oid FROM pg_catalog.pg_class WHERE relname='$sTableName'
+					AND relnamespace = (SELECT oid FROM pg_catalog.pg_namespace
+					WHERE nspname='public'))
+			ORDER BY
+				1";
 
-			foreach($MetaIndexes as $key => $index)
+			$oProc->m_odb->query($sql_f_keys, __LINE__, __FILE__);
+			while ($oProc->m_odb->next_record())
+			{
+				if($oProc->m_odb->f('contype') == 'f')
+				{
+					$f_temp = preg_split("/FOREIGN KEY|REFERENCES|[()]/",$oProc->m_odb->f('consrc'));
+					$f_temp_primary = explode(', ',$f_temp[2]);
+					$f_temp_foreign = explode(', ',$f_temp[5]);
+
+					$keystr = '';
+					for ($i=0;$i<count($f_temp_primary);$i++)
+					{
+						$keystr[] = "'" . $f_temp_primary[$i] . "' => '" . $f_temp_foreign[$i] . "'";
+					}				
+					
+					$this->fk[] = "'" . trim($f_temp[4]) . "' => array(" . implode(', ',$keystr)  . ')';
+				}
+			}
+			unset($keystr);
+			unset($f_temp);
+			unset($f_temp_primary);
+			unset($f_temp_foreign);
+
+
+			$metaindexes = $sdc->metaindexes($sTableName);
+
+			//FIXME: looks like unique is reported as index
+			foreach($metaindexes as $key => $index)
 			{
 				if(count($index['columns']) > 1)
 				{
-					$this->ix[] = "array('" . implode("', '",$index['columns']) . "')";
+					$this->ix[] = $index['columns'];
 				}
 				else
 				{
-					$this->ix[] = "'" . $index['columns'][0] . "'";	
+					$this->ix[] = $index['columns'][0];	
 				}
 			}
 
@@ -610,52 +680,27 @@
 
 		function AddColumn($oProc, &$aTables, $sTableName, $sColumnName, &$aColumnDef)
 		{
-			$default = '';
-			if (isset($aColumnDef['default']) && $aColumnDef['default'])	// pgsql cant add a colum with a default
+			if (!isset($aColumnDef['nullable']) || (isset($aColumnDef['nullable']) && ($aColumnDef['nullable'] === 'False' || $aColumnDef['nullable'] === false)) )	// pgsql cant add a column not nullable if there is data in the table
 			{
-				$default = $aColumnDef['default'];
-				unset($aColumnDef['default']);
-			}
-			if (isset($aColumnDef['nullable']) && !$aColumnDef['nullable'])	// pgsql cant add a column not nullable
-			{
-				$notnull = !$aColumnDef['nullable'];
-				unset($aColumnDef['nullable']);
+				if(!isset($aColumnDef['default']))
+				{
+					$oProc->m_odb->query("SELECT count(*) as cnt FROM $sTableName", __LINE__, __FILE__);
+					$oProc->m_odb->next_record();
+					if($oProc->m_odb->f(0))
+					{
+						throw new Exception(lang('ERROR: The column %1 in table %2 cannot be added as NOT NULL as there is data in the table', $sColumnName, $sTableName));
+					}
+				}
+				else
+				{
+					trigger_error(lang('column %1 for table %2 will be added as NULLABLE with DEFAULT value %3', $classname, $sTableName, $aColumnDef['default']), E_USER_WARNING);
+				}
 			}
+
 			$oProc->_GetFieldSQL($aColumnDef, $sFieldSQL);
 			$query = "ALTER TABLE $sTableName ADD COLUMN $sColumnName $sFieldSQL";
 
-			if (($Ok = !!$oProc->m_odb->query($query, __LINE__, __FILE__)) && isset($default) && $default)
-			{
-				if($default == '0')
-				{
-					$defaultSQL = " DEFAULT 0";
-				}								
-				elseif(!is_numeric($default) && $default != '')
-				{
-					$sTranslatedDefault = $this->TranslateDefault($default);
-					$defaultSQL = " DEFAULT $sTranslatedDefault";
-				}
-				elseif($default)
-				{
-					$defaultSQL = " DEFAULT $default";
-				}
-
-				$query = "ALTER TABLE $sTableName ALTER COLUMN $sColumnName SET $defaultSQL;\n";
-
-				$query .= "UPDATE $sTableName SET $sColumnName='$default';\n";
-
-				$Ok = !!$oProc->m_odb->query($query, __LINE__, __FILE__);
-
-				if ($OK && $notnull)
-				{
-					// unfortunally this is pgSQL >= 7.3
-					//$query .= "ALTER TABLE $sTableName ALTER COLUMN $sColumnName SET NOT NULL;\n";
-					//$Ok = !!($oProc->m_odb->query($query));
-					// so we do it the slow way
-					AlterColumn($oProc, $aTables, $sTableName, $sColumnName, $aColumnDef);
-				}
-			}
-			return $Ok;
+			return !!$oProc->m_odb->query($query, __LINE__, __FILE__);
 		}
 
 		function GetSequenceSQL($sTableName, &$sSequenceSQL)
