@@ -9,7 +9,7 @@
 	* @license http://www.fsf.org/licenses/gpl.html GNU General Public License
 	* @package phpgwapi
 	* @subpackage application
-	* @version $Id: class.setup.inc.php 18358 2007-11-27 04:43:37Z skwashd $
+	* @version $Id: class.setup.inc.php 6150 2010-06-26 08:08:50Z sigurd $
 	*/
 
 	/**
@@ -39,10 +39,11 @@
 		{
 			$this->detection = createObject('phpgwapi.setup_detection');
 			$this->process   = createObject('phpgwapi.setup_process');
+			$_translation    = &$this->process->translation;
 
 			/* The setup application needs these */
 			$this->html	= $html ? CreateObject('phpgwapi.setup_html') : null;
-			$this->translation = $translation ? CreateObject('phpgwapi.setup_translation') : null;
+			$this->translation = $translation ? $_translation : null ; //CreateObject('phpgwapi.setup_translation') : null;
 			
 			//$this->tbl_apps    = $this->get_apps_table_name();
 			//$this->tbl_config  = $this->get_config_table_name();
@@ -57,13 +58,18 @@
 		{
 			$form_domain = phpgw::get_var('FormDomain', 'string', 'POST', '');
 			$ConfigDomain = phpgw::get_var('ConfigDomain', 'string', 'REQUEST', $form_domain);
+			$ConfigDomain   = $ConfigDomain ? $ConfigDomain : phpgw::get_var('ConfigDomain', 'string', 'COOKIE');
 
 			$GLOBALS['phpgw_info']['server']['db_type'] = $GLOBALS['phpgw_domain'][$ConfigDomain]['db_type'];
 			$GLOBALS['phpgw_info']['server']['db_host']	= $GLOBALS['phpgw_domain'][$ConfigDomain]['db_host'];
 			$GLOBALS['phpgw_info']['server']['db_name'] = $GLOBALS['phpgw_domain'][$ConfigDomain]['db_name'];
 			$GLOBALS['phpgw_info']['server']['db_user'] = $GLOBALS['phpgw_domain'][$ConfigDomain]['db_user'];
 			$GLOBALS['phpgw_info']['server']['db_pass'] = $GLOBALS['phpgw_domain'][$ConfigDomain]['db_pass'];
+
+			$GLOBALS['phpgw_info']['server']['db_abstraction'] = $GLOBALS['phpgw_domain'][$ConfigDomain]['db_abstraction'];
 			$this->db	  = createObject('phpgwapi.db');
+			$this->db->fetchmode= 'BOTH';
+			$GLOBALS['phpgw']->db =& $this->db;
 
 			$GLOBALS['ConfigDomain'] = $ConfigDomain;
 		}
@@ -88,6 +94,14 @@
 			$HeaderPW     = phpgw::get_var('HeaderPW');
 			$ConfigLang   = phpgw::get_var('ConfigLang');
 
+			// In case the cookies are not included in $_REQUEST
+			$FormLogout   = $FormLogout ? $FormLogout : phpgw::get_var('FormLogout',	'string', 'COOKIE');
+			$ConfigDomain = $ConfigDomain ? $ConfigDomain: phpgw::get_var('ConfigDomain',	'string', 'COOKIE');
+			$ConfigPW     = $ConfigPW ? $ConfigPW : phpgw::get_var('ConfigPW',	'string', 'COOKIE');
+			$HeaderPW     = $HeaderPW ? $HeaderPW : phpgw::get_var('HeaderPW',	'string', 'COOKIE');
+			$ConfigLang   = $ConfigLang ? $ConfigLang : phpgw::get_var('ConfigLang',	'string', 'COOKIE');
+
+
 			/*
 			if(!empty($remoteip) && !$this->checkip($remoteip))
 			{
@@ -109,7 +123,7 @@
 			if(!empty($HeaderLogin) && $auth_type == 'Header')
 			{
 				/* header admin login */
-				if($FormPW == stripslashes($GLOBALS['phpgw_info']['server']['header_admin_password']))
+				if($FormPW == $GLOBALS['phpgw']->crypto->decrypt($GLOBALS['phpgw_info']['server']['header_admin_password']))
 				{
 					setcookie('HeaderPW',md5($FormPW),$expire);
 					setcookie('ConfigLang',$ConfigLang,$expire);
@@ -125,7 +139,8 @@
 			elseif(!empty($ConfigLogin) && $auth_type == 'Config')
 			{
 				/* config login */
-				if($FormPW == stripslashes(@$GLOBALS['phpgw_domain'][$FormDomain]['config_passwd']))
+//				if($FormPW == stripslashes(@$GLOBALS['phpgw_domain'][$FormDomain]['config_passwd']))
+				if($FormPW == $GLOBALS['phpgw']->crypto->decrypt($GLOBALS['phpgw_domain'][$FormDomain]['config_passwd']))
 				{
 					setcookie('ConfigPW', md5($FormPW), $expire);
 					setcookie('ConfigDomain', $FormDomain, $expire);
@@ -168,7 +183,7 @@
 			elseif(!empty($ConfigPW) && $auth_type == 'Config')
 			{
 				/* Returning after login to config */
-				if($ConfigPW == md5(stripslashes($GLOBALS['phpgw_domain'][$ConfigDomain]['config_passwd'])))
+				if($ConfigPW == md5($GLOBALS['phpgw']->crypto->decrypt($GLOBALS['phpgw_domain'][$ConfigDomain]['config_passwd'])))
 				{
 					setcookie('ConfigPW', $ConfigPW,  $expire);
 					setcookie('ConfigDomain', $ConfigDomain, $expire);
@@ -185,7 +200,13 @@
 			elseif(!empty($HeaderPW) && $auth_type == 'Header')
 			{
 				/* Returning after login to header admin */
-				if($HeaderPW == md5(stripslashes($GLOBALS['phpgw_info']['server']['header_admin_password'])))
+				if($HeaderPW == md5(@$GLOBALS['phpgw']->crypto->decrypt($GLOBALS['phpgw_info']['server']['header_admin_password'])))
+				{
+					setcookie('HeaderPW', $HeaderPW , $expire);
+					setcookie('ConfigLang', $ConfigLang, $expire);
+					return True;
+				}
+				else if($HeaderPW == md5(stripslashes($GLOBALS['phpgw_info']['server']['header_admin_password'])))
 				{
 					setcookie('HeaderPW', $HeaderPW , $expire);
 					setcookie('ConfigLang', $ConfigLang, $expire);
@@ -358,10 +379,14 @@
 					. intval($setup_info[$appname]['app_order']) . ", "
 					. "'$tables', "
 					. "'{$setup_info[$appname]['version']}')"
-					,__LINE__,__FILE__
+					,__LINE__,__FILE__, true
 				);
 				$this->clear_session_cache();
 			}
+			// hack to make phpgwapi_applications::name2id to work properly
+			unset($GLOBALS['phpgw_info']['apps']);
+			$GLOBALS['phpgw']->locations->add('run', "Automatically added on install - run {$appname}", $appname, false);
+			$GLOBALS['phpgw']->locations->add('admin', "Allow app admins - {$appname}", $appname, false);
 		}
 
 		/**
@@ -385,9 +410,9 @@
 				// _debug_array($setup_info[$appname]);
 			}
 
-			$this->db->query("SELECT COUNT(app_name) FROM phpgw_applications WHERE app_name='".$appname."'",__LINE__,__FILE__);
+			$this->db->query("SELECT COUNT(app_name) as cnt FROM phpgw_applications WHERE app_name='".$appname."'",__LINE__,__FILE__);
 			$this->db->next_record();
-			if($this->db->f(0))
+			if($this->db->f('cnt'))
 			{
 				if(@$GLOBALS['DEBUG'])
 				{
@@ -432,9 +457,9 @@
 				// _debug_array($setup_info[$appname]);
 			}
 
-			$this->db->query("SELECT COUNT(app_name) FROM $appstbl WHERE app_name='".$appname."'",__LINE__,__FILE__);
+			$this->db->query("SELECT COUNT(app_name) as cnt FROM $appstbl WHERE app_name='".$appname."'",__LINE__,__FILE__);
 			$this->db->next_record();
-			if(!$this->db->f(0))
+			if(!$this->db->f('cnt'))
 			{
 				return False;
 			}
@@ -510,6 +535,28 @@
 			$appname = $this->db->db_addslashes($appname);
 			$setup_info =& $GLOBALS['setup_info'];
 
+			// Clean up locations, custom fields and ACL
+			$this->db->query("SELECT app_id FROM phpgw_applications WHERE app_name = '{$appname}'");
+			$this->db->next_record();
+			$app_id = $this->db->f('app_id');
+
+			$this->db->query("SELECT location_id FROM phpgw_locations WHERE app_id = {$app_id}");
+
+			$locations = array();
+			while ($this->db->next_record())
+			{
+				$locations[] = $this->db->f('location_id');
+			}
+
+			if(count($locations))
+			{
+				$this->db->query('DELETE FROM phpgw_cust_choice WHERE location_id IN ('. implode (',',$locations) . ')');
+				$this->db->query('DELETE FROM phpgw_cust_attribute WHERE location_id IN ('. implode (',',$locations). ')');
+				$this->db->query('DELETE FROM phpgw_acl  WHERE location_id IN ('. implode (',',$locations) . ')');
+			}
+
+			$this->db->query("DELETE FROM phpgw_locations WHERE app_id = {$app_id}");
+
 			//echo 'DELETING application: ' . $appname;
 			$this->db->query("DELETE FROM phpgw_applications WHERE app_name='{$appname}'",__LINE__,__FILE__);
 			$this->clear_session_cache();
@@ -589,14 +636,13 @@
 			return $this->hooks->single($location,$appname,True,True);
 		}
 
-		/*
-		@function alessthanb
-		@abstract phpgw version checking, is param 1 < param 2 in phpgw versionspeak?
-		@param	$a	phpgw version number to check if less than $b
-		@param	$b	phpgw version number to check $a against
-		#return	True if $a < $b
+		/**
+		* phpgw version checking, is param 1 < param 2 in phpgw versionspeak?
+		* @param string $a phpgw version number to check if less than $b
+		* @param sting $b phpgw version number to check $a against
+		* @return bool True if $a < $b
 		*/
-		function alessthanb($a,$b,$DEBUG=False)
+		function alessthanb($a, $b, $DEBUG=False)
 		{
 			$num = array('1st','2nd','3rd','4th');
 
