@@ -7,7 +7,7 @@
 	* @license http://www.fsf.org/licenses/gpl.html GNU General Public License
 	* @package phpgwapi
 	* @subpackage application
-	* @version $Id: class.setup_detection.inc.php 17933 2007-02-10 13:18:43Z skwashd $
+	* @version $Id: class.setup_detection.inc.php 1040 2008-05-26 10:27:54Z dave $
 	*/
 
 	/**
@@ -28,7 +28,7 @@
 					$f = PHPGW_SERVER_ROOT . '/' . $entry . '/setup/setup.inc.php';
 					if ( file_exists($f) )
 					{
-						include($f);
+						require $f;
 						$setup_info[$entry]['filename'] = $f;
 					}
 				}
@@ -230,7 +230,7 @@
 			(
 				'phpgwapi'		=> true,
 				//if this isn't here, it can never be installed as it is part of the api - skwashd
-				'notifywindows'	=> true ,
+				'notifywindow'	=> true ,
 				'admin'			=> true,
 				'preferences'	=> true
 			);
@@ -413,11 +413,10 @@
 			}
 		}
 
-		/*
-		@function check_app_tables
-		@abstract	Verify that all of an app's tables exist in the db
-		@param $appname
-		@param $any		optional, set to True to see if any of the apps tables are installed
+		/**
+		* Verify that all of an app's tables exist in the db
+		* @param $appname
+		* @param $any optional, set to True to see if any of the apps tables are installed
 		*/
 		function check_app_tables($appname,$any=False)
 		{
