@@ -6,7 +6,7 @@
 	* @license http://www.fsf.org/licenses/gpl.html GNU General Public License
 	* @package phpgwapi
 	* @subpackage application
-	* @version $Id: class.setup_process.inc.php 18358 2007-11-27 04:43:37Z skwashd $
+	* @version $Id: class.setup_process.inc.php 4908 2010-02-24 20:49:33Z sigurd $
 	*/
 
 	/**
@@ -42,15 +42,20 @@
 		 */
 		function init_process()
 		{
-			$ConfigDomain = phpgw::get_var('ConfigDomain');
+			$ConfigDomain = phpgw::get_var('ConfigDomain','string', 'COOKIE');
 			$phpgw_domain = $GLOBALS['phpgw_domain'];
 
+			$_key = $GLOBALS['phpgw_info']['server']['setup_mcrypt_key'];
+			$_iv  = $GLOBALS['phpgw_info']['server']['mcrypt_iv'];
+			$crypto = createObject('phpgwapi.crypto',array($_key, $_iv));
+
+
 			$GLOBALS['phpgw_setup']->oProc = createObject('phpgwapi.schema_proc',$phpgw_domain[$ConfigDomain]['db_type']);
 			$GLOBALS['phpgw_setup']->oProc->m_odb           = $GLOBALS['phpgw_setup']->db;
-			$GLOBALS['phpgw_setup']->oProc->m_odb->Host     = $phpgw_domain[$ConfigDomain]['db_host'];
-			$GLOBALS['phpgw_setup']->oProc->m_odb->Database = $phpgw_domain[$ConfigDomain]['db_name'];
-			$GLOBALS['phpgw_setup']->oProc->m_odb->User     = $phpgw_domain[$ConfigDomain]['db_user'];
-			$GLOBALS['phpgw_setup']->oProc->m_odb->Password = $phpgw_domain[$ConfigDomain]['db_pass'];
+			$GLOBALS['phpgw_setup']->oProc->m_odb->Host     = $crypto->decrypt($phpgw_domain[$ConfigDomain]['db_host']);
+			$GLOBALS['phpgw_setup']->oProc->m_odb->Database = $crypto->decrypt($phpgw_domain[$ConfigDomain]['db_name']);
+			$GLOBALS['phpgw_setup']->oProc->m_odb->User     = $crypto->decrypt($phpgw_domain[$ConfigDomain]['db_user']);
+			$GLOBALS['phpgw_setup']->oProc->m_odb->Password = $crypto->decrypt($phpgw_domain[$ConfigDomain]['db_pass']);
 			$GLOBALS['phpgw_setup']->oProc->m_odb->Halt_On_Error = 'yes';
 			$GLOBALS['phpgw_setup']->oProc->m_odb->connect();
 		}
@@ -221,7 +226,8 @@
 				if ( isset($setup_info[$key]['tables'])
 					&& is_array($setup_info[$key]['tables']) )
 				{
-					foreach ( $setup_info[$key]['tables'] as $table )
+					//Tables has to be dropped in reversed order if they are referenced by others
+					foreach ( array_reverse($setup_info[$key]['tables']) as $table )
 					{
 						//echo $table;
 						if(in_array($table,$tables))
@@ -265,14 +271,14 @@
 
 				if($DEBUG) { echo '<br>process->current(): Incoming status: ' . $appname . ',status: '. $setup_info[$key]['status']; }
 
-				$appdir  = PHPGW_SERVER_ROOT . SEP . $appname . SEP . 'setup' . SEP;
+				$appdir  = PHPGW_SERVER_ROOT . "/{$appname}/setup/";
 
 				if ( isset($setup_info[$key]['tables']) 
 					&& $setup_info[$key]['tables'] 
 					&& file_exists("{$appdir}tables_current.inc.php") )
 				{
 					if($DEBUG) { echo '<br>process->current(): Including: ' . $appdir.'tables_current.inc.php'; }
-					include_once("{$appdir}tables_current.inc.php");
+					require_once "{$appdir}tables_current.inc.php";
 					$ret = $this->post_process($phpgw_baseline,$DEBUG);
 					if($ret)
 					{
@@ -348,20 +354,20 @@
 			foreach ( array_keys($setup_info) as $key )
 			{
 				$appname = isset($setup_info[$key]['name']) ? $setup_info[$key]['name'] : '';
-				$appdir  = PHPGW_SERVER_ROOT . SEP . $appname . SEP . 'setup' . SEP;
+				$appdir  = PHPGW_SERVER_ROOT . "/{$appname}/setup/";
 
-				if( isset($setup_info[$key]['tables'])
-					&& $setup_info[$key]['tables']
-					&& file_exists($appdir.'default_records.inc.php'))
+//				if( isset($setup_info[$key]['tables'])
+//					&& $setup_info[$key]['tables']
+//					&& file_exists($appdir.'default_records.inc.php'))
+				if( file_exists($appdir.'default_records.inc.php'))
 				{
 					if($DEBUG)
 					{
 						echo '<br>process->default_records(): Including default records for ' . $appname . "\n";
 					}
-					$GLOBALS['phpgw_setup']->oProc->m_odb->transaction_begin();
+
 					$oProc = &$GLOBALS['phpgw_setup']->oProc;	// to be compatible with old apps
-					include_once($appdir.'default_records.inc.php');
-					$GLOBALS['phpgw_setup']->oProc->m_odb->transaction_commit();
+					require_once $appdir.'default_records.inc.php';
 				}
 				/* $setup_info[$key]['status'] = 'C'; */
 			}
@@ -459,7 +465,7 @@
 			foreach($setup_info as $key => $ignored)
 			{
 				$appname = $setup_info[$key]['name'];
-				$appdir  = PHPGW_SERVER_ROOT . SEP . $appname . SEP . 'setup' . SEP;
+				$appdir  = PHPGW_SERVER_ROOT . "/{$appname}/setup/";
 
 				if(file_exists($appdir.'test_data.inc.php'))
 				{
@@ -468,7 +474,7 @@
 						echo '<br>process->test_data(): Including baseline test data for ' . $appname . "\n";
 					}
 					$GLOBALS['phpgw_setup']->oProc->m_odb->transaction_begin();
-					include_once($appdir.'test_data.inc.php');
+					require_once $appdir.'test_data.inc.php';
 					$GLOBALS['phpgw_setup']->oProc->m_odb->transaction_commit();
 				}
 			}
@@ -496,7 +502,7 @@
 			foreach($setup_info as $key => $ignored)
 			{
 				$appname = $setup_info[$key]['name'];
-				$appdir  = PHPGW_SERVER_ROOT . SEP . $appname . SEP . 'setup' . SEP;
+				$appdir  = PHPGW_SERVER_ROOT . "/{$appname}/setup/";
 
 				if(file_exists($appdir.'tables_baseline.inc.php'))
 				{
@@ -504,7 +510,7 @@
 					{
 						echo '<br>process->baseline(): Including baseline tables for ' . $appname . "\n";
 					}
-					include_once($appdir.'tables_baseline.inc.php');
+					require_once "{$appdir}tables_baseline.inc.php";
 					$GLOBALS['phpgw_setup']->oProc->GenerateScripts($phpgw_baseline, $DEBUG);
 					$this->post_process($phpgw_baseline,$DEBUG);
 
@@ -567,10 +573,10 @@
 						|| $setup_info[$key]['status'] == '' ) ) // TODO this is not getting set for api upgrade, sometimes ???
 				{
 					$appname    = $setup_info[$key]['name'];
-					$apptitle   = isset($setup_info[$key]['title']) ? $setup_info[$key]['title'] : '';
+					//$apptitle   = isset($setup_info[$key]['title']) ? $setup_info[$key]['title'] : '';
 					$currentver = $setup_info[$key]['currentver'];
 					$targetver  = $setup_info[$key]['version'];	// The version we need to match when done
-					$appdir     = PHPGW_SERVER_ROOT . SEP . $appname . SEP . 'setup' . SEP;
+					$appdir     = PHPGW_SERVER_ROOT . "/{$appname}/setup/";
 
 					$test   = array();
 					$GLOBALS['phpgw_setup']->oProc->m_aTables = $phpgw_baseline = array();
@@ -592,7 +598,7 @@
 						{
 							echo '<br>process->baseline(): Including baseline tables for ' . $appname . "\n";
 						}
-						include_once($appdir.'tables_baseline.inc.php');
+						require_once "{$appdir}tables_baseline.inc.php";
 						$GLOBALS['phpgw_setup']->oProc->m_aTables = $phpgw_baseline;
 						/* $GLOBALS['phpgw_setup']->oProc->GenerateScripts($phpgw_baseline, $DEBUG); */
 					}
@@ -606,14 +612,14 @@
 						break;
 						*/
 					}
-					if ( file_exists($appdir . 'tables_update.inc.php') )
+					if ( file_exists("{$appdir}tables_update.inc.php") )
 					{
-						include_once($appdir . 'tables_update.inc.php');
+						require_once("{$appdir}tables_update.inc.php");
 
 						if ( isset($test) && is_array($test) && count($test) )
 						{
 							/* $test array comes from update file.  It is a list of available upgrade functions */
-							foreach ( $test as $x => $value )
+							foreach ( $test as $value )
 							{
 								$currentver = isset($setup_info[$key]['currentver']) ? $setup_info[$key]['currentver'] : '';
 
@@ -821,6 +827,7 @@
 			}
 
 			$GLOBALS['phpgw_setup']->oProc->m_oTranslator->sCol = array();
+			$sColumns = '';
 			$GLOBALS['phpgw_setup']->oProc->m_oTranslator->_GetColumns($GLOBALS['phpgw_setup']->oProc, $tablename, $sColumns);
 
 			$arr = '';
@@ -840,4 +847,3 @@
 			return array($arr,$pk,$fk,$ix,$uc);
 		}
 	}
-?>
