@@ -7,17 +7,10 @@
 	* @license http://www.fsf.org/licenses/lgpl.html GNU Lesser General Public License
 	* @package phpgwapi
 	* @subpackage application
-	* @version $Id: class.setup_translation.inc.php 18358 2007-11-27 04:43:37Z skwashd $
+	* @version $Id: class.setup_translation.inc.php 6327 2010-09-11 14:04:15Z sigurd $
 	*/
 
-	if (!defined('MAX_MESSAGE_ID_LENGTH'))
-	{
-		/**
-		* Maximum message id length
-		*/
-		define('MAX_MESSAGE_ID_LENGTH',230);
-	}
-
+	phpgw::import_class('phpgwapi.translation');
 
 	/**
 	* Setup translation - Handles multi-language support using flat files
@@ -25,7 +18,7 @@
 	* @package phpgwapi
 	* @subpackage application
 	*/
-	class setup_translation
+	class phpgwapi_setup_translation extends phpgwapi_translation
 	{
 		var $langarray;
 
@@ -34,76 +27,64 @@
 		*
 		 * @param $lang	user lang variable (defaults to en)
 		 */
-		function setup_translation()
+		public function __construct()
 		{
-			$ConfigLang = phpgw::get_var('ConfigLang');
+			$ConfigLang = phpgw::get_var('ConfigLang', 'string', 'POST');
+			$this->set_userlang($ConfigLang);
 
-			if(!$ConfigLang)
-			{
-				$lang = 'en';
-			}
-			else
-			{
-				$lang = $ConfigLang;
-			}
-
-			$fn = '.' . SEP . 'lang' . SEP . 'phpgw_' . $lang . '.lang';
+			$fn = PHPGW_SERVER_ROOT . "/setup/lang/phpgw_{$this->userlang}.lang";
 			if (!file_exists($fn))
 			{
-				$fn = '.' . SEP . 'lang' . SEP . 'phpgw_en.lang';
+				$fn = PHPGW_SERVER_ROOT . '/phpgwapi/setup/phpgw_en.lang';
 			}
 
-			if (file_exists($fn))
+			$strings = $this->parse_lang_file($fn, $this->userlang);
+
+			if ( !is_array($strings) || !count($strings) )
 			{
-				$fp = fopen($fn,'r');
-				while ($data = fgets($fp,8000))
-				{
-					list($message_id,$app_name,$null,$content) = explode("\t",$data);
-					if ($app_name == 'setup' || $app_name == 'common' || $app_name == 'all')
-					{
-						$this->langarray[] = array(
-							'message_id' => $message_id,
-							'content'    => trim($content)
-						);
-					}
-				}
-				fclose($fp);
+				$this->lang[strtolower($string['message_id'])] = $string['content'];
+				echo "Unable to load lang file: {$fn}<br>String won't be translated";
+				return;
+			}
+			foreach ( $strings as $string )
+			{
+				$this->lang[strtolower($string['message_id'])] = $string['content'];
 			}
 		}
+
+		/**
+		* Populate shared memory with the available translation strings - disabled for setup
+		*/
+		public function populate_cache()
+		{}
 		
 		/**
 		 * Translate phrase to user selected lang
-		*
+		 *
 		 * @param $key  phrase to translate
 		 * @param $vars vars sent to lang function, passed to us
 		 */
-		function translate($key, $vars=False) 
+		public function translate($key, $vars = array(), $only_common = false ) 
 		{
-			if (!$vars)
+			if ( !is_array($vars) )
 			{
 				$vars = array();
 			}
 
 			$ret = $key;
 
-			@reset($this->langarray);
-			while(list($null,$data) = @each($this->langarray))
+			if ( isset($this->lang[strtolower($key)]) )
 			{
-				$lang[strtolower($data['message_id'])] = $data['content'];
-			}
-
-			if (isset($lang[strtolower ($key)]) && $lang[strtolower ($key)])
-			{
-				$ret = $lang[strtolower ($key)];
+				$ret = $this->lang[strtolower($key)];
 			}
 			else
 			{
-				$ret = $key.'*';
+				$ret = "!{$key}";
 			}
 			$ndx = 1;
-			while( list($key,$val) = each( $vars ) )
+			foreach ( $vars as $var )
 			{
-				$ret = preg_replace( "/%$ndx/", $val, $ret );
+				$ret = preg_replace( "/%$ndx/", $var, $ret );
 				++$ndx;
 			}
 			return $ret;
@@ -128,9 +109,9 @@
 			{
 				if($DEBUG)
 				{
-					echo '<br>get_langs(): found ' . $GLOBALS['phpgw_setup']->db->f(0);
+					echo '<br>get_langs(): found ' . $GLOBALS['phpgw_setup']->db->f('lang');
 				}
-				$langs[] = $GLOBALS['phpgw_setup']->db->f(0);
+				$langs[] = $GLOBALS['phpgw_setup']->db->f('lang');
 			}
 			return $langs;
 		}
@@ -146,21 +127,16 @@
 			{
 				echo '<br>drop_langs(): Working on: ' . $appname;
 			}
-			$GLOBALS['phpgw_setup']->db->query("SELECT COUNT(message_id) FROM phpgw_lang WHERE app_name='$appname'",__LINE__,__FILE__);
+			$GLOBALS['phpgw_setup']->db->query("SELECT COUNT(message_id) as cnt FROM phpgw_lang WHERE app_name='$appname'",__LINE__,__FILE__);
 			$GLOBALS['phpgw_setup']->db->next_record();
-			if($GLOBALS['phpgw_setup']->db->f(0))
+			if($GLOBALS['phpgw_setup']->db->f('cnt'))
 			{
 				if(function_exists('sem_get'))
 				{
-					if ( !isset($GLOBALS['phpgw']->shm) || !is_object($GLOBALS['phpgw']->shm) )
-					{
-						$GLOBALS['phpgw']->shm = CreateObject('phpgwapi.shm');
-					}
-
 					$GLOBALS['phpgw_setup']->db->query("SELECT lang FROM phpgw_lang WHERE app_name='$appname'",__LINE__,__FILE__);
 					while ($GLOBALS['phpgw_setup']->db->next_record())
 					{
-						$GLOBALS['phpgw']->shm->delete_key('lang_' . $GLOBALS['phpgw_setup']->db->f('lang'));
+						$GLOBALS['phpgw']->cache->system_clear('phpgwapi', 'lang_' . $GLOBALS['phpgw_setup']->db->f('lang'));
 					}
 				}
 
@@ -190,50 +166,48 @@
 				_debug_array($langs);
 			}
 
-			while (list($null,$lang) = each($langs))
+			foreach ( $langs as $lang )
 			{
+				// escape it here - that will increase the string length
+				$lang = $GLOBALS['phpgw_setup']->db->db_addslashes($lang);
+				if ( strlen($lang) != 2 )
+				{
+					continue; // invalid lang
+				}
+
+				$lang = strtolower($lang);
+
 				if($DEBUG)
 				{
 					echo '<br>add_langs(): Working on: ' . $lang . ' for ' . $appname;
 				}
-				$appfile = PHPGW_SERVER_ROOT . SEP . $appname . SEP . 'setup' . SEP . 'phpgw_' . strtolower($lang) . '.lang';
+				$appfile = PHPGW_SERVER_ROOT . "/{$appname}/setup/phpgw_{$lang}.lang";
 				if(file_exists($appfile))
 				{
 					if($DEBUG)
 					{
 						echo '<br>add_langs(): Including: ' . $appfile;
 					}
-					$raw_file = file($appfile);
+					$raw_file = $this->parse_lang_file($appfile, $lang);
 
 					foreach ( $raw_file as $line ) 
 					{
-						list($message_id,$app_name,$GLOBALS['phpgw_setup']->db_lang,$content) = explode("\t",$line);
-						if ( !strlen($content) )
-						{
-							echo "ERROR: Invalid translation entry: '$line'\n in /path/to/phpgroupware/$appname/setup/phpgw_$lang.lang<br>\n";
-						}
-
-						$message_id = $GLOBALS['phpgw_setup']->db->db_addslashes(chop(substr($message_id,0,MAX_MESSAGE_ID_LENGTH)));
+						$message_id = $GLOBALS['phpgw_setup']->db->db_addslashes(strtolower(substr($line['message_id'], 0, self::MAX_MESSAGE_ID_LENGTH)));
 						/* echo '<br>APPNAME:' . $app_name . ' PHRASE:' . $message_id; */
-						$app_name   = $GLOBALS['phpgw_setup']->db->db_addslashes(chop($app_name));
-						$GLOBALS['phpgw_setup']->db_lang    = $GLOBALS['phpgw_setup']->db->db_addslashes(chop($GLOBALS['phpgw_setup']->db_lang));
-						$content    = $GLOBALS['phpgw_setup']->db->db_addslashes(chop($content));
+						$app_name   = $GLOBALS['phpgw_setup']->db->db_addslashes($line['app_name']);
+						$content    = $GLOBALS['phpgw_setup']->db->db_addslashes($line['content']);
 
-						$GLOBALS['phpgw_setup']->db->query("SELECT COUNT(*) FROM phpgw_lang WHERE message_id='$message_id' and lang='"
-							. $GLOBALS['phpgw_setup']->db_lang . "'",__LINE__,__FILE__);
+						$GLOBALS['phpgw_setup']->db->query("SELECT COUNT(*) as cnt FROM phpgw_lang WHERE message_id='$message_id' AND app_name = '{$app_name}' AND lang='{$lang}' ", __LINE__, __FILE__);
 						$GLOBALS['phpgw_setup']->db->next_record();
-
-						if ($GLOBALS['phpgw_setup']->db->f(0) == 0)
+						if ($GLOBALS['phpgw_setup']->db->f('cnt') == 0)
 						{
 							if($message_id && $content)
 							{
 								if($DEBUG)
 								{
-									echo "<br>add_langs(): adding - INSERT INTO phpgw_lang VALUES ('$message_id','$app_name','"
-										. $GLOBALS['phpgw_setup']->db_lang . "','$content')";
+									echo "<br>add_langs(): adding - INSERT INTO phpgw_lang (message_id,app_name,lang,content) VALUES ('{$message_id}','{$app_name}','{$lang}','{$content}')";
 								}
-								$GLOBALS['phpgw_setup']->db->query("INSERT INTO phpgw_lang VALUES ('$message_id','$app_name','"
-									. $GLOBALS['phpgw_setup']->db_lang . "','$content')",__LINE__,__FILE__);
+								$GLOBALS['phpgw_setup']->db->query("INSERT INTO phpgw_lang (message_id,app_name,lang,content) VALUES ('{$message_id}','{$app_name}','{$lang}','{$content}')", __LINE__, __FILE__);
 							}
 						}
 					}
@@ -241,4 +215,3 @@
 			}
 		}
 	}
-?>
