@@ -63,15 +63,16 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package phpgwapi
 	* @subpackage application
- 	* @version $Id: class.shm.inc.php 18358 2007-11-27 04:43:37Z skwashd $
+ 	* @version $Id: class.shm.inc.php 1832 2008-11-15 15:35:58Z sigurd $
 	*/
 
 	//This makes sure there is something set for temp
-	if ( !isset($GLOBALS['phpgw_info']['server']['temp_dir']) )
+	if ( !isset($GLOBALS['phpgw_info']['server']['temp_dir'])  
+			|| !is_dir($GLOBALS['phpgw_info']['server']['temp_dir']) )
 	{
 		if ( substr(PHP_OS, 3) == 'WIN' )
 		{
-			$GLOBALS['phpgw_info']['server']['temp_dir'] = 'C:\\temp';
+			$GLOBALS['phpgw_info']['server']['temp_dir'] = 'c:/temp';
 		}
 		else
 		{
@@ -102,12 +103,12 @@
 	/**
 	* The path to store the lock files
 	*/
-	define('PHPGW_SHM_LOCK', PHPGW_SERVER_ROOT);
+	define('PHPGW_SHM_LOCK', $GLOBALS['phpgw_info']['server']['temp_dir']);
 
 	/**
 	* Shared memory handler class
 	*/
-	class shm
+	class phpgwapi_shm
 	{
 		/**
 		 * @var string $hashid the hash_table_key - example: 'lang_en'
@@ -117,7 +118,7 @@
 		/**
 		* Constructor
 		*/
-		function shm()
+		function __construct()
 		{}
  
 		/**
@@ -449,4 +450,20 @@
 			$this->garbage_collection();
 			ob_start("cache_end"); // callback
 		}
+
+		/**
+		* Check if shared memeory is enabled
+		*
+		* @return bool is it enabled?
+		*/
+		public static function is_enabled()
+		{
+			if ( isset($GLOBALS['phpgw_info']['server']['shm_enable'])  
+				&& $GLOBALS['phpgw_info']['server']['shm_enable'] )
+			{
+				return function_exists('sem_get') && function_exists('shmop_open');
+			}
+
+			return false;
+		}
 	}
