@@ -9,7 +9,7 @@
 	* @license http://www.fsf.org/licenses/gpl.html GNU General Public License
 	* @package phpgwapi
 	* @subpackage gui
-	* @version $Id: class.uijsaddressbook.inc.php 18358 2007-11-27 04:43:37Z skwashd $
+	* @version $Id: class.uijsaddressbook.inc.php 1040 2008-05-26 10:27:54Z dave $
 	* @internal Inherited some code from the addressbook.php file
 	*/
 
@@ -49,7 +49,7 @@
 	* the main frame its data is here by sending a call by the onLoad event (which is
 	* called just after we finish passing our data.
 	*/
-	class uijsaddressbook
+	class phpgwapi_uijsaddressbook
 	{
 		var $public_functions=array ('show' => True,
 						 'show_mainframe' => True,
