@@ -7,7 +7,7 @@
 	* @license http://www.fsf.org/licenses/lgpl.html GNU Lesser General Public License
 	* @package phpgwapi
 	* @subpackage vfs
-	* @version $Id: class.vfs_dav.inc.php 17757 2006-12-22 23:58:42Z Caeies $
+	* @version $Id: class.vfs_dav.inc.php 2519 2009-03-05 13:32:29Z sigurd $
 	*/
 
 	/**
@@ -103,10 +103,25 @@
 			{
 				$use_svn = true;
 				//so the 's' is kept
+
 				$this->basedir = preg_replace('/^svn/', 'http', $this->basedir);
+
 			}
-			$this->dav_user = isset($GLOBALS['phpgw_info']['user']['userid']) ? (string) $GLOBALS['phpgw_info']['user']['userid'] : '';
-			$this->dav_pwd = isset($GLOBALS['phpgw_info']['user']['passwd']) ? (string) $GLOBALS['phpgw_info']['user']['passwd'] : '';
+			
+			if(!$this->dav_user)
+			{
+				$this->dav_user = isset($GLOBALS['phpgw_info']['user']['userid']) ? (string) $GLOBALS['phpgw_info']['user']['userid'] : '';
+			}
+			//FIXME pwd has to be clear text.
+			if(!$this->dav_pwd)
+			{
+				$this->dav_pwd = isset($GLOBALS['phpgw_info']['user']['passwd']) ? (string) $GLOBALS['phpgw_info']['user']['passwd'] : '';
+			}
+			// For testing purpose:
+//			$this->dav_user = 'www-data';
+//			$this->dav_pwd = 'xxxxxx';
+
+
 			$parsed_url = parse_url($this->basedir);
 			$this->dav_host = $parsed_url['host'];
 			$this->dav_port = isset($parsed_url['port']) ? $parsed_url['port'] : '';
@@ -490,7 +505,7 @@
 				reset ($memberships);
 				while (list ($num, $group_array) = each ($memberships))
 				{
-					if ($owner_id == $group_array['account_id'])
+					if ($owner_id == $group_array->id)
 					{
 						$group_ok = 1;
 						break;
@@ -499,8 +514,7 @@
 			}
 
 			$acl = CreateObject ('phpgwapi.acl', $owner_id);
-			$acl->account_id = $owner_id;
-			$acl->read_repository ();
+			$acl->set_account_id($owner_id);
 
 			$rights = $acl->get_rights ($user_id);
 
@@ -510,7 +524,7 @@
 				reset ($memberships);
 				while (list ($num, $group_array) = each ($memberships))
 				{
-					$rights |= $acl->get_rights ($group_array['account_id']);
+					$rights |= $acl->get_rights ($group_array->id);
 				}
 			}
 
@@ -521,7 +535,7 @@
 			elseif (!$rights && $group_ok)
 			{
 				$conf = CreateObject('phpgwapi.config', 'phpgwapi');
-				$conf->read_repository();
+				$conf->read();
 				if ($conf->config_data['acl_default'] == 'grant')
 				{
 					return True;
@@ -537,12 +551,12 @@
 			}
 		}
 
-		/*
-		@function lock
-		@abstract DAV (class 2) locking - sets an exclusive write lock
-		@param string filename
-		@param relatives Relativity array
-		@result True if successfull 
+		/**
+		* DAV (class 2) locking - sets an exclusive write lock
+		*
+		* @param string filename
+		* @param relatives Relativity array
+		* @result True if successfull 
 		*/		
 		function lock ($data)
 		{
@@ -633,13 +647,12 @@
 		}
 
 		
-		/*
-		@function unlock
-		@abstract DAV (class 2) unlocking - unsets the specified lock
-		@param string filename
-		@param relatives Relativity array
-		@param tocken	The token for the lock we wish to remove.
-		@result True if successfull
+		/**
+		* DAV (class 2) unlocking - unsets the specified lock
+		* @param string filename
+		* @param relatives Relativity array
+		* @param token	The token for the lock we wish to remove.
+		* @return bool true if successfull
 		*/		
 		function unlock ($data)
 		{
@@ -677,16 +690,16 @@
 			}
 		}
 
-		/*
-		@function options
-		@abstract Allows querying for optional features - esp optional DAV features 
-		like locking
-		@param option	The option you want to test for.  Options include 'LOCKING'
-			'VIEW', 'VERSION-CONTROL (eventually) etc
-		@result true if the specified option is supported
-		@discussion This should really check the server.  Unfortunately the overhead of doing this
-		in every VFS instance is unacceptable (it essentially doubles the time for any request). Ideally
-		we would store these features in the session perhaps?
+		/**
+		* Allows querying for optional features - esp optional DAV features like locking
+		*
+		* @internal	This should really check the server.  Unfortunately the overhead of doing 
+		* this in every VFS instance is unacceptable (it essentially doubles the time for 
+		* any request). Ideally we would store these features in the session perhaps?
+		* 
+		* @param option	The option you want to test for.  Options include 'LOCKING'
+		*	'VIEW', 'VERSION-CONTROL (eventually) etc
+		* @return true if the specified option is supported
 		*/		
 		function options($option)
 		{
@@ -803,7 +816,9 @@
 			{
 				$parsed_url['pwd'] = $this->dav_pwd;
 			}
+
 			$location = $this->glue_url($parsed_url);
+
 			header( 'Location: '.$location, true);
 			$GLOBALS['phpgw']->common->phpgw_exit();
 		}
@@ -1549,7 +1564,7 @@ $this->debug('cp : success '.$result);
 				if ( substr($p->fake_leading_dirs, 0, strlen($homedir)) == $homedir)
 				{ 
 					$conf = CreateObject('phpgwapi.config', 'phpgwapi');
-					$conf->read_repository();
+					$conf->read();
 					if ($conf->config_data['acl_default'] != 'grant')
 					{
 						$htaccess = 'require user '.$GLOBALS['phpgw_info']['user']['account_lid'];
@@ -1686,20 +1701,17 @@ $this->debug('cp : success '.$result);
 			}
 			if (isset($data['attributes']['owner_id']) && $id=$data['attributes']['owner_id'])
 			{
-				$GLOBALS['phpgw']->accounts->get_account_name($id,$lid,$fname,$lname);
-				$dav_properties['dc:publisher'] = $fname .' '. $lname;
+				$dav_properties['dc:publisher'] = (string) $GLOBALS['phpgw']->accounts->get($id);
 				$dav_properties['publisher_id'] = $id;
 			}
 			if (isset($data['attributes']['createdby_id']) && $id=$data['attributes']['createdby_id'])
 			{
-				$GLOBALS['phpgw']->accounts->get_account_name($id,$lid,$fname,$lname);
-				$dav_properties['dc:creator'] = $fname .' '. $lname;
+				$dav_properties['dc:creator'] = (string) $GLOBALS['phpgw']->accounts->get($id);
 				$dav_properties['creator_id'] = $id;
 			}
 			if (isset($data['attributes']['modifiedby_id']) && $id=$data['attributes']['modifiedby_id'])
 			{
-				$GLOBALS['phpgw']->accounts->get_account_name($id,$lid,$fname,$lname);
-				$dav_properties['dc:contributor'] = $fname .' '. $lname;
+				$dav_properties['dc:contributor'] = (string) $GLOBALS['phpgw']->accounts->get($id);
 				$dav_properties['contributor_id'] = $id;
 			}
 			if (isset($data['attributes']['app']) && $id=$data['attributes']['app'])
@@ -1903,7 +1915,7 @@ $this->debug('ls branch 2 (outside)',DEBUG_LS);
 						}
 
 						$rarray[] = $this->get_real_info (array(
-								'string'	=> $p->real_full_path . SEP . $filename,
+								'string'	=> "{$p->real_full_path}/{$filename}",
 								'relatives'	=> array ($p->mask)
 							)
 						);
@@ -1982,16 +1994,16 @@ $this->debug('ls branch 3',DEBUG_LS);
 					* since forbiden infinite recursion is a good idea 
 					* to avoid DoS 
 					*/
-/*_debug_array($p->fake_full_path.$value['name'].SEP);*/
-//					$datanew['string'] = $p->fake_full_path.SEP.$value['name'];
-					$datanew['string'] = preg_replace('#[/]+#','/',$p->fake_full_path.SEP.$value['name']);
+/*_debug_array($p->fake_full_path.$value['name'].'/');*/
+//					$datanew['string'] = "{$p->fake_full_path}/{$value['name']};
+					$datanew['string'] = preg_replace('#[/]+#','/', "{$p->fake_full_path}/{$value['name']}");
 					$tmp = $this->ls($datanew);
 					foreach($tmp as $f)
 					{
 						//If ls is working well, 
 						//the returned ls match the values
 						//except if the directory is protected
-						if ( $f['directory'].SEP.$f['name'] != $p->fake_full_path.SEP.$value['name'] )
+						if ( "{$f['directory']}/{$f['name']}" != "{$p->fake_full_path}/{$value['name']}" )
 							$rarray[] = $f;
 					}
 				}
