@@ -8,7 +8,7 @@
 	* @license http://www.fsf.org/licenses/lgpl.html GNU Lesser General Public License
 	* @package phpgwapi
 	* @subpackage vfs
-	* @version $Id: class.vfs_shared.inc.php 17757 2006-12-22 23:58:42Z Caeies $
+	* @version $Id: class.vfs_shared.inc.php 5187 2010-04-13 08:38:09Z sigurd $
 	*/
 
 	/**
@@ -227,6 +227,7 @@
 
 			//Load the override_locks
 			$this->locks_restore_session();
+			$this->mime_magic = createObject('phpgwapi.mime_magic');
 		}
 
 		/*
@@ -1152,14 +1153,7 @@
 				return $data['string'];
 			}
 
-			if ($data['fake'])
-			{
-				$sep = '/';
-			}
-			else
-			{
-				$sep = SEP;
-			}
+			$sep = '/';
 
 			/* if RELATIVE_CURRENT, retrieve the current mask */
 			if ($data['mask'][0] & RELATIVE_CURRENT)
@@ -1233,14 +1227,24 @@
 		 *  * string	Real path to file, with or without leading paths
 		 *  * @return String.  MIME type based on file extension.
 		  */
-		function get_ext_mime_type ($data)
+		function get_ext_mime_type($data)
 		{
 			if (!is_array ($data))
 			{
-				$data = array ();
+				return '';
 			}
 
-			$file=basename($data['string']);
+			$path_parts = pathinfo($data['string']);
+
+			if(!isset($path_parts['extension']) || !$path_parts['extension'])
+			{
+				return '';
+			}
+			$file = $path_parts['basename'];
+
+			return $this->mime_magic->filename2mime($file);
+/*
+			$file = basename($data['string']);
 			$mimefile=PHPGW_API_INC.'/phpgw_mime.types';
 			$fp=fopen($mimefile,'r');
 			$contents = explode("\n",fread($fp,filesize($mimefile)));
@@ -1268,6 +1272,7 @@
 			}
 
 			return '';
+*/
  		}
 
 		/* PUBLIC functions (mandatory) they don't need to be implemented
@@ -1386,7 +1391,7 @@
 
 			$data = array_merge ($this->default_values ($data, $default_values), $data);
 
-			$sep = SEP;
+			$sep = '/';
 
 			$rarray['mask'] = RELATIVE_NONE;
 			$fake = false;
@@ -1501,7 +1506,7 @@
 					if (ereg ("^$link_info[directory]/$link_info[name](/|$)", $rarray['fake_full_path']))
 					{
 						$rarray['real_full_path'] = ereg_replace ("^$this->basedir", '', $rarray['real_full_path']);
-						$rarray['real_full_path'] = ereg_replace ("^$link_info[directory]" . SEP . "$link_info[name]", $link_info['link_directory'] . SEP . $link_info['link_name'], $rarray['real_full_path']);
+						$rarray['real_full_path'] = ereg_replace ("^{$link_info['directory']}/{$link_info['name']}", "{$link_info['link_directory']}/{$link_info['link_name']}", $rarray['real_full_path']);
 
 						$p = $this->path_parts (array(
 								'string'	=> $rarray['real_full_path'],
@@ -1594,14 +1599,7 @@
 
 			$data = array_merge ($this->default_values ($data, $default_values), $data);
 
-			if ($data['relatives'][0] & VFS_REAL)
-			{
-				$sep = SEP;
-			}
-			else
-			{
-				$sep = '/';
-			}
+			$sep = '/';
 
 			if ($data['relative'] == 'relative' || $data['relative'] == True)
 			{
