@@ -8,7 +8,7 @@
 	* @license http://www.fsf.org/licenses/lgpl.html GNU Lesser General Public License
 	* @package phpgwapi
 	* @subpackage vfs
-	* @version $Id: class.vfs_sql.inc.php 18302 2007-10-07 09:47:59Z sigurdne $
+	* @version $Id: class.vfs_sql.inc.php 6388 2010-09-23 12:44:16Z sigurd $
 	*/
 
 	/**
@@ -63,7 +63,7 @@
 			   in the database.
 			*/
 			$conf = CreateObject('phpgwapi.config', 'phpgwapi');
-			$conf->read_repository();
+			$conf->read();
 			if ($conf->config_data['file_store_contents'] == 'filesystem' || !$conf->config_data['file_store_contents'])
 			{
 				$this->file_actions = 1;
@@ -720,7 +720,7 @@
 				reset ($memberships);
 				while (list ($num, $group_array) = each ($memberships))
 				{
-					if ($owner_id == $group_array['account_id'])
+					if ($owner_id == $group_array->id)
 					{
 						$group_ok = 1;
 						break;
@@ -729,8 +729,7 @@
 			}
 
 			$acl = CreateObject ('phpgwapi.acl', $owner_id);
-			$acl->account_id = $owner_id;
-			$acl->read_repository ();
+			$acl->set_account_id($owner_id, true);
 
 			$rights = $acl->get_rights ($user_id);
 
@@ -740,7 +739,7 @@
 				reset ($memberships);
 				while (list ($num, $group_array) = each ($memberships))
 				{
-					$rights |= $acl->get_rights ($group_array['account_id']);
+					$rights |= $acl->get_rights ($group_array->id);
 				}
 			}
 
@@ -751,7 +750,7 @@
 			elseif (!$rights && $group_ok)
 			{
 				$conf = CreateObject('phpgwapi.config', 'phpgwapi');
-				$conf->read_repository();
+				$conf->read();
 				if ($conf->config_data['acl_default'] == 'grant')
 				{
 					return True;
@@ -801,7 +800,7 @@
 			}
 
 			$conf = CreateObject('phpgwapi.config', 'phpgwapi');
-			$conf->read_repository();
+			$conf->read();
 			if ($this->file_actions || $p->outside)
 			{
 				if (filesize ($p->real_full_path) > 0 && $fp = fopen ($p->real_full_path, 'rb'))
@@ -889,7 +888,7 @@
 			);
 
 			$conf = CreateObject('phpgwapi.config', 'phpgwapi');
-			$conf->read_repository();
+			$conf->read();
 			if ($this->file_actions)
 			{
 				if ($fp = fopen ($p->real_full_path, 'wb'))
@@ -1781,7 +1780,7 @@
 						return False;
 					}
 				}
-				elseif (!@mkdir ($p->real_full_path, 0770))
+				elseif (!mkdir ($p->real_full_path, 0770))
 				{
 					return False;
 				}
@@ -1990,7 +1989,9 @@
 			$edited_comment = False;
 
 			reset ($this->attributes);
-			while (list ($num, $attribute) = each ($this->attributes))
+			$value_set = array();
+//			while (list ($num, $attribute) = each ($this->attributes))
+			foreach ($this->attributes as $num => $attribute)
 			{
 				if (isset ($data['attributes'][$attribute]))
 				{
@@ -2005,14 +2006,22 @@
 						$edited_comment = True;
 					}
 
+					if ($attribute == 'owner_id' && !$$attribute)
+					{
+						$$attribute = $GLOBALS['phpgw_info']['user']['account_id'];
+					}
+
 					$$attribute = $this->clean_string (array ('string' => $$attribute));
 
+/*
 					if ($change_attributes > 0)
 					{
 						$sql .= ', ';
 					}
 
 					$sql .= "$attribute='" . $$attribute . "'";
+*/
+					$value_set[$attribute] = $$attribute;
 
 					$change_attributes++;
 				}
@@ -2020,7 +2029,8 @@
 
 			if ( $change_attributes )
 			{
-				$sql .= ' WHERE file_id=' . intval($record['file_id']);
+				$value_set	= $GLOBALS['phpgw']->db->validate_update($value_set);
+				$sql .= " {$value_set} WHERE file_id=" . (int)$record['file_id'];
 				$sql .= $this->extra_sql (array ('query_type' => VFS_SQL_UPDATE));
 
 				//echo 'sql: ' . $sql;
@@ -2285,7 +2295,7 @@
 							continue;
 						}
 						$rarray[] = $this->get_real_info (array(
-								'string'	=> $p->real_full_path . SEP . $filename,
+								'string'	=> "{$p->real_full_path}/{$filename}",
 								'relatives'	=> array ($p->mask)
 							)
 						);
@@ -2507,4 +2517,3 @@
 			return ($rarray);
 		}
 	}
-?>
