@@ -8,18 +8,22 @@
 	* @license http://www.gnu.org/licenses/lpl.html GNU General Public License
 	* @package phpgwapi
 	* @subpackage gui
-	* @version $Id: class.xslttemplates.inc.php 18358 2007-11-27 04:43:37Z skwashd $
+	* @version $Id: class.xslttemplates.inc.php 6092 2010-06-17 10:45:38Z sigurd $
 	*/
 
 	if( !extension_loaded('xsl') )
 	{
 		die('PHP CONFIGURATION. xslt-extension is not loaded. Please contact the system administrator.');
 	}
-	
+
+	phpgw::import_class('phpgwapi.browser');	
+
 	/**
 	* Include xml tool
 	*/
-	require_once('class.xmltool.inc.php');
+	phpgw::import_class('phpgwapi.xmlhelper');
+//	phpgw::import_class('phpgwapi.xmltool');
+
 
 	/**
 	* XSLT template engine
@@ -27,7 +31,7 @@
 	* @package phpgwapi
 	* @subpackage gui
 	*/
-	class xslttemplates
+	class phpgwapi_xslttemplates
 	{
 		var $rootdir = '';
 		var $prev_rootdir = '';
@@ -54,7 +58,12 @@
 		var $xmlvars = array();
 		var $xmldata = '';
 
-		function xslttemplates($root = '.')
+		/**
+		* Constructor
+		*
+		* @param string $root the root directory
+		*/
+		function __construct($root = '.')
 		{
 			//FIXME Print view/mode should be handled by CSS not different markup
 			if ( isset($GLOBALS['phpgw_info']['flags']['printview']) && $GLOBALS['phpgw_info']['flags']['printview'] )
@@ -62,12 +71,17 @@
 				$this->print = true;
 			}
 			$this->set_root($root);
-			if ( execMethod('phpgwapi.browser.is_mobile') )
+			if ( phpgwapi_browser::is_mobile() )
 			{
 				$this->set_output('wml');
 			}
 		}
 
+		/**
+		* Error hanlder
+		*
+		* @param string $msg the error message
+		*/
 		function halt($msg)
 		{
 			die($msg);
@@ -112,61 +126,61 @@
 
 		function add_file($filename, $rootdir='', $time=1)
 		{
-			if (!is_array($filename))
-			{
-				if($rootdir=='')
-				{
-					$rootdir=$this->rootdir;
-				}
-
-				if (substr($filename, 0, 1) != SEP && substr($filename, 1, 1) != ':')
-				{
-					$new_filename = $rootdir . SEP . $filename;
-				}
-				else
-				{
-					$new_filename = $filename;
-				}
-
-//				echo 'Rootdir: '.$rootdir.'<br>'."\n".'Filename: '.$filename.'<br>'."\n".'New Filename: '.$new_filename.'<br>'."\n";
-				if (!file_exists($new_filename.'.xsl'))
-				{
-					switch($time)
-					{
-						case 2:
-							$new_root = str_replace($GLOBALS['phpgw_info']['server']['template_set'],'base',$rootdir);
-							$this->add_file($filename,$new_root,3);
-							return true;
-						case 3:
-							$new_root = PHPGW_SERVER_ROOT . '/phpgwapi/templates/' . $GLOBALS['phpgw_info']['server']['template_set'];
-							$this->add_file($filename,$new_root,4);
-							return true;
-						case 4:
-							$new_root = PHPGW_SERVER_ROOT . '/phpgwapi/templates/base';
-							$this->add_file($filename,$new_root,5);
-							return true;
-						case 5:
-							$this->add_file($filename,$rootdir,6);
-							return true;
-						case 6:
-							$this->halt("filename: file $new_filename.xsl does not exist.");
-							break true;
-						default:
-							$this->add_file($filename,$rootdir,2);
-							return true;
-					}
-				}
-				else
-				{
-					$this->xslfiles[$filename] = $new_filename.'.xsl';
-				}
-			}
-			else
+			if ( is_array($filename) )
 			{
 				foreach ( $filename as $file )
 				{
 					$this->add_file($file);
 				}
+				return;
+			}
+
+			if($rootdir=='')
+			{
+				$rootdir=$this->rootdir;
+			}
+
+			if ( substr($filename, 0, 1) != '/' 
+				&& substr($filename, 1, 1) != ':' )
+			{
+				$new_filename = "{$rootdir}/{$filename}";
+			}
+			else
+			{
+				$new_filename = $filename;
+			}
+
+//				echo 'Rootdir: '.$rootdir.'<br>'."\n".'Filename: '.$filename.'<br>'."\n".'New Filename: '.$new_filename.'<br>'."\n";
+			if (!file_exists($new_filename.'.xsl'))
+			{
+				switch($time)
+				{
+					case 2:
+						$new_root = PHPGW_SERVER_ROOT . str_replace($GLOBALS['phpgw_info']['server']['template_set'], 'base', substr($rootdir,strlen(PHPGW_SERVER_ROOT)));
+						$this->add_file($filename, $new_root, 3);
+						return true;
+					case 3:
+						$new_root = PHPGW_SERVER_ROOT . '/phpgwapi/templates/' . $GLOBALS['phpgw_info']['server']['template_set'];
+						$this->add_file($filename, $new_root, 4);
+						return true;
+					case 4:
+						$new_root = PHPGW_SERVER_ROOT . '/phpgwapi/templates/base';
+						$this->add_file($filename, $new_root, 5);
+						return true;
+					case 5:
+						$this->add_file($filename, $rootdir, 6);
+						return true;
+					case 6:
+						$this->halt("filename: file $new_filename.xsl does not exist.");
+						break true;
+					default:
+						$this->add_file($filename, $rootdir, 2);
+						return true;
+				}
+			}
+			else
+			{
+				$this->xslfiles[$filename] = $new_filename.'.xsl';
 			}
 		}
 
@@ -230,7 +244,7 @@
 		*/
 		function xsl_parse()
 		{
-			if( is_array($this->xslfiles) && count($this->xslfiles) > 0)
+			if ( is_array($this->xslfiles) && count($this->xslfiles) )
 			{
 				$this->xsldata = <<<XSLT
 <?xml version="1.0" encoding="UTF-8"?>
@@ -254,7 +268,7 @@ XSLT;
 
 					case 'html':
 					default:
- 						$this->xsldata .= '<xsl:output method="html" version="1.0" encoding="utf-8" indent="yes" omit-xml-declaration="yes" standalone="yes" doctype-system="http://www.w3.org/TR/html4/strict.dtd" doctype-public="-//W3C//DTD HTML 4.01//EN" media-type="text/html"/>' . "\n";
+ 						$this->xsldata .= '<xsl:output method="html" version="4.01" encoding="utf-8" indent="yes" omit-xml-declaration="yes" standalone="yes" doctype-system="http://www.w3.org/TR/html4/loose.dtd" doctype-public="-//W3C//DTD HTML 4.01//EN" media-type="text/html"/>' . "\n";
 				}
 				
 				$this->xsldata .= <<<XSLT
@@ -281,7 +295,6 @@ XSLT;
 		function xml_parse()
 		{
 			$this->xmldata = '';
-			$xmlvars = $this->xmlvars;
 
 			$xmldata = $this->vars;
 
@@ -290,29 +303,54 @@ XSLT;
 			{
 				$xmldata[$key] = $value;
 			}
-			$this->xmldata = var2xml('PHPGW', $xmldata);
 
-			/*
+		//	$this->xmldata = var2xml('PHPGW', $xmldata);
+			//use simplexml - it's faster.
+			$this->xmldata = phpgwapi_xmlhelper::toXML($xmldata, 'PHPGW');
+
+			$debug = false;
+		//	$debug = true;			
+			if ($debug)
+			{
+				//$this->xmldata = str_replace("\n",'' ,$this->xmldata);
+				$doc = new DOMDocument;
+				$doc->preserveWhiteSpace = true;
+				$doc->loadXML( $this->xmldata );
+				$doc->formatOutput = true;
+				$xml = $doc->saveXML();
+				unset($doc);
+
 				echo "<textarea cols='200' rows='20'>";
-				echo $this->xmldata;
+				echo $xml;
 				echo "</textarea><br>";
-			*/
+			}
 			
 			return $this->xmldata;
 		}
 
-		function list_lineno($xml)
+		function list_lineno($xmldata, $format = false)
 		{
+			if ($format)
+			{
+				$doc = new DOMDocument;
+				$doc->preserveWhiteSpace = false;
+				$doc->loadXML( $xmldata );
+				$doc->formatOutput = true;
+				$xml = $doc->saveXML();
+				unset($doc);
+			}
+			else
+			{
+				$xml = $xmldata;
+			}
+
 			$lines = explode("\n", $xml);
 			unset($xml);
-
-			echo "<ol>\n";
-			$i = 1;
+			unset($xmldata);
+			echo "<ol class=\"source\">\n";
 			foreach ( $lines as $line )
 			{
-				$row = ($i % 2) ? 'row_on' : 'row_off';
-				echo "<li class=\"{$row}\" style=\"white-space: pre;\">" . htmlentities($line) . "</li>\n";
-				++$i;
+				echo "<li>" . htmlentities($line,ENT_COMPAT,'utf-8') . "</li>\n";
 			}
 			echo "</ol>\n";
 		}
@@ -344,6 +382,7 @@ XSLT;
 
 			// Configure the transformer
 			$proc = new XSLTProcessor;
+			$proc->registerPHPFunctions();
 			$proc->importStyleSheet($xsl); // attach the xsl rules
 
 			$html =  trim($proc->transformToXML($xml));
@@ -351,7 +390,7 @@ XSLT;
 			if (!$html || $html == '<?xml version="1.0"?>')
 			{
 				echo "<h2>xml-data</h2>";
-				$this->list_lineno($this->xmldata);
+				$this->list_lineno($this->xmldata, true);
 
 				echo "<h2>xsl-data</h2>";
 				$this->list_lineno($this->xsldata);
@@ -370,4 +409,3 @@ XSLT;
 			return $this->pparse();
 		}
 	}
-?>
