@@ -7,9 +7,8 @@
 	* @license http://www.fsf.org/licenses/lgpl.html GNU Lesser General Public License
 	* @package phpgwapi
 	* @subpackage utilities
-	* @version $Id: footer.inc.php 17286 2006-09-30 11:47:12Z skwashd $
+	* @version $Id: footer.inc.php 4618 2010-01-24 17:32:33Z sigurd $
 	*/
-
 	/**************************************************************************\
 	* Include the apps footer files if it exists                               *
 	\**************************************************************************/
@@ -26,15 +25,15 @@
 		}
 		elseif(file_exists(PHPGW_APP_INC.'/footer.inc.php'))
 		{
-			include_once(PHPGW_APP_INC . '/footer.inc.php');
+			require_once PHPGW_APP_INC . '/footer.inc.php';
 		}
 	}
 	elseif(file_exists(PHPGW_APP_INC.'/footer.inc.php'))
 	{
-		include_once(PHPGW_APP_INC . '/footer.inc.php');
+		require_once PHPGW_APP_INC . '/footer.inc.php';
 	}
 
-	if (DEBUG_TIMER)
+	if (isset($GLOBALS['phpgw_info']['user']['apps']['admin']) && DEBUG_TIMER)
 	{
 		$debug_timer_stop = perfgetmicrotime();
 		echo '<p class="api_timer">' . lang('page prepared in %1 seconds.', $debug_timer_stop - $GLOBALS['debug_timer_start'] ) . "<p>\n";
@@ -44,4 +43,3 @@
 	{
 		parse_navbar_end();
 	}
-?>
