@@ -8,10 +8,10 @@
 	* @license http://www.fsf.org/licenses/lgpl.html GNU Lesser General Public License
 	* @package phpgwapi
 	* @subpackage utilities
-	* @version $Id: functions.inc.php 18358 2007-11-27 04:43:37Z skwashd $
+	* @version $Id: functions.inc.php 6048 2010-06-12 15:28:01Z sigurd $
 	*/
-	
-	
+
+
 	if (!function_exists('filter_var')) // ext/filter was added in 5.2.0
 	{
 		die('<p class="msg">'
@@ -19,7 +19,7 @@
 			. '</p></body></html>');
 	}
 
-	include_once(PHPGW_API_INC.'/common_functions.inc.php');
+	require_once PHPGW_API_INC.'/common_functions.inc.php';
 
 	/**
 	* Translate a string to a user's prefer language - convience method
@@ -48,23 +48,34 @@
 		{
 			$vars = array($m1,$m2,$m3,$m4,$m5,$m6,$m7,$m8,$m9,$m10);
 		}
+
+		// Support DOMNodes from XSL templates
+		foreach($vars as &$var)
+		{
+			if (is_object($var) && $var instanceof DOMNode)
+			{
+				$var = $var->nodeValue;
+			}
+		}
+
+
 		if ( !isset($GLOBALS['phpgw']->translation) || !is_object($GLOBALS['phpgw']->translation) )
 		{
 			$str = $key;
 			for ( $i = 10; $i > 0; --$i )
-			{	
+			{
 				$var = "m{$i}";
 				$str = preg_replace("/(%$i)+/", $$var, $str);
 			}
 			return "$str*#*";
 		}
-		return $GLOBALS['phpgw']->translation->translate("$key", $vars);
+		return $GLOBALS['phpgw']->translation->translate($key, $vars);
 	}
 
 	/**
 	* cleans up a backtrace array and converts it to a string
 	*
-	* @internal this is such an ugly piece of code due to a reference to the error context 
+	* @internal this is such an ugly piece of code due to a reference to the error context
 	* being in the backtrace and the error context can not be edited - see php.net/set_error_handler
 	* @param array $bt php backtrace
 	* @return string the formatted backtrace, empty if the user is not an admin
@@ -76,86 +87,88 @@
 			return '';
 		}
 
-		$trace = array();
-		$trace[0] = array();
-
-		if ( isset($bt[0]['function']) )
-		{
-			$trace[0]['function'] = $bt[0]['function'];
-		}
-
-		if ( isset($bt[0]['args']) && is_array($bt[0]['args']) && count($bt[0]['args']) )
-		{
-			$trace[0]['args'] = array($bt[0]['args'][0], $bt[0]['args'][1], $bt[0]['args'][2],  $bt[0]['args'][3], '***error_handler_content_data***');
-		}
-
-		if ( isset($bt[0]['file']) )
-		{
-			$trace[0]['file'] = $bt[0]['file'];
-		}
-
-		if ( isset($bt[0]['line']) )
-		{
-			$trace[0]['line'] = $bt[0]['line'];
-		}
+		// we don't need the call to the error handler
 		unset($bt[0]);
+		$bt = array_reverse($bt);
 
-		foreach ( $bt as $num => $entry )
+		$trace = '&nbsp;';
+		$i = 0;
+		foreach ( $bt as $entry )
 		{
-			if ( isset($entry['file']) )
-			{
-				$trace[$num]['file'] = '/path/to/phpgroupware' . substr($entry['file'], strlen(PHPGW_SERVER_ROOT) );
-			}
-
-			if ( isset($entry['line']) )
-			{
-				$trace[$num]['line'] = $entry['line'];
-			}
-
-			if ( isset($entry['line']) )
-			{
-				$trace[$num]['line'] = $entry['line'];
-			}
+			$line = "#{$i}\t";
 
 			if ( isset($entry['type']) && isset($entry['class']) )
 			{
-				$trace[$num]['function'] = "{$entry['class']}{$entry['type']}{$entry['function']}";
+				$line .= "{$entry['class']}{$entry['type']}{$entry['function']}";
 			}
 			else
 			{
-				$trace[$num]['function'] = $entry['function'];
+				$line .= $entry['function'];
 			}
 
+			$line .= '(';
+
 			if ( isset($entry['args']) && is_array($entry['args']) && count($entry['args']) )
 			{
+				$args_count = count($entry['args']);
 				foreach ( $entry['args'] as $anum => $arg )
 				{
 					if ( is_array($arg) )
 					{
-						$trace[$num]['args'][$anum] = print_r($arg, true);
+						$line .= 'serialized_value = ' . serialize($arg);
 						continue;
 					}
 
 					// Drop passwords from backtrace
-					if ( !is_object($arg) 
-						&& ($arg == $GLOBALS['phpgw_info']['server']['header_admin_password']
+					if ( $arg == $GLOBALS['phpgw_info']['server']['header_admin_password']
 						|| (isset($GLOBALS['phpgw_info']['server']['db_pass']) && $arg == $GLOBALS['phpgw_info']['server']['db_pass'])
 						|| (isset($GLOBALS['phpgw_info']['user']['passwd']) && $arg == $GLOBALS['phpgw_info']['user']['passwd'] ) )
-					)
 					{
-						$trace[$num]['args'][$anum] = '***PASSWORD***';
+						$line .= '***REMOVED_FOR_SECURITY***';
+					}
+					else if(is_object($arg))
+					{
+						continue;
 					}
 					else
 					{
-						$trace[$num]['args'][$anum] = $arg;
+						$line .= $arg;					
+					}
+
+					if ( ($anum + 1) != $args_count )
+					{
+						$line .= ', ';
 					}
 				}
 			}
+
+			$file = 'unknown';
+			if ( isset($entry['file']) )
+			{
+				if ( !isset($GLOBALS['phpgw_info']['user']['apps']['admin']) )
+				{
+					$file = '/path/to/phpgroupware' . substr($entry['file'], strlen(PHPGW_SERVER_ROOT) );
+				}
+				else
+				{
+					$file = $entry['file'];
+				}
+			}
+
+			if ( isset($entry['line']) )
+			{
+				$file .= ":{$entry['line']}";
+			}
 			else
 			{
-				$trace[$num]['args'] = 'NONE';
+				$file .= ':?';
 			}
+
+			$line .= ") [$file]";
+			$trace .= "$line\n";
+			++$i;
 		}
+
 		return print_r($trace, true);
 	}
 
@@ -173,24 +186,63 @@
 	* phpGroupWare generic error handler
 	*
 	* @link http://php.net/set_error_handler
-	* 
+	*
 	*/
 	function phpgw_handle_error($error_level, $error_msg, $error_file, $error_line, $error_context = array())
 	{
-		if ( error_reporting() == 0 ) // 0 == @function() so we ignore it, as the dev requested 
+
+		if ( error_reporting() == 0 ) // 0 == @function() so we ignore it, as the dev requested
 		{
 			return true;
 		}
+/*
+_debug_array($error_level);
+_debug_array($error_msg);
+_debug_array($error_file);
+_debug_array($error_line);
+//_debug_array($bt = debug_backtrace());die();
+*/
+		if(isset($GLOBALS['phpgw_info']['server']['log_levels']['global_level']))
+		{
+			switch ($GLOBALS['phpgw_info']['server']['log_levels']['global_level'])
+			{
+				case 'F': // Fatal
+				case 'E': // Error
+					$error_reporting = E_ERROR | E_USER_ERROR |E_PARSE;
+					break;
+
+				case 'W': // Warn
+				case 'I': // Info
+					$error_reporting = E_ERROR | E_USER_ERROR| E_WARNING | E_USER_WARNING | E_PARSE;
+					break;
+
+				case 'N': // Notice
+				case 'D': // Debug
+					$error_reporting = E_ERROR | E_USER_ERROR | E_WARNING | E_USER_WARNING | E_NOTICE | E_USER_NOTICE | E_PARSE;
+					break;
+
+				case 'S': // Strict
+					$error_reporting = E_STRICT | E_PARSE;
+					break;
+			}
+
+			if( !(!!($error_reporting & $error_level)))
+			{
+				return true;
+			}
+		}
 
 		if ( !isset($GLOBALS['phpgw']->log)
 			|| !is_object($GLOBALS['phpgw']->log) )
 		{
 			$GLOBALS['phpgw']->log = createObject('phpgwapi.log');
 		}
-
 		$log =& $GLOBALS['phpgw']->log;
 
-		$error_file = str_replace(PHPGW_SERVER_ROOT, '/path/to/phpgroupware', $error_file);
+		if ( !isset($GLOBALS['phpgw_info']['user']['apps']['admin']) )
+		{
+			$error_file = str_replace(PHPGW_SERVER_ROOT, '/path/to/phpgroupware', $error_file);
+		}
 
 		$bt = debug_backtrace();
 
@@ -207,41 +259,92 @@
 			case E_ERROR:
 				$log_args['severity'] = 'F'; //all "ERRORS" should be fatal
 				$log->fatal($log_args);
-				break;
+				echo '<p class="msg">' . lang('ERROR: %1 in %2 at line %3', $error_msg, $error_file, $error_line) . "</p>\n";
+				die('<pre>' . phpgw_parse_backtrace($bt) . "</pre>\n");
+
 			case E_WARNING:
 			case E_USER_WARNING:
 				$log_args['severity'] = 'W';
 				$log->warn($log_args);
-				echo "\n<br>" . lang('ERROR Warning: %1 in %2 at line %3', $error_msg, $error_file, $error_line) . "<br>\n";
+				echo '<p class="msg">' . lang('Warning: %1 in %2 at line %3', $error_msg, $error_file, $error_line) . "</p>\n";
+				echo '<pre>' . phpgw_parse_backtrace($bt) . "</pre>\n";
 				break;
+
 			case PHPGW_E_INFO:
 				$log_args['severity'] = 'I';
 				$log->info($log_args);
 				break;
+
 			case PHPGW_E_DEBUG:
 				$log_args['severity'] = 'D';
 				$log->info($log_args);
 				break;
+
 			case E_NOTICE:
 			case E_USER_NOTICE:
 				$log_args['severity'] = 'N';
 				$log->notice($log_args);
 				if(isset($GLOBALS['phpgw_info']['server']['log_levels']['global_level']) && $GLOBALS['phpgw_info']['server']['log_levels']['global_level'] == 'N')
 				{
-					echo "\n<br>" . lang('ERROR Notice: %1 in %2 at line %3', $error_msg, $error_file, $error_line) . "<br>\n"; //this will be commented in the final version
+					echo '<p>' . lang('Notice: %1 in %2 at line %3', $error_msg, $error_file, $error_line) . "</p>\n";
+					echo '<pre>' . phpgw_parse_backtrace($bt) . "</pre>\n";
 				}
-			//No default, we just ignore it, for now
+				break;
+			case E_STRICT:
+				$log_args['severity'] = 'S';
+				$log->strict($log_args);
+				if(isset($GLOBALS['phpgw_info']['server']['log_levels']['global_level']) && $GLOBALS['phpgw_info']['server']['log_levels']['global_level'] == 'S')
+				{
+		
+		//  		Will find the messages in the log - no need to print to screen
+		//			echo '<p>' . lang('Strict: %1 in %2 at line %3', $error_msg, $error_file, $error_line) . "</p>\n";
+		//			echo '<pre>' . phpgw_parse_backtrace($bt) . "</pre>\n";
+				}
+				break;
+
+			case E_DEPRECATED:
+			case E_USER_DEPRECATED:
+				$log_args['severity'] = 'DP';
+				$log->deprecated_($log_args);
+				echo '<p class="msg">' . lang('deprecated: %1 in %2 at line %3', $error_msg, $error_file, $error_line) . "</p>\n";
+				echo '<pre>' . phpgw_parse_backtrace($bt) . "</pre>\n";
+				break;
 		}
 	}
 	set_error_handler('phpgw_handle_error');
 
+	/**
+	 * Last resort exception handler
+	 *
+	 * @param object $e the Exception that was thrown
+	 */
+	function phpgw_handle_exception(Exception $e)
+	{
+		$msg = $e->getMessage();
+		$help = 'Please contact your administrator for assistance';
+		$trace = $e->getTraceAsString();
+		echo <<<HTML
+			<h1>Uncaught Exception: {$msg}</h1>
+			<p>{$help}</p>
+			<h2>Backtrace:</h2>
+			<pre>
+{$trace}
+			</pre>
+
+HTML;
+		// all exceptions that make it this far are fatal
+		exit;
+	}
+
+	set_exception_handler('phpgw_handle_exception');
+
 	function clean_vars($vars, $safe_redirect = True)
 	{
 		if ( !is_array($vars) )
 		{
 			return $GLOBALS['data_cleaner']->clean($vars, $safe_redirect);
 		}
-		
+
 		foreach ( $vars as $key => $val )
 		{
 			$vars[$key] = clean_vars($val, $safe_redirect);
@@ -252,29 +355,36 @@
 	/* Make sure the header.inc.php is current. */
 	if ($GLOBALS['phpgw_info']['server']['versions']['header'] < $GLOBALS['phpgw_info']['server']['versions']['current_header'])
 	{
-		$setup_dir = ereg_replace($_SERVER['PHP_SELF'],'index.php','setup/');
-		echo '<center><b>You need to port your settings to the new header.inc.php version. <a href="' . $setup_dir . '">Run setup now!</a></b></center>';
-		exit;
+		$setup_dir = str_replace(array('login.php','index.php'), 'setup/', $_SERVER['PHP_SELF']);
+		$msg = lang('You need to port your settings to the new header.inc.php version. <a href="%1">Run setup now!</a>',  $setup_dir);
+		die("<div class=\"error\">{$msg}</div>");
 	}
 
 	/* Make sure the developer is following the rules. */
 	if (!isset($GLOBALS['phpgw_info']['flags']['currentapp']))
 	{
-		/* This object does not exist yet. */
-	/*	$GLOBALS['phpgw']->log->write(array('text'=>'W-MissingFlags, currentapp flag not set'));*/
-
 		echo '<b>!!! YOU DO NOT HAVE YOUR $GLOBALS[\'phpgw_info\'][\'flags\'][\'currentapp\'] SET !!!';
 		echo '<br>!!! PLEASE CORRECT THIS SITUATION !!!</b>';
+		exit;
 	}
 
-	magic_quotes_runtime(false);
+	 /* Load main class */
+	$GLOBALS['phpgw'] = createObject('phpgwapi.phpgw');
+
+	if(get_magic_quotes_runtime())
+	{
+		echo '<center><b>The magic_quotes_runtime has to set to Off in php.ini</b></center>';
+		exit;
+	}
+
+
 // Can't use this yet - errorlog hasn't been created.
 //	print_debug('sane environment','messageonly','api');
 
 	/****************************************************************************\
 	* Multi-Domain support                                                       *
 	\****************************************************************************/
-	
+
 	/* make them fix their header */
 	if (!isset($GLOBALS['phpgw_domain']))
 	{
@@ -295,24 +405,31 @@
 	}
 	else	// on "normal" pageview
 	{
-		$GLOBALS['phpgw_info']['user']['domain'] = phpgw::get_var('domain', 'string', 'REQUEST', false);
+//		$GLOBALS['phpgw_info']['user']['domain'] = phpgw::get_var('domain', 'string', 'REQUEST', false);
+
+		if(!$GLOBALS['phpgw_info']['user']['domain'] = phpgw::get_var('domain', 'string', 'REQUEST', false))
+		{
+			$GLOBALS['phpgw_info']['user']['domain'] = phpgw::get_var('domain', 'string', 'COOKIE', false);
+		}
 	}
 
 	if (isset($GLOBALS['phpgw_domain'][$GLOBALS['phpgw_info']['user']['domain']]))
 	{
-		$GLOBALS['phpgw_info']['server']['db_host'] = $GLOBALS['phpgw_domain'][$GLOBALS['phpgw_info']['user']['domain']]['db_host'];
-		$GLOBALS['phpgw_info']['server']['db_name'] = $GLOBALS['phpgw_domain'][$GLOBALS['phpgw_info']['user']['domain']]['db_name'];
-		$GLOBALS['phpgw_info']['server']['db_user'] = $GLOBALS['phpgw_domain'][$GLOBALS['phpgw_info']['user']['domain']]['db_user'];
-		$GLOBALS['phpgw_info']['server']['db_pass'] = $GLOBALS['phpgw_domain'][$GLOBALS['phpgw_info']['user']['domain']]['db_pass'];
-		$GLOBALS['phpgw_info']['server']['db_type'] = $GLOBALS['phpgw_domain'][$GLOBALS['phpgw_info']['user']['domain']]['db_type'];
+		$GLOBALS['phpgw_info']['server']['db_host']			= $GLOBALS['phpgw_domain'][$GLOBALS['phpgw_info']['user']['domain']]['db_host'];
+		$GLOBALS['phpgw_info']['server']['db_name']			= $GLOBALS['phpgw_domain'][$GLOBALS['phpgw_info']['user']['domain']]['db_name'];
+		$GLOBALS['phpgw_info']['server']['db_user']			= $GLOBALS['phpgw_domain'][$GLOBALS['phpgw_info']['user']['domain']]['db_user'];
+		$GLOBALS['phpgw_info']['server']['db_pass']			= $GLOBALS['phpgw_domain'][$GLOBALS['phpgw_info']['user']['domain']]['db_pass'];
+		$GLOBALS['phpgw_info']['server']['db_type']			= $GLOBALS['phpgw_domain'][$GLOBALS['phpgw_info']['user']['domain']]['db_type'];
+		$GLOBALS['phpgw_info']['server']['db_abstraction']	= $GLOBALS['phpgw_domain'][$GLOBALS['phpgw_info']['user']['domain']]['db_abstraction'];
 	}
 	else
 	{
-		$GLOBALS['phpgw_info']['server']['db_host'] = $GLOBALS['phpgw_domain'][$GLOBALS['phpgw_info']['server']['default_domain']]['db_host'];
-		$GLOBALS['phpgw_info']['server']['db_name'] = $GLOBALS['phpgw_domain'][$GLOBALS['phpgw_info']['server']['default_domain']]['db_name'];
-		$GLOBALS['phpgw_info']['server']['db_user'] = $GLOBALS['phpgw_domain'][$GLOBALS['phpgw_info']['server']['default_domain']]['db_user'];
-		$GLOBALS['phpgw_info']['server']['db_pass'] = $GLOBALS['phpgw_domain'][$GLOBALS['phpgw_info']['server']['default_domain']]['db_pass'];
-		$GLOBALS['phpgw_info']['server']['db_type'] = $GLOBALS['phpgw_domain'][$GLOBALS['phpgw_info']['server']['default_domain']]['db_type'];
+		$GLOBALS['phpgw_info']['server']['db_host']			= $GLOBALS['phpgw_domain'][$GLOBALS['phpgw_info']['server']['default_domain']]['db_host'];
+		$GLOBALS['phpgw_info']['server']['db_name']			= $GLOBALS['phpgw_domain'][$GLOBALS['phpgw_info']['server']['default_domain']]['db_name'];
+		$GLOBALS['phpgw_info']['server']['db_user']			= $GLOBALS['phpgw_domain'][$GLOBALS['phpgw_info']['server']['default_domain']]['db_user'];
+		$GLOBALS['phpgw_info']['server']['db_pass']			= $GLOBALS['phpgw_domain'][$GLOBALS['phpgw_info']['server']['default_domain']]['db_pass'];
+		$GLOBALS['phpgw_info']['server']['db_type']			= $GLOBALS['phpgw_domain'][$GLOBALS['phpgw_info']['server']['default_domain']]['db_type'];
+		$GLOBALS['phpgw_info']['server']['db_abstraction']	= $GLOBALS['phpgw_domain'][$GLOBALS['phpgw_info']['server']['default_domain']]['db_abstraction'];
 	}
 
 	if ($GLOBALS['phpgw_info']['flags']['currentapp'] != 'login' && ! $GLOBALS['phpgw_info']['server']['show_domain_selectbox'])
@@ -326,25 +443,16 @@
 	 /****************************************************************************\
 	 * These lines load up the API, fill up the $phpgw_info array, etc            *
 	 \****************************************************************************/
-	 /* Load main class */
-	$GLOBALS['phpgw'] = createObject('phpgwapi.phpgw');
 	 /************************************************************************\
 	 * Load up the main instance of the db class.                             *
 	 \************************************************************************/
 	$GLOBALS['phpgw']->db                = createObject('phpgwapi.db');
 	$GLOBALS['phpgw']->db->Debug         = $GLOBALS['phpgw']->debug ? 1 : 0;
 	$GLOBALS['phpgw']->db->Halt_On_Error = 'no';
-	$GLOBALS['phpgw']->adodb             =& $GLOBALS['phpgw']->db->adodb; //Reference
-	
-	@$GLOBALS['phpgw']->adodb->connect($GLOBALS['phpgw_info']['server']['db_host'],
-									   $GLOBALS['phpgw_info']['server']['db_user'],
-									   $GLOBALS['phpgw_info']['server']['db_pass'],
-									   $GLOBALS['phpgw_info']['server']['db_name']
-									  );
-	if(!$GLOBALS['phpgw']->adodb->ErrorNo())
+
+	if(is_object($GLOBALS['phpgw']->db))
 	{
-		$GLOBALS['phpgw']->adodb->query('select count(config_name) from phpgw_config');
-		if($GLOBALS['phpgw']->adodb->ErrorNo())
+		if(!$GLOBALS['phpgw']->db->query('select count(config_name) from phpgw_config',__LINE__,__FILE__))
 		{
 			$setup_dir = ereg_replace($_SERVER['PHP_SELF'],'index.php','setup/');
 			echo '<center><b>Fatal Error:</b> It appears that you have not created the database tables for '
@@ -370,6 +478,7 @@
 		$GLOBALS['phpgw_info']['server']['cache_phpgw_info'] = stripslashes($GLOBALS['phpgw']->db->f('config_value'));
 	}
 
+	/*
 	$cache_query = "SELECT content from phpgw_app_sessions WHERE"
 		." sessionid = '0' AND loginid = '0' and app = 'phpgwapi' AND location = 'config'";
 
@@ -385,13 +494,45 @@
 	}
 	else
 	{
+	*/
 		$c = createObject('phpgwapi.config','phpgwapi');
-		$c->read_repository();
+		$c->read();
 		foreach ($c->config_data as $k => $v)
 		{
 			$GLOBALS['phpgw_info']['server'][$k] = $v;
 		}
 
+		if ( isset($GLOBALS['phpgw_info']['server']['log_levels']['global_level']) )
+		{
+			switch ($GLOBALS['phpgw_info']['server']['log_levels']['global_level'])
+			{
+				case 'F': // Fatal
+				case 'E': // Error
+					error_reporting(E_ERROR | E_USER_ERROR | E_PARSE);
+					break;
+
+				case 'W': // Warn
+				case 'I': // Info
+					error_reporting(E_ERROR | E_USER_ERROR | E_WARNING | E_USER_WARNING | E_PARSE);
+					break;
+
+				case 'N': // Notice
+				case 'D': // Debug
+					error_reporting(E_ERROR | E_USER_ERROR | E_WARNING | E_USER_WARNING | E_NOTICE | E_USER_NOTICE | E_PARSE);
+					break;
+
+				case 'S': // Strict
+					error_reporting(E_STRICT | E_PARSE);
+					break;
+
+				case 'DP': // Deprecated
+					error_reporting(E_ERROR | E_USER_ERROR | E_DEPRECATED | E_USER_DEPRECATED | E_PARSE);
+					break;
+			}
+		}
+
+/*
+
 
 		if(isset($GLOBALS['phpgw_info']['server']['cache_phpgw_info'])
 			&& $GLOBALS['phpgw_info']['server']['cache_phpgw_info'])
@@ -403,13 +544,27 @@
 	}
 	unset($cache_query);
 	unset($server_info_cache);
+*/
+
+
+	// In case we use virtual hosts - some of them but not all with ntlm auth. 
+	if ($GLOBALS['phpgw_info']['server']['auth_type'] == 'ntlm' && !isset($_SERVER['REMOTE_USER']))
+	{
+		$GLOBALS['phpgw_remote_user_fallback'] = 'sql';
+	}
 
 	// In the case we use a fall back (mode Half remote_user)
 	if(isset($GLOBALS['phpgw_remote_user']) && !empty($GLOBALS['phpgw_remote_user']))
 	{
 		$GLOBALS['phpgw_info']['server']['auth_type'] = $GLOBALS['phpgw_remote_user'];
 	}
-	
+
+	// In the case remote_user fails
+	if(isset($GLOBALS['phpgw_remote_user_fallback']) && !empty($GLOBALS['phpgw_remote_user_fallback']))
+	{
+		$GLOBALS['phpgw_info']['server']['auth_type'] = $GLOBALS['phpgw_remote_user_fallback'];
+	}
+
 	// Remove this and I will make sure that you lose important parts of your anatomy - skwashd
 	$GLOBALS['RAW_REQUEST'] = $_REQUEST; // if you really need the raw value
 	$to_cleans = array('_GET', '_POST', '_COOKIE', '_REQUEST');
@@ -434,25 +589,17 @@
 	$GLOBALS['phpgw']->log			= createObject('phpgwapi.log');
 	include_once(PHPGW_API_INC . '/log_functions.inc.php');
 	$GLOBALS['phpgw']->translation	= createObject('phpgwapi.translation');
-	$GLOBALS['phpgw']->common		= createObject('phpgwapi.common');
-	$GLOBALS['phpgw']->hooks		= createObject('phpgwapi.hooks');
 	$GLOBALS['phpgw']->auth			= createObject('phpgwapi.auth');
 	$GLOBALS['phpgw']->accounts		= createObject('phpgwapi.accounts');
 	$GLOBALS['phpgw']->acl			= createObject('phpgwapi.acl');
 	$GLOBALS['phpgw']->session		= createObject('phpgwapi.sessions');
 	$GLOBALS['phpgw']->preferences	= createObject('phpgwapi.preferences');
 	$GLOBALS['phpgw']->applications	= createObject('phpgwapi.applications');
-	print_debug('main class loaded', 'messageonly','api');
+//	print_debug('main class loaded', 'messageonly','api');
 	// This include was here before for the old error class.  I've left it in for the
 	// new log_message class with replaced error.  I'm not sure if it is needed, though. -doug
 	include_once(PHPGW_INCLUDE_ROOT.'/phpgwapi/inc/class.log_message.inc.php');
 
-	/****************************************************************************\
-	* This is a global constant that should be used                              *
-	* instead of / or \ in file paths                                            *
-	\****************************************************************************/
-	define('SEP', filesystem_separator());
-
 	/*****************************************************************************\
 	* ACL defines - moved here to work for xml-rpc/soap, also                     *
 	\*****************************************************************************/
@@ -486,6 +633,12 @@
 				print_debug('User ID',$login_id,'app');
 				$GLOBALS['phpgw']->accounts->set_account($login_id);
 				$GLOBALS['phpgw']->preferences->set_account_id($login_id);
+				// cached menus contains old sessionid and has to be cleared when not using cookies
+				if ( !isset($GLOBALS['phpgw_info']['server']['usecookies']) && $login_id)
+				{
+					$GLOBALS['phpgw_info']['user']['account_id'] = $login_id;
+					execMethod('phpgwapi.menu.clear');
+				}
 			}
 		}
 	/**************************************************************************\
@@ -497,7 +650,7 @@
 	{
 		if (! $GLOBALS['phpgw']->session->verify())
 		{
-			if( isset($_GET['menuaction']) && $_GET['menuaction'])
+			if ( phpgw::get_var('menuaction', 'string', 'GET')  && phpgw::get_var('phpgw_return_as', 'string') != 'json')
 			{
 				unset($_GET['click_history']);
 				unset($_GET['sessionid']);
@@ -509,13 +662,23 @@
 			{
 				$cd_array['cd'] = $GLOBALS['phpgw']->session->cd_reason;
 			}
-			$GLOBALS['phpgw']->redirect_link('/login.php', $cd_array );
+
+			if(phpgw::get_var('phpgw_return_as', 'string') == 'json')
+			{
+				header('Content-Type: application/json'); 
+				echo json_encode(array('sessionExpired'=>true));
+				$GLOBALS['phpgw_info']['flags']['nofooter'] = true;
+				$GLOBALS['phpgw']->common->phpgw_exit();
+			}
+			else
+			{
+				$GLOBALS['phpgw']->redirect_link('/login.php', $cd_array );
+			}
 		}
 
-		if(isset($GLOBALS['phpgw_info']['user']['preferences']['common']['lang']) && $GLOBALS['phpgw_info']['user']['preferences']['common']['lang'] !='en')
+		if(isset($GLOBALS['phpgw_info']['user']['preferences']['common']['lang']) && $GLOBALS['phpgw_info']['user']['preferences']['common']['lang'] != $GLOBALS['phpgw_info']['server']['default_lang'])
 		{
-			$GLOBALS['phpgw']->translation->userlang = $GLOBALS['phpgw_info']['user']['preferences']['common']['lang'];
-			$GLOBALS['phpgw']->translation->translation($reset = True);
+			$GLOBALS['phpgw']->translation->set_userlang($GLOBALS['phpgw_info']['user']['preferences']['common']['lang'], true);
 		}
 
 		$redirect = unserialize(phpgw::get_var('redirect','raw', 'COOKIE'));
@@ -525,14 +688,14 @@
 			{
 				$redirect_data[$key] = phpgw::clean_value($value);
 			}
-			
+
 			$sessid = phpgw::get_var('sessionid', 'string', 'GET');
 			if ( $sessid )
 			{
 				$redirect_data['sessionid'] = $sessid;
 				$redirect_data['kp3'] = phpgw::get_var('kp3', 'string', 'GET');
 			}
-			
+
 			$GLOBALS['phpgw']->session->phpgw_setcookie('redirect', false, 0);
 			$GLOBALS['phpgw']->redirect_link('/index.php', $redirect_data);
 			unset($redirect);
@@ -569,7 +732,7 @@
 		/********* Optional classes, which can be disabled for performance increases *********/
 		while ($phpgw_class_name = each($GLOBALS['phpgw_info']['flags']))
 		{
-			if (ereg('enable_', $phpgw_class_name[0]))
+			if (preg_match('/enable_/', $phpgw_class_name[0]))
 			{
 				$enable_class = str_replace('enable_', '', $phpgw_class_name[0]);
 				$enable_class = str_replace('_class', '', $enable_class);
@@ -589,16 +752,6 @@
 			$GLOBALS['phpgw']->xslttpl = createObject('phpgwapi.xslttemplates',PHPGW_APP_TPL);
 		}
 
-		/*************************************************************************\
-		* If they are using frames, we need to set some variables                 *
-		\*************************************************************************/
-		if ( ( (isset($GLOBALS['phpgw_info']['user']['preferences']['common']['useframes']) && $GLOBALS['phpgw_info']['user']['preferences']['common']['useframes']) 
-			&& ( isset($GLOBALS['phpgw_info']['server']['useframes']) && $GLOBALS['phpgw_info']['server']['useframes'] == 'allowed') ) 
-			|| ( isset($GLOBALS['phpgw_info']['server']['useframes']) && $GLOBALS['phpgw_info']['server']['useframes'] == 'always') )
-		{
-			$GLOBALS['phpgw_info']['flags']['navbar_target'] = 'phpgw_body';
-		}
-
 		/*************************************************************************\
 		* Verify that the users session is still active otherwise kick them out   *
 		\*************************************************************************/
@@ -606,17 +759,36 @@
 		{
 			if (!$GLOBALS['phpgw']->acl->check('run', PHPGW_ACL_READ, $GLOBALS['phpgw_info']['flags']['currentapp']))
 			{
-				$GLOBALS['phpgw']->common->phpgw_header( true ); //!(isset($GLOBALS['phpgw_info']['flags']['nonavbar']) && $GLOBALS['phpgw_info']['flags']['nonavbar']) );
-				$GLOBALS['phpgw']->log->write(array('text'=>'W-Permissions, Attempted to access %1','p1'=>$GLOBALS['phpgw_info']['flags']['currentapp']));
+				$_access = false;
+				if ($GLOBALS['phpgw_info']['flags']['currentapp'] == 'admin' && $GLOBALS['phpgw']->acl->get_app_list_for_id('admin', phpgwapi_acl::ADD, $GLOBALS['phpgw_info']['user']['userid']))
+				{
+					$_access = true;
+				}
 
-				echo '<p><center><b>'.lang('Access not permitted').'</b></center>';
-				$GLOBALS['phpgw']->common->phpgw_exit(True);
+				if ($GLOBALS['phpgw']->acl->check('admin', phpgwapi_acl::ADD, $GLOBALS['phpgw_info']['flags']['currentapp']))
+				{
+					$_access = true;
+				}
+
+				if (!$_access)
+				{
+					$GLOBALS['phpgw']->common->phpgw_header(true);
+					$GLOBALS['phpgw']->log->write(array('text'=>'W-Permissions, Attempted to access %1','p1'=>$GLOBALS['phpgw_info']['flags']['currentapp']));
+
+					$lang_denied = lang('Access not permitted');
+					echo <<<HTML
+						<div class="error">$lang_denied</div>
+
+HTML;
+					$GLOBALS['phpgw']->common->phpgw_exit(True);
+				}
+				unset($_access);
 			}
 		}
 
 	//  Already called from sessions::verify
 	//	$GLOBALS['phpgw']->applications->read_installed_apps();	// to get translated app-titles
-		
+
 		/*************************************************************************\
 		* Load the header unless the developer turns it off                       *
 		\*************************************************************************/
@@ -635,12 +807,10 @@
 		{
 			include_once(PHPGW_APP_INC . '/functions.inc.php');
 		}
-		if (!@$GLOBALS['phpgw_info']['flags']['noheader'] && 
+		if (!@$GLOBALS['phpgw_info']['flags']['noheader'] &&
 			!@$GLOBALS['phpgw_info']['flags']['noappheader'] &&
 			file_exists(PHPGW_APP_INC . '/header.inc.php') && !isset($GLOBALS['phpgw_info']['menuaction']))
 		{
 			include_once(PHPGW_APP_INC . '/header.inc.php');
 		}
 	}
-
-	//error_reporting(E_ERROR | E_WARNING | E_PARSE);
