@@ -8,7 +8,7 @@
 	* @license http://www.fsf.org/licenses/gpl.html GNU General Public License
 	* @package phpgwapi
 	* @subpackage database
-	* @version $Id: class.sql_mssql.inc.php 17763 2006-12-26 11:37:44Z skwashd $
+	* @version $Id: class.sql_mssql.inc.php 1040 2008-05-26 10:27:54Z dave $
 	* @internal Development of this application was funded by http://www.sogrp.com
 	* @link http://www.sogrp.com/
 	*/
@@ -20,7 +20,7 @@
 	* @subpackage database
 	* @ignore
 	*/
-	class sql extends sql_
+	class phpgwapi_sql extends phpgwapi_sql_
 	{
 		function sql_()
 		{
@@ -34,8 +34,7 @@
 
 		function concat_null($elements)
 		{
-			$str = implode(' + ', sql::safe_null($elements));
+			$str = implode(' + ', self::safe_null($elements));
 			return ($str)? '('.$str.')' : '';
 		}
 	}
-?>
