@@ -6,7 +6,7 @@
 	* @license http://www.gnu.org/licenses/lgpl.html GNU Lesser General Public License
 	* @package phpgwapi
 	* @subpackage database
-	* @version $Id: class.sql_sapdb.inc.php 17763 2006-12-26 11:37:44Z skwashd $
+	* @version $Id: class.sql_sapdb.inc.php 1040 2008-05-26 10:27:54Z dave $
 	*/
 
 	/**
@@ -16,10 +16,9 @@
 	* @subpackage database
 	* @ignore
 	*/
-	class sql extends sql_
+	class phpgwapi_sql extends phpgwapi_sql_
 	{
-		function sql_()
+		public static function sql_()
 		{
 		}
 	}
-?>
