@@ -8,7 +8,7 @@
 	* @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 	* @package phpgwapi
 	* @subpackage sso
-	* @version $Id: create_mapping.php 17331 2006-10-03 19:40:45Z sigurdne $
+	* @version $Id: create_mapping.php 1040 2008-05-26 10:27:54Z dave $
 	*/
 										
 	/**
@@ -19,7 +19,7 @@
 	* Using with Single Sign-On(Shibbolelt, CAS, ...)
 	*/
 	
-	include_once('include_login.inc.php');
+	require_once 'include_login.inc.php';
 
 	if(!isset($GLOBALS['phpgw_info']['server']['mapping']) || $GLOBALS['phpgw_info']['server']['mapping'] == 'id')
 	{
@@ -80,4 +80,3 @@
 		$variables['additional_url'] = $GLOBALS['phpgw']->link('/phpgwapi/inc/sso/create_account.php');
 	}
 	$uilogin->phpgw_display_login($variables);
-?>
