@@ -8,7 +8,7 @@
 	* @copyright Copyright (C) 2000-2005 Free Software Foundation, Inc. http://www.fsf.org/
 	* @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 	* @package phpgroupware
-	* @version $Id: include_login.inc.php 18358 2007-11-27 04:43:37Z skwashd $
+	* @version $Id: include_login.inc.php 4616 2010-01-24 17:18:58Z sigurd $
 	*/
 	
 	/* 
@@ -16,35 +16,31 @@
 	 */
 	$GLOBALS['phpgw_info'] = array();
 	
-	$GLOBALS['phpgw_info']['flags'] = array(
+	$GLOBALS['phpgw_info']['flags'] = array
+	(
 		'disable_template_class' => true,
 		'login'                  => true,
 		'currentapp'             => 'login',
 		'noheader'               => true
 	);
-	if(file_exists('../../../header.inc.php'))
-	{
 
-		/**
-		* Include phpgroupware header
-		*/
-		include_once('../../../header.inc.php');
-		if(!is_object($GLOBALS['phpgw']->session))
-		{
-			$GLOBALS['phpgw']->session = createObject('phpgwapi.sessions');
-		}
-	}
-	else
+	$header = dirname(realpath(__FILE__)) . '/../../../header.inc.php';
+	if ( !file_exists($header) )
 	{
 		Header('Location: setup/index.php');
 		exit;
 	}
 
+	/**
+	* Include phpgroupware header
+	*/
+	require_once $header;
+
 	$GLOBALS['phpgw_info']['server']['template_set'] = $GLOBALS['phpgw_info']['login_template_set'];
 	$GLOBALS['phpgw_info']['server']['template_dir'] = PHPGW_SERVER_ROOT
 	 		. "/phpgwapi/templates/{$GLOBALS['phpgw_info']['server']['template_set']}";
 
-	$tmpl = CreateObject('phpgwapi.Template', $GLOBALS["phpgw_info"]['server']['template_dir']);
+	$tmpl = CreateObject('phpgwapi.Template', $GLOBALS['phpgw_info']['server']['template_dir']);
 
 	/*
 	 * Generic include for mapping / remoteuser mode
@@ -54,13 +50,20 @@
 	{
 		$phpgw_url_for_sso = '/phpgwapi/inc/sso/login_server.php';
 	}
-	$phpgw_map_location = isset($_SERVER['HTTP_SHIB_ORIGIN_SITE']) ? $_SERVER['HTTP_SHIB_ORIGIN_SITE'] : 'local';
-	$phpgw_map_authtype = isset($_SERVER['HTTP_SHIB_ORIGIN_SITE']) ? 'shibboleth':'remoteuser';
-								 
-	//Create the mapping if necessary :
-	if(isset($GLOBALS['phpgw_info']['server']['mapping']) && !empty($GLOBALS['phpgw_info']['server']['mapping']))
+
+	$phpgw_map_location = 'local';
+	$phpgw_map_authtype = 'remoteuser';
+	if ( isset($_SERVER['HTTP_SHIB_ORIGIN_SITE']) )
 	{
-		if(!is_object($GLOBALS['phpgw']->mapping))
+		$phpgw_map_location = $_SERVER['HTTP_SHIB_ORIGIN_SITE'];
+		$phpgw_map_authtype = 'shibboleth';
+	}
+
+	//Create the mapping if necessary :
+	if(isset($GLOBALS['phpgw_info']['server']['mapping']) 
+		&& !empty($GLOBALS['phpgw_info']['server']['mapping']))
+	{
+		if ( !is_object($GLOBALS['phpgw']->mapping) )
 		{
 			$GLOBALS['phpgw']->mapping = CreateObject('phpgwapi.mapping', array('auth_type'=> $phpgw_map_authtype, 'location' => $phpgw_map_location));
 		}
@@ -103,6 +106,7 @@
 		*/
 		function check_logoutcode($code)
 		{
+			$GLOBALS['phpgw']->session->phpgw_setcookie('phpgwsessid');
 			switch($code)
 			{
 				case 1:
@@ -115,17 +119,20 @@
 					return lang('Cannot find the mapping ! (please advice your adminstrator)');
 				case 21:
 					return lang('you had inactive mapping to %1 account', phpgw::get_var('phpgw_account', 'string', 'GET', ''));
+				case 22:
+					$GLOBALS['phpgw']->session->phpgw_setcookie('kp3');
+					$GLOBALS['phpgw']->session->phpgw_setcookie('domain');
+					return lang('you seemed to have an active session elsewhere for the domain "%1", now set to expired - please try again', phpgw::get_var('domain', 'string', 'COOKIE'));
 				case 99:
 					return lang('Blocked, too many attempts');
 				case 10:
-					$GLOBALS['phpgw']->session->phpgw_setcookie('sessionid');
 					$GLOBALS['phpgw']->session->phpgw_setcookie('kp3');
 					$GLOBALS['phpgw']->session->phpgw_setcookie('domain');
 
 					// fix for bug php4 expired sessions bug
-					if($GLOBALS['phpgw_info']['server']['sessions_type'] == 'php4')
+					if($GLOBALS['phpgw_info']['server']['sessions_type'] == 'php')
 					{
-						$GLOBALS['phpgw']->session->phpgw_setcookie(PHPGW_PHPSESSID);
+//						$GLOBALS['phpgw']->session->phpgw_setcookie('phpgwsessid');
 					}
 
 					return lang('Your session could not be verified.');
@@ -153,9 +160,9 @@
 			// _debug_array($GLOBALS['phpgw_info']['server']['lang_ctimes']);
 			
 			$lang = $GLOBALS['phpgw_info']['user']['preferences']['common']['lang'];
-			$apps = $GLOBALS['phpgw_info']['user']['apps'];
+			$apps = (array)$GLOBALS['phpgw_info']['user']['apps'];
 			$apps['phpgwapi'] = true;	// check the api too
-			while (list($app,$data) = each($apps))
+			foreach ( array_keys($apps) as $app )
 			{
 				$fname = PHPGW_SERVER_ROOT . "/$app/setup/phpgw_$lang.lang";
 				
@@ -164,7 +171,7 @@
 					$ctime = filectime($fname);
 					$ltime = isset($GLOBALS['phpgw_info']['server']['lang_ctimes'][$lang]) && 
 						isset($GLOBALS['phpgw_info']['server']['lang_ctimes'][$lang][$app]) ? 
-						intval($GLOBALS['phpgw_info']['server']['lang_ctimes'][$lang][$app]) : 0;
+						(int) $GLOBALS['phpgw_info']['server']['lang_ctimes'][$lang][$app] : 0;
 					//echo "checking lang='$lang', app='$app', ctime='$ctime', ltime='$ltime'<br>\n";
 					
 					if ($ctime != $ltime)
@@ -181,28 +188,38 @@
 		*/
 		function update_langs()
 		{
-			$GLOBALS['phpgw_setup'] = CreateObject('phpgwapi.setup');
-			$GLOBALS['phpgw_setup']->db = $GLOBALS['phpgw']->db;
-			
-			$GLOBALS['phpgw_setup']->detection->check_lang(false);	// get installed langs
-			$langs = $GLOBALS['phpgw_info']['setup']['installed_langs'];
-			while (list($lang) = @each($langs))
+			$langs = $GLOBALS['phpgw']->translation->get_installed_langs();
+			foreach ( array_keys($langs) as $lang )
 			{
 				$langs[$lang] = $lang;
 			}
-			$_POST['submit'] = true;
-			$_POST['lang_selected'] = $langs;
-			$_POST['upgrademethod'] = 'dumpold';
-			$included = 'from_login';
-			
-			/**
-			* Include languages setup
-			*/
-			include(PHPGW_SERVER_ROOT . '/setup/lang.php');
+			$GLOBALS['phpgw']->translation->update_db($langs, 'dumpold');
 		}
 
 		function phpgw_display_login($variables)
 		{
+			
+			$lang = array
+			(
+				'domain'	=> lang('domain'),
+				'username'	=> lang('username'),
+				'password'	=> lang('password')
+			);
+
+			$text_len = 0;
+			foreach($lang as $key => $text)
+			{
+				if($text_len < strlen($text))
+				{
+					$text_len = strlen($text);
+				}
+			}
+
+			foreach($lang as $key => & $text)
+			{
+				$text = str_repeat('&nbsp;', ($text_len-strlen($text))) . $text;
+			}
+		
 			$this->tmpl->set_file(array('login_form'  => 'login.tpl'));
 			$this->tmpl->set_var('charset', lang('charset'));
 			$this->tmpl->set_block('login_form', 'domain_option', 'domain_options');
@@ -246,7 +263,7 @@
 				$this->tmpl->set_var(
 						array(
 							'domain_from_hosts'	=> '',
-							'lang_domain'		=> lang('domain')
+							'lang_domain'		=> $lang['domain']
 						)
 					);
 			}
@@ -272,7 +289,7 @@
 				}
 				else
 				{
-					$GLOBALS['phpgw_info']['user']['preferences'] = $prefs->read_repository();
+					$GLOBALS['phpgw_info']['user']['preferences'] = $prefs->read();
 				}
 				#print 'LANG:' . $GLOBALS['phpgw_info']['user']['preferences']['common']['lang'] . '<br>';
 			}
@@ -284,7 +301,7 @@
 			}
 			$GLOBALS['phpgw']->translation->add_app('login');
 			$GLOBALS['phpgw']->translation->add_app('loginscreen');
-			if ( ($login_msg = lang('loginscreen_message') ) != 'loginscreen_message*')
+			if ( ($login_msg = lang('loginscreen_message') ) != '!loginscreen_message')
 			{
 				$this->tmpl->set_var('lang_message', stripslashes($login_msg) );
 			}
@@ -320,7 +337,7 @@
 				reset($GLOBALS['phpgw_domain']);
 				list($default_domain) = each($GLOBALS['phpgw_domain']);
 
-				if ($_COOKIE['last_domain'] != $default_domain && !empty($_COOKIE['last_domain']))
+				if ($_COOKIE['last_domain'] != $default_domain && !empty($_COOKIE['last_domain']) && !$GLOBALS['phpgw_info']['server']['show_domain_selectbox'])
 				{
 					$last_loginid .= '@' . $_COOKIE['last_domain'];
 				}
@@ -373,7 +390,7 @@
 			$extra_vars = array();
 			foreach($_GET as $name => $value)
 			{
-				if (ereg('phpgw_',$name))
+				if (preg_match('/phpgw_/',$name))
 				{
 					$extra_vars[$name] = urlencode($value);
 				}
@@ -387,12 +404,18 @@
 
 			$this->tmpl->set_var('login_url', $GLOBALS['phpgw_info']['server']['webserver_url'] . '/'.$variables['partial_url'].'?' . http_build_query($extra_vars) );
 			$this->tmpl->set_var('registration_url',$GLOBALS['phpgw_info']['server']['webserver_url'] . '/registration/');
-			$this->tmpl->set_var('version', $GLOBALS['phpgw_info']['server']['versions']['phpgwapi']);
+			$this->tmpl->set_var('system', isset($GLOBALS['phpgw_info']['server']['system_name']) ? $GLOBALS['phpgw_info']['server']['system_name'] : 'phpGroupWare');
+			$this->tmpl->set_var('version', isset($GLOBALS['phpgw_info']['server']['versions']['system']) ? $GLOBALS['phpgw_info']['server']['versions']['system'] : $GLOBALS['phpgw_info']['server']['versions']['phpgwapi']);
+
 			$this->tmpl->set_var('cd', $this->check_logoutcode($cd) );
 			$this->tmpl->set_var('last_loginid', $last_loginid);
+			if(isset($_REQUEST['skip_remote']) && $_REQUEST['skip_remote'])
+			{
+				$this->tmpl->set_var('skip_remote', true);				
+			}
 
-			$this->tmpl->set_var('lang_username', lang('username'));
-			$this->tmpl->set_var('lang_password', lang('password'));
+			$this->tmpl->set_var('lang_username', $lang['username']);
+			$this->tmpl->set_var('lang_password', $lang['password']);
 			if(isset($variables['lang_login']))
 			{
 				$this->tmpl->set_var('lang_login', $variables['lang_login']);
@@ -451,4 +474,3 @@
 			$this->tmpl->pfp('loginout','login_form');
 		}
 	}
-?>
