@@ -8,7 +8,7 @@
 	* @copyright Copyright (C) 2000-2005 Free Software Foundation, Inc. http://www.fsf.org/
 	* @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 	* @package phpgroupware
-	* @version $Id: login_server.php 17321 2006-10-03 14:05:03Z Caeies $
+	* @version $Id: login_server.php 1040 2008-05-26 10:27:54Z dave $
 	*/
 
 	/*
@@ -22,8 +22,6 @@
 	chdir('../../../');
 	
 	//Now do the right work :)
-	include_once('login.php');
+	require_once 'login.php';
 
 	$GLOBALS['phpgw']->common->phpgw_exit();
-
-?>
