@@ -231,14 +231,14 @@ function openwindow(url, h, w)
 		w = 600;
 	}
 
-	if ( phpgw_popup )
+	/*if ( phpgw_popup )
 	{
 		if ( phpgw_popup.closed )
 		{
 			phpgw_popup.stop;
 			phpgw_popup.close;
 		}
-	}
+	}*/
 	phpgw_popup = window.open(url, "pageWindow","width="+h+",height="+w+",location=no,menubar=no,directories=no,toolbar=no,scrollbars=yes,resizable=yes,status=yes");
 	if (phpgw_popup.opener == null)
 	{
