@@ -5,7 +5,7 @@
 	* @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 	* @package phpgwapi
 	* @subpackage setup
-	* @version $Id: default_records.inc.php 17544 2006-11-12 12:44:13Z sigurdne $
+	* @version $Id: default_records.inc.php 4175 2009-11-22 14:00:45Z sigurd $
 	*/
 
 	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('aa','Afar','No')");
@@ -148,11 +148,6 @@
 	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('zt','Chinese (Traditional)','Yes')");
 	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('zu','Zulu','No')");
 
-	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_config (config_app, config_name, config_value) VALUES ('phpgwapi','sessions_checkip','True')");
-
-	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_config (config_app, config_name, config_value) VALUES ('phpgwapi','log_levels', '" . serialize(array( 'global_level' => 'E', 'module' => array(), 'user' => array())) ."')");
-	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_config (config_app, config_name, config_value) VALUES ('phpgwapi','addressmaster','-3')");
-
 	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_interserv(server_name,server_host,server_url,trust_level,trust_rel,server_mode) VALUES ('phpGW cvsdemo',NULL,'http://www.phpgroupware.org/cvsdemo/xmlrpc.php',99,0,'xmlrpc')");
 
 	$GLOBALS['phpgw_setup']->oProc->query ("INSERT INTO phpgw_vfs (owner_id, createdby_id, modifiedby_id, created, modified, size, mime_type, deleteable, comment, app, directory, name, link_directory, link_name) VALUES (0,0,0,'1970-01-01',NULL,NULL,'Directory','Y',NULL,NULL,'/','', NULL, NULL)");
@@ -177,7 +172,7 @@
 	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_contact_note_type (description) VALUES ('system')");
 
 	$GLOBALS['phpgw_setup']->oProc->query("SELECT comm_type_id FROM phpgw_contact_comm_type WHERE type='email'");
-	$comm_type_ids = $GLOBALS['phpgw_setup']->oProc->m_odb->resultSet->getArray();
+	$comm_type_ids = $GLOBALS['phpgw_setup']->oProc->m_odb->resultSet;
 	for($i = 0; $i < count($comm_type_ids); $i++)
 	{
 		$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_contact_comm_descr (comm_type_id,descr) VALUES (" 
@@ -192,7 +187,7 @@
 	}
 
 	$GLOBALS['phpgw_setup']->oProc->query("SELECT comm_type_id FROM phpgw_contact_comm_type WHERE type='phone'"); 
-	$comm_type_ids = $GLOBALS['phpgw_setup']->oProc->m_odb->resultSet->getArray();
+	$comm_type_ids = $GLOBALS['phpgw_setup']->oProc->m_odb->resultSet;
 	for($i = 0; $i < count($comm_type_ids); $i++)
 	{
 		$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_contact_comm_descr (comm_type_id,descr) VALUES (" 
@@ -233,7 +228,7 @@
 			.  ")");
 	}
 	$GLOBALS['phpgw_setup']->oProc->query("SELECT comm_type_id FROM phpgw_contact_comm_type WHERE type='fax'"); 
-	$comm_type_ids = $GLOBALS['phpgw_setup']->oProc->m_odb->resultSet->getArray();
+	$comm_type_ids = $GLOBALS['phpgw_setup']->oProc->m_odb->resultSet;
 	for($i = 0; $i < count($comm_type_ids); $i++)
 	{
 		$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_contact_comm_descr (comm_type_id,descr) VALUES (" 
@@ -246,7 +241,7 @@
 			.  ")");
 	}
 	$GLOBALS['phpgw_setup']->oProc->query("SELECT comm_type_id FROM phpgw_contact_comm_type WHERE type='mobile phone'"); 
-	$comm_type_ids = $GLOBALS['phpgw_setup']->oProc->m_odb->resultSet->getArray();
+	$comm_type_ids = $GLOBALS['phpgw_setup']->oProc->m_odb->resultSet;
 	for($i = 0; $i < count($comm_type_ids); $i++)
 	{
 		$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_contact_comm_descr (comm_type_id,descr) VALUES (" 
@@ -259,7 +254,7 @@
 			.  ")");
 	}
 	$GLOBALS['phpgw_setup']->oProc->query("SELECT comm_type_id FROM phpgw_contact_comm_type WHERE type='instant messaging'"); 
-	$comm_type_ids = $GLOBALS['phpgw_setup']->oProc->m_odb->resultSet->getArray();
+	$comm_type_ids = $GLOBALS['phpgw_setup']->oProc->m_odb->resultSet;
 	for($i = 0; $i < count($comm_type_ids); $i++)
 	{
 		$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_contact_comm_descr (comm_type_id,descr) VALUES (" 
@@ -284,7 +279,7 @@
 			.  ")");				
 	}
 	$GLOBALS['phpgw_setup']->oProc->query("SELECT comm_type_id FROM phpgw_contact_comm_type WHERE type='url'"); 
-	$comm_type_ids = $GLOBALS['phpgw_setup']->oProc->m_odb->resultSet->getArray();
+	$comm_type_ids = $GLOBALS['phpgw_setup']->oProc->m_odb->resultSet;
 	for($i = 0; $i < count($comm_type_ids); $i++)
 	{
 		$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_contact_comm_descr (comm_type_id,descr) VALUES (" 
@@ -292,5 +287,29 @@
 			. ",'website'" 
 			.  ")");
 	}
-	//force users to config their install - was dropped sometime ago - adding it again - skwashd
-	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_config VALUES('phpgwapi', 'freshinstall', '1')");
+
+	// Sane defaults for the API
+	$values = array
+	(
+		'max_access_log_age'	=> 90,
+		'block_time'			=> 30,
+		'num_unsuccessful_id'	=> 3,
+		'num_unsuccessful_ip'	=> 3,
+		'install_id'			=> sha1(uniqid(rand(), true)),
+		'max_history'			=> 20,
+		'sessions_checkip'		=> 'True',
+		'sessions_timeout'		=> 1440,
+		'addressmaster'			=> -3,
+		'log_levels'			=> serialize(array('global_level' => 'E', 'module' => array(), 'user' => array())),
+		'freshinstall'			=> 1,
+		'usecookies'			=> 'True'
+	);
+
+	foreach ( $values as $name => $val )
+	{
+		$sql = "INSERT INTO phpgw_config VALUES('phpgwapi', '{$name}', '{$val}')";
+		$GLOBALS['phpgw_setup']->oProc->query($sql, __LINE__, __FILE__);
+	}
+
+	$GLOBALS['phpgw']->locations->add('changepassword', 'allow user to change password', 'preferences', false);
+	$GLOBALS['phpgw']->locations->add('anonymous', 'allow anonymous sessions for public modules', 'phpgwapi', false);
