@@ -5,23 +5,53 @@
 	* @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 	* @package phpgwapi
 	* @subpackage gui
-	* @version $Id: head.inc.php 17835 2007-01-02 12:04:29Z sigurdne $
+	* @version $Id: head.inc.php 2104 2009-01-14 10:58:21Z sigurd $
 	*/
 
+	phpgw::import_class('phpgwapi.yui');
+
 	if ( !isset($GLOBALS['phpgw_info']['server']['site_title']) )
 	{
 		$GLOBALS['phpgw_info']['server']['site_title'] = lang('please set a site name in admin &gt; siteconfig');
 	}
 
-	$tpl = CreateObject('phpgwapi.Template',PHPGW_TEMPLATE_DIR);
-	$tpl->set_unknowns('remove');
+	// we hack the template root here as this is the template set of last resort
+	$tpl = CreateObject('phpgwapi.Template', dirname(__FILE__), "remove");
 	$tpl->set_file(array('head' => 'head.tpl'));
 	$tpl->set_block('head', 'theme_stylesheet', 'theme_stylesheets');
 
 	$app = $GLOBALS['phpgw_info']['flags']['currentapp'];
 
+	$theme_styles = array();
+	if( !isset($GLOBALS['phpgw_info']['flags']['noframework']) )
+	{
+		phpgwapi_yui::load_widget('dragdrop');
+		phpgwapi_yui::load_widget('element');
+		phpgwapi_yui::load_widget('container');
+		phpgwapi_yui::load_widget('connection');
+		phpgwapi_yui::load_widget('resize');
+		phpgwapi_yui::load_widget('layout');
+
+		$javascripts = array
+		(
+			"/phpgwapi/js/json/json.js",
+			"/phpgwapi/templates/portico/js/base.js"
+
+		);
+
+		$theme_styles = array
+		(
+			"{$GLOBALS['phpgw_info']['server']['webserver_url']}/phpgwapi/templates/simple/css/base.css",
+			"{$GLOBALS['phpgw_info']['server']['webserver_url']}/phpgwapi/js/yahoo/reset-fonts-grids/reset-fonts-grids.css",
+			"{$GLOBALS['phpgw_info']['server']['webserver_url']}/phpgwapi/js/yahoo/menu/assets/skins/sam/menu.css",
+			"{$GLOBALS['phpgw_info']['server']['webserver_url']}/phpgwapi/js/yahoo/button/assets/skins/sam/button.css",
+			"{$GLOBALS['phpgw_info']['server']['webserver_url']}/phpgwapi/js/yahoo/tabview/assets/skins/sam/tabview.css",
+			"{$GLOBALS['phpgw_info']['server']['webserver_url']}/phpgwapi/js/yahoo/resize/assets/skins/sam/resize.css",
+			"{$GLOBALS['phpgw_info']['server']['webserver_url']}/phpgwapi/js/yahoo/layout/assets/skins/sam/layout.css"
+		);
+	}
+	phpgwapi_yui::load_widget('button');
 
-	$theme_styles[] = "{$GLOBALS['phpgw_info']['server']['webserver_url']}/phpgwapi/templates/simple/css/base.css";
 	if(file_exists(PHPGW_SERVER_ROOT . '/phpgwapi/templates/simple/css/' . $GLOBALS['phpgw_info']['user']['preferences']['common']['theme'] . '.css'))
 	{
 		$theme_styles[] = "{$GLOBALS['phpgw_info']['server']['webserver_url']}/phpgwapi/templates/simple/css/{$GLOBALS['phpgw_info']['user']['preferences']['common']['theme']}.css";
