@@ -5,7 +5,7 @@
 	* @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 	* @package phpgwapi
 	* @subpackage gui
-	* @version $Id: navbar.inc.php 18011 2007-03-06 13:39:29Z sigurdne $
+	* @version $Id: navbar.inc.php 2098 2009-01-13 19:14:04Z sigurd $
 	*/
 
 
@@ -18,86 +18,62 @@
 	function parse_navbar($force = False)
 	{
 
-		$GLOBALS['phpgw_info']['theme']['bg_color']    = '#FFFFFF';
-		$GLOBALS['phpgw_info']['theme']['bg_text']     = '#000000';
-		$GLOBALS['phpgw_info']['theme']['vlink']       = 'blue';
-		$GLOBALS['phpgw_info']['theme']['alink']       = 'red';
-		$GLOBALS['phpgw_info']['theme']['link']        = 'blue';
-		$GLOBALS['phpgw_info']['theme']['row_on']      = '#CCEEFF';
-		$GLOBALS['phpgw_info']['theme']['row_off']     = '#DDF0FF';
-		$GLOBALS['phpgw_info']['theme']['row_text']    = '#000000';
-		$GLOBALS['phpgw_info']['theme']['th_bg']       = '#80BBFF';
-		$GLOBALS['phpgw_info']['theme']['th_text']     = '#000000';
-		$GLOBALS['phpgw_info']['theme']['navbar_bg']   = '#80CCFF';
-		$GLOBALS['phpgw_info']['theme']['navbar_text'] = '#FFFFFF';
-		$GLOBALS['phpgw_info']['theme']['table_bg']    = '#7090FF';
-		$GLOBALS['phpgw_info']['theme']['table_text']  = '#000000';
-		$GLOBALS['phpgw_info']['theme']['font']        = 'Arial, Helvetica, san-serif';
-		$GLOBALS['phpgw_info']['theme']['bg01']        = '#dadada';
-		$GLOBALS['phpgw_info']['theme']['bg02']        = '#dad0d0';
-		$GLOBALS['phpgw_info']['theme']['bg03']        = '#dacaca';
-		$GLOBALS['phpgw_info']['theme']['bg04']        = '#dac0c0';
-		$GLOBALS['phpgw_info']['theme']['bg05']        = '#dababa';
-		$GLOBALS['phpgw_info']['theme']['bg06']        = '#dab0b0';
-		$GLOBALS['phpgw_info']['theme']['bg07']        = '#daaaaa';
-		$GLOBALS['phpgw_info']['theme']['bg08']        = '#da9090';
-		$GLOBALS['phpgw_info']['theme']['bg09']        = '#da8a8a';
-		$GLOBALS['phpgw_info']['theme']['bg10']        = '#da7a7a';
-
-
 		$tpl = createobject('phpgwapi.Template',PHPGW_TEMPLATE_DIR);
 
-		$tpl->set_file(
-			array(
-				'navbartpl' => 'navbar.tpl'
-			)
-		);
+		$tpl->set_file('navbartpl', 'navbar.tpl');
 		$tpl->set_block('navbartpl','preferences');
 		$tpl->set_block('navbartpl','navbar');
 
 		$var['img_root'] = $GLOBALS['phpgw_info']['server']['webserver_url'] . '/phpgwapi/templates/verdilak/images';
-		$var['table_bg_color'] = $GLOBALS['phpgw_info']['theme']['navbar_bg'];
-		$var['navbar_text'] = $GLOBALS['phpgw_info']['theme']['navbar_text'];
 		$applications = '';
-		foreach($GLOBALS['phpgw_info']['navbar'] as $app => $app_data)
+		$exclude = array('home', 'preferences', 'about', 'logout');
+		$navbar = execMethod('phpgwapi.menu.get', 'navbar');
+		prepare_navbar($navbar);
+		foreach ( $navbar as $app => $app_data )
 		{
-			if ($app != 'home' && $app != 'preferences' && ! ereg('about',$app) && $app != 'logout')
+			if ( in_array($app, $exclude) )
 			{
-				if ($GLOBALS['phpgw_info']['user']['preferences']['common']['navbar_format'] != 'text')
-				{
-					$title = '<img src="' . $app_data['icon'] . '" alt="' . $app_data['title'] . '" title="'
-						. $app_data['title'] . '" border="0">';
-				}
-
-				if ($GLOBALS['phpgw_info']['user']['preferences']['common']['navbar_format'] != 'icons')
-				{
-					$title .= '<br>' . $app_data['title'];
-				}
-				$applications .= '<br><a href="' . $app_data['url'] . '"';
-				if (isset($app_data['target']) &&  $app_data['target'])
-				{
-					$applications .= ' target="' . $app_data['target'] . '"';
-				}
-				$applications .= '>' . $title . '</a>';
-				unset($title);
+				continue;
 			}
+			$icon = $GLOBALS['phpgw']->common->image($app_data['image'][0], $app_data['image'][1]);
+			$applications .= <<<HTML
+				<br>
+				<a href="{$app_data['url']}">
+					<img src="{$icon}" alt="{$app_data['text']}" title="{$app_data['text']}">
+				</a>
+
+HTML;
 		}
+
 		$var['applications'] = $applications;
+		$var['logo'] = 'logo.png';
 
-		if (isset($GLOBALS['phpgw_info']['theme']['special_logo']))
+		$var['home_url']                = $GLOBALS['phpgw']->link('/home.php');
+		$var['home_text']               = lang('home');
+		$var['about_url']               = $GLOBALS['phpgw']->link('/about.php', array('appname' => $GLOBALS['phpgw_info']['flags']['currentapp']) );
+		$var['about_text']              = lang('about');
+		$var['logout_url']              = $GLOBALS['phpgw']->link('/logout.php');
+		$var['logout_text']             = lang('logout');
+		if ( isset($GLOBALS['phpgw_info']['user']['apps']['manual']) )
 		{
-			$var['logo'] = $GLOBALS['phpgw_info']['theme']['special_logo'];
-		}
-		else
-		{
-			$var['logo'] = 'logo.png';
+			$var['help_url'] = "javascript:openwindow('"
+			 . $GLOBALS['phpgw']->link('/index.php', array
+			 (
+			 	'menuaction'=> 'manual.uimanual.help',
+			 	'app' => $GLOBALS['phpgw_info']['flags']['currentapp'],
+			 	'section' => isset($GLOBALS['phpgw_info']['apps']['manual']['section']) ? $GLOBALS['phpgw_info']['apps']['manual']['section'] : '',
+			 	'referer' => phpgw::get_var('menuaction')
+			 )) . "','700','600')";
+
+			$var['help_text'] = lang('help');
+			$var['help_icon'] = 'icon icon-help';
 		}
 
-		$var['home_link'] = $GLOBALS['phpgw_info']['navbar']['home']['url'];
-		//XXX Caeies not sure of that :(
-		$var['preferences_link'] = isset($GLOBALS['phpgw_info']['navbar']['preferences']) && isset($GLOBALS['phpgw_info']['navbar']['preferences']['url']) ? $GLOBALS['phpgw_info']['navbar']['preferences']['url'] : '' ;
-		$var['logout_link'] = $GLOBALS['phpgw_info']['navbar']['logout']['url'];
-		$var['help_link'] = $GLOBALS['phpgw_info']['navbar']['about']['url'];
+		if ( $GLOBALS['phpgw']->acl->check('run', PHPGW_ACL_READ, 'preferences') )
+		{
+			$var['preferences_url'] = $GLOBALS['phpgw']->link('/preferences/index.php');
+			$var['preferences_text'] = lang('preferences');
+		}
 
 		if ($GLOBALS['phpgw_info']['flags']['currentapp'] == 'home')
 		{
@@ -145,15 +121,6 @@
 		{
 			$api_messages = lang('it has been more then %1 days since you changed your password',30);
 		}
- 
-		// get sidebox content and parse it as a menu
-		// it's just a hack. You need to enable the folders module to get an ouput
-		if (isset($GLOBALS['phpgw_info']['user']['apps']['folders']['enabled']) && $GLOBALS['phpgw_info']['user']['apps']['folders']['enabled'] == true )
-		{
-			$GLOBALS['phpgw']->hooks->single('sidebox_menu',$GLOBALS['phpgw_info']['flags']['currentapp']);
-			$var['sideboxcontent'] = parseMenu();
-		}
-
 
 		// This is gonna change
 		if (isset($cd))
@@ -163,7 +130,6 @@
 		if (isset($GLOBALS['phpgw_info']['flags']['app_header']))
 		{
 			$var['current_app_header'] = $GLOBALS['phpgw_info']['flags']['app_header'];
-			$var['th_bg'] = $GLOBALS['phpgw_info']['theme']['th_bg'];
 		}
 		else
 		{
@@ -181,11 +147,14 @@
 			$tpl->set_var('preferences_icon','');
 		}
 		$tpl->pfp('out','navbar');
+
 		// If the application has a header include, we now include it
-		if (!@$GLOBALS['phpgw_info']['flags']['noappheader'] && @isset($GLOBALS['HTTP_GET_VARS']['menuaction']))
+		$menuaction = phpgw::get_var('menuaction', 'string', 'GET');
+		if ( !isset($GLOBALS['phpgw_info']['flags']['noappheader'])
+			&& $menuaction )
 		{
-			list($app,$class,$method) = explode('.',$GLOBALS['HTTP_GET_VARS']['menuaction']);
-			if (is_array($GLOBALS[$class]->public_functions) && isset($GLOBALS[$class]->public_functions['header']))
+			list($app,$class,$method) = explode('.', $menuaction);
+			if ( is_array($GLOBALS[$class]->public_functions ) && isset($GLOBALS[$class]->public_functions['header']))
 			{
 				$GLOBALS[$class]->header();
 			}
@@ -209,7 +178,6 @@
 		);
 		$var = Array(
 			'img_root'		=> $GLOBALS['phpgw_info']['server']['webserver_url'] . '/phpgwapi/templates/verdilak/images',
-			'table_bg_color'	=> (isset($GLOBALS['phpgw_info']['theme']['navbar_bg'])?$GLOBALS['phpgw_info']['theme']['navbar_bg']:''),
 			'version'		=> $GLOBALS['phpgw_info']['server']['versions']['phpgwapi']
 		);
 		if (isset($GLOBALS['phpgw_info']['navbar']['admin']) && isset($GLOBALS['phpgw_info']['user']['preferences']['common']['show_currentusers']))
@@ -275,3 +243,33 @@
 			return $return;
 		}
 	}
+
+	/**
+	* Callback for usort($navbar)
+	*
+	* @param array $item1 the first item to compare
+	* @param array $item2 the second item to compare
+	* @return int result of comparision
+	*/
+	function sort_navbar($item1, $item2)
+	{
+		$a =& $item1['order'];
+		$b =& $item2['order'];
+
+		if ($a == $b)
+		{
+			return strcmp($item1['text'], $item2['text']);
+		}
+		return ($a < $b) ? -1 : 1;
+	}
+
+	/**
+	* Organise the navbar properly
+	*
+	* @param array $navbar the navbar items
+	* @return array the organised navbar
+	*/
+	function prepare_navbar(&$navbar)
+	{
+		uasort($navbar, 'sort_navbar');
+	}
