@@ -3,12 +3,12 @@
 	* phpGroupWare - HRM: a  human resource competence management system.
 	*
 	* @author Sigurd Nes <sigurdne@online.no>
-	* @copyright Copyright (C) 2003-2005 Free Software Foundation, Inc. http://www.fsf.org/
-	* @license http://www.gnu.org/licenses/gpl.html GNU General Public License
+	* @copyright Copyright (C) 2003-2008 Free Software Foundation, Inc. http://www.fsf.org/
+	* @license http://www.gnu.org/licenses/gpl.html GNU General Public License v2 or later
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package hrm
 	* @subpackage admin
- 	* @version $Id: class.boadmin_acl.inc.php 18358 2007-11-27 04:43:37Z skwashd $
+ 	* @version $Id: class.boadmin_acl.inc.php 4827 2010-02-16 13:09:25Z sigurd $
 	*/
 
 	/**
@@ -34,8 +34,6 @@
 		function boadmin_acl($session='')
 		{
 			$this->currentapp	= $GLOBALS['phpgw_info']['flags']['currentapp'];
-			$this->so 		= CreateObject('preferences.soadmin_acl');
-	//		$this->catbo = createobject('phpgwapi.categories');
 
 			$this->acl 		= $GLOBALS['phpgw']->acl;
 			$this->right		= array(1,2,4,8,16);
@@ -58,6 +56,8 @@
 			$granting_group	= phpgw::get_var('granting_group');
 			$allrows	= phpgw::get_var('allrows');
 
+			$this->allrows = $allrows ? $allrows : '';
+
 			if ($start)
 			{
 				$this->start=$start;
@@ -103,10 +103,6 @@
 			{
 				$this->granting_group = $granting_group;
 			}
-			if(isset($allrows))
-			{
-				$this->allrows = $allrows;
-			}
 		}
 
 
@@ -122,7 +118,6 @@
 			$this->cat_id		= $data['cat_id'];
 			$this->location		= $data['location'];
 			$this->granting_group	= $data['granting_group'];
-			$this->allrows	= $data['allrows'];
 		}
 
 		function save_sessiondata($data)
@@ -148,7 +143,7 @@
 
 			$location_list = array();
 
-			$locations = $this->so->select_location($grant, $this->acl_app, $allow_c_attrib);
+			$locations = $GLOBALS['phpgw']->locations->get_locations($grant, $this->acl_app, $allow_c_attrib);
 
 			$i = 0;
 			foreach ( $locations as $loc_id => $loc_descr )
@@ -165,7 +160,7 @@
 					'descr'		=> "{$loc_id} [{$loc_descr}]",
 					'selected'	=> $sel_loc
 				);
-				
+
 				if ($location_list[$i]['selected'] != 'selected')
 				{
 					unset($location_list[$i]['selected']);
@@ -191,7 +186,7 @@
 			$categories[0]['name']	= lang('Groups');
 			$categories[1]['id']	= 'accounts';
 			$categories[1]['name']	= lang('Users');
-			
+
 			foreach ( $categories as $row => $category )
 			{
 				if ($category['id']==$selected)
@@ -216,7 +211,7 @@
 			return $category_list;
 		}
 
-		function set_permission2($values,$r_processed, $grantor = 0, $type = 0)
+		function set_permission2($values,$r_processed, $grantor = -1, $type = 0)
 		{
 			if ( !is_array($values) )
 			{
@@ -241,8 +236,7 @@
 			{
 				$user_checked[] = $user_id;
 
-				$this->acl->account_id = $user_id;
-				$this->acl->read_repository();
+				$this->acl->set_account_id($user_id, true);
 				$this->acl->delete($this->acl_app, $this->location, $grantor, $type);
 				$this->acl->add($this->acl_app, $this->location, $rights, $grantor, $type);
 				$this->acl->save_repository($this->acl_app, $this->location);
@@ -258,15 +252,14 @@
 			}
 
 			$users_at_location = $this->acl->get_accounts_at_location($this->acl_app, $this->location, $grantor ,$type);
-			
+
 			if(is_array($user_delete) && count($user_delete)>0)
 			{
-				while(list(,$user_id) = each($user_delete))
+				foreach ($user_delete as $user_id)
 				{
 					if(isset($users_at_location[$user_id]) && $users_at_location[$user_id])
 					{
-						$this->acl->account_id = $user_id;
-						$this->acl->read_repository();
+						$this->acl->set_account_id($user_id, true, $this->acl_app, $this->location, 'accounts'); 
 						$this->acl->delete($this->acl_app, $this->location, $grantor, $type);
 						$this->acl->save_repository($this->acl_app, $this->location);
 					}
@@ -276,6 +269,7 @@
 
 		function set_permission($values,$r_processed,$set_grant = false)
 		{
+			$this->acl->enable_inheritance = phpgw::get_var('enable_inheritance', 'bool', 'POST');
 
 			$process = explode('_', $r_processed);
 
@@ -289,7 +283,7 @@
 				$values['mask'] = array();
 			}
 
-			$grantor = 0;
+			$grantor = -1;
 			if($set_grant)
 			{
 				if($this->granting_group)
@@ -305,7 +299,7 @@
 			$this->set_permission2($values['right'], $process, $grantor, 0);
 			$this->set_permission2($values['mask'], $process, $grantor, 1);
 			$receipt['message'][] = array('msg' => lang('permissions are updated!'));
-			
+
 			// this feature will probably move into the api as standard
 			if($this->acl_app == 'property')
 			{
@@ -313,6 +307,8 @@
 				$receipt['message'][] = array('msg' => lang('%1 userlists cleared from cache',$cleared));
 			}
 
+			phpgwapi_cache::user_clear('phpgwapi', 'menu', -1);
+
 			return $receipt;
 		}
 
@@ -322,13 +318,24 @@
 			if($type == 'groups')
 			{
 				$check_account_type = array('accounts');
+				$acl_account_type = 'accounts';
+				$valid_users	= $GLOBALS['phpgw']->acl->get_ids_for_location('run', phpgwapi_acl::READ, $this->acl_app);
 			}
 			else
 			{
 				$check_account_type = array('groups','accounts');
+				$acl_account_type = 'both';
+				$_valid_users	= $GLOBALS['phpgw']->acl->get_user_list_right(phpgwapi_acl::READ, 'run', $this->acl_app);
+				$valid_users = array();
+				foreach($_valid_users as $_user)
+				{
+					$valid_users[] = $_user['account_id'];
+				}
+				unset($_user);
+				unset($_valid_users);
 			}
 
-			$grantor = 0;
+			$grantor = -1;
 			if($get_grants)
 			{
 				if($this->granting_group)
@@ -343,33 +350,49 @@
 
 			$right=$this->right;
 
-			$offset = $GLOBALS['phpgw_info']['user']['preferences']['common']['maxmatchs'];
+			$allusers = $GLOBALS['phpgw']->accounts->get_list($type, -1,$this->sort, $this->order, $this->query);
+
+//_debug_array($type);die();
+//_debug_array($valid_users);die();
+			//$allusers	= array_intersect_key($allusers, $valid_users);
+
+			foreach($allusers as  $user)
+			{
+				if(!in_array($user->id, $valid_users))
+				{
+					unset($allusers[$user->id]);
+				}
+			}
+			unset($user);
+			reset($allusers);
+
+			$this->total_records = count($allusers);
+			$length = $GLOBALS['phpgw_info']['user']['preferences']['common']['maxmatchs'];
+
 			if ($this->allrows)
 			{
-				$this->start = -1;
-				$offset = -1;
+				$this->start = 0;
+				$length = $this->total_records;
 			}
-			
-			$allusers = $GLOBALS['phpgw']->accounts->get_list($type, $this->start,$this->sort, $this->order, $this->query, $offset);
+
+			$allusers = array_slice($allusers, $this->start , $length, true);
 
 			if ( isset($allusers) && is_array($allusers))
 			{
 				$j=0;
 				foreach($allusers as $account)
 				{
-					$user_list[$j]['account_id'] 		= $account['account_id'];
-					$user_list[$j]['account_lid'] 		= $account['account_lid'];
-					$user_list[$j]['account_firstname'] 	= $account['account_firstname'];
-					$user_list[$j]['account_lastname'] 	= $account['account_lastname'];
+					$user_list[$j]['account_id'] 		= $account->id;
+					$user_list[$j]['account_lid'] 		= $account->lid;
+					$user_list[$j]['account_firstname'] = $account->firstname;
+					$user_list[$j]['account_lastname'] 	= $account->lastname;
 
-					$this->acl->account_id=$account['account_id'];
-
-					$this->acl->read_repository();
+					$this->acl->set_account_id($account->id, true, $this->acl_app, $this->location, $acl_account_type);
 
 					$count_right=count($right);
 					for ( $i = 0; $i < $count_right; ++$i )
 					{
-						if($this->acl->check_brutto($this->location, $right[$i],$this->acl_app,$grantor,0,$check_account_type))
+						if($this->acl->check_rights($this->location, $right[$i],$this->acl_app,$grantor,0,$check_account_type))
 						{
 							if($this->acl->account_type == 'g')
 							{
@@ -381,7 +404,7 @@
 							}
 							$user_list[$j]['result'][$right[$i]] = 'checked';
 						}
-						if($this->acl->check_brutto($this->location, $right[$i],$this->acl_app,$grantor,1,$check_account_type))
+						if($this->acl->check_rights($this->location, $right[$i],$this->acl_app,$grantor,1,$check_account_type))
 						{
 							if($this->acl->account_type == 'g')
 							{
@@ -399,8 +422,6 @@
 				}
 			}
 
-			$this->total_records = $GLOBALS['phpgw']->accounts->total;
-
 			return $user_list;
 		}
 
@@ -416,19 +437,19 @@
 					break;
 			}
 
-			$accounts 	= CreateObject('phpgwapi.accounts');
-			$groups = $accounts->get_list('groups', $start, $sort, $order, $query,$offset);
+			$groups = $GLOBALS['phpgw']->accounts->get_list('groups', $start, $sort, $order, $query,$offset);
+
 			unset($accounts);
-			if (isSet($groups) AND is_array($groups))
+			if (isset($groups) AND is_array($groups))
 			{
 				foreach($groups as $group)
 				{
-					if ($group['account_id']==$selected)
+					if ($group->id==$selected)
 					{
 						$group_list[] = array
 						(
-							'id'	=> $group['account_id'],
-							'name'		=> $group['account_firstname'],
+							'id'		=> $group->id,
+							'name'		=> $group->firstname,
 							'selected'	=> 'selected'
 						);
 					}
@@ -436,8 +457,8 @@
 					{
 						$group_list[] = array
 						(
-							'id'	=> $group['account_id'],
-							'name'		=> $group['account_firstname'],
+							'id'		=> $group->id,
+							'name'		=> $group->firstname,
 						);
 					}
 				}
@@ -445,4 +466,3 @@
 			return $group_list;
 		}
 	}
-?>
