@@ -3,32 +3,31 @@
 	* phpGroupWare - property: a Facilities Management System.
 	*
 	* @author Sigurd Nes <sigurdne@online.no>
-	* @copyright Copyright (C) 2003,2004,2005,2006,2007 Free Software Foundation, Inc. http://www.fsf.org/
-	* This file is part of phpGroupWare.
-	*
-	* phpGroupWare is free software; you can redistribute it and/or modify
-	* it under the terms of the GNU General Public License as published by
-	* the Free Software Foundation; either version 2 of the License, or
-	* (at your option) any later version.
-	*
-	* phpGroupWare is distributed in the hope that it will be useful,
-	* but WITHOUT ANY WARRANTY; without even the implied warranty of
-	* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-	* GNU General Public License for more details.
-	*
-	* You should have received a copy of the GNU General Public License
-	* along with phpGroupWare; if not, write to the Free Software
-	* Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
-	*
-	* @license http://www.gnu.org/licenses/gpl.html GNU General Public License
+	* @copyright Copyright (C) 2003,2004,2005,2006,2007,2008 Free Software Foundation, Inc. http://www.fsf.org/
+	* @license http://www.gnu.org/licenses/gpl.html GNU General Public License v2 or later
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage admin
- 	* @version $Id: class.boadmin.inc.php 18358 2007-11-27 04:43:37Z skwashd $
+ 	* @version $Id: class.boadmin.inc.php 4969 2010-03-08 12:59:23Z sigurd $
 	*/
 
+	/*
+	   This program is free software: you can redistribute it and/or modify
+	   it under the terms of the GNU General Public License as published by
+	   the Free Software Foundation, either version 2 of the License, or
+	   (at your option) any later version.
+
+	   This program is distributed in the hope that it will be useful,
+	   but WITHOUT ANY WARRANTY; without even the implied warranty of
+	   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+	   GNU General Public License for more details.
+
+	   You should have received a copy of the GNU General Public License
+	   along with this program.  If not, see <http://www.gnu.org/licenses/>.
+	 */
+
 	/**
-	 * Description
+	 * FIXME I need a proper description
 	 * @package property
 	 */
 
@@ -47,14 +46,15 @@
 		{
 		//	$this->currentapp	= $GLOBALS['phpgw_info']['flags']['currentapp'];
 			$this->so 			= CreateObject('property.soadmin');
-			$this->acl 			= CreateObject('phpgwapi.acl');
+			$this->acl 			= & $GLOBALS['phpgw']->acl;
 			$this->bocommon 	= CreateObject('property.bocommon');
 			$this->right		= array(1,2,4,8,16);
+			$this->account_id	= $GLOBALS['phpgw_info']['user']['account_id'];
 
 			if ($session)
 			{
 				$this->read_sessiondata();
-				$this->use_session = True;
+				$this->use_session = true;
 			}
 
 			$start	= phpgw::get_var('start', 'int', 'REQUEST', 0);
@@ -107,21 +107,13 @@
 			{
 				$this->granting_group = $granting_group;
 			}
-			if(isset($allrows))
-			{
-				$this->allrows = $allrows;
-			}
+
+			$this->allrows = $allrows ? $allrows : '';
 
 			if(isset($acl_app))
 			{
 				$this->acl_app = $acl_app;
 			}
-
-			if ($this->allrows)
-			{
-				$this->start = -1;
-				$this->offset = -1;
-			}
 		}
 
 
@@ -137,7 +129,6 @@
 			$this->cat_id			= $data['cat_id'];
 			$this->location			= $data['location'];
 			$this->granting_group	= $data['granting_group'];
-			$this->allrows			= $data['allrows'];
 		}
 
 		function save_sessiondata($data)
@@ -148,46 +139,6 @@
 			}
 		}
 
-		function select_location($format='',$selected='',$grant='')
-		{
-			switch($format)
-			{
-				case 'select':
-					$GLOBALS['phpgw']->xslttpl->add_file(array('select_location'));
-					break;
-				case 'filter':
-					$GLOBALS['phpgw']->xslttpl->add_file(array('filter_location'));
-					break;
-			}
-
-			$locations= $this->so->select_location($grant);
-
-			while (is_array($locations) && list(,$loc) = each($locations))
-			{
-				$sel_loc = '';
-				if ($loc['id']==$selected)
-				{
-					$sel_loc = 'selected';
-				}
-
-				$location_list[] = array
-				(
-					'id'		=> $loc['id'],
-					'descr'		=> $loc['id'] . ' [' . $loc['descr'] . ']',
-					'selected'	=> $sel_loc
-				);
-			}
-
-			for ($i=0;$i<count($location_list);$i++)
-			{
-				if ($location_list[$i]['selected'] != 'selected')
-				{
-					unset($location_list[$i]['selected']);
-				}
-			}
-
-			return $location_list;
-		}
 
 		function select_category_list($format='',$selected='')
 		{
@@ -205,11 +156,11 @@
 			$categories[0]['name']	= lang('Groups');
 			$categories[1]['id']	= 'accounts';
 			$categories[1]['name']	= lang('Users');
-			
+
 			return $this->bocommon->select_list($selected,$categories);
 		}
 
-		function set_permission2($values,$r_processed, $grantor = 0, $type = 0)
+		function set_permission2($values,$r_processed, $grantor = -1, $type = 0)
 		{
 			if ( !is_array($values) )
 			{
@@ -233,10 +184,8 @@
 			foreach ( $totalacl as $user_id => $rights )
 			{
 				$user_checked[] = $user_id;
-
-				$this->acl->account_id = $user_id;
-				$this->acl->read_repository();
-				$this->acl->delete($this->acl_app, $this->location, $grantor, $type);			
+				$this->acl->set_account_id($user_id, true, $this->acl_app, $this->location, $account_type = 'accounts');
+				$this->acl->delete($this->acl_app, $this->location, $grantor, $type);
 				$this->acl->add($this->acl_app, $this->location, $rights, $grantor, $type);
 				$this->acl->save_repository($this->acl_app, $this->location);
 			}
@@ -250,16 +199,15 @@
 				$user_delete = $r_processed;
 			}
 
-			$users_at_location = $this->so->get_accounts_at_location($this->acl_app, $this->location, $grantor ,$type);
+			$users_at_location = $this->acl->get_accounts_at_location($this->acl_app, $this->location, $grantor ,$type);
 
 			if(is_array($user_delete) && count($user_delete)>0)
 			{
-				while(list(,$user_id) = each($user_delete))
+				foreach ($user_delete as $user_id)
 				{
 					if(isset($users_at_location[$user_id]) && $users_at_location[$user_id])
 					{
-						$this->acl->account_id = $user_id;
-						$this->acl->read_repository();
+						$this->acl->set_account_id($user_id, true);
 						$this->acl->delete($this->acl_app, $this->location, $grantor, $type);
 						$this->acl->save_repository($this->acl_app, $this->location);
 					}
@@ -269,6 +217,8 @@
 
 		function set_permission($values,$r_processed,$set_grant = false,$initials='')
 		{
+			$this->acl->enable_inheritance = phpgw::get_var('enable_inheritance', 'bool', 'POST');
+
 			if($initials)
 			{
 				$this->so->set_initials($initials);
@@ -286,7 +236,7 @@
 				$values['mask'] = array();
 			}
 
-			$grantor = 0;
+			$grantor = -1;
 			if($set_grant)
 			{
 				if($this->granting_group)
@@ -295,7 +245,7 @@
 				}
 				else
 				{
-					$grantor = $GLOBALS['phpgw_info']['user']['account_id'];
+					$grantor = $this->account_id;
 				}
 			}
 
@@ -304,6 +254,7 @@
 			$cleared = $this->bocommon->reset_fm_cache_userlist();
 			$receipt['message'][] = array('msg' => lang('permissions are updated!'));
 			$receipt['message'][] = array('msg' => lang('%1 userlists cleared from cache',$cleared));
+			phpgwapi_cache::user_clear('phpgwapi', 'menu', -1);
 			return $receipt;
 		}
 
@@ -312,13 +263,24 @@
 			if($type == 'groups')
 			{
 				$check_account_type = array('accounts');
+				$acl_account_type = 'accounts';
+				$valid_users	= $GLOBALS['phpgw']->acl->get_ids_for_location('run', phpgwapi_acl::READ, 'property');
 			}
 			else
 			{
 				$check_account_type = array('groups','accounts');
+				$acl_account_type = 'both';
+				$_valid_users	= $GLOBALS['phpgw']->acl->get_user_list_right(phpgwapi_acl::READ, 'run', $this->acl_app);
+				$valid_users = array();
+				foreach($_valid_users as $_user)
+				{
+					$valid_users[] = $_user['account_id'];
+				}
+				unset($_user);
+				unset($_valid_users);
 			}
 
-			$grantor = 0;
+			$grantor = -1;
 			if($get_grants)
 			{
 				if($this->granting_group)
@@ -327,7 +289,7 @@
 				}
 				else
 				{
-					$grantor = $GLOBALS['phpgw_info']['user']['account_id'];
+					$grantor = $this->account_id;
 				}
 			}
 
@@ -338,39 +300,54 @@
 
 			$right=$this->right;
 
-			$offset = $GLOBALS['phpgw_info']['user']['preferences']['common']['maxmatchs'];
+			$allusers = $GLOBALS['phpgw']->accounts->get_list($type, -1,$this->sort, $this->order, $this->query);
+
+//			$allusers	= array_intersect_key($allusers, $valid_users);
+
+			foreach($allusers as  $user)
+			{
+				if(!in_array($user->id, $valid_users))
+				{
+					unset($allusers[$user->id]);
+				}
+			}
+			unset($user);
+			reset($allusers);
+
+			$this->total_records = count($allusers);
+			$length = $GLOBALS['phpgw_info']['user']['preferences']['common']['maxmatchs'];
+
 			if ($this->allrows)
 			{
-				$this->start = -1;
-				$offset = -1;
+				$this->start = 0;
+				$length = $this->total_records;
 			}
-			
-			$allusers = $GLOBALS['phpgw']->accounts->get_list($type, $this->start,$this->sort, $this->order, $this->query, $offset);
 
+			$allusers = array_slice($allusers, $this->start , $length, true);
+
+			$user_list = array();
 			if ( isset($allusers) && is_array($allusers))
 			{
 				$j=0;
 				foreach($allusers as $account)
 				{
-					$user_list[$j]['account_id'] 			= $account['account_id'];
-					$user_list[$j]['account_lid'] 			= $account['account_lid'];
-					$user_list[$j]['account_firstname'] 	= $account['account_firstname'];
-					$user_list[$j]['account_lastname'] 		= $account['account_lastname'];
-					
+					$user_list[$j]['account_id'] 			= $account->id;
+					$user_list[$j]['account_lid'] 			= $account->lid;
+					$user_list[$j]['account_firstname'] 	= $account->firstname;
+					$user_list[$j]['account_lastname'] 		= $account->lastname;
+
 					if($this->location == '.invoice')
 					{
-						$user_list[$j]['initials']			= $this->so->get_initials($account['account_id']);
+						$user_list[$j]['initials']			= $this->so->get_initials($account->id);
 					}
-										
-					$this->acl->account_id=$account['account_id'];
 
-					$this->acl->read_repository();
+					$this->acl->set_account_id($account->id, true, $this->acl_app, $this->location, $acl_account_type);
 
 					$count_right=count($right);
-					
+
 					for ( $i = 0; $i < $count_right; ++$i )
 					{
-						if($this->acl->check_brutto($this->location, $right[$i],$this->acl_app,$grantor,0,$check_account_type))
+						if($this->acl->check_rights($this->location, $right[$i],$this->acl_app,$grantor,0,$check_account_type))
 						{
 							if($this->acl->account_type == 'g')
 							{
@@ -382,7 +359,7 @@
 							}
 							$user_list[$j]['result'][$right[$i]] = 'checked';
 						}
-						if($this->acl->check_brutto($this->location, $right[$i],$this->acl_app,$grantor,1,$check_account_type))
+						if($this->acl->check_rights($this->location, $right[$i],$this->acl_app,$grantor,1,$check_account_type))
 						{
 							if($this->acl->account_type == 'g')
 							{
@@ -398,7 +375,7 @@
 					$j++;
 				}
 			}
-			$this->total_records = $GLOBALS['phpgw']->accounts->total;
+
 //_debug_array($user_list);
 			return $user_list;
 		}
@@ -416,4 +393,3 @@
 
 		}
 	}
-?>
