@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage agreement
- 	* @version $Id: class.boagreement.inc.php 18358 2007-11-27 04:43:37Z skwashd $
+ 	* @version $Id: class.boagreement.inc.php 4807 2010-02-12 09:46:39Z sigurd $
 	*/
 
 	/**
@@ -43,28 +43,30 @@
 		var $role;
 		var $member_id;
 
+		/**
+		* @var object $custom reference to custom fields object
+		*/
+		protected $custom;
+
 		var $public_functions = array
 		(
-			'read'				=> True,
-			'read_single'		=> True,
-			'save'				=> True,
-			'delete'			=> True,
-			'check_perms'		=> True
+			'read'				=> true,
+			'read_single'		=> true,
+			'save'				=> true,
+			'delete'			=> true,
+			'check_perms'		=> true
 		);
 
-		function property_boagreement($session=False)
+		function property_boagreement($session=false)
 		{
 			$this->so = CreateObject('property.soagreement');
 			$this->bocommon = CreateObject('property.bocommon');
-			$this->custom 		= createObject('phpgwapi.custom_fields');
-			$this->vfs 			= CreateObject('phpgwapi.vfs');
-			$this->rootdir 		= $this->vfs->basedir;
-			$this->fakebase 	= $this->vfs->fakebase;
+			$this->custom 		= createObject('property.custom_fields');
 
 			if ($session)
 			{
 				$this->read_sessiondata();
-				$this->use_session = True;
+				$this->use_session = true;
 			}
 
 			$start	= phpgw::get_var('start', 'int', 'REQUEST', 0);
@@ -103,10 +105,9 @@
 			{
 				$this->sort = $sort;
 			}
-			if(isset($order))
-			{
-				$this->order = $order;
-			}
+
+			$this->order	= isset($order) && $order ? $order : '';
+
 			if(isset($cat_id))
 			{
 				$this->cat_id = $cat_id;
@@ -153,7 +154,7 @@
 
 		function check_perms($has, $needed)
 		{
-			return (!!($has & $needed) == True);
+			return (!!($has & $needed) == true);
 		}
 
 		function select_vendor_list($format='',$selected='')
@@ -230,7 +231,7 @@
 		function read_event($data)
 		{
 			$boalarm		= CreateObject('property.boalarm');
-			$event	= $this->so->read_single($data);
+			$event	= $this->so->read_single($data['agreement_id']);
 			$event['alarm_date']=$event['termination_date'];
 			$event['alarm']	= $boalarm->read_alarms($type='agreement',$data['agreement_id']);
 			return $event;
@@ -238,15 +239,15 @@
 
 		function read_single($data)
 		{
-			$values['attributes'] = $this->custom->get_attribs('property', '.agreement', 0, '', 'ASC', 'attrib_sort', true, true);
-			
+			$values['attributes'] = $this->custom->find('property', '.agreement', 0, '', 'ASC', 'attrib_sort', true, true);
+
 			if(isset($data['agreement_id']) && $data['agreement_id'])
 			{
 				$values = $this->so->read_single($data['agreement_id'], $values);
 			}
-			
-			$values = $this->custom->prepare_attributes($values, 'property', '.agreement');
-			
+
+			$values = $this->custom->prepare($values, 'property', '.agreement');
+
 			$dateformat = $GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat'];
 			if(isset($values['entry_date']) && $values['entry_date'])
 			{
@@ -260,13 +261,14 @@
 				$values['termination_date']= $GLOBALS['phpgw']->common->show_date($values['termination_date'],$dateformat);
 			}
 
-			$this->vfs->override_acl = 1;
+			$vfs = CreateObject('phpgwapi.vfs');
+			$vfs->override_acl = 1;
 
-			$values['files'] = $this->vfs->ls (array(
-			     'string' => $this->fakebase. '/' . 'agreement' .  '/' . $data['agreement_id'],
+			$values['files'] = $vfs->ls (array(
+			     'string' => "/property/agreement/{$data['agreement_id']}",
 			     'relatives' => array(RELATIVE_NONE)));
 
-			$this->vfs->override_acl = 0;
+			$vfs->override_acl = 0;
 
 			if(!isset($values['files'][0]['file_id']) || !$values['files'][0]['file_id'])
 			{
@@ -278,15 +280,29 @@
 
 		function read_single_item($data)
 		{
-			$values['attributes'] = $this->custom->get_attribs('property', '.agreement.detail', 0, '', 'ASC', 'attrib_sort', true, true);
+			$values['attributes'] = $this->custom->find('property', '.agreement.detail', 0, '', 'ASC', 'attrib_sort', true, true);
 			if(isset($data['agreement_id']) && $data['agreement_id'] && isset($data['id']) && $data['id'])
 			{
 				$values = $this->so->read_single_item($data, $values);
 			}
-			$values = $this->custom->prepare_attributes($values, 'property', '.agreement.detail');
+			$values = $this->custom->prepare($values, 'property', '.agreement.detail');
 			return $values;
 		}
 
+		/**
+		* Arrange attributes within groups
+		*
+		* @param string  $location    the name of the location of the attribute
+		* @param array   $attributes  the array of the attributes to be grouped
+		*
+		* @return array the grouped attributes
+		*/
+
+		public function get_attribute_groups($location, $attributes = array())
+		{
+			return $this->custom->get_attribute_groups('property', $location, $attributes);
+		}
+
 		function save($values,$values_attribute='',$action='')
 		{
 			$values['start_date']	= $this->bocommon->date_to_timestamp($values['start_date']);
@@ -304,37 +320,6 @@
 				if ($values['agreement_id'] != 0)
 				{
 					$receipt=$this->so->edit($values,$values_attribute);
-
-					if($values['delete_file'])
-					{
-						for ($i=0;$i<count($values['delete_file']);$i++)
-						{
-							$file = $this->fakebase. SEP . 'agreement' . SEP . $values['agreement_id'] . SEP . $values['delete_file'][$i];
-
-							if($this->vfs->file_exists(array(
-									'string' => $file,
-									'relatives' => Array(RELATIVE_NONE)
-								)))
-							{
-								$this->vfs->override_acl = 1;
-
-								if(!$this->vfs->rm (array(
-									'string' => $file,
-								     'relatives' => array(
-								          RELATIVE_NONE
-								     )
-								)))
-								{
-									$receipt['error'][]=array('msg'=>lang('failed to delete file') . ' :'. $this->fakebase. SEP . 'agreement'. SEP . $values['agreement_id'] . SEP .$values['delete_file'][$i]);
-								}
-								else
-								{
-									$receipt['message'][]=array('msg'=>lang('file deleted') . ' :'. $this->fakebase. SEP . 'agreement'. SEP . $values['id'] . SEP . $values['delete_file'][$i]);
-								}
-								$this->vfs->override_acl = 0;
-							}
-						}
-					}
 				}
 			}
 			else
@@ -378,7 +363,6 @@
 			$this->so->delete_last_index($agreement_id,$id);
 		}
 
-
 		function delete_item($agreement_id,$activity_id)
 		{
 			$this->so->delete_item($agreement_id,$activity_id);
@@ -389,7 +373,6 @@
 			$this->so->delete($agreement_id);
 		}
 
-	
 		function column_list($selected='',$allrows='')
 		{
 			if(!$selected)
@@ -397,7 +380,8 @@
 				$selected = isset($GLOBALS['phpgw_info']['user']['preferences']['property']["agreement_columns"])?$GLOBALS['phpgw_info']['user']['preferences']['property']["agreement_columns"]:'';
 			}
 
-			$columns = $this->custom->get_attribs('property','.agreement', 0, '','','',true);
+			$filter = array('list' => ''); // translates to "list IS NULL"
+			$columns = $this->custom->find('property','.agreement', 0, '','','',true, false, $filter);
 
 			$column_list=$this->bocommon->select_multi_list($selected,$columns);
 
@@ -409,63 +393,6 @@
 				return $this->so->request_next_id();
 		}
 
-		function create_home_dir($receipt='')
-		{
-			if(!$this->vfs->file_exists(array(
-					'string' => $this->fakebase. SEP . 'agreement',
-					'relatives' => Array(RELATIVE_NONE)
-				)))
-			{
-				$this->vfs->override_acl = 1;
-
-				if(!$this->vfs->mkdir (array(
-				     'string' => $this->fakebase. SEP . 'agreement',
-				     'relatives' => array(
-				          RELATIVE_NONE
-				     )
-				)))
-				{
-					$receipt['error'][]=array('msg'=>lang('failed to create directory') . ' :'. $this->fakebase. SEP . 'agreement');
-				}
-				else
-				{
-					$receipt['message'][]=array('msg'=>lang('directory created') . ' :'. $this->fakebase. SEP . 'agreement');
-				}
-				$this->vfs->override_acl = 0;
-			}
-
-			return $receipt;
-		}
-
-		function create_document_dir($id='')
-		{
-
-			if(!$this->vfs->file_exists(array(
-					'string' => $this->fakebase. SEP . 'agreement' .  SEP . $id,
-					'relatives' => Array(RELATIVE_NONE)
-				)))
-			{
-				$this->vfs->override_acl = 1;
-				if(!$this->vfs->mkdir (array(
-				     'string' => $this->fakebase. SEP . 'agreement' .  SEP . $id,
-				     'relatives' => array(
-				          RELATIVE_NONE
-				     )
-				)))
-				{
-					$receipt['error'][]=array('msg'=>lang('failed to create directory') . ' :'. $this->fakebase. SEP  . 'agreement' .  SEP . $id);
-				}
-				else
-				{
-					$receipt['message'][]=array('msg'=>lang('directory created') . ' :'. $this->fakebase. SEP . 'agreement' .  SEP . $id);
-				}
-				$this->vfs->override_acl = 0;
-			}
-
-//_debug_array($receipt);
-			return $receipt;
-		}
-
 		function get_agreement_group_list($selected='')
 		{
 			$agreement_groups= $this->so->get_agreement_group_list();
@@ -479,7 +406,7 @@
 			return $activity_list;
 		}
 
-		function add_activity($values='',$agreement_id='')
+		function add_activity($values,$agreement_id)
 		{
 			return $this->so->add_activity($values,$agreement_id);
 		}
@@ -500,10 +427,10 @@
 
 			return $this->bocommon->select_list($selected,$status_entries);
 		}
-		
+
 		function get_activity_descr($id)
 		{
 			return $this->so->get_activity_descr($id);
 		}
 	}
-?>
+
