@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage document
- 	* @version $Id: class.bodocument.inc.php 18358 2007-11-27 04:43:37Z skwashd $
+ 	* @version $Id: class.bodocument.inc.php 6336 2010-09-13 15:52:25Z sigurd $
 	*/
 
 	/**
@@ -40,94 +40,59 @@
 		var $sort;
 		var $order;
 		var $cat_id;
+		var $entity_id;
+		var $status_id;
+		var $allrows;
 
 		var $public_functions = array
 		(
-			'read'			=> True,
-			'read_single'		=> True,
-			'save'			=> True,
-			'delete'		=> True,
-			'check_perms'		=> True
+			'read'			=> true,
+			'read_single'		=> true,
+			'save'			=> true,
+			'delete'		=> true,
+			'check_perms'		=> true
 		);
 
-		function property_bodocument($session=False)
+		function property_bodocument($session=false)
 		{
-		//	$this->currentapp	= $GLOBALS['phpgw_info']['flags']['currentapp'];
-			$this->so 			= CreateObject('property.sodocument');
-			$this->bocommon 	= CreateObject('property.bocommon');
-			$this->solocation 	= CreateObject('property.solocation');
-			$this->historylog	= CreateObject('property.historylog','document');
-			$this->contacts		= CreateObject('property.soactor');
-			$this->contacts->role='vendor';
-
-			$this->vfs 			= CreateObject('phpgwapi.vfs');
-			$this->rootdir 		= $this->vfs->basedir;
-			$this->fakebase 	= $this->vfs->fakebase;
+			$this->so 				= CreateObject('property.sodocument');
+			$this->bocommon 		= CreateObject('property.bocommon');
+			$this->solocation 		= CreateObject('property.solocation');
+			$this->historylog		= CreateObject('property.historylog','document');
+			$this->contacts			= CreateObject('property.soactor');
+			$this->contacts->role	='vendor';
+			$this->cats				= & $this->so->cats;
+			$this->bofiles			= CreateObject('property.bofiles');
 
 			if ($session)
 			{
 				$this->read_sessiondata();
-				$this->use_session = True;
+				$this->use_session = true;
 			}
 
-			$start	= phpgw::get_var('start', 'int', 'REQUEST', 0);
-			$query	= phpgw::get_var('query');
-			$sort	= phpgw::get_var('sort');
-			$order	= phpgw::get_var('order');
-			$filter	= phpgw::get_var('filter', 'int');
-			$cat_id	= phpgw::get_var('cat_id', 'int');
-			$status_id	= phpgw::get_var('status_id');
-			$entity_id	= phpgw::get_var('entity_id', 'int');
-			$doc_type	= phpgw::get_var('doc_type');
+			$start			= phpgw::get_var('start', 'int', 'REQUEST', 0);
+			$query			= phpgw::get_var('query');
+			$sort			= phpgw::get_var('sort');
+			$order			= phpgw::get_var('order');
+			$filter			= phpgw::get_var('filter', 'int');
+			$cat_id			= phpgw::get_var('cat_id', 'int');
+			$status_id		= phpgw::get_var('status_id');
+			$entity_id		= phpgw::get_var('entity_id', 'int');
+			$doc_type		= phpgw::get_var('doc_type');
 			$query_location	= phpgw::get_var('query_location');
+			$allrows		= phpgw::get_var('allrows', 'bool');
 
-
-			if ($start)
-			{
-				$this->start=$start;
-			}
-			else
-			{
-				$this->start=0;
-			}
-
-			if(isset($query))
-			{
-				$this->query = $query;
-			}
-			if(isset($filter))
-			{
-				$this->filter = $filter;
-			}
-			if(isset($sort))
-			{
-				$this->sort = $sort;
-			}
-			if(isset($order))
-			{
-				$this->order = $order;
-			}
-			if(isset($cat_id))
-			{
-				$this->cat_id = $cat_id;
-			}
-			if(isset($status_id))
-			{
-				$this->status_id = $status_id;
-			}
-			if(isset($entity_id))
-			{
-				$this->entity_id = $entity_id;
-			}
-			if(isset($doc_type))
-			{
-				$this->doc_type = $doc_type;
-			}
-			if(isset($query_location))
-			{
-				$this->query_location = $query_location;
-			}
-
+			$this->start			= $start ? $start : 0;
+			$this->query			= isset($query) ? $query : '';
+			$this->sort				= isset($sort) && $sort ? $sort : '';
+			$this->order			= isset($order) && $order ? $order : '';
+			$this->filter			= isset($filter) && $filter ? $filter : '';
+			$this->cat_id			= isset($cat_id) && $cat_id ? $cat_id : '';
+			$this->status_id		= isset($status_id) && $status_id ? $status_id : '';
+			$this->entity_id		= isset($entity_id) && $entity_id ? $entity_id : '';
+			$this->doc_type			= isset($doc_type) && $doc_type ? $doc_type : '';
+			$this->query_location	= isset($query_location) && $query_location ? $query_location : '';
+			$this->allrows			= isset($allrows) && $allrows ? $allrows : '';
 		}
 
 		function save_sessiondata($data)
@@ -150,7 +115,7 @@
 			$this->sort		= $data['sort'];
 			$this->order	= $data['order'];
 			$this->cat_id	= $data['cat_id'];
-			$this->entity_id	= $data['entity_id'];
+		//	$this->entity_id	= $data['entity_id'];
 			$this->doc_type	= $data['doc_type'];
 			$this->query_location	= $data['query_location'];
 		}
@@ -179,7 +144,7 @@
 
 		function read()
 		{
-			$document = $this->so->read(array('start' => $this->start,'query' => $this->query,'sort' => $this->sort,'order' => $this->order,
+			$documents = $this->so->read(array('start' => $this->start,'query' => $this->query,'sort' => $this->sort,'order' => $this->order,
 											'filter' => $this->filter,'cat_id' => $this->cat_id,'entity_id' => $this->entity_id,'doc_type'=>$this->doc_type));
 			$this->total_records = $this->so->total_records;
 
@@ -187,33 +152,63 @@
 			$cols_extra		= $this->so->cols_extra;
 
 			$dateformat = $GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat'];
-			for ($i=0; $i<count($document); $i++)
+			foreach ($documents as &$document)
 			{
-				$location_data=$this->solocation->read_single($document[$i]['location_code']);
+				$location_data	= $this->solocation->read_single($document['location_code']);
+
+				if(isset($location_data['street_name']) && $location_data['street_name'])
+				{
+					$document['address'] = "{$location_data['street_name']} {$location_data['street_number']}";
+				}
+				elseif($location_data['loc2_name'])
+				{
+					$document['address'] = $location_data['loc2_name'];
+				}
+				elseif($location_data['loc1_name'])
+				{
+					$document['address'] = $location_data['loc1_name'];
+				}
 
 				for ($j=0;$j<count($cols_extra);$j++)
 				{
-					$document[$i][$cols_extra[$j]] = $location_data[$cols_extra[$j]];
+					$document[$cols_extra[$j]] = $location_data[$cols_extra[$j]];
 				}
 			}
 
-			return $document;
+			return $documents;
 		}
 
+		function get_files_at_location($location_code)
+		{
+			return $this->so->get_files_at_location($location_code);
+		}
+
+
 		function read_at_location($location_code='')
 		{
+			$use_svn = false;
+			if(ereg('svn[s:][:/]/', $GLOBALS['phpgw_info']['server']['files_dir']))
+			{
+		//		$use_svn = true;
+			}
+
+
 			$document = $this->so->read_at_location(array('start' => $this->start,'query' => $this->query,'sort' => $this->sort,'order' => $this->order,
 											'filter' => $this->filter,'cat_id' => $this->cat_id,'entity_id' => $this->entity_id,
-											'location_code' => $location_code,'doc_type'=>$this->doc_type));
+											'location_code' => $location_code,'doc_type'=>$this->doc_type, 'allrows' => $this->allrows));
 			$this->total_records = $this->so->total_records;
 
 			$dateformat = $GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat'];
 
-			for ($i=0; $i<count($document); $i++)
+			foreach ($document as & $entry)
 			{
-				$document[$i]['user'] = $GLOBALS['phpgw']->accounts->id2name($document[$i]['user_id']);
-				$document[$i]['document_date'] = $GLOBALS['phpgw']->common->show_date($document[$i]['start_date'],$dateformat);
-				$document[$i]['entry_date'] = $GLOBALS['phpgw']->common->show_date($document[$i]['entry_date'],$dateformat);
+				$entry['user'] = $GLOBALS['phpgw']->accounts->id2name($entry['user_id']);
+				$entry['document_date'] = $GLOBALS['phpgw']->common->show_date($entry['document_date'],$dateformat);
+				$entry['entry_date'] 	= $GLOBALS['phpgw']->common->show_date($entry['entry_date'],$dateformat);
+				if($use_svn)
+				{
+					$entry['journal'] 		= $this->get_file($entry['document_id'], true);
+				}
 			}
 
 			return $document;
@@ -225,10 +220,15 @@
 			$dateformat						= $GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat'];
 			$document['document_date']		= $GLOBALS['phpgw']->common->show_date($document['document_date'],$dateformat);
 
+			if(ereg('svn[s:][:/]/', $GLOBALS['phpgw_info']['server']['files_dir']))
+			{
+				$document['journal']			= $this->get_file($document_id, true, $document);
+			}
+
 			if(isset($document['vendor_id']) && $document['vendor_id'])
 			{
-				$custom 				= createObject('phpgwapi.custom_fields');
-				$vendor['attributes']	= $custom->get_attribs('property','.vendor', 0, '', 'ASC', 'attrib_sort', true, true);
+				$custom 				= createObject('property.custom_fields');
+				$vendor['attributes']	= $custom->find('property','.vendor', 0, '', 'ASC', 'attrib_sort', true, true);
 				$vendor					= $this->contacts->read_single($document['vendor_id'],$vendor);
 				foreach($vendor['attributes'] as $attribute)
 				{
@@ -255,7 +255,6 @@
 				$document['p'][$document['p_entity_id']]['p_cat_id']=$document['p_cat_id'];
 				$document['p'][$document['p_entity_id']]['p_cat_name'] = $category['name'];
 			}
-
 			return $document;
 		}
 
@@ -269,7 +268,7 @@
 		function select_category_list($format='',$selected='')
 		{
 			$soadmin_entity 	= CreateObject('property.soadmin_entity');
-			$categories		= $soadmin_entity->read_category(array('allrows'=>True,'entity_id'=>$this->entity_id));
+			$categories		= $soadmin_entity->read_category(array('allrows'=>true,'entity_id'=>$this->entity_id));
 
 			$category_list	= $this->bocommon->select_list($selected,$categories);
 
@@ -332,7 +331,13 @@
 				}
 				else if ($value['status'] == 'T' || $value['status'] == 'TO')
 				{
-					$record_history[$i]['value_new_value']	= $this->so->read_single_category($value['new_value']);
+					$category 								= $this->cats->return_single($value['new_value']);
+					$record_history[$i]['value_new_value']	= $category[0]['name'];
+					if($value['old_value'])
+					{
+						$category 								= $this->cats->return_single($value['old_value']);
+						$record_history[$i]['value_old_value']	= $category[0]['name'];
+					}
 				}
 				else if ($value['status'] != 'O' && $value['new_value'])
 				{
@@ -349,161 +354,49 @@
 			return $record_history;
 		}
 
-
-		function create_home_dir()
+		function get_file($document_id, $get_journal = false, $values = array())
 		{
-			if(!$this->vfs->file_exists(array(
-					'string' => $this->fakebase. SEP . 'document',
+			if(!$values)
+			{
+				$values = $this->read_single($document_id);
+			}
+
+			if($values['p_num'])
+			{
+				$file	= "{$this->bofiles->fakebase}/document/entity_{$values['p_entity_id']}_{$values['p_cat_id']}/{$values['p_num']}/{$values['doc_type']}/{$values['document_name']}";
+			}
+			else
+			{
+				$file	= "{$this->bofiles->fakebase}/document/{$values['location_code']}/{$values['doc_type']}/{$values['document_name']}";
+			}
+
+			if($this->bofiles->vfs->file_exists(array(
+					'string' => $file,
 					'relatives' => Array(RELATIVE_NONE)
 				)))
 			{
-				$this->vfs->override_acl = 1;
 
-				if(!$this->vfs->mkdir (array(
-				     'string' => $this->fakebase. SEP . 'document',
-				     'relatives' => array(
-				          RELATIVE_NONE
-				     )
-				)))
+				if($get_journal)
 				{
-					$receipt['error'][]=array('msg'=>lang('failed to create directory') . ' :'. $this->fakebase. SEP . 'document');
+					return $this->bofiles->vfs->get_journal(array(
+							'string' => $file,
+							'relatives' => Array(RELATIVE_NONE)
+							));
 				}
 				else
 				{
-					$receipt['message'][]=array('msg'=>lang('directory created') . ' :'. $this->fakebase. SEP . 'document');
+					return $file;
 				}
-				$this->vfs->override_acl = 0;
-				return $receipt;
 			}
+			return false;
 		}
 
-
-		function create_document_dir($data,$receipt)
-		{
-			if(is_array($data))
-			{
-				$loc1			= (isset($data['loc1'])?$data['loc1']:'');
-				$entity_name 	= (isset($data['entity_name'])?$data['entity_name']:'');
-				$category_name	= (isset($data['category_name'])?$data['category_name']:'');
-				$p_num = (isset($data['p_num'])?$data['p_num']:'');
-			}
-
-			$this->vfs->override_acl = 1;
-//_debug_array($data);
-			if(!$this->vfs->file_exists(array(
-					'string' => $this->fakebase. SEP . 'document' .  SEP . $loc1,
-					'relatives' => Array(RELATIVE_NONE)
-				)))
-			{
-				if(!$this->vfs->mkdir (array(
-				     'string' => $this->fakebase. SEP . 'document' .  SEP . $loc1,
-				     'relatives' => array(
-				          RELATIVE_NONE
-				     )
-				)))
-				{
-					$receipt['error'][]=array('msg'=>lang('failed to create directory') . ' :'. $this->fakebase. SEP . 'document' .  SEP . $loc1);
-				}
-				else
-				{
-					$receipt['message'][]=array('msg'=>lang('directory created') . ' :'. $this->fakebase. SEP . 'document' .  SEP . $loc1);
-				}
-				$this->vfs->override_acl = 0;
-			}
-
-			if($entity_name)
-			{
-				if(!$this->vfs->file_exists(array(
-						'string' => $this->fakebase. SEP . 'document' .  SEP . $loc1 .  SEP . $entity_name,
-						'relatives' => Array(RELATIVE_NONE)
-					)))
-				{
-
-					if(!$this->vfs->mkdir (array(
-						 'string' => $this->fakebase. SEP . 'document' .  SEP . $loc1 .  SEP . $entity_name,
-					     'relatives' => array(
-					          RELATIVE_NONE
-					     )
-					)))
-					{
-						$receipt['error'][]=array('msg'=>lang('failed to create directory') . ' :'. $this->fakebase. SEP . 'document'  .  SEP . $loc1 .  SEP . $entity_name);
-					}
-					else
-					{
-						$receipt['message'][]=array('msg'=>lang('directory created') . ' :'. $this->fakebase. SEP . 'document'  .  SEP . $loc1 .  SEP . $entity_name);
-					}
-				}
-			}
-			if($category_name)
-			{
-				if(!$this->vfs->file_exists(array(
-						'string' => $this->fakebase. SEP . 'document' .  SEP . $loc1 .  SEP . $entity_name .  SEP . $category_name,
-						'relatives' => Array(RELATIVE_NONE)
-					)))
-				{
-
-					if(!$this->vfs->mkdir (array(
-						 'string' => $this->fakebase. SEP . 'document' .  SEP . $loc1 .  SEP . $entity_name .  SEP . $category_name,
-					     'relatives' => array(
-					          RELATIVE_NONE
-					     )
-					)))
-					{
-						$receipt['error'][]=array('msg'=>lang('failed to create directory') . ' :'. $this->fakebase. SEP . 'document'  .  SEP . $loc1 .  SEP . $entity_name .  SEP . $category_name);
-					}
-					else
-					{
-						$receipt['message'][]=array('msg'=>lang('directory created') . ' :'. $this->fakebase. SEP . 'document'  .  SEP . $loc1 .  SEP . $entity_name .  SEP . $category_name);
-					}
-				}
-			}
-			if($p_num)
-			{
-				if(!$this->vfs->file_exists(array(
-						'string' => $this->fakebase. SEP . 'document' .  SEP . $loc1 .  SEP . $entity_name .  SEP . $category_name .  SEP . $p_num,
-						'relatives' => Array(RELATIVE_NONE)
-					)))
-				{
-
-					if(!$this->vfs->mkdir (array(
-						 'string' => $this->fakebase. SEP . 'document' .  SEP . $loc1 .  SEP . $entity_name .  SEP . $category_name .  SEP . $p_num,
-					     'relatives' => array(
-					          RELATIVE_NONE
-					     )
-					)))
-					{
-						$receipt['error'][]=array('msg'=>lang('failed to create directory') . ' :'. $this->fakebase. SEP . 'document'  .  SEP . $loc1 .  SEP . $entity_name .  SEP . $category_name .  SEP . $p_num);
-					}
-					else
-					{
-						$receipt['message'][]=array('msg'=>lang('directory created') . ' :'. $this->fakebase. SEP . 'document'  .  SEP . $loc1 .  SEP . $entity_name .  SEP . $category_name .  SEP . $p_num);
-					}
-				}
-			}
-
-			$this->vfs->override_acl = 0;
-
-//_debug_array($receipt);
-			return $receipt;
-		}
-
-
 		function save($values)
 		{
 
 			$document_date	= $this->bocommon->date_array($values['document_date']);
 			$values['document_date']	= mktime (2,0,0,$document_date['month'],$document_date['day'],$document_date['year']);
 
-			while (is_array($values['location']) && list(,$value) = each($values['location']))
-			{
-				if($value)
-				{
-					$location[] = $value;
-				}
-			}
-
-			$values['location_code']=implode("-", $location);
-
 //_debug_array($values);
 			if ($values['document_id'])
 			{
@@ -524,4 +417,4 @@
 			$this->so->delete($document_id);
 		}
 	}
-?>
+
