@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage entity
- 	* @version $Id: class.boentity.inc.php 18358 2007-11-27 04:43:37Z skwashd $
+ 	* @version $Id: class.boentity.inc.php 5790 2010-05-22 15:39:16Z sigurd $
 	*/
 
 	/**
@@ -42,14 +42,20 @@
 		var $cat_id;
 		var $allrows;
 		var $part_of_town_id;
+		var $location_code;
+
+		/**
+		* @var object $custom reference to custom fields object
+		*/
+		protected $custom;
 
 		var $public_functions = array
 		(
-			'read'			=> True,
-			'read_single'		=> True,
-			'save'			=> True,
-			'delete'		=> True,
-			'check_perms'		=> True
+			'read'			=> true,
+			'read_single'		=> true,
+			'save'			=> true,
+			'delete'		=> true,
+			'check_perms'		=> true
 		);
 
 		var $soap_functions = array(
@@ -71,19 +77,18 @@
 			)
 		);
 
-		function property_boentity($session=False)
+		var $type_app = array();
+		var $type;
+
+		function property_boentity($session=false)
 		{
 			$this->solocation 	= CreateObject('property.solocation');
 			$this->bocommon 	= CreateObject('property.bocommon');
-			$this->custom 		= createObject('phpgwapi.custom_fields');
-			$this->vfs 			= CreateObject('phpgwapi.vfs');
-			$this->rootdir 		= $this->vfs->basedir;
-			$this->fakebase 	= $this->vfs->fakebase;
 
 			if ($session)
 			{
 				$this->read_sessiondata();
-				$this->use_session = True;
+				$this->use_session = true;
 			}
 
 			$start		= phpgw::get_var('start', 'int', 'REQUEST', 0);
@@ -98,20 +103,29 @@
 			$start_date	= phpgw::get_var('start_date');
 			$end_date	= phpgw::get_var('end_date');
 			$allrows	= phpgw::get_var('allrows', 'bool');
-		
+			$type		= phpgw::get_var('type');
+			$criteria_id	= phpgw::get_var('criteria_id');
 
-			$this->soadmin_entity 	= CreateObject('property.soadmin_entity',$entity_id,$cat_id);
-			$this->so 		= CreateObject('property.soentity',$entity_id,$cat_id);
-			$this->category_dir = 'entity_' . $entity_id . '_' . $cat_id;
+			$this->criteria_id		= isset($criteria_id) && $criteria_id ? $criteria_id : '';
+
+			$location_code		= phpgw::get_var('location_code');
+			$this->so 			= CreateObject('property.soentity',$entity_id,$cat_id);
+			$this->type_app		= $this->so->get_type_app();
+
+			$this->type	= isset($type)  && $type && $this->type_app[$type] ? $type : 'entity';
+			$this->location_code	= isset($location_code)  && $location_code ? $location_code : '';
+			
+			$this->soadmin_entity 			= CreateObject('property.soadmin_entity',$entity_id,$cat_id);
+			$this->custom 					= & $this->so->custom;
+			$this->soadmin_entity->type		= $this->type;
+			$this->soadmin_entity->type_app	= $this->type_app;
+			$this->so->type					= $this->type;
+
+
+			$this->category_dir = "{$this->type}_{$entity_id}_{$cat_id}";
+
+			$this->start			= $start ? $start : 0;
 
-			if ($start)
-			{
-				$this->start=$start;
-			}
-			else
-			{
-				$this->start=0;
-			}
 			if(isset($_POST['query']) || isset($_GET['query']))
 			{
 				$this->query = $query;
@@ -162,13 +176,13 @@
 		{
 			if ($this->use_session)
 			{
-				$GLOBALS['phpgw']->session->appsession('session_data','entity',$data);
+				$GLOBALS['phpgw']->session->appsession('session_data',$this->type,$data);
 			}
 		}
 
 		function read_sessiondata()
 		{
-			$data = $GLOBALS['phpgw']->session->appsession('session_data','entity');
+			$data = $GLOBALS['phpgw']->session->appsession('session_data',$this->type);
 			//_debug_array($data);
 			$this->start		= isset($data['start'])?$data['start']:'';
 			$this->query		= isset($data['query'])?$data['query']:'';
@@ -186,14 +200,15 @@
 		{
 			if(!$selected)
 			{
-				$selected=$GLOBALS['phpgw_info']['user']['preferences']['property']["entity_columns_" . $this->entity_id . '_' . $this->cat_id];
+				$selected=$GLOBALS['phpgw_info']['user']['preferences'][$this->type_app[$this->type]]["{$this->type}_columns_{$this->entity_id}_{$this->cat_id}"];
 			}
-			$columns = $this->custom->get_attribs('property','.entity.' . $entity_id . '.' . $cat_id, 0, '','','',true);
+			$filter = array('list' => ''); // translates to "list IS NULL"
+			$columns = $this->custom->find($this->type_app[$this->type],".{$this->type}.{$entity_id}.{$cat_id}", 0, '','','',true, false, $filter);
 			$column_list=$this->bocommon->select_multi_list($selected,$columns);
 			return $column_list;
 		}
 
-		function select_category_list($format='',$selected='')
+		function select_category_list($format='',$selected='', $required = '')
 		{
 			switch($format)
 			{
@@ -205,7 +220,7 @@
 					break;
 			}
 
-			$categories= $this->soadmin_entity->read_category(array('allrows'=>True,'entity_id'=>$this->entity_id));
+			$categories= $this->soadmin_entity->read_category(array('allrows'=>true,'entity_id'=>$this->entity_id, 'required' => $required));
 
 			return $this->bocommon->select_list($selected,$categories);
 		}
@@ -228,7 +243,30 @@
 			return $this->bocommon->select_list($selected,$status_entries);
 		}
 
-		function read($data='')
+		function get_criteria_list($selected='')
+		{
+			$criteria = array
+			(
+				array
+				(
+					'id'	=> 'vendor',
+					'name'	=> lang('vendor')
+				),
+				array
+				(
+					'id'	=> 'ab',
+					'name'	=> lang('contact')
+				),
+				array
+				(
+					'id'	=> 'abo',
+					'name'	=> lang('organisation')
+				)
+			);
+			return $this->bocommon->select_list($selected,$criteria);
+		}
+
+		function read($data= array())
 		{
 			if(isset($this->allrows))
 			{
@@ -237,8 +275,12 @@
 
 			$entity = $this->so->read(array('start' => $this->start,'query' => $this->query,'sort' => $this->sort,'order' => $this->order,
 											'filter' => $this->filter,'cat_id' => $this->cat_id,'district_id' => $this->district_id,
-											'lookup'=>isset($data['lookup'])?$data['lookup']:'','allrows'=>isset($data['allrows'])?$data['allrows']:'','entity_id'=>$this->entity_id,'cat_id'=>$this->cat_id,'status'=>$this->status,
-											'start_date'=>$this->bocommon->date_to_timestamp($data['start_date']),'end_date'=>$this->bocommon->date_to_timestamp($data['end_date'])));
+											'lookup'=>isset($data['lookup'])?$data['lookup']:'','allrows'=>isset($data['allrows'])?$data['allrows']:'',
+											'entity_id'=>$this->entity_id,'cat_id'=>$this->cat_id,'status'=>$this->status,
+											'start_date'=>$this->bocommon->date_to_timestamp($data['start_date']),
+											'end_date'=>$this->bocommon->date_to_timestamp($data['end_date']),
+											'dry_run'=>$data['dry_run'], 'type'=>$data['type'], 'location_code' => $this->location_code,
+											'criteria_id' => $this->criteria_id));
 
 			$this->total_records = $this->so->total_records;
 			$this->uicols	= $this->so->uicols;
@@ -271,16 +313,16 @@
 			return $entity;
 		}
 
-		function read_single($data)
+		function read_single($data, $values = array())
 		{
-			$values['attributes'] = $this->custom->get_attribs('property','.entity.' . $data['entity_id'] .'.' . $data['cat_id'], 0, '', 'ASC', 'attrib_sort', true, true);
+			$values['attributes'] = $this->custom->find($this->type_app[$this->type],".{$this->type}.{$data['entity_id']}.{$data['cat_id']}", 0, '', 'ASC', 'attrib_sort', true, true);
 			if(isset($data['id']) && $data['id'])
 			{
 				$values = $this->so->read_single($data, $values);
 			}
-			$values = $this->custom->prepare_attributes($values, 'property','.entity.' . $data['entity_id'] .'.' . $data['cat_id'], $data['view']);
+			$values = $this->custom->prepare($values, $this->type_app[$this->type],".{$this->type}.{$data['entity_id']}.{$data['cat_id']}", $data['view']);
 
-			$soadmin_entity	= CreateObject('property.soadmin_entity');
+	//		$soadmin_entity	= CreateObject('property.soadmin_entity');
 
 			if($values['location_code'])
 			{
@@ -297,105 +339,67 @@
 
 			if($values['p_num'])
 			{
-				$category = $soadmin_entity->read_single_category($values['p_entity_id'],$values['p_cat_id']);
+				$category = $this->soadmin_entity->read_single_category($values['p_entity_id'],$values['p_cat_id']);
 				$values['p'][$values['p_entity_id']]['p_num']=$values['p_num'];
 				$values['p'][$values['p_entity_id']]['p_entity_id']=$values['p_entity_id'];
 				$values['p'][$values['p_entity_id']]['p_cat_id']=$values['p_cat_id'];
 				$values['p'][$values['p_entity_id']]['p_cat_name'] = $category['name'];
 			}
 
-			$this->vfs->override_acl = 1;
-			$values['files'] = $this->vfs->ls (array(
-			     'string' => $this->fakebase. '/' . $this->category_dir . '/' . $values['location_data']['loc1'] .  '/' . $data['id'],
-			     'relatives' => array(RELATIVE_NONE)));
+			$vfs = CreateObject('phpgwapi.vfs');
+			$vfs->override_acl = 1;
+			
+			$loc1 = isset($values['location_data']['loc1']) && $values['location_data']['loc1'] ? $values['location_data']['loc1'] : 'dummy';
 
-			$this->vfs->override_acl = 0;
-
-			if(!isset($values['files'][0]['file_id']) || !$values['files'][0]['file_id'])
+			if($this->type_app[$this->type] == 'catch')
 			{
-				unset($values['files']);
+				$loc1 = 'dummy';
 			}
 
+			$files = $vfs->ls (array(
+			     'string' => "/property/{$this->category_dir}/{$loc1}/{$data['id']}",
+			     'relatives' => array(RELATIVE_NONE)));
+
+			$vfs->override_acl = 0;
+
+			$values['jasperfiles']	= array();
+			$values['files']		= array();
+			foreach ($files as $file)
+			{
+				if (strpos($file['name'], 'jasper::')===0)// check for jasper
+				{
+					$values['jasperfiles'][] = array
+					(
+						'name' 		=> $file['name']
+					);
+				}
+				else
+				{
+					$values['files'][] = array
+					(
+						'name' 		=> $file['name']
+					);
+				}
+			}
+			
+			$interlink 	= CreateObject('property.interlink');
+			$values['origin'] = $interlink->get_relation($this->type_app[$this->type], ".{$this->type}.{$data['entity_id']}.{$data['cat_id']}", $data['id'], 'origin');
+			$values['target'] = $interlink->get_relation($this->type_app[$this->type], ".{$this->type}.{$data['entity_id']}.{$data['cat_id']}", $data['id'], 'target');
 			return $values;
 		}
 
-		function create_home_dir($receipt='')
+		/**
+		* Arrange attributes within groups
+		*
+		* @param string  $location    the name of the location of the attribute
+		* @param array   $attributes  the array of the attributes to be grouped
+		*
+		* @return array the grouped attributes
+		*/
+
+		public function get_attribute_groups($location, $attributes = array())
 		{
-			if(!$this->vfs->file_exists(array(
-					'string' => $this->fakebase. SEP . $this->category_dir,
-					'relatives' => Array(RELATIVE_NONE)
-				)))
-			{
-				$this->vfs->override_acl = 1;
-
-				if(!$this->vfs->mkdir (array(
-				     'string' => $this->fakebase. SEP . $this->category_dir,
-				     'relatives' => array(
-				          RELATIVE_NONE
-				     )
-				)))
-				{
-					$receipt['error'][]=array('msg'=>lang('failed to create directory') . ' :'. $this->fakebase. SEP . $this->category_dir);
-				}
-				else
-				{
-					$receipt['message'][]=array('msg'=>lang('directory created') . ' :'. $this->fakebase. SEP . $this->category_dir);
-				}
-				$this->vfs->override_acl = 0;
-			}
-
-			return $receipt;
-		}
-
-		function create_document_dir($loc1='',$id='')
-		{
-			if(!$this->vfs->file_exists(array(
-					'string' => $this->fakebase. SEP . $this->category_dir .  SEP . $loc1,
-					'relatives' => Array(RELATIVE_NONE)
-				)))
-			{
-				$this->vfs->override_acl = 1;
-				if(!$this->vfs->mkdir (array(
-				     'string' => $this->fakebase. SEP . $this->category_dir .  SEP . $loc1,
-				     'relatives' => array(
-				          RELATIVE_NONE
-				     )
-				)))
-				{
-					$receipt['error'][]=array('msg'=>lang('failed to create directory') . ' :'. $this->fakebase. SEP . $this->category_dir .  SEP . $loc1);
-				}
-				else
-				{
-					$receipt['message'][]=array('msg'=>lang('directory created') . ' :'. $this->fakebase. SEP . $this->category_dir .  SEP . $loc1);
-				}
-				$this->vfs->override_acl = 0;
-			}
-
-
-			if(!$this->vfs->file_exists(array(
-					'string' => $this->fakebase. SEP . $this->category_dir .  SEP . $loc1 .  SEP . $id,
-					'relatives' => Array(RELATIVE_NONE)
-				)))
-			{
-				$this->vfs->override_acl = 1;
-				if(!$this->vfs->mkdir (array(
-				     'string' => $this->fakebase. SEP . $this->category_dir .  SEP . $loc1 .  SEP . $id,
-				     'relatives' => array(
-				          RELATIVE_NONE
-				     )
-				)))
-				{
-					$receipt['error'][]=array('msg'=>lang('failed to create directory') . ' :'. $this->fakebase. SEP  . $this->category_dir  .  SEP . $loc1 .  SEP . $id);
-				}
-				else
-				{
-					$receipt['message'][]=array('msg'=>lang('directory created') . ' :'. $this->fakebase. SEP . $this->category_dir .  SEP . $loc1 .  SEP . $id);
-				}
-				$this->vfs->override_acl = 0;
-			}
-
-//_debug_array($receipt);
-			return $receipt;
+			return $this->custom->get_attribute_groups($this->type_app[$this->type], $location, $attributes);
 		}
 
 		function save($values,$values_attribute,$action='',$entity_id,$cat_id)
@@ -420,58 +424,40 @@
 			if ($action=='edit')
 			{
 				$receipt = $this->so->edit($values,$values_attribute,$entity_id,$cat_id);
-
-				if(isset($values['delete_file']) && is_array($values['delete_file']))
-				{
-					for ($i=0;$i<count($values['delete_file']);$i++)
-					{
-						$file = $this->fakebase. SEP . $this->category_dir . SEP . $location[0] . SEP . $values['id'] . SEP . $values['delete_file'][$i];
-
-						if($this->vfs->file_exists(array(
-								'string' => $file,
-								'relatives' => Array(RELATIVE_NONE)
-							)))
-						{
-							$this->vfs->override_acl = 1;
-
-							if(!$this->vfs->rm (array(
-								'string' => $file,
-							     'relatives' => array(
-							          RELATIVE_NONE
-							     )
-							)))
-							{
-								$receipt['error'][]=array('msg'=>lang('failed to delete file') . ' :'. $this->fakebase. SEP . $this->category_dir . SEP . $location[0]. SEP . $values['id'] . SEP .$values['delete_file'][$i]);
-							}
-							else
-							{
-								$receipt['message'][]=array('msg'=>lang('file deleted') . ' :'. $this->fakebase. SEP . $this->category_dir . SEP . $location[0]. SEP . $values['id'] . SEP . $values['delete_file'][$i]);
-							}
-							$this->vfs->override_acl = 0;
-						}
-					}
-				}
 			}
 			else
 			{
 				$receipt = $this->so->add($values,$values_attribute,$entity_id,$cat_id);
 			}
 
-			$acl_location = '.entity.' . $entity_id . '.' . $cat_id;
-			$custom_functions = $this->custom->read_custom_function(array('appname'=>'property','location' => $acl_location,'allrows'=>True));
+			$criteria = array
+			(
+				'appname'	=> $this->type_app[$this->type],
+				'location'	=> ".{$this->type}.{$entity_id}.{$cat_id}",
+				'allrows'	=> true
+			);
 
-			if (isSet($custom_functions) AND is_array($custom_functions))
+			$custom_functions = $GLOBALS['phpgw']->custom_functions->find($criteria);
+
+			foreach ( $custom_functions as $entry )
 			{
-				foreach($custom_functions as $entry)
+				// prevent path traversal
+				if ( preg_match('/\.\./', $entry['file_name']) )
 				{
-					if (is_file(PHPGW_APP_INC . SEP . 'custom' . SEP . $entry['file_name']) && $entry['active'])
-					include (PHPGW_APP_INC . SEP . 'custom' . SEP . $entry['file_name']);
+					continue;
+				}
+
+				$file = PHPGW_SERVER_ROOT . "/{$this->type_app[$this->type]}/inc/custom/{$GLOBALS['phpgw_info']['user']['domain']}/{$entry['file_name']}";
+
+				if ( $entry['active'] && is_file($file) )
+				{
+					require_once $file;
 				}
 			}
+
 			return $receipt;
 		}
 
-
 		function delete($id )
 		{
 			$this->so->delete($this->entity_id,$this->cat_id,$id);
@@ -485,11 +471,50 @@
 			}
 		}
 
+		function get_history_type_for_location($acl_location)
+		{
+			switch($acl_location)
+			{
+				case '.project.request':
+					$history_type ='request';
+					break;
+				case '.project.workorder':
+					$history_type ='workorder';
+					break;
+				case '.project':
+					$history_type ='project';
+					break;
+				case '.tts':
+					$history_type ='tts';
+					break;
+				case '.document':
+					$history_type ='document';
+					break;
+				case 'entity':
+					$this->table='fm_entity_history';
+					$this->attrib_id_field = ',history_attrib_id';
+					break;
+				case '.s_agreement':
+					$history_type ='s_agreement';
+					break;
+				case '.s_agreement.detail':
+					$history_type ='s_agreement';
+				default:
+					$history_type = str_replace('.','_',substr($acl_location,-strlen($acl_location)+1));
+			}
+			if(!$history_type)
+			{
+					throw new Exception(lang('Unknown history type for acl_location: %1', $acl_location));
+			}
+			return $history_type;
+		}
+		
 		function read_attrib_history($data)
 		{
 		//	_debug_array($data);
-			$historylog = CreateObject('property.historylog','entity_' . $data['entity_id'] .'_' . $data['cat_id']);
-			$history_values = $historylog->return_array(array(),array('SO'),'history_timestamp','ASC',$data['id'],$data['attrib_id']);
+			$history_type = $this->get_history_type_for_location($data['acl_location']);
+			$historylog = CreateObject('property.historylog',$history_type);
+			$history_values = $historylog->return_array(array(),array('SO'),'history_timestamp','ASC',$data['id'],$data['attrib_id'], $data['detail_id']);
 			$this->total_records = count($history_values);
 		//	_debug_array($history_values);
 			return $history_values;
@@ -497,7 +522,8 @@
 
 		function delete_history_item($data)
 		{
-			$historylog = CreateObject('property.historylog','entity_' . $data['entity_id'] .'_' . $data['cat_id']);
+			$history_type = $this->get_history_type_for_location($data['acl_location']);
+			$historylog = CreateObject('property.historylog', $history_type);
 			$historylog->delete_single_record($data['history_id']);
 		}
 
@@ -505,5 +531,10 @@
 		{
 			return $this->so->read_attrib_help($data);
 		}
+
+		function read_entity_to_link($data)
+		{
+				return $this->so->read_entity_to_link($data);
+		}
+
 	}
-?>
