@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage eco
- 	* @version $Id: class.boinvoice.inc.php 18358 2007-11-27 04:43:37Z skwashd $
+ 	* @version $Id: class.boinvoice.inc.php 6179 2010-07-05 06:52:20Z sigurd $
 	*/
 
 	/**
@@ -34,82 +34,41 @@
 
 	class property_boinvoice
 	{
-		var $db = '';
-
-		function property_boinvoice($session=False)
+		function property_boinvoice($session=false)
 		{
-			$this->db		= $GLOBALS['phpgw']->db;
-		//	$this->currentapp	= $GLOBALS['phpgw_info']['flags']['currentapp'];
-			$this->so		= CreateObject('property.soinvoice',True);
+			$this->so		= CreateObject('property.soinvoice',true);
 			$this->bocommon		= CreateObject('property.bocommon');
 			$this->account_id	= $GLOBALS['phpgw_info']['user']['account_id'];
 
 			if ($session)
 			{
 				$this->read_sessiondata();
-				$this->use_session = True;
+				$this->use_session = true;
 			}
 
-			$start			= phpgw::get_var('start', 'int', 'REQUEST', 0);
-			$query			= phpgw::get_var('query');
-			$sort			= phpgw::get_var('sort');
-			$order			= phpgw::get_var('order');
-			$filter			= phpgw::get_var('filter', 'int');
-			$cat_id			= phpgw::get_var('cat_id', 'int');
-			$user_lid		= phpgw::get_var('user_lid');
-			$allrows		= phpgw::get_var('allrows', 'bool');
-			$b_account_class	= phpgw::get_var('b_account_class', 'int');
-			$district_id		= phpgw::get_var('district_id', 'int');
-			
-			
-			if ($start)
-			{
-				$this->start=$start;
-			}
-			else
-			{
-				$this->start=0;
-			}
+			$start					= phpgw::get_var('start', 'int', 'REQUEST', 0);
+			$query					= phpgw::get_var('query');
+			$sort					= phpgw::get_var('sort');
+			$order					= phpgw::get_var('order');
+			$filter					= phpgw::get_var('filter', 'int');
+			$cat_id					= phpgw::get_var('cat_id', 'int');
+			$user_lid				= phpgw::get_var('user_lid');
+			$allrows				= phpgw::get_var('allrows', 'bool');
+			$b_account_class		= phpgw::get_var('b_account_class', 'int');
+			$district_id			= phpgw::get_var('district_id', 'int');
+			$b_account				= phpgw::get_var('b_account');
 
-			if(isset($district_id))
-			{
-				$this->district_id = $district_id;
-			}
-
-			if(isset($b_account_class))
-			{
-				$this->b_account_class = $b_account_class;
-			}
-
-			if(isset($query))
-			{
-				$this->query = $query;
-			}
-
-			if(!empty($filter))
-			{
-				$this->filter = $filter;
-			}
-			if(isset($sort))
-			{
-				$this->sort = $sort;
-			}
-			if(isset($order))
-			{
-				$this->order = $order;
-			}
-			if(isset($cat_id))
-			{
-				$this->cat_id = $cat_id;
-			}
-			if(isset($user_lid))
-			{
-				$this->user_lid = $user_lid;
-			}
-			if(isset($allrows))
-			{
-				$this->allrows = $allrows;
-			}
+			$this->start			= $start ? $start : 0;
+			$this->b_account		= isset($b_account) ? $b_account : $b_account;
+			$this->district_id		= isset($district_id) ? $district_id : $district_id;
+			$this->b_account_class	= isset($b_account_class) ? $b_account_class : $b_account_class;
+			$this->query			= isset($query) ? $query : $query;
+			$this->filter			= isset($filter) ? $filter : $filter;
+			$this->sort				= isset($sort) ? $sort : $sort;
+			$this->order			= isset($order) ? $order : $order;
+			$this->cat_id			= isset($cat_id) ? $cat_id : $cat_id;
+			$this->user_lid			= isset($user_lid) ? $user_lid : $user_lid;
+			$this->allrows			= isset($allrows) ? $allrows : $allrows;
 		}
 
 
@@ -137,11 +96,14 @@
 			$this->sub				= isset($data['sub'])?$data['sub']:'';
 			$this->allrows			= isset($data['allrows'])?$data['allrows']:'';
 			$this->b_account_class	= isset($data['b_account_class'])?$data['b_account_class']:'';
-			$this->district_id		= isset($data['district_id'])?$data['district_id']:'';		
+			$this->district_id		= isset($data['district_id'])?$data['district_id']:'';
 		}
 
 		function read_invoice($paid='',$start_date='',$end_date='',$vendor_id='',$loc1='',$workorder_id='',$voucher_id='')
 		{
+			$start_date	= $this->bocommon->date_to_timestamp($start_date);
+			$end_date	= $this->bocommon->date_to_timestamp($end_date);
+			
 			$invoice = $this->so->read_invoice(array('start' => $this->start,'query' => $this->query,'sort' => $this->sort,'order' => $this->order,
 											'user_lid' => $this->user_lid,'cat_id' => $this->cat_id, 'paid' => $paid,
 											'start_date'=>$start_date,'end_date'=>$end_date,'vendor_id'=>$vendor_id,
@@ -174,11 +136,14 @@
 
 		function read_consume($start_date='',$end_date='',$vendor_id='',$loc1='',$workorder_id='',$b_account_class='',$district_id='')
 		{
+			$start_date	= $this->bocommon->date_to_timestamp($start_date);
+			$end_date	= $this->bocommon->date_to_timestamp($end_date);
+
 			$invoice = $this->so->read_consume(array('start' => $this->start,'query' => $this->query,'sort' => $this->sort,'order' => $this->order,
 											'user_lid' => $this->user_lid,'cat_id' => $this->cat_id,
 											'start_date'=>$start_date,'end_date'=>$end_date,'vendor_id'=>$vendor_id,
 											'loc1'=>$loc1,'workorder_id'=>$workorder_id,'b_account_class' =>$b_account_class,
-											'district_id' => $district_id ));
+											'district_id' => $district_id, 'b_account' => $this->b_account ));
 
 			$this->total_records = $this->so->total_records;
 
@@ -311,7 +276,7 @@
 					$GLOBALS['phpgw']->xslttpl->add_file(array('user_lid_filter'));
 					break;
 			}
-			$users=$this->bocommon->get_user_list_right(1,$selected,'.invoice',$extra,$default);
+			$users=$this->bocommon->get_user_list_right(array(32, 64, 128),$selected,'.invoice',$extra,$default);
 			return $users;
 		}
 
@@ -361,14 +326,11 @@
 				$values['dima']=implode('',$values['location']);
 			}
 
-			$values['spbudact_code']=$values['b_account_id'];
-			$values['fakturanr']=$values['invoice_num'];
-			$values['spvend_code']=$values['vendor_id'];
-
-			$values['belop'] = str_replace('kr','',$values['amount']);
-			$values['belop'] = str_replace(' ','',$values['belop']);
-			$values['belop'] = str_replace(',','.',$values['belop']);
-			$values['godkjentbelop']=$values['belop'];
+			$values['spbudact_code']	= $values['b_account_id'];
+			$values['fakturanr']		= $values['invoice_num'];
+			$values['spvend_code']		= $values['vendor_id'];
+			$values['belop'] 			= $values['amount'];
+			$values['godkjentbelop']	= $values['amount'];
 
 			$values['fakturadato'] = date($this->bocommon->dateformat,mktime(2,0,0,$values['smonth'],$values['sday'],$values['syear']));
 
@@ -382,7 +344,7 @@
 			}
 
 			$values['artid'] 			= $values['art'];
-			$values['periode']			= $values['smonth'];
+			$values['periode']			= $values['syear'] . sprintf("%02d",$values['smonth']);
 			$values['dimb']				= $values['dim_b'];
 			$values['oppsynsmannid']	= $values['janitor'];
 			$values['saksbehandlerid']	= $values['supervisor'];
@@ -390,7 +352,8 @@
 			$values['kildeid'] 			= 1;
 			$values['kidnr'] 			= $values['kid_nr'];
 			$values['typeid'] 			= $values['type'];
-			if($order_type = $this->soXport->check_order(intval($values['order_id'])))
+//_debug_array($values);die();
+			if($values['order_id'] && $order_type = $this->soXport->check_order($values['order_id']))
 			{
 				if($order_type=='workorder')
 				{
@@ -406,6 +369,10 @@
 					$values['vendor_name']		= $this->get_vendor_name($workorder['vendor_id']);
 					$values['pmwrkord_code']	= $values['order_id'];
 					$values['project_id']			= $workorder['project_id'];
+					if(!$values['dimb'])
+					{
+						$values['dimb']			= $workorder['ecodimb'];
+					}
 
 					$values = $this->set_responsible($values,$workorder['user_id'],$workorder['b_account_id']);
 
@@ -432,7 +399,7 @@
 					$values = $this->set_responsible($values,$s_agreement['user_id'],$s_agreement['b_account_id']);
 
 
-					$s_agreement_detail = $sos_agreement->read(array('allrows'=>True,'s_agreement_id'=>$values['order_id'],'detail'=>True));
+					$s_agreement_detail = $sos_agreement->read(array('allrows'=>true,'s_agreement_id'=>$values['order_id'],'detail'=>true));
 
 					$sum_agreement=0;
 					for ($i=0;$i<count($s_agreement_detail);$i++)
@@ -497,12 +464,24 @@
 			$contacts	= CreateObject('property.soactor');
 			$contacts->role='vendor';
 
-			$vendor_data	= $contacts->read_single(array('actor_id'=>$vendor_id));
+			$criteria = array
+			(
+				'attributes' => array
+				(
+					array
+					(
+						'column_name' => 'org_name'
+					)
+				)
+			);
+
+			$vendor_data	= $contacts->read_single($vendor_id, $criteria);
+
 			if(is_array($vendor_data))
 			{
 				foreach($vendor_data['attributes'] as $attribute)
 				{
-					if($attribute['name']=='org_name')
+					if($attribute['column_name']=='org_name')
 					{
 						return $attribute['value'];
 					}
@@ -512,27 +491,55 @@
 
 		function set_responsible($values,$user_id='',$b_account_id='')
 		{
+			$config				= CreateObject('phpgwapi.config','property');
+			$config->read();
+			$responsible_supervisor = isset($config->config_data['dimb_responsible_1']) && $config->config_data['dimb_responsible_1'] ? $config->config_data['dimb_responsible_1'] : 0;
+			$responsible_responsible = isset($config->config_data['dimb_responsible_2']) && $config->config_data['dimb_responsible_2'] ? $config->config_data['dimb_responsible_2'] : 0;
+
+			$responsible		= CreateObject('property.soresponsible');
+			if (!$values['budget_responsible'])
+			{
+				$criteria_budget_responsible		= array('ecodimb' => $values['dimb'], 'cat_id' => $responsible_responsible);
+				$budget_responsible_contact_id		= $responsible->get_responsible($criteria_budget_responsible);
+				$budget_responsible_user_id			= $responsible->get_contact_user_id($budget_responsible_contact_id);
+				$values['budget_responsible']		= $GLOBALS['phpgw']->accounts->get($budget_responsible_user_id)->lid;
+				$values['budsjettansvarligid']		= $values['budget_responsible'];
+			}
+
 			if (!$values['budget_responsible'])
 			{
 				$values['budget_responsible'] = $this->soXport->get_responsible($b_account_id);
 				$values['budsjettansvarligid'] = $values['budget_responsible'];
 			}
 
-			$acl 	= CreateObject('phpgwapi.acl',$user_id);
-			if($acl->check('.invoice',32) && !$acl->check('.invoice',64)):
-			{
-				$values['janitor']	= $GLOBALS['phpgw']->accounts->id2name($user_id);
-				$values['oppsynsmannid']	= $values['janitor'];
-			}
-	//		elseif((!$acl->check('.invoice',32) && $acl->check('.invoice',64)) || ($acl->check('.invoice',32) && $acl->check('.invoice',64))):
-			elseif($acl->check('.invoice',64)):
-			{
-				$values['supervisor']	= $GLOBALS['phpgw']->accounts->id2name($user_id);
-				$values['saksbehandlerid']	= $values['supervisor'];
-			}
-			endif;
 
+			if(!$values['supervisor'])
+			{
+				$criteria_supervisor				= array('ecodimb' => $values['dimb'], 'cat_id' => $responsible_supervisor);
+				$supervisor_contact_id				= $responsible->get_responsible($criteria_supervisor);
+				$supervisor_user_id					= $responsible->get_contact_user_id($supervisor_contact_id);
+				$values['supervisor']				= $GLOBALS['phpgw']->accounts->get($supervisor_user_id)->lid;
+				$values['saksbehandlerid']			= $values['supervisor'];
+			}
+
+			$values['janitor']				= $GLOBALS['phpgw']->accounts->get($user_id)->lid;
+			$values['oppsynsmannid']		= $values['janitor'];
+
+			if(!$values['supervisor'])
+			{
+				$acl 	= CreateObject('phpgwapi.acl',$user_id);
+				if($acl->check('.invoice', 32, 'property') && !$acl->check('.invoice', 64, 'property'))
+				{
+					$values['janitor']	= $GLOBALS['phpgw']->accounts->get($user_id)->lid;
+					$values['oppsynsmannid']	= $values['janitor'];
+				}
+				else if($acl->check('.invoice', 64, 'property'))
+				{
+					$values['supervisor']	= $GLOBALS['phpgw']->accounts->get($user_id)->lid;
+					$values['saksbehandlerid']	= $values['supervisor'];
+				}
+			}
 			return $values;
 		}
 	}
-?>
+
