@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage location
- 	* @version $Id: class.bolocation.inc.php 18358 2007-11-27 04:43:37Z skwashd $
+ 	* @version $Id: class.bolocation.inc.php 6124 2010-06-21 08:38:33Z sigurd $
 	*/
 
 	/**
@@ -43,14 +43,21 @@
 		var $type_id;
 		var $lookup;
 		var $use_session;
+		var $location_code;
+		var $total_records;
+
+		/**
+		* @var object $custom reference to custom fields object
+		*/
+		protected $custom;
 
 		var $public_functions = array
 		(
-			'read'		=> True,
-			'read_single'	=> True,
-			'save'		=> True,
-			'delete'	=> True,
-			'check_perms'	=> True
+			'read'		=> true,
+			'read_single'	=> true,
+			'save'		=> true,
+			'delete'	=> true,
+			'check_perms'	=> true
 		);
 
 		var $soap_functions = array(
@@ -72,20 +79,19 @@
 			)
 		);
 
-		function property_bolocation($session=False)
+		function property_bolocation($session=false)
 		{
-		//	$this->currentapp			= $GLOBALS['phpgw_info']['flags']['currentapp'];
-			$this->so 					= CreateObject('property.solocation');
-			$this->bocommon 			= CreateObject('property.bocommon');
 			$this->soadmin_location		= CreateObject('property.soadmin_location');
-			$this->custom 				= createObject('phpgwapi.custom_fields');
+			$this->bocommon 			= CreateObject('property.bocommon');
+			$this->so 					= CreateObject('property.solocation', $this->bocommon);
+			$this->custom 				= & $this->so->custom;
 
 			$this->lookup    = phpgw::get_var('lookup', 'bool');
 
 			if ($session && !$this->lookup)
 			{
 				$this->read_sessiondata();
-				$this->use_session = True;
+				$this->use_session = true;
 			}
 
 			$start					= phpgw::get_var('start', 'int', 'REQUEST', 0);
@@ -93,16 +99,17 @@
 			$sort					= phpgw::get_var('sort');
 			$order					= phpgw::get_var('order');
 			$filter					= phpgw::get_var('filter', 'int');
-			$cat_id					= phpgw::get_var('cat_id', 'int');
+			$cat_id					= phpgw::get_var('cat_id');
 			$lookup_tenant			= phpgw::get_var('lookup_tenant', 'bool');
 			$district_id			= phpgw::get_var('district_id', 'int');
 			$part_of_town_id		= phpgw::get_var('part_of_town_id', 'int');
 			$status					= phpgw::get_var('status');
 			$type_id				= phpgw::get_var('type_id', 'int');
 			$allrows				= phpgw::get_var('allrows', 'bool');
-			
+			$location_code			= phpgw::get_var('location_code');
+
 			$this->start			= $start ? $start : 0;
-			$this->query			= isset($query) && $query ? $query : '';
+			$this->query			= isset($query) ? $query : $this->query;
 			$this->filter			= isset($filter) && $filter ? $filter : '';
 			$this->sort				= isset($sort) && $sort ? $sort : '';
 			$this->order			= isset($order) && $order ? $order : '';
@@ -113,14 +120,53 @@
 			$this->type_id			= isset($type_id) && $type_id ? $type_id : 1;
 			$this->allrows			= isset($allrows) && $allrows ? $allrows : '';
 			$this->acl_location		= '.location.' . $this->type_id;
+			$this->location_code	= isset($location_code) && $location_code ? $location_code : '';
+			
+			if(isset($_REQUEST['query']) && !$query && !isset($_REQUEST['block_query']))
+			{
+				$this->location_code = '';
+			}
 		}
 
 		function read_sessiondata()
 		{
-			$data = $GLOBALS['phpgw']->session->appsession('session_data','location');
+			$referer = parse_url(phpgw::get_var('HTTP_REFERER', 'string', 'SERVER') );
+			//cramirez@ccfirst.com validation evita NOTICE  for JSON
+			$referer_out = array();
+			if(isset($referer['query']) && is_array($referer['query'])) {
+				parse_str($referer['query'],$referer_out);
+			}
+			$self_out = array();
+			$self = parse_url(phpgw::get_var('QUERY_STRING', 'string', 'SERVER') );
+			parse_str($self['path'],$self_out);
+
+			if(isset($referer_out['menuaction']) && isset($self_out['menuaction']) && $referer_out['menuaction'] == $self_out['menuaction'])
+			{
+				$data = $GLOBALS['phpgw']->session->appsession('session_data','location');
+			}
+
+			$query			= isset($data['query']) ? $data['query'] : '';
+			$type_id		= phpgw::get_var('type_id', 'int', 'REQUEST', 1);
+
+			$query_temp = explode('-',$query);
+
+			for ($i=0;$i<$type_id;$i++)
+			{
+				if(isset($query_temp[$i]) && $query_temp[$i])
+				{
+					$query_location[] = $query_temp[$i];
+				}
+			}
+			if(isset($query_location) && is_array($query_location))
+			{
+				$this->query = implode('-',$query_location);
+			}
+			else
+			{
+				$this->query = '';
+			}
 
 			$this->start			= isset($data['start'])?$data['start']:'';
-			$this->query			= isset($data['query'])?$data['query']:'';
 			$this->filter			= isset($data['filter'])?$data['filter']:'';
 			$this->sort				= isset($data['sort'])?$data['sort']:'';
 			$this->order			= isset($data['order'])?$data['order']:'';;
@@ -128,7 +174,7 @@
 			$this->part_of_town_id	= isset($data['part_of_town_id'])?$data['part_of_town_id']:'';
 			$this->district_id		= isset($data['district_id'])?$data['district_id']:'';
 			$this->status			= isset($data['status'])?$data['status']:'';
-			$this->type_id			= isset($data['type_id'])?$data['type_id']:'';			
+			$this->type_id			= isset($data['type_id'])?$data['type_id']:'';
 		//	$this->allrows			= $data['allrows'];
 		}
 
@@ -140,13 +186,14 @@
 			}
 		}
 
-		function column_list($selected='',$type_id='',$allrows='')
+		function column_list($selected = array(),$type_id='',$allrows='')
 		{
 			if(!$selected)
 			{
 				$selected = isset($GLOBALS['phpgw_info']['user']['preferences']['property']['location_columns_' . $this->type_id . !!$this->lookup]) ? $GLOBALS['phpgw_info']['user']['preferences']['property']["location_columns_" . $this->type_id . !!$this->lookup]:'';
 			}
-			$columns = $this->custom->get_attribs('property','.location.' . $type_id, 0, '','','',true);
+			$filter = array('list' => ''); // translates to "list IS NULL"
+			$columns = $this->custom->find('property','.location.' . $type_id, 0, '','','',true, false, $filter);
 			$column_list=$this->bocommon->select_multi_list($selected,$columns);
 			return $column_list;
 		}
@@ -211,6 +258,13 @@
 
 		function initiate_ui_location($data)
 		{
+			$config		= CreateObject('phpgwapi.config','property');
+			$config->read();
+			if (isset($config->config_data['suppress_tenant']) &&  $config->config_data['suppress_tenant'])
+			{
+				$data['tenant'] = false;
+			}
+			unset($config);
 
 			if(isset($data['lookup_type']))
 			{
@@ -225,7 +279,9 @@
 				}
 			}
 
-			$location_link		= "menuaction:'". 'property'.".uilocation.index',lookup:1";
+			$filter_location	= isset($data['filter_location']) ? $data['filter_location'] : '';
+			$block_query 		= !!$filter_location;
+			$location_link		= "menuaction:'property.uilocation.index',lookup:1";
 
 			$config = $this->soadmin_location->read_config('');
 
@@ -238,12 +294,19 @@
 			{
 				$data['type_id'] = count($location_types);
 			}
-//_debug_array($data);
+//_debug_array($data);die();
 //_debug_array($location_types);
-//			$filtermethod = " OR (type_id < $lookup_type AND lookup_form=1)";
-			$filtermethod = " OR (lookup_form=1)";
-			$fm_location_cols = $this->custom->get_attribs('property', '.location.' . $data['type_id'], 0, '', '', '', true,$filtermethod);
-
+			$fm_location_cols = array();
+			for ($i=1;$i<($data['type_id']+1);$i++)
+			{
+				$fm_location_cols_temp = $this->custom->find('property', '.location.' . $i, 0, '', '', '', true);
+				foreach ($fm_location_cols_temp as & $entry)
+				{
+					$entry['location_type']=$i;
+				}
+				$fm_location_cols = array_merge($fm_location_cols, $fm_location_cols_temp);
+			}
+			unset($fm_location_cols_temp);
 
 //_debug_array($fm_location_cols);
 
@@ -256,7 +319,7 @@
 				$location['location'][$i]['size']					= 5;
 				$location['location'][$i]['name']					= $location_types[($i)]['name'];
 				$location['location'][$i]['value']					= (isset($data['values']['loc' . ($i+1)])?$data['values']['loc' . ($i+1)]:'');
-				$location['location'][$i]['statustext']				= lang('Klick this link to select') . ' ' . $location_types[($i)]['name'];
+				$location['location'][$i]['statustext']				= lang('click this link to select') . ' ' . $location_types[($i)]['name'];
 
 				if($i==0)
 				{
@@ -278,18 +341,26 @@
 				}
 
 				$location['location'][$i]['lookup_function_call']			= 'lookup_loc' . ($i+1) . '()';
-				$location['location'][$i]['lookup_link']				= True;
-				$location['location'][$i]['readonly']					= True;
-				$lookup_functions[$i]['name'] 						= 'lookup_loc' . ($i+1) . '()';
-				$lookup_functions[$i]['link']						=  $location_link .',type_id:' . ($i+1) . ',lookup_name:' . $i;
-				$lookup_functions[$i]['action'] 					= 'Window1=window.open(strURL,"Search","width=800,height=700,toolbar=no,scrollbars=yes,resizable=yes");';
+				$location['location'][$i]['readonly']					= true;
+				
+				if(!isset($data['block_parent']) || $data['block_parent'] < ($i+1))
+				{
+					$location['location'][$i]['lookup_link']				= true;
+					$lookup_functions[] = array
+					(
+						'name' 						=> 'lookup_loc' . ($i+1) . '()',
+						'filter_level'				=> $i,
+						'link'						=>  $location_link .',type_id:' . ($i+1) . ',lookup_name:' . $i,
+						'action' 					=> 'Window1=window.open(strURL,"Search","width=1000,height=700,toolbar=no,scrollbars=yes,resizable=yes");'
+					);
+				}
 
 				if(isset($data['no_link']) && $data['no_link']>=($i+3))
 				{
-					$location['location'][$i]['lookup_link']			= False;
+					$location['location'][$i]['lookup_link']			= false;
 					$lookup_functions[$i]['link'] 					= $location_link .',type_id:' . ($data['no_link']-1) . ',lookup_name:' . ($data['no_link']-2);
-					$lookup_functions[$i]['action'] 				= 'Window1=window.open(strURL,"Search","width=800,height=700,toolbar=no,scrollbars=yes,resizable=yes");';
-					$location['location'][$i]['statustext']				= lang('Klick this link to select') . ' ' . $location_types[($data['no_link']-2)]['name'];
+					$lookup_functions[$i]['action'] 				= 'Window1=window.open(strURL,"Search","width=1000,height=700,toolbar=no,scrollbars=yes,resizable=yes");';
+					$location['location'][$i]['statustext']				= lang('click this link to select') . ' ' . $location_types[($data['no_link']-2)]['name'];
 				}
 
 				if(isset($data['query_link']) && $i < ($data['type_id']-1))
@@ -313,18 +384,18 @@
 			$location_cols_count =count($fm_location_cols);
 			for ($j=0;$j<$location_cols_count;$j++)
 			{
-				if(($fm_location_cols[$j]['location_type'] <= $data['type_id']) && $fm_location_cols[$j]['lookup_form'])
+				if((isset($fm_location_cols[$j]['location_type']) && $fm_location_cols[$j]['location_type'] <= $data['type_id']) && $fm_location_cols[$j]['lookup_form'])
 				{
 					$location['location'][$i]['input_type']				= 'text';
 					$location['location'][$i]['input_name']				= $fm_location_cols[$j]['column_name'];
-					$input_name[]							= $location['location'][$i]['input_name'];
-					$location['location'][$i]['size']				= 5;
-					$location['location'][$i]['lookup_function_call']		= 'lookup_loc' . $fm_location_cols[$j]['location_type'] . '()';
-					$location['location'][$i]['lookup_link']			= True;
-					$location['location'][$i]['readonly']				= True;
-					$location['location'][$i]['name']				= $fm_location_cols[$j]['input_text'];
-					$location['location'][$i]['value']				= isset($data['values'][$fm_location_cols[$j]['column_name']]) ? $data['values'][$fm_location_cols[$j]['column_name']] : '';
-					$location['location'][$i]['statustext']				= lang('Klick this link to select') . ' ' . $location_types[($fm_location_cols[$j]['location_type']-1)]['name'];
+					$input_name[]										= $location['location'][$i]['input_name'];
+					$location['location'][$i]['size']					= 5;
+					$location['location'][$i]['lookup_function_call']	= 'lookup_loc' . $fm_location_cols[$j]['location_type'] . '()';
+					$location['location'][$i]['lookup_link']			= true;
+					$location['location'][$i]['readonly']				= true;
+					$location['location'][$i]['name']					= $fm_location_cols[$j]['input_text'];
+					$location['location'][$i]['value']					= isset($data['values'][$fm_location_cols[$j]['column_name']]) ? $data['values'][$fm_location_cols[$j]['column_name']] : '';
+					$location['location'][$i]['statustext']				= lang('click this link to select') . ' ' . $location_types[($fm_location_cols[$j]['location_type']-1)]['name'];
 					$i++;
 
 				}
@@ -339,7 +410,7 @@
 					{
 						$location['location'][$i]['input_name']				= $config[$j]['column_name'];
 						$input_name[]										= 'street_id';
-						$location['location'][$i]['lookup_link']			= True;
+						$location['location'][$i]['lookup_link']			= true;
 						$location['location'][$i]['lookup_function_call']	= 'lookup_loc' . $config[$j]['location_type'] . '()';
 						$location['location'][$i]['name']					= lang('address');
 						$location['location'][$i]['input_type']				= 'hidden';
@@ -347,7 +418,7 @@
 
 						$location['location'][$i]['extra'][0]['input_type']	= 'text';
 						$location['location'][$i]['extra'][0]['input_name']	= 'street_name';
-						$location['location'][$i]['extra'][0]['readonly']	= True;
+						$location['location'][$i]['extra'][0]['readonly']	= true;
 						$input_name[]										= $location['location'][$i]['extra'][0]['input_name'];
 						$location['location'][$i]['extra'][0]['size']		= 30;
 						$location['location'][$i]['extra'][0]['lookup_function_call']	= 'lookup_loc' . $config[$j]['location_type'] . '()';
@@ -355,7 +426,7 @@
 
 						$location['location'][$i]['extra'][1]['input_type']	= 'text';
 						$location['location'][$i]['extra'][1]['input_name']	= 'street_number';
-						$location['location'][$i]['extra'][1]['readonly']	= True;
+						$location['location'][$i]['extra'][1]['readonly']	= true;
 						$input_name[]										= $location['location'][$i]['extra'][1]['input_name'];
 						$location['location'][$i]['extra'][1]['size']		= 6;
 						$location['location'][$i]['extra'][1]['lookup_function_call']	= 'lookup_loc' . $config[$j]['location_type'] . '()';
@@ -365,35 +436,39 @@
 					elseif($config[$j]['column_name']=='tenant_id' && $data['tenant']):
 					{
 						$m++;
-						$lookup_functions[$m]['name'] 						= 'lookup_loc' . ($m+1) . '()';
-						$lookup_functions[$m]['link']						= $location_link .',lookup_tenant:1,type_id:' . $config[$j]['location_type'] . ',lookup_name:' . $i;
-						$lookup_functions[$m]['action'] 					= 'Window1=window.open(strURL,"Search","width=800,height=700,toolbar=no,scrollbars=yes,resizable=yes");';
+						$lookup_functions[] = array
+						(
+							'name' 						=> 'lookup_loc' . ($m+1) . '()',
+							'filter_level'				=> $m,
+							'link'						=> $location_link .',lookup_tenant:1,type_id:' . $config[$j]['location_type'] . ',lookup_name:' . $i,
+							'action' 					=> 'Window1=window.open(strURL,"Search","width=1600,height=700,toolbar=no,scrollbars=yes,resizable=yes");'
+						);
 
-						$location['location'][$i]['lookup_link']			= True;
+						$location['location'][$i]['lookup_link']			= true;
 						$location['location'][$i]['name']					= lang('Tenant');
 						$location['location'][$i]['input_type']				= 'hidden';
 						$location['location'][$i]['input_name']				= 'tenant_id';
 						$input_name[]										= $location['location'][$i]['input_name'];
 						$location['location'][$i]['value']					= (isset($data['values'][$config[$j]['column_name']])?$data['values'][$config[$j]['column_name']]:'');
-						$location['location'][$i]['lookup_function_call']	= $lookup_functions[$m]['name'];
+						$location['location'][$i]['lookup_function_call']	= 'lookup_loc' . ($m+1) . '()';
 						$location['location'][$i]['statustext']				= lang('tenant');
 						$insert_record['extra']['tenant_id']				= 'tenant_id';
 
 						$location['location'][$i]['extra'][0]['input_type']	= 'text';
 						$location['location'][$i]['extra'][0]['input_name']	= 'last_name';
-						$location['location'][$i]['extra'][0]['readonly']	= True;
+						$location['location'][$i]['extra'][0]['readonly']	= true;
 						$input_name[]										= $location['location'][$i]['extra'][0]['input_name'];
 						$location['location'][$i]['extra'][0]['size']		= 15;
-						$location['location'][$i]['extra'][0]['lookup_function_call']	= $lookup_functions[$m]['name'];
+						$location['location'][$i]['extra'][0]['lookup_function_call']	= 'lookup_loc' . ($m+1) . '()';
 						$location['location'][$i]['extra'][0]['value']		= (isset($data['values']['last_name'])?$data['values']['last_name']:'');
 						$location['location'][$i]['extra'][0]['statustext']	= lang('last name');
 
 						$location['location'][$i]['extra'][1]['input_type']	= 'text';
 						$location['location'][$i]['extra'][1]['input_name']	= 'first_name';
-						$location['location'][$i]['extra'][1]['readonly']	= True;
+						$location['location'][$i]['extra'][1]['readonly']	= true;
 						$input_name[]										= $location['location'][$i]['extra'][1]['input_name'];
 						$location['location'][$i]['extra'][1]['size']		= 15;
-						$location['location'][$i]['extra'][1]['lookup_function_call']	= $lookup_functions[$m]['name'];
+						$location['location'][$i]['extra'][1]['lookup_function_call']	= 'lookup_loc' . ($m+1) . '()';
 						$location['location'][$i]['extra'][1]['value']		= (isset($data['values']['first_name'])?$data['values']['first_name']:'');
 						$location['location'][$i]['extra'][1]['statustext']	= lang('first name');
 						$i++;
@@ -416,10 +491,10 @@
 						$location['location'][$i]['size']					= 5;
 						$location['location'][$i]['value']					= $data['location']['value'][$config[$j]['column_name']];
 						$location['location'][$i]['lookup_function_call']	= 'lookup_loc' . $fm_location_cols[$j]['location_type'] . '()';
-						$location['location'][$i]['lookup_link']			= True;
+						$location['location'][$i]['lookup_link']			= true;
 						$location['location'][$i]['name']					= $config[$j]['descr'];
 						$location['location'][$i]['value']					= $data['values'][$config[$j]['column_name']];
-						$location['location'][$i]['statustext']				= lang('Klick this link to select') . ' ' .$location_types[($fm_location_cols[$j]['location_type']-1)]['name'];
+						$location['location'][$i]['statustext']				= lang('click this link to select') . ' ' .$location_types[($fm_location_cols[$j]['location_type']-1)]['name'];
 						$location['location'][$i]['input_type']				= 'text';
 						$i++;
 					}
@@ -433,9 +508,12 @@
 				{
 					$m++;
 
-					$lookup_functions[$m]['name'] = 'lookup_entity_' . $entity['id'] .'()';
-					$lookup_functions[$m]['link'] = "menuaction:'". 'property'.".uilookup.entity',location_type:".$data['type_id'] . ',entity_id:'. $entity['id'];
-					$lookup_functions[$m]['action'] = 'Window1=window.open(strURL,"Search","width=800,height=700,toolbar=no,scrollbars=yes,resizable=yes");';
+					$lookup_functions[] = array
+					(
+						'name'		=> 'lookup_entity_' . $entity['id'] .'()',
+						'link'		=> "menuaction:'property.uilookup.entity',location_type:{$data['type_id']},entity_id:{$entity['id']},location_code:'{$filter_location}',block_query:'{$block_query}'",
+						'action'	=> 'Window1=window.open(strURL,"Search","width=1200,height=700,toolbar=no,scrollbars=yes,resizable=yes");'
+					);
 
 					$location['location'][$i]['input_type']						= 'text';
 					$location['location'][$i]['input_name']						= 'entity_num_' . $entity['id'];
@@ -444,21 +522,21 @@
 
 					$location['location'][$i]['size']							= 8;
 					$location['location'][$i]['lookup_function_call']			= 'lookup_entity_' . $entity['id'] .'()';
-					$location['location'][$i]['lookup_link']					= True;
+					$location['location'][$i]['lookup_link']					= true;
 					$location['location'][$i]['name']							= $entity['name'];
-					
+
 					if (is_array($data['entity_data']))
 					{
 						$location['location'][$i]['value']						= $data['entity_data'][$entity['id']]['p_num'];
 					}
-					$location['location'][$i]['statustext']						= lang('Klick this link to select') .' ' . $entity['name'];
+					$location['location'][$i]['statustext']						= lang('click this link to select') .' ' . $entity['name'];
 
 					$location['location'][$i]['extra'][0]['input_name']			= 'entity_cat_name_' . $entity['id'];
 					$input_name[]												= $location['location'][$i]['extra'][0]['input_name'];
 					$location['location'][$i]['extra'][0]['input_type']			= 'text';
 					$location['location'][$i]['extra'][0]['size']				= 30;
 					$location['location'][$i]['extra'][0]['lookup_function_call']	= 'lookup_entity_' . $entity['id'] .'()';
-					
+
 					if (is_array($data['entity_data']))
 					{
 						$location['location'][$i]['extra'][0]['value']			= $data['entity_data'][$entity['id']]['p_cat_name'];
@@ -477,7 +555,7 @@
 					$location['location'][$i]['extra'][2]['input_name']			= 'cat_id_' . $entity['id'];
 					$input_name[]												= 'cat_id_' . $entity['id'];
 					$insert_record['extra']['cat_id_' . $entity['id']]			= 'p_cat_id';
-				
+
 					if (is_array($data['entity_data']))
 					{
 						$location['location'][$i]['extra'][2]['value']			= $data['entity_data'][$entity['id']]['p_cat_id'];
@@ -502,10 +580,51 @@
 			if(isset($lookup_functions) && is_array($lookup_functions))
 			{
 				$location['lookup_functions'] = '';
+				$filter_level = 0;
 				for ($j=0;$j<count($lookup_functions);$j++)
 				{
+					if(isset( $lookup_functions[$j]['filter_level']) && $lookup_functions[$j]['filter_level'] > 0)
+					{
+						$lookup_functions[$j]['link'] .= ",block_query:block,location_code:filter";
+						$_filter = array();
+						for ($i=1;$i<=$lookup_functions[$j]['filter_level'];$i++)
+						{
+							$_filter[] = "document.form.loc{$i}.value";
+						}
+						$filter_level = $lookup_functions[$j]['filter_level'];
+					}
+					else
+					{
+						$lookup_functions[$j]['link'] .= ",location_code:'{$filter_location}',block_query:'{$block_query}'";
+					}
+					
 					$location['lookup_functions'] .= "\t".'function ' . $lookup_functions[$j]['name'] ."\n";
 					$location['lookup_functions'] .= "\t".'{'."\n";
+					if($filter_level)
+					{
+						$location['lookup_functions'] .= "
+						var block = '';
+						var filter = '';
+						var filter_level = {$filter_level};
+						if (filter_level) 
+						{
+							for(i=1;i<=filter_level;i++)
+							{
+								if(eval('document.form.loc'+i+'.value'))
+								{
+									block = true;
+									if(!filter)
+									{
+										filter = eval('document.form.loc'+i+'.value');
+									}
+									else
+									{
+										filter = filter  + '-' + eval('document.form.loc'+i+'.value');									
+									}
+								}
+							}
+						}";
+					}
 					$location['lookup_functions'] .= "\t\tvar oArgs = {" . $lookup_functions[$j]['link'] ."};" . "\n";
 					$location['lookup_functions'] .= "\t\tvar strURL = phpGWLink('index.php', oArgs);\n";
 					$location['lookup_functions'] .= "\t\t".$lookup_functions[$j]['action'] ."\n";
@@ -532,15 +651,27 @@
 											'filter' => $this->filter,'cat_id' => $this->cat_id,'type_id' => $data['type_id'],
 											'lookup_tenant'=>$data['lookup_tenant'],'lookup'=>$data['lookup'],
 											'district_id'=>$this->district_id,'allrows'=>$data['allrows'],
-											'status'=>$this->status,'part_of_town_id'=>$this->part_of_town_id));
+											'status'=>$this->status,'part_of_town_id'=>$this->part_of_town_id,'dry_run'=>$data['dry_run'],
+											'location_code' => $this->location_code));
+
 			$this->total_records = $this->so->total_records;
 			$this->uicols = $this->so->uicols;
 
 			return $location;
 		}
 
-		function read_single($location_code='',$extra=array())
+		function read_single($data='',$extra=array())
 		{
+			if(is_array($data))
+			{
+				$location_code	= $data['location_code'];
+				$extra 			= $data['extra'];
+			}
+			else
+			{
+				$location_code = $data;
+			}
+
 			$location_array = split('-',$location_code);
 			$type_id= count($location_array);
 
@@ -549,9 +680,17 @@
 				return;
 			}
 
-			$values['attributes'] = $this->custom->get_attribs('property','.location.' . $type_id, 0, '', 'ASC', 'attrib_sort', true, true);
-			$values = $this->so->read_single($location_code, $values);
-			$values = $this->custom->prepare_attributes($values, 'property','.location.' . $type_id, $extra['view']);
+			if(!isset($extra['noattrib']) || !$extra['noattrib'])
+			{
+				$values['attributes'] = $this->custom->find('property','.location.' . $type_id, 0, '', 'ASC', 'attrib_sort', true, true);
+				$values = $this->so->read_single($location_code, $values);
+				$values = $this->custom->prepare($values, 'property',".location.{$type_id}", $extra['view']);
+			}
+			else
+			{
+				$values = $this->so->read_single($location_code);
+			}
+			
 
 			if( isset($extra['tenant_id']) && $extra['tenant_id']!='lookup')
 			{
@@ -614,6 +753,19 @@
 			return $this->so->check_location($location_code,$type_id);
 		}
 
+		/**
+		* Arrange attributes within groups
+		*
+		* @param string  $location    the name of the location of the attribute
+		* @param array   $attributes  the array of the attributes to be grouped
+		*
+		* @return array the grouped attributes
+		*/
+
+		public function get_attribute_groups($location, $attributes = array())
+		{
+			return $this->custom->get_attribute_groups('property', $location, $attributes);
+		}
 
 		function save($location,$values_attribute,$action='',$type_id='',$location_code_parent='')
 		{
@@ -641,31 +793,54 @@
 				}
 			}
 
-			$acl_location = '.location.' . $type_id;
-			$custom_functions = $this->custom->read_custom_function(array('appname'=>'property','location' => $acl_location,'allrows'=>True));
+			$criteria = array
+			(
+				'appname'	=> 'property',
+				'location'	=> ".location.{$type_id}",
+				'allrows'	=> true
+			);
 
-			if (isSet($custom_functions) AND is_array($custom_functions))
+			$custom_functions = $GLOBALS['phpgw']->custom_functions->find($criteria);
+
+			foreach ( $custom_functions as $entry )
 			{
-				foreach($custom_functions as $entry)
+				// prevent path traversal
+				if ( preg_match('/\.\./', $entry['file_name']) )
 				{
-					if (is_file(PHPGW_APP_INC . SEP . 'custom' . SEP . $entry['file_name']) && $entry['active'])
-					include (PHPGW_APP_INC . SEP . 'custom' . SEP . $entry['file_name']);
+					continue;
+				}
+
+				$file = PHPGW_SERVER_ROOT . "/property/inc/custom/{$GLOBALS['phpgw_info']['user']['domain']}/{$entry['file_name']}";
+				if ( $entry['active'] && is_file($file) )
+				{
+					require_once $file;
 				}
 			}
 
-
 			return $receipt;
 		}
 
-		function delete($location_code)
+		/*function delete2($location_code)
 		{
 			$this->so->delete($location_code);
+		}*/
+
+		function delete()
+		{
+			$location_code = phpgw::get_var('location_code','string','GET');
+			$this->so->delete($location_code);
 		}
 
 		function update_cat()
 		{
 			return $this->so->update_cat();
 		}
+
+		function update_location()
+		{
+			return $this->so->update_location();
+		}
+
 		function read_summary($data=array())
 		{
 			$summary = $this->so->read_summary(array('filter' => $this->filter,'type_id' => isset($data['type_id'])?$data['type_id']:'',
@@ -701,5 +876,32 @@
 		{
 			return $this->so->get_tenant_location($tenant_id);
 		}
+
+		/**
+		 * Get a list of attributes
+		 *
+		 * @param string $location     the name of the location
+		 *
+		 * @return array holding custom fields at this location
+		 */
+
+		function find_attribute($location)
+		{
+			return $this->custom->find('property', $location, 0, '', 'ASC', 'attrib_sort', true, true);
+		}
+
+		/**
+		 * Prepare custom attributes for ui
+		 *
+		 * @param array  $values    values and definitions of custom attributes
+		 * @param string $location  the name of the location
+		 * @param bool   $view_only if set - calendar listeners is not activated
+		 *
+		 * @return array values and definitions of custom attributes prepared for ui
+		 */
+
+		function prepare_attribute($values, $location, $view_only= false)
+		{
+			return $this->custom->prepare($values, 'property', $location, $view_only);
+		}
 	}
-?>
