@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage agreement
- 	* @version $Id: class.bor_agreement.inc.php 18358 2007-11-27 04:43:37Z skwashd $
+ 	* @version $Id: class.bor_agreement.inc.php 2176 2009-01-24 17:28:12Z sigurd $
 	*/
 
 	/**
@@ -43,29 +43,31 @@
 		var $role;
 		var $member_id;
 
+		/**
+		* @var object $custom reference to custom fields object
+		*/
+		protected $custom;
+
 		var $public_functions = array
 		(
-			'read'				=> True,
-			'read_single'		=> True,
-			'save'				=> True,
-			'delete'			=> True,
-			'check_perms'		=> True
+			'read'				=> true,
+			'read_single'		=> true,
+			'save'				=> true,
+			'delete'			=> true,
+			'check_perms'		=> true
 		);
 
-		function property_bor_agreement($session=False)
+		function property_bor_agreement($session=false)
 		{
 		//	$this->currentapp		= $GLOBALS['phpgw_info']['flags']['currentapp'];
 			$this->so = CreateObject('property.sor_agreement');
 			$this->bocommon = CreateObject('property.bocommon');
-			$this->custom 		= createObject('phpgwapi.custom_fields');
-			$this->vfs 			= CreateObject('phpgwapi.vfs');
-			$this->rootdir 		= $this->vfs->basedir;
-			$this->fakebase 	= $this->vfs->fakebase;
+			$this->custom 		= createObject('property.custom_fields');
 
 			if ($session)
 			{
 				$this->read_sessiondata();
-				$this->use_session = True;
+				$this->use_session = true;
 			}
 
 			$reset_query 		= phpgw::get_var('reset_query', 'bool');
@@ -92,7 +94,7 @@
 				$cat_id	= phpgw::get_var('cat_id', 'int');
 				$customer_id	= phpgw::get_var('tenant_id', 'int');
 				$member_id	= phpgw::get_var('member_id', 'int');
-				$loc1	= phpgw::get_var('loc1');	
+				$loc1	= phpgw::get_var('loc1');
 			}
 
 
@@ -178,7 +180,7 @@
 
 		function check_perms($has, $needed)
 		{
-			return (!!($has & $needed) == True);
+			return (!!($has & $needed) == true);
 		}
 
 
@@ -227,7 +229,7 @@
 		{
 			$list = $this->so->read(array('start' => $this->start,'query' => $this->query,'sort' => $this->sort,'order' => $this->order,
 											'filter' => $this->filter,'cat_id' => $this->cat_id,'allrows'=>$this->allrows,'member_id'=>$this->member_id,
-											'r_agreement_id'=>$id,'detail'=>True));
+											'r_agreement_id'=>$id,'detail'=>true));
 			$this->total_records = $this->so->total_records;
 
 			$this->uicols	= $this->so->uicols;
@@ -264,7 +266,7 @@
 		function read_event($data)
 		{
 			$boalarm		= CreateObject('property.boalarm');
-			$event	= $this->so->read_single($data);
+			$event	= $this->so->read_single($data['r_agreement_id']);
 			$event['alarm_date']=$event['termination_date'];
 			$event['alarm']	= $boalarm->read_alarms($type='r_agreement',$data['r_agreement_id']);
 			return $event;
@@ -273,14 +275,14 @@
 		function read_single($data)
 		{
 
-			$values['attributes'] = $this->custom->get_attribs('property', '.r_agreement', 0, '', 'ASC', 'attrib_sort', true, true);
-			
+			$values['attributes'] = $this->custom->find('property', '.r_agreement', 0, '', 'ASC', 'attrib_sort', true, true);
+
 			if(isset($data['r_agreement_id']) && $data['r_agreement_id'])
 			{
 				$values = $this->so->read_single($data['r_agreement_id'], $values);
 			}
 
-			$values = $this->custom->prepare_attributes($values, 'property', '.r_agreement', $data['view']);
+			$values = $this->custom->prepare($values, 'property', '.r_agreement', $data['view']);
 
 			$dateformat = $GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat'];
 			$values['start_date']		= $GLOBALS['phpgw']->common->show_date($values['start_date'],$dateformat);
@@ -290,13 +292,14 @@
 				$values['termination_date']= $GLOBALS['phpgw']->common->show_date($values['termination_date'],$dateformat);
 			}
 
-			$this->vfs->override_acl = 1;
+			$vfs = CreateObject('phpgwapi.vfs');
+			$vfs->override_acl = 1;
 
-			$values['files'] = $this->vfs->ls (array(
-			     'string' => $this->fakebase. '/' . 'rental_agreement' .  '/' . $data['r_agreement_id'],
+			$values['files'] = $vfs->ls (array(
+			     'string' => '/property/rental_agreement/' . $data['r_agreement_id'],
 			     'relatives' => array(RELATIVE_NONE)));
 
-			$this->vfs->override_acl = 0;
+			$vfs->override_acl = 0;
 
 			if(!$values['files'][0]['file_id'])
 			{
@@ -308,13 +311,13 @@
 
 		function read_single_item($data)
 		{
-			$values['attributes'] = $this->custom->get_attribs('property', '.r_agreement.detail', 0, '', 'ASC', 'attrib_sort', true, true);
-			
+			$values['attributes'] = $this->custom->find('property', '.r_agreement.detail', 0, '', 'ASC', 'attrib_sort', true, true);
+
 			if(isset($data['r_agreement_id']) && $data['r_agreement_id'] && isset($data['id']) && $data['id'])
 			{
 				$values = $this->so->read_single_item($data, $values);
 			}
-			$values = $this->custom->prepare_attributes($values, 'property', '.r_agreement.detail');
+			$values = $this->custom->prepare($values, 'property', '.r_agreement.detail');
 
 			if($values['location_code'])
 			{
@@ -335,6 +338,20 @@
 			return $values;
 		}
 
+		/**
+		* Arrange attributes within groups
+		*
+		* @param string  $location    the name of the location of the attribute
+		* @param array   $attributes  the array of the attributes to be grouped
+		*
+		* @return array the grouped attributes
+		*/
+
+		public function get_attribute_groups($location, $attributes = array())
+		{
+			return $this->custom->get_attribute_groups('property', $location, $attributes);
+		}
+
 		function save($values,$values_attribute='',$action='')
 		{
 
@@ -353,37 +370,6 @@
 				if ($values['r_agreement_id'] != 0)
 				{
 					$receipt=$this->so->edit($values,$values_attribute);
-
-					if($values['delete_file'])
-					{
-						for ($i=0;$i<count($values['delete_file']);$i++)
-						{
-							$file = $this->fakebase. SEP . 'rental_agreement' . SEP . $values['r_agreement_id'] . SEP . $values['delete_file'][$i];
-
-							if($this->vfs->file_exists(array(
-									'string' => $file,
-									'relatives' => Array(RELATIVE_NONE)
-								)))
-							{
-								$this->vfs->override_acl = 1;
-
-								if(!$this->vfs->rm (array(
-									'string' => $file,
-								     'relatives' => array(
-								          RELATIVE_NONE
-								     )
-								)))
-								{
-									$receipt['error'][]=array('msg'=>lang('failed to delete file') . ' :'. $this->fakebase. SEP . 'rental_agreement'. SEP . $values['r_agreement_id'] . SEP .$values['delete_file'][$i]);
-								}
-								else
-								{
-									$receipt['message'][]=array('msg'=>lang('file deleted') . ' :'. $this->fakebase. SEP . 'rental_agreement'. SEP . $values['id'] . SEP . $values['delete_file'][$i]);
-								}
-								$this->vfs->override_acl = 0;
-							}
-						}
-					}
 				}
 			}
 			else
@@ -400,7 +386,7 @@
 			{
 				$values['start_date']	= $this->bocommon->date_to_timestamp($values['start_date']);
 			}
-			
+
 			if($values['start_date'])
 			{
 				$values['end_date']	= $this->bocommon->date_to_timestamp($values['end_date']);
@@ -442,7 +428,7 @@
 			{
 				$values['start_date']	= $this->bocommon->date_to_timestamp($values['start_date']);
 			}
-			
+
 			if($values['start_date'])
 			{
 				$values['end_date']	= $this->bocommon->date_to_timestamp($values['end_date']);
@@ -491,7 +477,8 @@
 			{
 				$selected=$GLOBALS['phpgw_info']['user']['preferences']['property']['r_agreement_columns'];
 			}
-			$columns = $this->custom->get_attribs('property','.r_agreement', 0, '','','',true);
+			$filter = array('list' => ''); // translates to "list IS NULL"
+			$columns = $this->custom->find('property','.r_agreement', 0, '','','',true, false, $filter);
 			$column_list=$this->bocommon->select_multi_list($selected,$columns);
 			return $column_list;
 		}
@@ -501,63 +488,6 @@
 				return $this->so->request_next_id();
 		}
 
-		function create_home_dir($receipt='')
-		{
-			if(!$this->vfs->file_exists(array(
-					'string' => $this->fakebase. SEP . 'rental_agreement',
-					'relatives' => Array(RELATIVE_NONE)
-				)))
-			{
-				$this->vfs->override_acl = 1;
-
-				if(!$this->vfs->mkdir (array(
-				     'string' => $this->fakebase. SEP . 'rental_agreement',
-				     'relatives' => array(
-				          RELATIVE_NONE
-				     )
-				)))
-				{
-					$receipt['error'][]=array('msg'=>lang('failed to create directory') . ' :'. $this->fakebase. SEP . 'rental_agreement');
-				}
-				else
-				{
-					$receipt['message'][]=array('msg'=>lang('directory created') . ' :'. $this->fakebase. SEP . 'rental_agreement');
-				}
-				$this->vfs->override_acl = 0;
-			}
-
-			return $receipt;
-		}
-
-		function create_document_dir($id='')
-		{
-
-			if(!$this->vfs->file_exists(array(
-					'string' => $this->fakebase. SEP . 'rental_agreement' .  SEP . $id,
-					'relatives' => Array(RELATIVE_NONE)
-				)))
-			{
-				$this->vfs->override_acl = 1;
-				if(!$this->vfs->mkdir (array(
-				     'string' => $this->fakebase. SEP . 'rental_agreement' .  SEP . $id,
-				     'relatives' => array(
-				          RELATIVE_NONE
-				     )
-				)))
-				{
-					$receipt['error'][]=array('msg'=>lang('failed to create directory') . ' :'. $this->fakebase. SEP  . 'rental_agreement' .  SEP . $id);
-				}
-				else
-				{
-					$receipt['message'][]=array('msg'=>lang('directory created') . ' :'. $this->fakebase. SEP . 'rental_agreement' .  SEP . $id);
-				}
-				$this->vfs->override_acl = 0;
-			}
-
-//_debug_array($receipt);
-			return $receipt;
-		}
-		
 		function get_rental_type_list($selected = '')
 		{
 			$input_list[0]['id'] = 1;
@@ -568,7 +498,7 @@
 			$input_list[2]['name'] = lang('Building common');
 			$input_list[3]['id'] = 4;
 			$input_list[3]['name'] = lang('Shared use');
-			
+
 			$rental_type_list= $this->bocommon->select_list($selected,$input_list);
 
 			return $rental_type_list;
@@ -628,7 +558,7 @@
 			{
 				$values['start_date']	= $this->bocommon->date_to_timestamp($values['start_date']);
 			}
-			
+
 			if($values['start_date'])
 			{
 				$values['end_date']	= $this->bocommon->date_to_timestamp($values['end_date']);
@@ -652,4 +582,4 @@
 			$this->so->delete_common_h($r_agreement_id,$c_id,$id);
 		}
 	}
-?>
+
