@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage agreement
- 	* @version $Id: class.bos_agreement.inc.php,v 1.16 2007/08/12 21:25:10 sigurdne Exp $
+ 	* @version $Id: class.bos_agreement.inc.php 5148 2010-04-08 13:42:11Z sigurd $
 	*/
 
 	/**
@@ -42,29 +42,34 @@
 		var $cat_id;
 		var $role;
 		var $member_id;
+		var $uicols = array();
+
+		/**
+		* @var object $custom reference to custom fields object
+		*/
+		public $custom;
 
 		var $public_functions = array
 		(
-			'read'				=> True,
-			'read_single'		=> True,
-			'save'				=> True,
-			'delete'			=> True,
-			'check_perms'		=> True
+			'read'				=> true,
+			'read_single'		=> true,
+			'save'				=> true,
+			'delete'			=> true,
+			'check_perms'		=> true
 		);
 
-		function property_bos_agreement($session=False)
+		function property_bos_agreement($session=false)
 		{
-			$this->so = CreateObject('property.sos_agreement');
-			$this->bocommon = CreateObject('property.bocommon');
-			$this->custom 		= createObject('phpgwapi.custom_fields');
-			$this->vfs 			= CreateObject('phpgwapi.vfs');
-			$this->rootdir 		= $this->vfs->basedir;
-			$this->fakebase 	= $this->vfs->fakebase;
+			$this->so			= CreateObject('property.sos_agreement');
+			$this->bocommon		= CreateObject('property.bocommon');
+			$this->custom 		= createObject('property.custom_fields');
+			$this->cats					= CreateObject('phpgwapi.categories', -1,  'property', '.vendor');
+			$this->cats->supress_info	= true;
 
 			if ($session)
 			{
 				$this->read_sessiondata();
-				$this->use_session = True;
+				$this->use_session = true;
 			}
 
 			$start	= phpgw::get_var('start', 'int', 'REQUEST', 0);
@@ -82,51 +87,15 @@
 			$this->role	= $role;
 			$this->so->role	= $role;
 
-			if ($start)
-			{
-				$this->start=$start;
-			}
-			else
-			{
-				$this->start=0;
-			}
-
-			if(isset($query))
-			{
-				$this->query = $query;
-			}
-			if(!empty($filter))
-			{
-				$this->filter = $filter;
-			}
-			if(isset($sort))
-			{
-				$this->sort = $sort;
-			}
-			if(isset($order))
-			{
-				$this->order = $order;
-			}
-			if(isset($cat_id) && !empty($cat_id))
-			{
-				$this->cat_id = $cat_id;
-			}
-			else
-			{
-				unset($this->cat_id);
-			}
-			if(isset($allrows))
-			{
-				$this->allrows = $allrows;
-			}
-			if(isset($member_id))
-			{
-				$this->member_id = $member_id;
-			}
-			if(isset($vendor_id))
-			{
-				$this->vendor_id = $vendor_id;
-			}
+			$this->start			= $start ? $start : 0;
+			$this->query			= isset($query) ? $query : $this->query;
+			$this->sort				= isset($sort) && $sort ? $sort : '';
+			$this->order			= isset($order) && $order ? $order : '';
+			$this->filter			= isset($filter) && $filter ? $filter : '';
+			$this->cat_id			= isset($cat_id) && $cat_id ? $cat_id : '';
+			$this->member_id		= isset($member_id) && $member_id ? $member_id : '';
+			$this->vendor_id		= isset($vendor_id) && $vendor_id ? $vendor_id : '';
+			$this->allrows			= isset($allrows) && $allrows ? $allrows : '';
 		}
 
 		function save_sessiondata($data)
@@ -143,20 +112,20 @@
 
 			//_debug_array($data);
 
-			$this->start	= $data['start'];
-			$this->query	= $data['query'];
-			$this->filter	= $data['filter'];
-			$this->sort		= $data['sort'];
-			$this->order	= $data['order'];
-			$this->cat_id	= $data['cat_id'];
-			$this->vendor_id= $data['vendor_id'];
-			$this->member_id= $data['member_id'];
-			$this->allrows	= $data['allrows'];
+			$this->start	= isset($data['start']) ? $data['start'] : '';
+			$this->query	= isset($data['query']) ? $data['query'] : '';
+			$this->filter	= isset($data['filter']) ? $data['filter'] : '';
+			$this->sort		= isset($data['sort']) ? $data['sort'] : '';
+			$this->order	= isset($data['order']) ? $data['order'] : '';
+			$this->cat_id	= isset($data['cat_id']) ? $data['cat_id'] : '';
+			$this->vendor_id= isset($data['vendor_id']) ? $data['vendor_id'] : '';
+			$this->member_id= isset($data['member_id']) ? $data['member_id'] : '';
+			$this->allrows	= isset($data['allrows']) ? $data['allrows'] : '';
 		}
 
 		function check_perms($has, $needed)
 		{
-			return (!!($has & $needed) == True);
+			return (!!($has & $needed) == true);
 		}
 
 		function select_vendor_list($format='',$selected='')
@@ -204,7 +173,7 @@
 		{
 			$list = $this->so->read(array('start' => $this->start,'query' => $this->query,'sort' => $this->sort,'order' => $this->order,
 											'filter' => $this->filter,'cat_id' => $this->cat_id,'allrows'=>$this->allrows,'member_id'=>$this->member_id,
-											's_agreement_id'=>$id,'detail'=>True));
+											's_agreement_id'=>$id,'detail'=>true));
 			$this->total_records = $this->so->total_records;
 
 			$this->uicols	= $this->so->uicols;
@@ -234,23 +203,23 @@
 
 		function read_event($data)
 		{
-			$boalarm		= CreateObject('property.boalarm');
-			$event	= $this->so->read_single($data);
-			$event['alarm_date']=$event['termination_date'];
-			$event['alarm']	= $boalarm->read_alarms($type='s_agreement',$data['s_agreement_id']);
+			$boalarm			= CreateObject('property.boalarm');
+			$event				= $this->so->read_single($data['s_agreement_id']);
+			$event['alarm_date']= $event['termination_date'];
+			$event['alarm']		= $boalarm->read_alarms($type='s_agreement',$data['s_agreement_id']);
 			return $event;
 		}
 
 		function read_single($data)
 		{
-			$values['attributes'] = $this->custom->get_attribs('property', '.s_agreement', 0, '', 'ASC', 'attrib_sort', true, true);
-			
+			$values['attributes'] = $this->custom->find('property', '.s_agreement', 0, '', 'ASC', 'attrib_sort', true, true);
+
 			if(isset($data['s_agreement_id']) && $data['s_agreement_id'])
 			{
 				$values = $this->so->read_single($data['s_agreement_id'], $values);
 			}
 
-			$values = $this->custom->prepare_attributes($values, 'property', '.s_agreement', $data['view']);
+			$values = $this->custom->prepare($values, 'property', '.s_agreement', $data['view']);
 
 			$dateformat = $GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat'];
 			$values['start_date']		= $GLOBALS['phpgw']->common->show_date($values['start_date'],$dateformat);
@@ -260,13 +229,14 @@
 				$values['termination_date']= $GLOBALS['phpgw']->common->show_date($values['termination_date'],$dateformat);
 			}
 
-			$this->vfs->override_acl = 1;
+			$vfs = CreateObject('phpgwapi.vfs');
+			$vfs->override_acl = 1;
 
-			$values['files'] = $this->vfs->ls (array(
-			     'string' => $this->fakebase. '/' . 'service_agreement' .  '/' . $data['s_agreement_id'],
+			$values['files'] = $vfs->ls (array(
+			     'string' => "/property/service_agreement/{$data['s_agreement_id']}",
 			     'relatives' => array(RELATIVE_NONE)));
 
-			$this->vfs->override_acl = 0;
+			$vfs->override_acl = 0;
 
 			if(!$values['files'][0]['file_id'])
 			{
@@ -278,13 +248,13 @@
 
 		function read_single_item($data)
 		{
-			$values['attributes'] = $this->custom->get_attribs('property', '.s_agreement.detail', 0, '', 'ASC', 'attrib_sort', true, true);
-			
+			$values['attributes'] = $this->custom->find('property', '.s_agreement.detail', 0, '', 'ASC', 'attrib_sort', true, true);
+
 			if(isset($data['s_agreement_id']) && $data['s_agreement_id'] && isset($data['id']) && $data['id'])
 			{
 				$values = $this->so->read_single_item($data, $values);
 			}
-			$values = $this->custom->prepare_attributes($values, 'property', '.s_agreement.detail');
+			$values = $this->custom->prepare($values, 'property', '.s_agreement.detail');
 
 //_debug_array($item);
 
@@ -308,6 +278,20 @@
 			return $values;
 		}
 
+		/**
+		* Arrange attributes within groups
+		*
+		* @param string  $location    the name of the location of the attribute
+		* @param array   $attributes  the array of the attributes to be grouped
+		*
+		* @return array the grouped attributes
+		*/
+
+		public function get_attribute_groups($location, $attributes = array())
+		{
+			return $this->custom->get_attribute_groups('property', $location, $attributes);
+		}
+
 		function save($values,$values_attribute='',$action='')
 		{
 
@@ -326,37 +310,6 @@
 				if ($values['s_agreement_id'] != 0)
 				{
 					$receipt=$this->so->edit($values,$values_attribute);
-
-					if($values['delete_file'])
-					{
-						for ($i=0;$i<count($values['delete_file']);$i++)
-						{
-							$file = $this->fakebase. SEP . 'service_agreement' . SEP . $values['s_agreement_id'] . SEP . $values['delete_file'][$i];
-
-							if($this->vfs->file_exists(array(
-									'string' => $file,
-									'relatives' => Array(RELATIVE_NONE)
-								)))
-							{
-								$this->vfs->override_acl = 1;
-
-								if(!$this->vfs->rm (array(
-									'string' => $file,
-								     'relatives' => array(
-								          RELATIVE_NONE
-								     )
-								)))
-								{
-									$receipt['error'][]=array('msg'=>lang('failed to delete file') . ' :'. $this->fakebase. SEP . 'service_agreement'. SEP . $values['s_agreement_id'] . SEP .$values['delete_file'][$i]);
-								}
-								else
-								{
-									$receipt['message'][]=array('msg'=>lang('file deleted') . ' :'. $this->fakebase. SEP . 'service_agreement'. SEP . $values['id'] . SEP . $values['delete_file'][$i]);
-								}
-								$this->vfs->override_acl = 0;
-							}
-						}
-					}
 				}
 			}
 			else
@@ -419,7 +372,7 @@
 			's_agreement_id' 	=> $id,
 			'location_code'		=> $import_data['location_code'],
 			'location_name'		=> $import_data['address'],
-			'cost'				=> $import_data['cost']			
+			'cost'				=> $import_data['cost']
 			);
 			unset($values['extra']['location_code']);
 			unset($values['extra']['address']);
@@ -456,7 +409,8 @@
 				$selected=$GLOBALS['phpgw_info']['user']['preferences']['property']['s_agreement_columns'];
 			}
 
-			$columns = $this->custom->get_attribs('property','.s_agreement', 0, '','','',true);
+			$filter = array('list' => ''); // translates to "list IS NULL"
+			$columns = $this->custom->find('property','.s_agreement', 0, '','','',true, false, $filter);
 
 			$column_list=$this->bocommon->select_multi_list($selected,$columns);
 
@@ -468,62 +422,6 @@
 				return $this->so->request_next_id();
 		}
 
-		function create_home_dir($receipt='')
-		{
-			if(!$this->vfs->file_exists(array(
-					'string' => $this->fakebase. SEP . 'service_agreement',
-					'relatives' => Array(RELATIVE_NONE)
-				)))
-			{
-				$this->vfs->override_acl = 1;
-
-				if(!$this->vfs->mkdir (array(
-				     'string' => $this->fakebase. SEP . 'service_agreement',
-				     'relatives' => array(
-				          RELATIVE_NONE
-				     )
-				)))
-				{
-					$receipt['error'][]=array('msg'=>lang('failed to create directory') . ' :'. $this->fakebase. SEP . 'service_agreement');
-				}
-				else
-				{
-					$receipt['message'][]=array('msg'=>lang('directory created') . ' :'. $this->fakebase. SEP . 'service_agreement');
-				}
-				$this->vfs->override_acl = 0;
-			}
-
-			return $receipt;
-		}
-
-		function create_document_dir($id='')
-		{
-			if(!$this->vfs->file_exists(array(
-					'string' => $this->fakebase. SEP . 'service_agreement' .  SEP . $id,
-					'relatives' => Array(RELATIVE_NONE)
-				)))
-			{
-				$this->vfs->override_acl = 1;
-				if(!$this->vfs->mkdir (array(
-				     'string' => $this->fakebase. SEP . 'service_agreement' .  SEP . $id,
-				     'relatives' => array(
-				          RELATIVE_NONE
-				     )
-				)))
-				{
-					$receipt['error'][]=array('msg'=>lang('failed to create directory') . ' :'. $this->fakebase. SEP  . 'service_agreement' .  SEP . $id);
-				}
-				else
-				{
-					$receipt['message'][]=array('msg'=>lang('directory created') . ' :'. $this->fakebase. SEP . 'service_agreement' .  SEP . $id);
-				}
-				$this->vfs->override_acl = 0;
-			}
-
-//_debug_array($receipt);
-			return $receipt;
-		}
-
 		function read_attrib_history($data)
 		{
 		//	_debug_array($data);
@@ -539,5 +437,62 @@
 			$historylog = CreateObject('property.historylog','s_agreement');
 			$historylog->delete_single_record($data['history_id']);
 		}
+
+		function get_year_list($agreement_id = '')
+		{
+			if($agreement_id)
+			{
+				$list = $this->so->get_year_filter_list($agreement_id);
+			}
+			else
+			{
+				$list = array();
+			}
+			$year = date('Y');
+			$limit = $year + 4;
+			
+			while ($year < $limit)
+			{
+				$list[] =  $year;
+				$year++;
+			}
+
+			$list = array_unique($list);
+			sort($list);
+			
+			$values;
+			foreach($list as $entry)
+			{
+				$values[] = array
+				(
+					'id'	=> $entry,
+					'name'	=> $entry
+				);
+			}
+			return $values;
+		}
+
+		function get_budget($agreement_id)
+		{
+			$values = $this->so->get_budget($agreement_id);
+
+			$this->cats->set_appname('property', '.project');
+
+			foreach($values as & $entry)
+			{
+				$category = $this->cats->return_single($entry['cat_id']);
+				$entry['category']		= $category[0]['name'];
+			}
+
+			$this->cats->set_appname('property', '.vendor');
+
+			return $values;		
+		}
+
+		function delete_year_from_budget($data,$agreement_id)
+		{
+			return $this->so->delete_year_from_budget($data,$agreement_id);
+		}
+
 	}
-?>
+
