@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage project
- 	* @version $Id: class.botemplate.inc.php 18358 2007-11-27 04:43:37Z skwashd $
+ 	* @version $Id: class.botemplate.inc.php 977 2008-05-11 08:38:25Z sigurd $
 	*/
 
 	/**
@@ -43,14 +43,14 @@
 
 		var $public_functions = array
 		(
-			'read'				=> True,
-			'read_single'		=> True,
-			'save'				=> True,
-			'delete'			=> True,
-			'check_perms'		=> True
+			'read'				=> true,
+			'read_single'		=> true,
+			'save'				=> true,
+			'delete'			=> true,
+			'check_perms'		=> true
 		);
 
-		function property_botemplate($session=False)
+		function property_botemplate($session=false)
 		{
 		//	$this->currentapp	= $GLOBALS['phpgw_info']['flags']['currentapp'];
 			$this->so 		= CreateObject('property.sotemplate');
@@ -59,7 +59,7 @@
 			if ($session)
 			{
 				$this->read_sessiondata();
-				$this->use_session = True;
+				$this->use_session = true;
 			}
 
 			$start	= phpgw::get_var('start', 'int', 'REQUEST', 0);
@@ -137,7 +137,7 @@
 		function read()
 		{
 			$template = $this->so->read(array('filter' => $this->filter,'start' => $this->start,'query' => $this->query,'sort' => $this->sort,'order' => $this->order,
-											'chapter_id' => $this->chapter_id,'allrows'=>$this->allrows, 'template_id'=>$template_id));
+											'chapter_id' => $this->chapter_id,'allrows'=>$this->allrows));
 			$this->total_records = $this->so->total_records;
 
 			$dateformat					= $GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat'];
@@ -159,12 +159,6 @@
 
 			$dateformat					= $GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat'];
 
-			for ($i=0; $i<count($template); $i++)
-			{
-				$template[$i]['owner'] = $GLOBALS['phpgw']->accounts->id2name($template[$i]['owner']);
-				$template[$i]['entry_date']		= $GLOBALS['phpgw']->common->show_date($template[$i]['entry_date'],$dateformat);
-			}
-
 			return $template;
 		}
 
@@ -245,4 +239,4 @@
 		}
 
 	}
-?>
+
