@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage core
- 	* @version $Id: class.custom_functions.inc.php 18358 2007-11-27 04:43:37Z skwashd $
+ 	* @version $Id: class.custom_functions.inc.php 3310 2009-08-04 09:27:21Z sigurd $
 	*/
 
 	/**
@@ -36,22 +36,14 @@
 
 	class property_custom_functions
 	{
-
 		var $public_functions = array(
-			'index' => True
+			'index' => true
 		);
 
-		function property_custom_functions ()
+		function __construct()
 		{
-			$GLOBALS['phpgw_info']['flags']['noheader'] = True;
-			$GLOBALS['phpgw_info']['flags']['nonavbar'] = True;
-
-
-			$GLOBALS['phpgw_info']['flags']['currentapp']	=	'property';
-
-		//	$this->currentapp		= $GLOBALS['phpgw_info']['flags']['currentapp'];
-			$this->config		= CreateObject('phpgwapi.config','property');
-
+			$GLOBALS['phpgw_info']['flags']['noheader'] = true;
+			$GLOBALS['phpgw_info']['flags']['nonavbar'] = true;
 		}
 
 		/**
@@ -62,6 +54,11 @@
 
 		function index($data='')
 		{
+			if ( !isset($GLOBALS['phpgw_info']['user']['apps']['admin']))
+			{
+				return;
+			}
+
 			if(is_array($data))
 			{
 				$function = $data['function'];
@@ -69,17 +66,34 @@
 			else
 			{
 				$data = unserialize(urldecode(phpgw::get_var('data')));
+
+				$data = phpgw::clean_value($data);
 				if(!isset($data['function']))
 				{
-					$data['function'] = phpgw::get_var('function');
+					$function = phpgw::get_var('function');
+				}
+				else
+				{
+					$function =$data['function'];
 				}
 			}
+			// prevent path traversal
+			if ( preg_match('/\.\./', $function) )
+			{
+				return;
+			}
 
-			include_once(PHPGW_SERVER_ROOT.'/'.'property'.'/inc/cron/' . $data['function'] . '.php');
-			$custom = new $data['function'];
-			$custom->pre_run($data);
+			$file = PHPGW_SERVER_ROOT . "/property/inc/cron/{$GLOBALS['phpgw_info']['user']['domain']}/{$function}.php";
+
+			if (is_file($file))
+			{
+				require_once $file;
+				$custom = new $function;
+				$custom->pre_run($data);
+			}
+			else
+			{
+				echo "no such file: path_to_phpgw_server_root/property/inc/cron/{$GLOBALS['phpgw_info']['user']['domain']}/{$function}.php";
+			}
 		}
-
-
 	}
-?>
