@@ -23,9 +23,9 @@
 	* @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package Excel
- 	* @version $Id: class.excel.inc.php,v 1.8 2007/01/26 14:53:46 sigurdne Exp $
+ 	* @version $Id: class.excel.inc.php 3719 2009-09-29 07:52:53Z sigurd $
 	*/
 
-	require_once(PHPGW_APP_INC . '/excel/Worksheet.php');
-	require_once(PHPGW_APP_INC . '/excel/Workbook.php');
-?>
+	require_once PHPGW_SERVER_ROOT . '/property/inc/excel/Worksheet.php';
+	require_once PHPGW_SERVER_ROOT . '/property/inc/excel/Workbook.php';
+
