@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage admin
- 	* @version $Id: class.soXport.inc.php 18358 2007-11-27 04:43:37Z skwashd $
+ 	* @version $Id: class.soXport.inc.php 6275 2010-08-26 18:00:32Z sigurd $
 	*/
 
 	/**
@@ -38,20 +38,17 @@
 		var $account_id = 0;
 		var $total_records = 0;
 		var $bilagsnr;
+		var $voucher_id;
 
-		function property_soXport($useacl=True)
+		function __construct()
 		{
-
 			$GLOBALS['phpgw_info']['flags']['currentapp']	=	'property';
-		//	$this->currentapp	= $GLOBALS['phpgw_info']['flags']['currentapp'];
-			$this->bocommon		= CreateObject('property.bocommon');
-			$this->soinvoice	= CreateObject('property.soinvoice',True);
-			$this->db           	= $this->bocommon->new_db();
-			$this->db2           	= $this->bocommon->new_db();
-			$this->join		= $this->bocommon->join;
-			$this->left_join	= $this->bocommon->left_join;
-			$this->datetimeformat	= $this->bocommon->datetimeformat;
-			$this->like		= $this->bocommon->like;
+			$this->soinvoice	= CreateObject('property.soinvoice',true);
+			$this->db 			= & $GLOBALS['phpgw']->db;
+			$this->like 		= & $this->db->like;
+			$this->join 		= & $this->db->join;
+			$this->left_join	= & $this->db->left_join;
+			$this->datetimeformat	= $this->db->datetime_format();
 			$this->account_id 	= $GLOBALS['phpgw_info']['user']['account_id'];
 		}
 
@@ -62,7 +59,7 @@
 			{
 				return;
 			}
-			$sql = "select mva as tax_code from fm_location1 where loc1=" . substr($dima,0,4);
+			$sql = "select mva as tax_code from fm_location1 where loc1='" . substr($dima,0,4) . "'";
 			$this->db->query($sql);
 			$this->db->next_record();
 
@@ -117,7 +114,7 @@
 			{
 				return;
 			}
-			$sql = "select kostra_id from fm_location1 where loc1=" . substr($dima,0,4);
+			$sql = "select kostra_id from fm_location1 where loc1='" . substr($dima,0,4) . "'";
 			$this->db->query($sql);
 			$this->db->next_record();
 
@@ -183,24 +180,27 @@
 
 		function check_order($id)
 		{
-			$this->db->query("select id,type from fm_orders where id='$id'");
+			$this->db->query("SELECT id,type FROM fm_orders where id='{$id}'");
 			$this->db->next_record();
 			return $this->db->f('type');
 		}
 
 		function get_project($id)
 		{
-			$this->db->query("select project_id from fm_workorder where id='$id'");
+			$id = (int) $id;
+			$sql = "SELECT project_group FROM fm_workorder"
+			. " $this->join fm_project ON fm_workorder.project_id = fm_project.id WHERE fm_workorder.id={$id}";
+			$this->db->query($sql, __LINE__, __FILE__);
 			$this->db->next_record();
-			return $this->db->f('project_id');
+			return $this->db->f('project_group');
 		}
 
 		function check_spbudact_code($id)
 		{
 
-			$this->db->query("select count(*) from fm_b_account where id='$id'");
+			$this->db->query("select count(*) as cnt from fm_b_account where id='$id'");
 			$this->db->next_record();
-			return $this->db->f(0);
+			return $this->db->f('cnt');
 		}
 
 		function add($buffer)
@@ -215,9 +215,10 @@
 					if(!$fields['bilagsnr'])
 					{
 						$fields['bilagsnr']  = $this->soinvoice->next_bilagsnr();
-						$this->bilagsnr = $fields['bilagsnr'];
+						$this->bilagsnr = $fields['bilagsnr'];//FIXME
+						$this->voucher_id = $fields['bilagsnr'];
 					}
-					
+
 					$values= array(
 						$fields['project_id'],
 						$fields['kostra_id'],
@@ -244,23 +245,24 @@
 						$fields['mvakode'],
 						$fields['periode'],
 						$this->db->db_addslashes($fields['merknad']),
-						False,
-						False,
-						False,
-						False,
+						false,
+						false,
+						false,
+						false,
 						$fields['item_type'],
-						$fields['item_id']
+						$fields['item_id'],
+						$fields['external_ref']
 						);
 
 					$bilagsnr	= $fields['bilagsnr'];
 
-					$values	= $this->bocommon->validate_db_insert($values);
+					$values	= $this->db->validate_insert($values);
 
 					$sql= "INSERT INTO fm_ecobilag (project_id,kostra_id,pmwrkord_code,bilagsnr,splitt,kildeid,kidnr,typeid,fakturadato,"
 					. " forfallsdato,regtid,artid,spvend_code,dimb,oppsynsmannid,saksbehandlerid,budsjettansvarligid,"
 					. " fakturanr,spbudact_code,loc1,dima,dimd,mvakode,periode,merknad,oppsynsigndato,saksigndato,"
-					. " budsjettsigndato,utbetalingsigndato,item_type,item_id,belop,godkjentbelop)"
-					. " VALUES ($values," . $this->bocommon->moneyformat($fields['belop']) . "," . $this->bocommon->moneyformat($fields['godkjentbelop']) . ")";
+					. " budsjettsigndato,utbetalingsigndato,item_type,item_id,external_ref, belop,godkjentbelop)"
+					. " VALUES ($values," . $this->db->money_format($fields['belop']) . "," . $this->db->money_format($fields['godkjentbelop']) . ")";
 
 					$this->db->query($sql,__LINE__,__FILE__);
 
@@ -310,22 +312,23 @@
 				$data['utbetalingid'],
 				$data['utbetalingsigndato'],
 				$data['filnavn'],
-				date("Y-m-d G:i:s"),
+				date($this->db->datetime_format()),
 				$data['item_type'],
 				$data['item_id'],
+				$data['external_ref']
 				);
 
-			$values	= $this->bocommon->validate_db_insert($values);
+			$values	= $this->db->validate_insert($values);
 
 			$sql="INSERT INTO fm_ecobilagoverf (id,bilagsnr,kidnr,typeid,kildeid,project_id,kostra_id,pmwrkord_code,fakturadato,"
 				. " periode,forfallsdato,fakturanr,spbudact_code,regtid,artid,spvend_code,dima,loc1,"
 				. " dimb,mvakode,dimd,oppsynsmannid,saksbehandlerid,budsjettansvarligid,oppsynsigndato,saksigndato,"
-				. " budsjettsigndato,merknad,splitt,utbetalingid,utbetalingsigndato,filnavn,overftid,item_type,item_id,"
+				. " budsjettsigndato,merknad,splitt,utbetalingid,utbetalingsigndato,filnavn,overftid,item_type,item_id,external_ref,"
 				. " belop,godkjentbelop,ordrebelop)"
 				. "values ($values, "
-				. $this->bocommon->moneyformat($data['belop']) . ","
-				. $this->bocommon->moneyformat($data['godkjentbelop']) . ","
-				. $this->bocommon->moneyformat($data['ordrebelop']) . ")";
+				. $this->db->money_format($data['belop']) . ","
+				. $this->db->money_format($data['godkjentbelop']) . ","
+				. $this->db->money_format($data['ordrebelop']) . ")";
 
 			$this->db->query($sql,__LINE__,__FILE__);
 //echo 'sql ' . $sql.'<br>';
@@ -337,7 +340,7 @@
 			$this->db->query($sql,__LINE__,__FILE__);
 		}
 
-		// Velg ut alle hoved bilag som skal overfres
+		// Velg ut alle hoved bilag som skal overføres
     	function hoved_bilag ($periode,$pre_transfer='')
     	{
 			if($pre_transfer)
@@ -566,4 +569,4 @@
 			return $responsible;
 		}
 	}
-?>
+
