@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage admin
- 	* @version $Id: class.soadmin.inc.php 18358 2007-11-27 04:43:37Z skwashd $
+ 	* @version $Id: class.soadmin.inc.php 4709 2010-02-02 15:18:50Z sigurd $
 	*/
 
 	/**
@@ -34,15 +34,12 @@
 
 	class property_soadmin
 	{
-		function property_soadmin()
+		function __construct()
 		{
 			$this->account		= $GLOBALS['phpgw_info']['user']['account_id'];
-			$this->bocommon		= CreateObject('property.bocommon');
-			$this->db           	= $this->bocommon->new_db();
-			$this->db2           	= $this->bocommon->new_db();
-
-			$this->join		= $this->bocommon->join;
-			$this->like		= $this->bocommon->like;
+			$this->db           = & $GLOBALS['phpgw']->db;
+			$this->join			= & $this->db->join;
+			$this->like			= & $this->db->like;
 		}
 
 		function get_initials($id)
@@ -68,26 +65,6 @@
 			}
 		}
 
-		function select_location($grant='')
-		{
-			$filter = '';
-			if($grant)
-			{
-				$filter = ' AND allow_grant=1';
-			}
-			$this->db->query("SELECT * FROM phpgw_acl_location WHERE appname = 'property' $filter ORDER BY id ");
-
-				$i = 0;
-				while ($this->db->next_record())
-				{
-					$location[$i]['id']		= $this->db->f('id');
-					$location[$i]['descr']		= stripslashes($this->db->f('descr'));
-					$i++;
-				}
-
-				return $location;
-		}
-
 
 		function read_fm_id()
 		{
@@ -123,34 +100,5 @@
 			$receipt['message'][] = array('msg' => lang('ID is updated'));
 			return $receipt;
 		}
-		
-		function get_accounts_at_location($appname = '', $location ='', $grantor=0 ,$type ='')
-		{
-			if (!$appname)
-			{
-				settype($appname,'string');
-				$appname = $GLOBALS['phpgw_info']['flags']['currentapp'];
-			}
-			
-			if($grantor > 0)
-			{
-				$filter_grants = ' AND acl_grantor IS NOT NULL';
-			}
-			else
-			{
-				$filter_grants = ' AND acl_grantor IS NULL';
-			}
-
-			$sql = "SELECT acl_account from phpgw_acl WHERE acl_appname = '$appname' AND acl_location $this->like '$location%' $filter_grants AND acl_type = '$type' GROUP BY acl_account";
-			$this->db->query($sql,__LINE__,__FILE__);
-
-			$acl_accounts = array();
-			while ($this->db->next_record())
-			{
-				$acl_accounts[$this->db->f('acl_account')] = true;
-			}
-
-			return $acl_accounts;
-		}
 	}
-?>
+
