@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage admin
- 	* @version $Id: class.soadmin_location.inc.php 18358 2007-11-27 04:43:37Z skwashd $
+ 	* @version $Id: class.soadmin_location.inc.php 6128 2010-06-21 19:50:26Z sigurd $
 	*/
 
 	/**
@@ -34,14 +34,12 @@
 
 	class property_soadmin_location
 	{
-		function property_soadmin_location()
+		function __construct()
 		{
 			$this->account		= $GLOBALS['phpgw_info']['user']['account_id'];
-			$this->bocommon		= CreateObject('property.bocommon','property');
-			$this->db           	= $this->bocommon->new_db();
-
-			$this->join		= $this->bocommon->join;
-			$this->like		= $this->bocommon->like;
+			$this->db           = & $GLOBALS['phpgw']->db;
+			$this->join			= & $this->db->join;
+			$this->like			= & $this->db->like;
 		}
 
 		function reset_fm_cache()
@@ -59,7 +57,6 @@
 			if ($order)
 			{
 				$ordermethod = " order by $order $sort";
-
 			}
 			else
 			{
@@ -169,22 +166,26 @@
 		function read_single($id)
 		{
 
+			$id = (int) $id;
 			$table = 'fm_location_type';
 
-			$sql = "SELECT * FROM $table  where id='$id'";
+			$sql = "SELECT * FROM $table  where id={$id}";
 
 			$this->db->query($sql,__LINE__,__FILE__);
 
+			$standard = array();
 			if ($this->db->next_record())
 			{
-				$standard['id']			= $this->db->f('id');
-				$standard['name']		= $this->db->f('name');
-				$standard['descr']		= $this->db->f('descr');
-				$standard['list_info']	= unserialize($this->db->f('list_info'));
-				$standard['list_address']	= $this->db->f('list_address');
-
-				return $standard;
+				$standard = array
+				(
+					'id'			=> $this->db->f('id'),
+					'name'			=> $this->db->f('name'),
+					'descr'			=> $this->db->f('descr'),
+					'list_info'		=> $this->db->f('list_info',true),
+					'list_address'	=> $this->db->f('list_address')
+				);
 			}
+			return $standard;
 		}
 
 		function add($standard)
@@ -193,7 +194,7 @@
 			$standard['name'] = $this->db->db_addslashes($standard['name']);
 			$standard['descr'] = $this->db->db_addslashes($standard['descr']);
 
-			$standard['id'] = $this->bocommon->next_id('fm_location_type');
+			$standard['id'] = $this->db->next_id('fm_location_type');
 
 			$receipt['id']= $standard['id'];
 
@@ -204,7 +205,7 @@
 			$default_attrib['column_name'][]= 'location_code';
 			$default_attrib['type'][]='V';
 			$default_attrib['precision'][] =4*$standard['id'];
-			$default_attrib['nullable'][] ='False';
+			$default_attrib['nullable'][] ='false';
 			$default_attrib['input_text'][] ='dummy';
 			$default_attrib['statustext'][] ='dummy';
 			$default_attrib['attrib_sort'][] ='';
@@ -215,7 +216,7 @@
 			$default_attrib['column_name'][]= 'loc' . $standard['id'] . '_name';
 			$default_attrib['type'][]='V';
 			$default_attrib['precision'][] =50;
-			$default_attrib['nullable'][] ='True';
+			$default_attrib['nullable'][] ='true';
 			$default_attrib['input_text'][] ='dummy';
 			$default_attrib['statustext'][] ='dummy';
 			$default_attrib['attrib_sort'][] ='';
@@ -226,7 +227,7 @@
 			$default_attrib['column_name'][]= 'entry_date';
 			$default_attrib['type'][]='I';
 			$default_attrib['precision'][] =4;
-			$default_attrib['nullable'][] ='True';
+			$default_attrib['nullable'][] ='true';
 			$default_attrib['input_text'][] ='dummy';
 			$default_attrib['statustext'][] ='dummy';
 			$default_attrib['attrib_sort'][] ='';
@@ -237,7 +238,7 @@
 			$default_attrib['column_name'][]= 'category';
 			$default_attrib['type'][]='I';
 			$default_attrib['precision'][] =4;
-			$default_attrib['nullable'][] ='False';
+			$default_attrib['nullable'][] ='false';
 			$default_attrib['input_text'][] ='dummy';
 			$default_attrib['statustext'][] ='dummy';
 			$default_attrib['attrib_sort'][] ='';
@@ -248,7 +249,7 @@
 			$default_attrib['column_name'][]= 'user_id';
 			$default_attrib['type'][]='I';
 			$default_attrib['precision'][] =4;
-			$default_attrib['nullable'][] ='False';
+			$default_attrib['nullable'][] ='false';
 			$default_attrib['input_text'][] ='dummy';
 			$default_attrib['statustext'][] ='dummy';
 			$default_attrib['attrib_sort'][] ='';
@@ -259,8 +260,8 @@
 			$default_attrib['id'][]= $j;
 			$default_attrib['column_name'][]= 'status';
 			$default_attrib['type'][]='LB';
-			$default_attrib['precision'][] = False;
-			$default_attrib['nullable'][] ='True';
+			$default_attrib['precision'][] = false;
+			$default_attrib['nullable'][] ='true';
 			$default_attrib['input_text'][] ='Status';
 			$default_attrib['statustext'][] ='Status';
 			$default_attrib['attrib_sort'][] =1;
@@ -270,8 +271,8 @@
 			$default_attrib['id'][]= $j;
 			$default_attrib['column_name'][]= 'remark';
 			$default_attrib['type'][]='T';
-			$default_attrib['precision'][] = False;
-			$default_attrib['nullable'][] ='False';
+			$default_attrib['precision'][] = false;
+			$default_attrib['nullable'][] ='True';
 			$default_attrib['input_text'][] ='Remark';
 			$default_attrib['statustext'][] ='Remark';
 			$default_attrib['attrib_sort'][] =2;
@@ -282,33 +283,67 @@
 			$default_attrib['column_name'][]= 'change_type';
 			$default_attrib['type'][]='I';
 			$default_attrib['precision'][] =4;
-			$default_attrib['nullable'][] ='True';
+			$default_attrib['nullable'][] ='true';
 			$default_attrib['input_text'][] ='dummy';
 			$default_attrib['statustext'][] ='dummy';
 			$default_attrib['attrib_sort'][] ='';
 			$default_attrib['custom'][] ='';
 
+			$j++;
+			$default_attrib['id'][]= $j;
+			$default_attrib['column_name'][]= 'area_gross';
+			$default_attrib['type'][]='N';
+			$default_attrib['precision'][] = false;
+			$default_attrib['nullable'][] ='True';
+			$default_attrib['input_text'][] ='gross area';
+			$default_attrib['statustext'][] ='Sum of the areas included within the outside face of the exterior walls of a building.';
+			$default_attrib['attrib_sort'][] =3;
+			$default_attrib['custom'][] =1;
+
+			$j++;
+			$default_attrib['id'][]= $j;
+			$default_attrib['column_name'][]= 'area_net';
+			$default_attrib['type'][]='N';
+			$default_attrib['precision'][] = false;
+			$default_attrib['nullable'][] ='True';
+			$default_attrib['input_text'][] ='Net area';
+			$default_attrib['statustext'][] ='The wall-to-wall floor area of a room.';
+			$default_attrib['attrib_sort'][] =4;
+			$default_attrib['custom'][] =1;
+
+			$j++;
+			$default_attrib['id'][]= $j;
+			$default_attrib['column_name'][]= 'area_usable';
+			$default_attrib['type'][]='N';
+			$default_attrib['precision'][] = false;
+			$default_attrib['nullable'][] ='True';
+			$default_attrib['input_text'][] ='Usable area';
+			$default_attrib['statustext'][] ='Generally measured from "paint to paint" inside the permanent walls and to the middle of partitions separating rooms.';
+			$default_attrib['attrib_sort'][] =5;
+			$default_attrib['custom'][] =1;
+
+
 			$fd=array();
-			$fd['location_code'] = array('type' => 'varchar', 'precision' => 25, 'nullable' => False);
+			$fd['location_code'] = array('type' => 'varchar', 'precision' => 25, 'nullable' => false);
 
 			for ($i=1; $i<$standard['id']+1; $i++)
 			{
 				if($i==1)
 				{
-					$fd['loc' . $i] = array('type' => 'varchar', 'precision' => 6, 'nullable' => False);
+					$fd['loc' . $i] = array('type' => 'varchar', 'precision' => 6, 'nullable' => false);
 				}
 				else
 				{
-					$fd['loc' . $i] = array('type' => 'varchar', 'precision' => 4, 'nullable' => False);
+					$fd['loc' . $i] = array('type' => 'varchar', 'precision' => 4, 'nullable' => false);
 				}
-				
+
 				$pk[$i-1]= 'loc' . $i;
 
 				$default_attrib['id'][]= $i+$j;
 				$default_attrib['column_name'][]= 'loc' . $i;
 				$default_attrib['type'][]='V';
 				$default_attrib['precision'][] =4;
-				$default_attrib['nullable'][] ='False';
+				$default_attrib['nullable'][] ='false';
 				$default_attrib['input_text'][] ='dummy';
 				$default_attrib['statustext'][] ='dummy';
 				$default_attrib['attrib_sort'][] ='';
@@ -324,26 +359,28 @@
 
 			if($standard['id']==1)
 			{
-				$fd['part_of_town_id'] = array('type' => 'int', 'precision' => 2, 'nullable' => True);
+				$fd['part_of_town_id'] = array('type' => 'int', 'precision' => 2, 'nullable' => true);
 			}
 
-			$fd['loc' .$standard['id'] . '_name'] = array('type' => 'varchar', 'precision' => 25, 'nullable' => True);
-			$fd['entry_date'] = array('type' => 'int', 'precision' => 4, 'nullable' => True);
-			$fd['category'] = array('type' => 'int', 'precision' => 4, 'nullable' => True);
-			$fd['user_id'] = array('type' => 'int', 'precision' => 4, 'nullable' => True);
-			$fd['remark'] = array('type' => 'text', 'nullable' => True);
-			$fd['status'] = array('type' => 'int', 'precision' => 4, 'nullable' => True);
-			$fd['change_type'] = array('type' => 'int', 'precision' => 4, 'nullable' => True);
+			$fd['loc' .$standard['id'] . '_name'] = array('type' => 'varchar', 'precision' => 25, 'nullable' => true);
+			$fd['entry_date'] = array('type' => 'int', 'precision' => 4, 'nullable' => true);
+			$fd['category'] = array('type' => 'int', 'precision' => 4, 'nullable' => true);
+			$fd['user_id'] = array('type' => 'int', 'precision' => 4, 'nullable' => true);
+			$fd['remark'] = array('type' => 'text', 'nullable' => true);
+			$fd['status'] = array('type' => 'int', 'precision' => 4, 'nullable' => true);
+			$fd['change_type'] = array('type' => 'int', 'precision' => 4, 'nullable' => true);
+			$fd['area_gross'] = array('type' => 'decimal','precision' => '20','scale' => '2','nullable' => True,'default' => '0.00');
+			$fd['area_net'] = array('type' => 'decimal','precision' => '20','scale' => '2','nullable' => True,'default' => '0.00');
+			$fd['area_usable'] = array('type' => 'decimal','precision' => '20','scale' => '2','nullable' => True,'default' => '0.00');
 
 			$ix = array('location_code');
 			$uc = array();
 
 			$fd_history = $fd;
-			$fd_history['exp_date'] = array('type' => 'timestamp','nullable' => True,'default' => 'current_timestamp');
+			$fd_history['exp_date'] = array('type' => 'timestamp','nullable' => true,'default' => 'current_timestamp');
 
-			$add_columns_in_tables=array('fm_project','fm_tts_tickets','fm_request','fm_document','fm_investment');
+			$add_columns_in_tables = $this->get_tables_to_alter();
 
-			$this->oProc->m_odb->transaction_begin();
 			$this->db->transaction_begin();
 
 			if($this->oProc->CreateTable('fm_location'. $standard['id'],array('fd' => $fd,'pk' => $pk,'fk' => $fk,'ix' => $ix,'uc' => $uc))
@@ -352,8 +389,8 @@
 
 				$this->oProc->CreateTable('fm_location'. $standard['id'] . '_category', array(
 				'fd' => array(
-					'id' => array('type' => 'int','precision' => '4','nullable' => False),
-					'descr' => array('type' => 'varchar','precision' => '50','nullable' => True)
+					'id' => array('type' => 'int','precision' => '4','nullable' => false),
+					'descr' => array('type' => 'varchar','precision' => '50','nullable' => true)
 				),
 				'pk' => array('id'),
 				'fk' => array(),
@@ -362,9 +399,10 @@
 
 				for ($i=0;$i<count($add_columns_in_tables);$i++)
 				{
-					$this->oProc->AddColumn($add_columns_in_tables[$i],'loc'. $standard['id'], array('type' => 'varchar', 'precision' => 4, 'nullable' => True));
+					$this->oProc->AddColumn($add_columns_in_tables[$i],'loc'. $standard['id'], array('type' => 'varchar', 'precision' => 4, 'nullable' => true));
 				}
 
+
 				$values_insert= array(
 					$standard['id'],
 					$standard['name'],
@@ -374,16 +412,17 @@
 				    $this->db->db_addslashes(implode(',',$uc)),
 					);
 
-				$values_insert	= $this->bocommon->validate_db_insert($values_insert);
+				$values_insert	= $this->db->validate_insert($values_insert);
 
 				$this->db->query("INSERT INTO fm_location_type (id,name, descr,pk,ix,uc) "
 					. "VALUES ($values_insert)",__LINE__,__FILE__);
 
+				$location_id = $GLOBALS['phpgw']->locations->add(".location.{$standard['id']}", $standard['name'], 'property', true, "fm_location{$standard['id']}");
+
 				for ($i=0;$i<count($default_attrib['id']);$i++)
 				{
 					$values_insert= array(
-						'property',
-						'.location.'.$standard['id'],
+						$location_id,
 						$default_attrib['id'][$i],
 						$default_attrib['column_name'][$i],
 						$default_attrib['type'][$i],
@@ -395,31 +434,25 @@
 						$default_attrib['nullable'][$i]
 						);
 
-					$values_insert	= $this->bocommon->validate_db_insert($values_insert);
+					$values_insert	= $this->db->validate_insert($values_insert);
 
-					$this->db->query("INSERT INTO phpgw_cust_attribute (appname,location,id,column_name,datatype,precision_,input_text,statustext,attrib_sort,custom,nullable) "
+					$this->db->query("INSERT INTO phpgw_cust_attribute (location_id,id,column_name,datatype,precision_,input_text,statustext,attrib_sort,custom,nullable) "
 						. "VALUES ($values_insert)",__LINE__,__FILE__);
 				}
 
 				$type_id=$standard['id'];
 
-				$this->db->query("INSERT INTO phpgw_cust_choice (appname,location,attrib_id,id,value) "
-					. "VALUES ('property','.location.$type_id',$status_id,1,'ok')",__LINE__,__FILE__);
-				$this->db->query("INSERT INTO phpgw_cust_choice (appname,location,attrib_id,id,value) "
-					. "VALUES ('property','.location.$type_id',$status_id,2,'Not Ok')",__LINE__,__FILE__);
+				$this->db->query("INSERT INTO phpgw_cust_choice (location_id,attrib_id,id,value) "
+					. "VALUES ($location_id,$status_id,1,'ok')",__LINE__,__FILE__);
+				$this->db->query("INSERT INTO phpgw_cust_choice (location_id,attrib_id,id,value) "
+					. "VALUES ($location_id,$status_id,2,'Not Ok')",__LINE__,__FILE__);
 				$this->db->query("INSERT INTO fm_location{$type_id}_category (id,descr) "
 					. "VALUES (1,'Category 1')",__LINE__,__FILE__);
 				$this->db->query("INSERT INTO fm_location{$type_id}_category (id,descr) "
-					. "VALUES (99,'Not active')",__LINE__,__FILE__);
-
-				$this->db->query("INSERT INTO phpgw_acl_location (appname, id, descr)"
-		 			. " VALUES ('" . 'property' ."','" . '.location.' . $standard['id'] ."', '" . $standard['name'] . "')");
-		 			
-	//			$GLOBALS['phpgw']->acl->add_location('.location.' . $standard['id'], $standard['name'], 'property', $allow_grant = false, $custom_tbl = '');
+					. "VALUES ('99','Not active')",__LINE__,__FILE__);
 
 				$receipt['message'][] = array('msg' => lang('table %1 has been saved','fm_location'. $receipt['id']));
 				$this->db->transaction_commit();
-				$this->oProc->m_odb->transaction_commit();
 			}
 			else
 			{
@@ -439,6 +472,22 @@
 			return $receipt;
 		}
 
+		function get_tables_to_alter()
+		{
+			$tables = array('fm_project','fm_tts_tickets','fm_request','fm_document','fm_investment');
+			$entity			= CreateObject('property.soadmin_entity');
+			$entity_list 	= $entity->read(array('allrows' => true));
+			foreach($entity_list as $entry)
+			{
+				$cat_list = $entity->read_category(array('allrows'=>true,'entity_id'=>$entry['id']));
+				foreach($cat_list as $category)
+				{
+					$tables[] = "fm_entity_{$entry['id']}_{$category['id']}";
+				}
+			}
+			return $tables;
+		}
+
 		function edit($values)
 		{
 
@@ -450,8 +499,8 @@
 				'list_info'		=> (isset($values['list_info'])?serialize($values['list_info']):''),
 				'list_address'	=> (isset($values['list_address'])?$values['list_address']:''),
 				);
-			
-			$value_set	= $this->bocommon->validate_db_update($value_set);
+
+			$value_set	= $this->db->validate_update($value_set);
 
 			$this->db->query("UPDATE $table SET $value_set WHERE id='" . $values['id']. "'",__LINE__,__FILE__);
 
@@ -462,9 +511,11 @@
 		}
 
 		function delete($id)
-		{
+		{	
+			$tables_to_drop_from = $this->get_tables_to_alter();
+			
+			$receipt = array();
 			$this->init_process();
-			$this->oProc->m_odb->transaction_begin();
 			$this->db->transaction_begin();
 
 			$table 		= 'fm_location_type';
@@ -473,34 +524,43 @@
 			if($this->db->f('id') > $id)
 			{
 				$this->db->transaction_abort();
-				$this->oProc->m_odb->transaction_abort();
 				$receipt['error'][] = array('msg' => lang('please delete from the bottom'));
-				$GLOBALS['phpgw']->session->appsession('receipt','property',$receipt);
-				
-				return;
+				return $receipt;
 			}
-				
+
 			$this->oProc->DropTable('fm_location' . $id);
 			$this->oProc->DropTable('fm_location' . $id . '_category');
 			$this->oProc->DropTable('fm_location' . $id . '_history');
 
+			foreach($tables_to_drop_from as $entry)
+			{
+				$this->oProc->DropColumn($entry ,array(),"loc{$id}");
+			}
+
 			$attrib_table 	= 'phpgw_cust_attribute';
 			$choice_table 	= 'phpgw_cust_choice';
-			
-			$this->db->query("DELETE FROM $attrib_table WHERE appname = 'property' AND location = '.location. " . $id . "'",__LINE__,__FILE__);
-			$this->db->query("DELETE FROM $choice_table WHERE appname = 'property' AND location = '.location. " . $id . "'",__LINE__,__FILE__);
-			$this->db->query("DELETE FROM $table WHERE id=" . (int)$id,__LINE__,__FILE__);
+			$location_id	= $GLOBALS['phpgw']->locations->get_id('property', ".location.{$id}");
 
-			$this->db->transaction_commit();
-			$this->oProc->m_odb->transaction_commit();
+			$this->db->query("DELETE FROM {$attrib_table} WHERE location_id = {$location_id}",__LINE__,__FILE__);
+			$this->db->query("DELETE FROM {$choice_table} WHERE location_id = {$location_id}",__LINE__,__FILE__);
+			$this->db->query("DELETE FROM {$table} WHERE id=" . (int)$id,__LINE__,__FILE__);
+
+			if($this->db->transaction_commit())
+			{
+				$receipt['message'][] = array('msg' => lang('location at level %1 has been deleted', $id));
+			}
+			else
+			{
+				$receipt['error'][] = array('msg' => lang('the process failed'));			
+			}
+			return $receipt;
 		}
 
 
-
 		function init_process()
 		{
 			$this->oProc 				= CreateObject('phpgwapi.schema_proc',$GLOBALS['phpgw_info']['server']['db_type']);
-			$this->oProc->m_odb			= $this->db;
+			$this->oProc->m_odb			= & $this->db;
 			$this->oProc->m_odb->Halt_On_Error	= 'yes';
 		}
 
@@ -515,19 +575,20 @@
 			$column_info['default']		= $this->db->f('default_value');
 			$column_info['nullable']	= $this->db->f('nullable');
 			$location_type				= $this->db->f('location_type');
+			$location_id 				= $GLOBALS['phpgw']->locations->get_id('property', ".location.{$location_type}");
 
-			$custom 	= createObject('phpgwapi.custom_fields');
+			$custom 	= createObject('property.custom_fields');
 			$table_def = $custom->get_table_def('fm_location'.$location_type);
 			$history_table_def = $custom->get_table_def('fm_location' . $location_type . '_history');
 //_debug_array($table_def);
 //_debug_array($history_table_def);
 			if(!($location_type==$values[$column_name]))
 			{
-				$id = $this->bocommon->next_id('phpgw_cust_attribute',array('appname' => 'property', 'location' => '.location.' .$values[$column_name]));
+				$id = $this->db->next_id('phpgw_cust_attribute',array('location_id' => $location_id));
 
 				$this->init_process();
 
-				$this->oProc->m_odb->transaction_begin();
+	//			$this->oProc->m_odb->transaction_begin();
 				$this->db->transaction_begin();
 				if($this->oProc->AddColumn('fm_location'.$values[$column_name],$column_name, $column_info) &&
 					$this->oProc->AddColumn('fm_location'.$values[$column_name] . '_history',$column_name, $column_info))
@@ -547,8 +608,7 @@
 						location_type = '". $values[$column_name]	. "' WHERE column_name='" . $column_name . "'",__LINE__,__FILE__);
 
 					$values= array(
-						'property',
-						'.location.' . $values[$column_name],
+						$location_id,
 						$id,
 						$column_name,
 						$column_name,
@@ -561,20 +621,21 @@
 						''
 					);
 
-					$values	= $this->bocommon->validate_db_insert($values);
+					$values	= $this->db->validate_insert($values);
 
-					$this->db->query("INSERT INTO phpgw_cust_attribute (appname,location,id,column_name, input_text, statustext,datatype,precision_,scale,default_value,nullable,custom) "
+					$this->db->query("INSERT INTO phpgw_cust_attribute (location_id,id,column_name, input_text, statustext,datatype,precision_,scale,default_value,nullable,custom) "
 						. "VALUES ($values)",__LINE__,__FILE__);
 
-					$this->db->query("DELETE from phpgw_cust_attribute WHERE appname = 'property' AND location = '.location.". $location_type . "' AND column_name = '" . $column_name . "'",__LINE__,__FILE__);
+					//FIXME: what??
+					$this->db->query("DELETE from phpgw_cust_attribute WHERE location_id = {$location_id} AND column_name = '{$column_name}'",__LINE__,__FILE__);
 
 					$ok = true;
 				}
-				
+
 				if(isset($ok) && $ok)
 				{
 					$this->db->transaction_commit();
-					$this->oProc->m_odb->transaction_commit();				
+//					$this->oProc->m_odb->transaction_commit();
 
 					$receipt['message'][] = array('msg'	=> lang('column %1 has been moved',$column_name));
 				}
@@ -589,6 +650,11 @@
 		}
 
 
+		function get_location_type()
+		{
+			return $this->select_location_type();
+		}
+
 		function select_location_type()
 		{
 			$this->db->query("SELECT * FROM fm_location_type ORDER BY id ");
@@ -608,4 +674,4 @@
 			return $location_type;
 		}
 	}
-?>
+
