@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage agreement
- 	* @version $Id: class.soagreement.inc.php 18358 2007-11-27 04:43:37Z skwashd $
+ 	* @version $Id: class.soagreement.inc.php 4807 2010-02-12 09:46:39Z sigurd $
 	*/
 
 	/**
@@ -36,14 +36,12 @@
 	{
 		var $role;
 
-		function property_soagreement()
+		function __construct()
 		{
-		//	$this->currentapp	= $GLOBALS['phpgw_info']['flags']['currentapp'];
 			$this->account		= $GLOBALS['phpgw_info']['user']['account_id'];
 			$this->bocommon		= CreateObject('property.bocommon');
-			$this->db           = $this->bocommon->new_db();
-			$this->db2          = $this->bocommon->new_db();
-
+			$this->db           = clone($GLOBALS['phpgw']->db);
+			$this->db2          = clone($this->db);
 			$this->join			= $this->bocommon->join;
 			$this->left_join	= $this->bocommon->left_join;
 			$this->like			= $this->bocommon->like;
@@ -90,7 +88,8 @@
 
 			$entity_table = 'fm_agreement';
 			$category_table = 'fm_branch';
-			$attribute_filter = " appname = 'property' AND location = '.agreement'";
+			$location_id = $GLOBALS['phpgw']->locations->get_id('property', '.agreement'); 
+			$attribute_filter = " location_id = {$location_id}";
 			$paranthesis ='(';
 			$joinmethod = " $this->join $category_table ON ( $entity_table.category =$category_table.id)";
 			$joinmethod .= " $this->join  fm_vendor ON ( $entity_table.vendor_id =fm_vendor.id ))";
@@ -254,9 +253,11 @@
 
 			if($query)
 			{
-				$query = preg_replace("/'/",'',$query);
-				$query = preg_replace('/"/','',$query);
+				$query = $this->db->db_addslashes($query);
 
+				$querymethod[]= "fm_branch.descr {$this->like} '%{$query}%'";
+				$querymethod[]= "{$entity_table}.name {$this->like} '%{$query}%'";
+				
 				$this->db->query("SELECT * FROM $attribute_table WHERE search='1' AND $attribute_filter ");
 
 				while ($this->db->next_record())
@@ -279,7 +280,6 @@
 			}
 
 			$sql .= " $filtermethod $querymethod";
-//echo $sql;
 
 			$this->db2->query($sql,__LINE__,__FILE__);
 			$this->total_records = $this->db2->num_rows();
@@ -337,7 +337,7 @@
 						else if($cols_return_extra[$i]['datatype']=='CH' && $value)
 						{
 							$ch= unserialize($value);
-	
+
 							if (isset($ch) AND is_array($ch))
 							{
 								for ($k=0;$k<count($ch);$k++)
@@ -355,10 +355,16 @@
 						}
 						else if($cols_return_extra[$i]['datatype']=='D' && $value)
 						{
-//_debug_array($value);
-
 							$agreement_list[$j][$cols_return_extra[$i]['name']]=date($GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat'],strtotime($value));
 						}
+						else if($cols_return_extra[$i]['datatype']=='timestamp' && $value)
+						{
+							$agreement_list[$j][$cols_return_extra[$i]['name']]=date($GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat'],$value);
+						}
+						else if($cols_return_extra[$i]['datatype']=='link' && $value)
+						{
+							$agreement_list[$j][$cols_return_extra[$i]['name']]= phpgw::safe_redirect($value);
+						}
 						else
 						{
 							$agreement_list[$j][$cols_return_extra[$i]['name']]=$value;
@@ -384,6 +390,7 @@
 				$allrows		= (isset($data['allrows'])?$data['allrows']:'');
 				$agreement_id	= (isset($data['agreement_id'])?$data['agreement_id']:'');
 			}
+$allrows = true; // return all..
 
 			$entity_table = 'fm_activity_price_index';
 
@@ -399,7 +406,7 @@
 			$uicols['name'][]			= 'activity_id';
 			$uicols['descr'][]			= lang('ID');
 			$uicols['input_type'][]		= 'I';
-			
+
 			$uicols['name'][]			= 'num';
 			$uicols['descr'][]			= lang('Code');
 			$uicols['input_type'][]		= 'V';
@@ -522,8 +529,8 @@
 			$cols_return[] 			= 'id';
 			$uicols['input_type'][]		= 'hidden';
 			$uicols['name'][]			= 'id';
-			$uicols['descr'][]			= False;
-			$uicols['statustext'][]		= False;
+			$uicols['descr'][]			= false;
+			$uicols['statustext'][]		= false;
 
 			$cols_return[] 			= 'm_cost';
 			$uicols['input_type'][]		= 'text';
@@ -687,6 +694,7 @@
 
 			$this->db->transaction_begin();
 			$id = $this->bocommon->next_id($table);
+			$vals = array();
 			$vals[] = $id;
 			$vals[] = $agreement['name'];
 			$vals[] = $agreement['descr'];
@@ -947,18 +955,18 @@
 			{
 				case 'fm_agreement':
 					$fd=array(
-						'group_id' => array('type' => 'int','precision' => '4','nullable' => False),
-						'id' => array('type' => 'int','precision' => '4','nullable' => False),
-						'vendor_id' => array('type' => 'int','precision' => '4','nullable' => False),
-						'name' => array('type' => 'varchar','precision' => '100','nullable' => False),
-						'descr' => array('type' => 'text','nullable' => True),
-						'status' => array('type' => 'varchar','precision' => '10','nullable' => True),
-						'entry_date' => array('type' => 'int','precision' => '4','nullable' => True),
-						'start_date' => array('type' => 'int','precision' => '4','nullable' => True),
-						'end_date' => array('type' => 'int','precision' => '4','nullable' => True),
-						'termination_date' => array('type' => 'int','precision' => '4','nullable' => True),
-						'category' => array('type' => 'int','precision' => '4','nullable' => True),
-						'user_id' => array('type' => 'int','precision' => '4','nullable' => True)
+						'group_id' => array('type' => 'int','precision' => '4','nullable' => false),
+						'id' => array('type' => 'int','precision' => '4','nullable' => false),
+						'vendor_id' => array('type' => 'int','precision' => '4','nullable' => false),
+						'name' => array('type' => 'varchar','precision' => '100','nullable' => false),
+						'descr' => array('type' => 'text','nullable' => true),
+						'status' => array('type' => 'varchar','precision' => '10','nullable' => true),
+						'entry_date' => array('type' => 'int','precision' => '4','nullable' => true),
+						'start_date' => array('type' => 'int','precision' => '4','nullable' => true),
+						'end_date' => array('type' => 'int','precision' => '4','nullable' => true),
+						'termination_date' => array('type' => 'int','precision' => '4','nullable' => true),
+						'category' => array('type' => 'int','precision' => '4','nullable' => true),
+						'user_id' => array('type' => 'int','precision' => '4','nullable' => true)
 						);
 					break;
 				case 'fm_agreement_detail':
@@ -969,7 +977,7 @@
 					return;
 					break;
 			}
-			
+
 			return $fd;
 		}
 
@@ -1001,7 +1009,7 @@
 			}
 
 			$fd = $this->get_default_column_def($table);
-			
+
 			for ($i=0; $i<count($metadata); $i++)
 			{
 				$sql = "SELECT * FROM fm_agreement_attribute WHERE column_name = '" . $metadata[$i]['name'] . "' $filtermethod";
@@ -1030,11 +1038,11 @@
 					'fd' => $fd
 					)
 				);
-			
+
 			$table_def[$table]['pk'] = $pk;
-			$table_def[$table]['fk'] = array();			
-			$table_def[$table]['ix'] = array();			
-			$table_def[$table]['uc'] = array();			
+			$table_def[$table]['fk'] = array();
+			$table_def[$table]['ix'] = array();
+			$table_def[$table]['uc'] = array();
 
 			return $table_def;
 		}
@@ -1063,6 +1071,7 @@
 
 		function read_group_activity($group_id='',$agreement_id='')
 		{
+			$uicols = array();
 			$uicols['name'][]			= 'id';
 			$uicols['descr'][]			= lang('ID');
 			$uicols['name'][]			= 'num';
@@ -1081,6 +1090,7 @@
 			$sql="SELECT fm_activities.* FROM fm_activities WHERE agreement_group_id = $group_id";
 			$this->db->query($sql);
 
+			$activity_list = array();
 			while ($this->db->next_record())
 			{
 				$activity_list[$this->db->f('id')]=array
@@ -1111,27 +1121,74 @@
 			return $activity_list_result;
 		}
 
-		function add_activity($values='',$agreement_id='')
+		function add_activity($values,$agreement_id)
 		{
+			$agreement_id = (int)$agreement_id;
+
 			if (isset($values['select']) AND is_array($values['select']))
 			{
 				$this->db->transaction_begin();
 
-				$this->db->query("SELECT start_date FROM fm_agreement WHERE id=" . $values['agreement_id']);
+				$this->db->query("SELECT start_date FROM fm_agreement WHERE id={$agreement_id}");
 				$this->db->next_record();
 				$date	= $this->db->f('start_date');
+				if(!$date)
+				{
+					throw new Exception("missing start date for agreement {$agreement_id}");
+//					return $receipt['error'][] = array('msg'=>lang('missing start date for agreement %1',$agreement_id));
+				}
+				
+				$sql = 'INSERT INTO fm_activity_price_index (agreement_id, activity_id, index_count, current_index, index_date, entry_date, user_id)'
+							. ' VALUES(?, ?, ?, ?, ?, ?, ?)';
+				$valueset=array();
 
 				foreach($values['select'] as $activity_id)
 				{
-					$this->db->query("INSERT INTO fm_activity_price_index ( agreement_id, activity_id,index_count,current_index,index_date,entry_date,user_id) "
-					. "VALUES ($agreement_id,$activity_id,-1,1,$date," . time() . "," . $this->account . ")");
+					$valueset[] = array
+					(
+						1	=> array
+						(
+							'value'	=> $agreement_id,
+							'type'	=> PDO::PARAM_INT
+						),
+						2	=> array
+						(
+							'value'	=> $activity_id,
+							'type'	=>	PDO::PARAM_INT
+						),
+						3	=> array
+						(
+							'value'	=> -1,
+							'type'	=> PDO::PARAM_INT
+						),
+						4	=> array
+						(
+							'value'	=> 1,
+							'type'	=>	PDO::PARAM_INT
+						),
+						5	=> array
+						(
+							'value'	=> $date,
+							'type'	=> PDO::PARAM_INT
+						),
+						6	=> array
+						(
+							'value'	=> time(),
+							'type'	=> PDO::PARAM_INT
+						),
+						7	=> array
+						(
+							'value'	=> $this->account,
+							'type'	=> PDO::PARAM_INT
+						)
+					);
 				}
 
+				$this->db->insert($sql, $valueset, __LINE__, __FILE__);
 				$this->db->transaction_commit();
 			}
 
-
-			$receipt['agreement_id']= $id;//$this->db->get_last_insert_id($table,'id');
+			$receipt['agreement_id']= $agreement_id;
 
 			$receipt['message'][] = array('msg'=>lang('agreement %1 has been saved',$receipt['agreement_id']));
 
@@ -1141,23 +1198,23 @@
 		function select_status_list()
 		{
 			$this->db->query("SELECT id, descr FROM fm_agreement_status ORDER BY id ");
-
-			$i = 0;
+			$status = array();
 			while ($this->db->next_record())
 			{
-				$status_entries[$i]['id']				= $this->db->f('id');
-				$status_entries[$i]['name']				= stripslashes($this->db->f('descr'));
-				$i++;
+				$status[] = array
+				(
+					'id'	=> $this->db->f('id'),
+					'name'	=> $this->db->f('descr',true)
+				);
 			}
-			return $status_entries;
+			return $status;
 		}
 
 		function get_activity_descr($id)
 		{
+			$id = (int)$id;
 			$this->db->query("SELECT descr FROM fm_activities WHERE id = $id",__LINE__,__FILE__);
 			$this->db->next_record();
-			return stripslashes($this->db->f('descr'));
+			return $this->db->f('descr',true);
 		}
-
 	}
-?>
