@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage admin
- 	* @version $Id: class.soasync.inc.php 18358 2007-11-27 04:43:37Z skwashd $
+ 	* @version $Id: class.soasync.inc.php 4709 2010-02-02 15:18:50Z sigurd $
 	*/
 
 	/**
@@ -34,43 +34,32 @@
 
 	class property_soasync
 	{
-		function property_soasync()
+		function __construct()
 		{
-		//	$this->currentapp	= $GLOBALS['phpgw_info']['flags']['currentapp'];
 			$this->account		= $GLOBALS['phpgw_info']['user']['account_id'];
-			$this->bocommon		= CreateObject('property.bocommon');
-			$this->db           	= $this->bocommon->new_db();
-			$this->db2           	= $this->bocommon->new_db();
-
-			$this->join			= $this->bocommon->join;
-			$this->like			= $this->bocommon->like;
+			$this->db           = & $GLOBALS['phpgw']->db;
+			$this->join			= & $this->db->join;
+			$this->like			= & $this->db->like;
 		}
 
 		function read($data)
 		{
 			if(is_array($data))
 			{
-				if ($data['start'])
-				{
-					$start=$data['start'];
-				}
-				else
-				{
-					$start=0;
-				}
-				$query = (isset($data['query'])?$data['query']:'');
-				$sort = (isset($data['sort'])?$data['sort']:'DESC');
-				$order = (isset($data['order'])?$data['order']:'');
+				$start	= isset($data['start']) && $data['start'] ? $data['start'] : 0;
+				$query	= isset($data['query']) ? $data['query'] : '';
+				$sort	= isset($data['sort']) && $data['sort'] ? $data['sort'] : 'DESC';
+				$order	= isset($data['order']) ? $data['order'] : '';
+				$allrows	= isset($data['allrows']) ? $data['allrows'] : '';
 			}
 
 			if ($order)
 			{
-				$ordermethod = " order by $order $sort";
-
+				$ordermethod = " ORDER BY $order $sort";
 			}
 			else
 			{
-				$ordermethod = ' order by id asc';
+				$ordermethod = ' ORDER BY id asc';
 			}
 
 			$table='fm_async_method';
@@ -78,26 +67,33 @@
 			$querymethod = '';
 			if($query)
 			{
-				$query = preg_replace("/'/",'',$query);
-				$query = preg_replace('/"/','',$query);
-
-				$querymethod = " where id $this->like '%$query%' or descr $this->like '%$query%'";
+				$query = $this->db->db_addslashes($query);
+				$querymethod = " WHERE name $this->like '%$query%' OR data $this->like '%$query%' OR descr $this->like '%$query%'";
 			}
 
 			$sql = "SELECT * FROM $table $querymethod";
 
-			$this->db2->query($sql,__LINE__,__FILE__);
-			$this->total_records = $this->db2->num_rows();
-			$this->db->limit_query($sql . $ordermethod,$start,__LINE__,__FILE__);
+			$this->db->query($sql,__LINE__,__FILE__);
+			$this->total_records = $this->db->num_rows();
 
+			if(!$allrows)
+			{
+				$this->db->limit_query($sql . $ordermethod,$start,__LINE__,__FILE__);
+			}
+			else
+			{
+				$this->db->query($sql . $ordermethod,__LINE__,__FILE__);
+			}
+
+			$method = array();
 			while ($this->db->next_record())
 			{
 				$method[] = array
 				(
 					'id'	=> $this->db->f('id'),
-					'name'	=> $this->db->f('name'),
-					'data'	=> $this->db->f('data'),
-					'descr'	=> $this->db->f('descr')
+					'name'	=> $this->db->f('name',true),
+					'data'	=> $this->db->f('data',true),
+					'descr'	=> $this->db->f('descr',true)
 				);
 			}
 			return $method;
@@ -106,36 +102,43 @@
 
 		function read_single($id)
 		{
+			$id = (int) $id;
+
 			$table='fm_async_method';
 
-			$sql = "SELECT * FROM $table  where id='$id'";
+			$sql = "SELECT * FROM {$table} WHERE id={$id}";
 
 			$this->db->query($sql,__LINE__,__FILE__);
 
+			$method = array();
 			if ($this->db->next_record())
 			{
 				$method['id']		= $this->db->f('id');
-				$method['name']		= $this->db->f('name');
-				$method['data']		= $this->db->f('data');
-				$method['descr']	= $this->db->f('descr');
-
-				return $method;
+				$method['name']		= $this->db->f('name', true);
+				$method['data']		= $this->db->f('data', true);
+				$method['descr']	= $this->db->f('descr', true);
 			}
+			return $method;
 		}
 
 		function add($method)
 		{
+			$receipt = array();
 			$table='fm_async_method';
 
-			$method['id'] = $this->bocommon->next_id($table);
+			$this->db->transaction_begin();
+			$method['id'] = $this->db->next_id($table);
 			$method['name'] = $this->db->db_addslashes($method['name']);
 			$method['descr'] = $this->db->db_addslashes($method['descr']);
 
 			$this->db->query("INSERT INTO $table (id, name,data, descr) "
 				. "VALUES ('" . $method['id'] . "','" . $method['name'] . "','" . $method['data'] . "','" . $method['descr']. "')",__LINE__,__FILE__);
 
-			$receipt['id'] = $method['id'];
-			$receipt['message'][] = array('msg' => lang('async method has been saved'));
+			if( $this->db->transaction_commit() )
+			{
+				$receipt['id'] = $method['id'];
+				$receipt['message'][] = array('msg' => lang('async method has been saved'));
+			}
 
 			return $receipt;
 		}
@@ -162,4 +165,4 @@
 			$this->db->query("DELETE FROM $table WHERE id='" . $id . "'",__LINE__,__FILE__);
 		}
 	}
-?>
+
