@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage eco
- 	* @version $Id: class.soinvestment.inc.php 18358 2007-11-27 04:43:37Z skwashd $
+ 	* @version $Id: class.soinvestment.inc.php 4709 2010-02-02 15:18:50Z sigurd $
 	*/
 
 	/**
@@ -34,20 +34,18 @@
 
 	class property_soinvestment
 	{
-		function property_soinvestment()
+		function __construct()
 		{
-		//	$this->currentapp	= $GLOBALS['phpgw_info']['flags']['currentapp'];
 			$this->account	= $GLOBALS['phpgw_info']['user']['account_id'];
-			$this->bocommon		= CreateObject('property.bocommon');
-			$this->db           	= $this->bocommon->new_db();
-			$this->db2           	= $this->bocommon->new_db();
-			$this->join			= $this->bocommon->join;
-			$this->like			= $this->bocommon->like;
+			$this->db           = & $GLOBALS['phpgw']->db;
+			$this->join			= & $this->db->join;
+			$this->like			= & $this->db->like;
 		}
 
 		function get_type_list()
 		{
 			$this->db->query("SELECT entity_type FROM fm_investment GROUP BY entity_type ");
+			$type_list = array();
 			while ($this->db->next_record())
 			{
 				$type_list[] = Array(
@@ -142,8 +140,8 @@
 			}
 			if($sql)
 			{
-				$this->db2->query($sql,__LINE__,__FILE__);
-				$this->total_records = $this->db2->num_rows();
+				$this->db->query($sql,__LINE__,__FILE__);
+				$this->total_records = $this->db->num_rows();
 
 				if(!$allrows)
 				{
@@ -156,6 +154,7 @@
 			}
 
 
+			$investment = array();
 			$i=0;
 			while ($this->db->next_record())
 			{
@@ -192,6 +191,7 @@
 		{
 //_debug_array($values);
 
+			$receipt = array();
 			while (is_array($values['location']) && list($input_name,$value) = each($values['location']))
 			{
 				if($value)
@@ -263,7 +263,9 @@
 
 		function update_investment($values)
 		{
-			if (isSet($values) AND is_array($values))
+			$receipt = array();
+
+			if ($values)
 			{
 				$this->db->transaction_begin();
 				foreach($values as $entry)
@@ -286,13 +288,16 @@
 						1
 						);
 
-					$insert	= $this->bocommon->validate_db_insert($insert);
+					$insert	= $this->db->validate_insert($insert);
 
 
 					$this->db->query("insert into fm_investment_value (entity_id, invest_id, index_count, this_index, value,initial_value, index_date,current_index) "
 					. " values ($insert)");
+
+					$receipt['message'][]=array('msg'=>lang('investment %1 is updated at entity %2', $entry['invest_id'], $entry['entity_id']));
 				}
 				$this->db->transaction_commit();
+				return $receipt;
 			}
 		}
 
@@ -307,8 +312,8 @@
 			$sql = "SELECT index_count, this_index,current_index,value, initial_value, index_date  "
 			. " FROM fm_investment_value Where entity_id= '$entity_id' and invest_id= '$investment_id' order by index_count";
 
-			$this->db2->query($sql,__LINE__,__FILE__);
-			$this->total_records = $this->db2->num_rows();
+			$this->db->query($sql,__LINE__,__FILE__);
+			$this->total_records = $this->db->num_rows();
 
 			if(!$allrows)
 			{
@@ -319,6 +324,7 @@
 				$this->db->query($sql,__LINE__,__FILE__);
 			}
 
+			$investment = array();
 			$i=0;
 			while ($this->db->next_record())
 			{
@@ -341,6 +347,7 @@
 		{
 			$this->db->query("SELECT writeoff_year FROM fm_investment GROUP BY writeoff_year ",__LINE__,__FILE__);
 
+			$period_list = array();
 			while ($this->db->next_record())
 			{
 				$period_list[] = Array(
@@ -372,4 +379,4 @@
 			$this->db->transaction_commit();
 		}
 	}
-?>
+
