@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage eco
- 	* @version $Id: class.soinvoice.inc.php 18358 2007-11-27 04:43:37Z skwashd $
+ 	* @version $Id: class.soinvoice.inc.php 6275 2010-08-26 18:00:32Z sigurd $
 	*/
 
 	/**
@@ -35,58 +35,68 @@
 	class property_soinvoice
 	{
 		var $total_records = 0;
+		var $role = array();
+		protected $invoice_approval = 2;
 
-		function property_soinvoice()
+		function __construct()
 		{
-		//	$this->currentapp	= $GLOBALS['phpgw_info']['flags']['currentapp'];
-			$this->bocommon		= CreateObject('property.bocommon');
-			$this->db           	= $this->bocommon->new_db();
-			$this->db2           	= $this->bocommon->new_db();
 			$this->account_id 	= $GLOBALS['phpgw_info']['user']['account_id'];
-
-			$this->acl 		= CreateObject('phpgwapi.acl');
-
-			$this->join		= $this->bocommon->join;
-			$this->left_join	= $this->bocommon->left_join;
-			$this->like		= $this->bocommon->like;
+			$this->acl 			= & $GLOBALS['phpgw']->acl;
+			$this->db           = & $GLOBALS['phpgw']->db;
+			$this->join			= & $this->db->join;
+			$this->left_join	= & $this->db->left_join;
+			$this->like			= & $this->db->like;
+			$this->config		= CreateObject('phpgwapi.config','property');
+			$this->config->read();
+			$this->invoice_approval = isset($this->config->config_data['invoice_approval']) && $this->config->config_data['invoice_approval'] ? $this->config->config_data['invoice_approval'] : 2;
 		}
 
 		function read_invoice($data)
 		{
-			if(is_array($data))
-			{
-				if ($data['start'])
-				{
-					$start=$data['start'];
-				}
-				else
-				{
-					$start=0;
-				}
-				$query 			= (isset($data['query'])?$data['query']:'');
-				$sort 			= (isset($data['sort'])?$data['sort']:'DESC');
-				$order 			= (isset($data['order'])?$data['order']:'');
-				$cat_id 		= (isset($data['cat_id'])?$data['cat_id']:0);
-				$user_lid 		= (isset($data['user_lid'])?$data['user_lid']:'none');
-				$paid 			= (isset($data['paid'])?$data['paid']:'');
-				$start_date 		= (isset($data['start_date'])?$data['start_date']:'');
-				$end_date 		= (isset($data['end_date'])?$data['end_date']:'');
-				$vendor_id 		= (isset($data['vendor_id'])?$data['vendor_id']:'');
-				$loc1 			= (isset($data['loc1'])?$data['loc1']:'');
-				$workorder_id 		= (isset($data['workorder_id'])?$data['workorder_id']:'');
-				$allrows 		= (isset($data['allrows'])?$data['allrows']:'');
-				$voucher_id 		= (isset($data['voucher_id'])?$data['voucher_id']:'');
-				$b_account_class	= (isset($data['b_account_class'])?$data['b_account_class']:'');
-				$district_id 		= (isset($data['district_id'])?$data['district_id']:'');			
-			}
+
+			$valid_order = array
+			(
+				'bilagsnr'			=> true,
+				'spvend_code'		=> true,
+				'fakturadato'		=> true,
+				'oppsynsigndato'	=> true,
+				'saksigndato'		=> true,
+				'budsjettsigndato'	=> true,
+				'periode'			=> true
+			);
+
+			$start			= isset($data['start']) && $data['start'] ? $data['start'] : 0;
+			$query 			= isset($data['query'])?$data['query']:'';
+			$sort 			= isset($data['sort']) && $data['sort'] ? $data['sort']:'DESC';
+			$order 			= isset($data['order']) && $valid_order[$data['order']] ? $data['order']:'';
+			$cat_id 		= isset($data['cat_id']) && $data['cat_id'] ? $data['cat_id']:0;
+			$user_lid 		= isset($data['user_lid']) && $data['user_lid']?$data['user_lid']:'none';
+			$paid 			= isset($data['paid'])?$data['paid']:'';
+			$start_date 	= isset($data['start_date']) && $data['start_date'] ? $data['start_date'] : 0;
+			$end_date 		= isset($data['end_date']) && $data['end_date'] ? $data['end_date'] : time();
+			$vendor_id 		= isset($data['vendor_id'])?$data['vendor_id']:'';
+			$loc1 			= isset($data['loc1'])?$data['loc1']:'';
+			$workorder_id 	= isset($data['workorder_id'])?$data['workorder_id']:'';
+			$allrows 		= isset($data['allrows'])?$data['allrows']:'';
+			$voucher_id 	= isset($data['voucher_id'])?$data['voucher_id']:'';
+			$b_account_class= isset($data['b_account_class'])?$data['b_account_class']:'';
+			$district_id 	= isset($data['district_id'])?$data['district_id']:'';
+
 			$join_tables	= '';
 			$filtermethod	= '';
 			$querymethod	= '';
 //_debug_array($data);
+			
+			$this->db->query("SELECT * FROM fm_ecoart");
+			$art_list = array();
+			while ($this->db->next_record())
+			{
+				$art_list[$this->db->f('id')] = $this->db->f('descr',true);
+			}
 
 			if ($order)
 			{
-				$ordermethod = " order by $order $sort";
+				$ordermethod = " ORDER BY $order $sort";
 			}
 			else
 			{
@@ -112,7 +122,7 @@
 				$where= 'AND';
 			}
 
-			if ($district_id > 0)
+			if ($district_id > 0 && $paid)
 			{
 				$filtermethod .= " $where  district_id='$district_id' ";
 				$join_tables = " $this->join fm_location1 ON fm_ecobilagoverf.loc1 = fm_location1.loc1"
@@ -135,11 +145,11 @@
 				$filtermethod .= " $where  pmwrkord_code ='$workorder_id' ";
 				$where= 'AND';
 			}
-			
+
 
 			if ($voucher_id)
 			{
-				$filtermethod .= " $where  bilagsnr $this->like '%$voucher_id%' ";
+				$filtermethod .= " $where  bilagsnr = " . (int)$voucher_id;
 				$where= 'AND';
 			}
 
@@ -155,48 +165,12 @@
 					$join_tables .= " $this->join fm_b_account ON fm_ecobilagoverf.spbudact_code = fm_b_account.id";
 				}
 
-				if (!$workorder_id && !$voucher_id)
+				if (!$workorder_id && !$voucher_id  && $start_date)
 				{
-					$dateformat = strtolower($GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat']);
-					$dateformat = str_replace(".","",$dateformat);
-					$dateformat = str_replace("-","",$dateformat);
-					$dateformat = str_replace("/","",$dateformat);
-					$y=strpos($dateformat,'y');
-					$d=strpos($dateformat,'d');
-					$m=strpos($dateformat,'m');
+					$start_periode = date('Ym',$start_date);
+					$end_periode = date('Ym',$end_date);
 
-	 				$dateparts = explode('/', $start_date);
-	 				$sday = $dateparts[$d];
-	 				$smonth = $dateparts[$m];
-	 				$syear = $dateparts[$y];
-
-		 			$dateparts = explode('/', $end_date);
-	 				$eday = $dateparts[$d];
-	 				$emonth = $dateparts[$m];
-	 				$eyear = $dateparts[$y];
-
-					$start_date = date($this->bocommon->dateformat,mktime(2,0,0,$smonth,$sday,$syear));				
-					if ($syear == $eyear)
-					{
-						$end_date = date($this->bocommon->dateformat,mktime(2,0,0,12,31,$eyear));
-						$filtermethod .= " $where (fakturadato >'$start_date' AND fakturadato < '$end_date'"
-								. " AND periode >" . ($smonth -1) . " AND periode <" . ($emonth+1) . ')';						
-					}
-
-					$end_date = date($this->bocommon->dateformat,mktime(2,0,0,$emonth,$eday,$eyear));
-
-
-		/*			$filtermethod .= " $where (fakturadato >'$start_date' AND fakturadato < '$end_date'";
-		
-					if($smonth < 3)
-					{
-						$filtermethod .= " AND periode = 1)";
-					}
-					else
-					{
-						$filtermethod .= ")";
-					}
-		*/	
+					$filtermethod .= " $where (periode >='$start_periode' AND periode <= '$end_periode')";
 				}
 			}
 			else
@@ -206,19 +180,15 @@
 
 			if($query)
 			{
-				$query = preg_replace("/'/",'',$query);
-				$query = preg_replace('/"/','',$query);
-
-				$querymethod = " $where ( spvend_code $this->like '%$query%' OR bilagsnr $this->like '%$query%' )";
+				$query = (int) $query;
+				$querymethod = " $where ( spvend_code = {$query} OR bilagsnr = {$query})";
 			}
 
-
-			$sql = "SELECT bilagsnr, count(bilagsnr) as invoice_count, sum(belop) as belop,spvend_code,fakturadato FROM  $table $join_tables $filtermethod $querymethod group by bilagsnr,spvend_code,fakturadato ";
+			$sql = "SELECT bilagsnr, count(bilagsnr) as invoice_count, sum(belop) as belop,spvend_code,fakturadato FROM  $table $join_tables $filtermethod $querymethod GROUP BY periode, bilagsnr,spvend_code,fakturadato,oppsynsigndato,saksigndato,budsjettsigndato";
 			$sql2 = "SELECT DISTINCT bilagsnr FROM  $table $join_tables $filtermethod $querymethod";
 
-//echo $sql;
-			$this->db2->query($sql2,__LINE__,__FILE__);
-			$this->total_records = $this->db2->num_rows();
+			$this->db->query($sql2,__LINE__,__FILE__);
+			$this->total_records = $this->db->num_rows();
 
 			if(!$allrows)
 			{
@@ -229,6 +199,7 @@
 				$this->db->query($sql . $ordermethod,__LINE__,__FILE__);
 			}
 
+			$temp = array();
 			while ($this->db->next_record())
 			{
 				$temp[] = array
@@ -240,13 +211,13 @@
 			}
 
 			$invoice = array();
-			if (isset($temp) && $temp)
+			if ($temp)
 			{
 				$role= $this->check_role();
 				$i = 0;
 				foreach($temp as $invoice_temp)
 				{
-					$voucher_id=$invoice_temp['voucher_id'];
+					$voucher_id = $invoice_temp['voucher_id'];
 
 					$sql = "SELECT spvend_code,oppsynsmannid,saksbehandlerid,budsjettansvarligid,"
 					. " utbetalingid,oppsynsigndato,saksigndato,budsjettsigndato,utbetalingsigndato,fakturadato,org_name,"
@@ -265,8 +236,6 @@
 
 					if($this->db->f('oppsynsmannid') && $this->db->f('oppsynsigndato'))
 					{
-//						$timestamp_jan_date			= mktime(0,0,0,date(m,strtotime($this->db->f('oppsynsigndato'))),date(d,strtotime($this->db->f('oppsynsigndato'))),date(y,strtotime($this->db->f('oppsynsigndato'))));
-//						$invoice[$i]['jan_date']	= $GLOBALS['phpgw']->common->show_date($timestamp_jan_date,$GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat']);
 						$invoice[$i]['jan_date']=date($GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat'],strtotime($this->db->f('oppsynsigndato')));
 					}
 					else
@@ -275,8 +244,6 @@
 					}
 					if($this->db->f('saksbehandlerid') && $this->db->f('saksigndato'))
 					{
-//						$timestamp_super_date		= mktime(0,0,0,date(m,strtotime($this->db->f('saksigndato'))),date(d,strtotime($this->db->f('saksigndato'))),date(y,strtotime($this->db->f('saksigndato'))));
-//						$invoice[$i]['super_date']	= $GLOBALS['phpgw']->common->show_date($timestamp_super_date,$GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat']);
 						$invoice[$i]['super_date']=date($GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat'],strtotime($this->db->f('saksigndato')));
 					}
 					else
@@ -286,8 +253,6 @@
 
 					if($this->db->f('budsjettansvarligid') && $this->db->f('budsjettsigndato'))
 					{
-//							$timestamp_budget_date		= mktime(0,0,0,date(m,strtotime($this->db->f('budsjettsigndato'))),date(d,strtotime($this->db->f('budsjettsigndato'))),date(y,strtotime($this->db->f('budsjettsigndato'))));
-//							$invoice[$i]['budget_date']	= $GLOBALS['phpgw']->common->show_date($timestamp_budget_date,$GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat']);
 							$invoice[$i]['budget_date']=date($GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat'],strtotime($this->db->f('budsjettsigndato')));
 					}
 					else
@@ -297,8 +262,6 @@
 
 					if($this->db->f('utbetalingid') && $this->db->f('utbetalingsigndato'))
 					{
-//						$timestamp_transfer_date= mktime(0,0,0,date(m,strtotime($this->db->f('utbetalingsigndato'))),date(d,strtotime($this->db->f('utbetalingsigndato'))),date(y,strtotime($this->db->f('utbetalingsigndato'))));
-//						$invoice[$i]['transfer_date']			= $GLOBALS['phpgw']->common->show_date($timestamp_transfer_date,$GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat']);
 						$invoice[$i]['transfer_date']=date($GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat'],strtotime($this->db->f('utbetalingsigndato')));
 					}
 					else
@@ -324,7 +287,7 @@
 					$invoice[$i]['voucher_date'] 			= $GLOBALS['phpgw']->common->show_date($timestamp_voucher_date,$GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat']);
 					$invoice[$i]['payment_date'] 			= $GLOBALS['phpgw']->common->show_date($timestamp_payment_date,$GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat']);
 					$invoice[$i]['period']					= $this->db->f('periode');
-					$invoice[$i]['type']					= $this->db->f('artid');
+					$invoice[$i]['type']					= $art_list[$this->db->f('artid')];
 					$invoice[$i]['kidnr']					= $this->db->f('kidnr');
 					$invoice[$i]['kreditnota']				= $this->db->f('kreditnota');
 					$invoice[$i]['amount']					= $invoice_temp['amount'];
@@ -361,19 +324,12 @@
 		{
 			if(is_array($data))
 			{
-				if ($data['start'])
-				{
-					$start=$data['start'];
-				}
-				else
-				{
-					$start=0;
-				}
-				$filter	= (isset($data['filter'])?$data['filter']:'none');
-				$sort = (isset($data['sort'])?$data['sort']:'DESC');
-				$order = (isset($data['order'])?$data['order']:'');
-				$voucher_id = (isset($data['voucher_id'])?$data['voucher_id']:0);
-				$paid = (isset($data['paid'])?$data['paid']:'');
+				$start		= isset($data['start']) && $data['start'] ? $data['start'] : 0;
+				$filter		= isset($data['filter']) ? $data['filter'] : 'none';
+				$sort		= isset($data['sort']) ? $data['sort'] : 'DESC';
+				$order		= isset($data['order']) ? $data['order'] : '';
+				$voucher_id	= isset($data['voucher_id']) && $data['voucher_id'] ? $data['voucher_id'] : 0;
+				$paid		= isset($data['paid']) ? $data['paid'] : '';
 			}
 
 			if ($paid)
@@ -392,7 +348,7 @@
 			}
 			else
 			{
-				$ordermethod = ' order by bilagsnr DESC';
+				$ordermethod = ' order by id DESC';
 			}
 
 			if ($voucher_id)
@@ -400,48 +356,49 @@
 				$filtermethod = " WHERE ( bilagsnr= '$voucher_id')";
 			}
 
-			$sql = "SELECT $table.*,fm_workorder.status,fm_workorder.charge_tenant,org_name,fm_workorder.claim_issued FROM $table "
-			. " $this->left_join fm_workorder on fm_workorder.id = $table.pmwrkord_code  "
-			. " $this->join fm_vendor  on $table.spvend_code = fm_vendor.id  $filtermethod ";
+			$sql = "SELECT $table.*,fm_workorder.status,fm_workorder.charge_tenant,org_name,fm_workorder.claim_issued, fm_workorder.paid_percent, project_group FROM $table"
+			. " $this->left_join fm_workorder ON fm_workorder.id = $table.pmwrkord_code"
+			. " $this->left_join fm_project ON fm_workorder.project_id = fm_project.id"
+			. " $this->join fm_vendor ON $table.spvend_code = fm_vendor.id $filtermethod";
 
-			$this->db2->query($sql,__LINE__,__FILE__);
-			$this->total_records = $this->db2->num_rows();
-			$this->db->query($sql . $ordermethod,$start,__LINE__,__FILE__);
+			$this->db->query($sql . $ordermethod,__LINE__,__FILE__);
+			$this->total_records = $this->db->num_rows();
 
 			$i = 0;
 
+			$closed = isset($this->config->config_data['workorder_closed_status']) && $this->config->config_data['workorder_closed_status'] ? $this->config->config_data['workorder_closed_status'] : 'closed';
+			$invoice = array();
 			while ($this->db->next_record())
 			{
-				$invoice[$i]['counter']					= $i;
-				$invoice[$i]['claim_issued']			= $this->db->f('claim_issued');
-				$invoice[$i]['project_id']				= $this->db->f('project_id');
-				$invoice[$i]['workorder_id']			= $this->db->f('pmwrkord_code');
-				$invoice[$i]['status']					= $this->db->f('status');
-				if ($this->db->f('status')=='closed')
-				{
-					$invoice[$i]['closed']				= True;
-				}
-				$invoice[$i]['voucher_id']				= $voucher_id;
-				$invoice[$i]['id']						= $this->db->f('id');
-				$invoice[$i]['invoice_id']				= $this->db->f('fakturanr');
-				$invoice[$i]['budget_account']			= $this->db->f('spbudact_code');
-				$invoice[$i]['dima']					= $this->db->f('dima');
-				$invoice[$i]['dimb']					= $this->db->f('dimb');
-				$invoice[$i]['dimd']					= $this->db->f('dimd');
-				if ($this->db->f('merknad'))
-				{
-					$invoice[$i]['remark']				= True;
-				}
-				$invoice[$i]['tax_code']				= $this->db->f('mvakode');
-				$invoice[$i]['amount']					= $this->db->f('belop');
-				$invoice[$i]['charge_tenant']			= $this->db->f('charge_tenant');
-				$invoice[$i]['vendor']					= $this->db->f('org_name');
-				$i++;
+				$invoice[] = array
+				(
+					'counter'				=> $i,
+					'claim_issued'			=> $this->db->f('claim_issued'),
+					'project_id'			=> $this->db->f('project_id'),
+					'workorder_id'			=> $this->db->f('pmwrkord_code'),
+					'status'				=> $this->db->f('status'),
+					'closed'				=> $this->db->f('status') == $closed,
+					'voucher_id'			=> $voucher_id,
+					'id'					=> $this->db->f('id'),
+					'invoice_id'			=> $this->db->f('fakturanr'),
+					'budget_account'		=> $this->db->f('spbudact_code'),
+					'dima'					=> $this->db->f('dima'),
+					'dimb'					=> $this->db->f('dimb'),
+					'dimd'					=> $this->db->f('dimd'),
+					'remark' 				=> !!$this->db->f('merknad'),
+					'tax_code'				=> $this->db->f('mvakode'),
+					'amount'				=> $this->db->f('belop'),
+					'charge_tenant'			=> $this->db->f('charge_tenant'),
+					'vendor'				=> $this->db->f('org_name'),
+					'paid_percent'			=> $this->db->f('paid_percent'),
+					'project_group'			=> $this->db->f('project_group'),
+					'external_ref'			=> $this->db->f('external_ref')
+				);
 
+				$i++;
 			}
 
 			return $invoice;
-
 		}
 
 
@@ -449,49 +406,21 @@
 		{
 			if(is_array($data))
 			{
-				if ($data['start'])
-				{
-					$start=$data['start'];
-				}
-				else
-				{
-					$start=0;
-				}
-				$filter			= (isset($data['filter'])?$data['filter']:'none');
-				$query 			= (isset($data['query'])?$data['query']:'');
-				$sort 			= (isset($data['sort'])?$data['sort']:'DESC');
-				$order 			= (isset($data['order'])?$data['order']:'');
-				$cat_id 		= (isset($data['cat_id'])?$data['cat_id']:0);
-				$start_date 	= (isset($data['start_date'])?$data['start_date']:'');
-				$end_date 		= (isset($data['end_date'])?$data['end_date']:'');
-				$vendor_id 		= (isset($data['vendor_id'])?$data['vendor_id']:'');
-				$loc1 	= (isset($data['loc1'])?$data['loc1']:'');
-				$district_id 	= (isset($data['district_id'])?$data['district_id']:'');
-				$workorder_id 	= (isset($data['workorder_id'])?$data['workorder_id']:0);
-				$b_account_class = (isset($data['b_account_class'])?$data['b_account_class']:'');
+				$start			= isset($data['start']) && $data['start'] ? $data['start'] : 0;
+				$filter			= isset($data['filter'])?$data['filter']:'none';
+				$query 			= isset($data['query'])?$data['query']:'';
+				$sort 			= isset($data['sort'])?$data['sort']:'DESC';
+				$order 			= isset($data['order'])?$data['order']:'';
+				$cat_id 		= isset($data['cat_id']) && $data['cat_id'] ? $data['cat_id']:0;
+				$start_date 	= isset($data['start_date']) && $data['start_date'] ? $data['start_date'] : 0;
+				$end_date 		= isset($data['end_date']) && $data['end_date'] ? $data['end_date'] : time();
+				$vendor_id 		= isset($data['vendor_id'])?$data['vendor_id']:'';
+				$loc1 			= isset($data['loc1'])?$data['loc1']:'';
+				$district_id 	= isset($data['district_id'])?$data['district_id']:'';
+				$workorder_id 	= isset($data['workorder_id']) && $data['workorder_id'] ? $data['workorder_id']:0;
+				$b_account_class = isset($data['b_account_class'])?$data['b_account_class']:'';
+				$b_account		= isset($data['b_account']) ? $data['b_account'] : '';
 			}
-//_debug_array($data);
-
-			$dateformat = strtolower($GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat']);
-			$dateformat = str_replace(".","",$dateformat);
-			$dateformat = str_replace("-","",$dateformat);
-			$dateformat = str_replace("/","",$dateformat);
-			$y=strpos($dateformat,'y');
-			$d=strpos($dateformat,'d');
-			$m=strpos($dateformat,'m');
- 			$dateparts = explode('/', $start_date);
- 			$sday = $dateparts[$d];
- 			$smonth = $dateparts[$m];
- 			$syear = $dateparts[$y];
-
- 			$dateparts = explode('/', $end_date);
- 			$eday = $dateparts[$d];
- 			$emonth = $dateparts[$m];
- 			$eyear = $dateparts[$y];
-
-			$start_date = date($this->bocommon->dateformat,mktime(2,0,0,$smonth,$sday,$syear));
-			$end_date = date($this->bocommon->dateformat,mktime(2,0,0,$emonth,$eday,$eyear));
-
 
 			$where = 'AND';
 
@@ -506,6 +435,16 @@
 				$group_account_class=', spbudact_code,fm_b_account.category';
 			}
 
+			if ($b_account)
+			{
+				$filtermethod .= " {$where} fm_b_account.id = '{$b_account}'";
+				$where= 'AND';
+				$select_account_class=',fm_b_account.id as b_account_class';
+				$group_account_class=', spbudact_code,fm_b_account.id';
+
+			}
+
+
 			if ($vendor_id)
 			{
 				$filtermethod .= " $where (spvend_code = $vendor_id)";
@@ -538,59 +477,44 @@
 				$where= 'AND';
 			}
 
-
-			$year = date("Y",strtotime($start_date));
-			$month = date("m",strtotime($start_date));
-			if($month < 3)
-			{
-				$start_date = date($this->bocommon->dateformat,mktime(2,0,0,3,1,$year));
-			}
-
-			$start_date2 = date($this->bocommon->dateformat,mktime(2,0,0,1,1,$year));
+			$start_periode = date('Ym',$start_date);
+			$end_periode = date('Ym',$end_date);
 
 			$sql = "SELECT district_id,periode,sum(godkjentbelop) as consume $select_account_class "
 				. " FROM  fm_ecobilagoverf $this->join fm_location1 ON (fm_ecobilagoverf.loc1 = fm_location1.loc1) "
 				. " $this->join fm_part_of_town ON (fm_location1.part_of_town_id = fm_part_of_town.part_of_town_id) "
 				. " $this->join fm_b_account ON (fm_ecobilagoverf.spbudact_code = fm_b_account.id) "
-		        	. " WHERE (fakturadato >'$start_date' AND fakturadato < '$end_date' $filtermethod )"
-		        	. " OR (fakturadato >'$start_date2' AND fakturadato < '$end_date'  AND periode < 3  $filtermethod) "
+		        	. " WHERE (periode >='$start_periode' AND periode <= '$end_periode' $filtermethod )"
 		        	. " GROUP BY district_id,periode $group_account_class"
 		        	. " ORDER BY periode";
 //echo $sql;
 
 			$this->db->query($sql,__LINE__,__FILE__);
 			$this->total_records = $this->db->num_rows();
-			$this->db->query($sql . $ordermethod,$start,__LINE__,__FILE__);
 
-			$i = 0;
+			$consume = array();
 
 			while ($this->db->next_record())
 			{
-				$consume[$i]['consume']				= round($this->db->f('consume'));
-				$consume[$i]['period']					= $this->db->f('periode');
-				$consume[$i]['district_id']				= $this->db->f('district_id');
-				if(!$b_account_class)
-				{
-					$consume[$i]['account_class']			= $this->db->f('b_account_class');
-				}
-				else
-				{
-					$consume[$i]['account_class']			= $b_account_class;
-				}
-
-				$i++;
+				$consume[] = array
+				(
+					'consume'		=> round($this->db->f('consume')),
+					'period'		=> $this->db->f('periode'),
+					'district_id'	=> $this->db->f('district_id'),
+					'account_class'	=> $b_account_class ? $b_account_class : $this->db->f('b_account_class')
+				);	
 			}
-//_debug_array($consume);
+
 			return $consume;
 		}
 
 		function check_for_updates($values)
 		{
-			$update=False;
+			$update=false;
 
 			if($values['sign_orig']!=$values['sign'])
 			{
-				$update=True;
+				$update=true;
 				return $update;
 			}
 
@@ -601,13 +525,13 @@
 
 			if( ($this->db->f('utbetalingsigndato') && !$values['transfer']) || (!$this->db->f('utbetalingsigndato') && $values['transfer']))
 			{
-				$update=True;
+				$update=true;
 				return $update;
 			}
 
 			if( ($this->db->f('kreditnota') && !$values['kreditnota']) || (!$this->db->f('kreditnota') && $values['kreditnota']) )
 			{
-				$update=True;
+				$update=true;
 				return $update;
 			}
 
@@ -616,18 +540,18 @@
 
 			if( ((intval(($timestamp_payment_date-$timestamp_voucher_date)/(24*3600)))!=$values['num_days']) )
 			{
-				$update=True;
+				$update=true;
 				return $update;
 			}
 		}
 
 		function update_invoice_sub($values)
 		{
-
+			$receipt = array();
 			$GLOBALS['phpgw']->db->transaction_begin();
 
 			while($entry=each($values['counter']))
-				{
+			{
 					$local_error='';
 
 					$n=$entry[0];
@@ -635,14 +559,13 @@
 
 //_debug_array($entry);
 
-
 				if ($values['budget_account'][$n])
 				{
 					$budget_account=$values['budget_account'][$n];
 
-					$GLOBALS['phpgw']->db->query("select count(*) from fm_b_account  where id =$budget_account");
+					$GLOBALS['phpgw']->db->query("select count(*) as cnt from fm_b_account  where id ='{$budget_account}'");
 					$GLOBALS['phpgw']->db->next_record();
-					if ($GLOBALS['phpgw']->db->f(0) == 0)
+					if ($GLOBALS['phpgw']->db->f('cnt') == 0)
 					{
 						$receipt['error'][] = array('msg'=> lang('This account is not valid:'). " ".$budget_account);
 						$local_error= true;
@@ -661,9 +584,9 @@
 				else
 				{
 					$dimd=$values['dimd'][$n];
-					$GLOBALS['phpgw']->db->query("select count(*) from fm_ecodimd where id ='$dimd'");
+					$GLOBALS['phpgw']->db->query("select count(*) as cnt from fm_ecodimd where id ='$dimd'");
 					$GLOBALS['phpgw']->db->next_record();
-					if ($GLOBALS['phpgw']->db->f(0) == 0)
+					if ($GLOBALS['phpgw']->db->f('cnt') == 0)
 					{
 						$receipt['error'][] = array('msg'=>lang('This Dim D is not valid:'). " ".$dimd);
 						$local_error= true;
@@ -691,7 +614,7 @@
 
 					if (!$GLOBALS['phpgw']->db->f('kostra_id') || $GLOBALS['phpgw']->db->f('kostra_id') == 0)
 					{
-						$receipt['error'][] = array('msg'=>'objektet mangler tjeneste - utgtt? '. " ".$values['dima'][$n]);
+						$receipt['error'][] = array('msg'=>'objektet mangler tjeneste - utgått? '. " ".$values['dima'][$n]);
 						$local_error= true;
 					}
 
@@ -718,6 +641,11 @@
 						$update_status[$workorder_id]='R';
 					}
 
+					if(isset($values['paid_percent'][$n]) && $values['paid_percent'][$n])
+					{
+						$update_paid_percent[$workorder_id] = $values['paid_percent'][$n];
+					}
+
 					$GLOBALS['phpgw']->db->query("UPDATE fm_ecobilag set $dima_field ,$kostra_field,$dimd_field, mvakode = '$tax_code',spbudact_code = '$budget_account',dimb = $dimb where id='$id'");
 
 					$receipt['message'][] = array('msg'=>lang('Voucher is updated '));
@@ -727,18 +655,49 @@
 
 			if (isset($update_status) AND is_array($update_status))
 			{
-				$status_code=array('X'=>'closed','R'=>'re_opened');
+				$closed = isset($this->config->config_data['workorder_closed_status']) && $this->config->config_data['workorder_closed_status'] ? $this->config->config_data['workorder_closed_status'] : 'closed';
+				$reopen = isset($this->config->config_data['workorder_reopen_status']) && $this->config->config_data['workorder_reopen_status'] ? $this->config->config_data['workorder_reopen_status'] : 're_opened';
+
+				$status_code=array('X' => $closed,'R' => $reopen);
 
 				$historylog_workorder	= CreateObject('property.historylog','workorder');
 
-				while (list($id,$entry) = each($update_status))
+				foreach ($update_status as $id => $entry)
 				{
-					$historylog_workorder->add($entry,$id,$status_code[$entry]);
-					$GLOBALS['phpgw']->db->query("UPDATE fm_workorder set status=" . "'$status_code[$entry]'" . "where id=$id");
-					$receipt['message'][] = array('msg'=>lang('Workorder %1 is %2',$id, $status_code[$entry]));
+					$this->db->query("SELECT type FROM fm_orders WHERE id={$id}",__LINE__,__FILE__);
+					$this->db->next_record();
+					switch ( $this->db->f('type') )
+					{
+						case 'workorder':
+						$historylog_workorder->add($entry,$id,$status_code[$entry]);
+						$GLOBALS['phpgw']->db->query("UPDATE fm_workorder set status=" . "'$status_code[$entry]'" . "where id=$id");
+						$receipt['message'][] = array('msg'=>lang('Workorder %1 is %2',$id, $status_code[$entry]));
+					}
 				}
 			}
 
+			if (isset($update_paid_percent) AND is_array($update_paid_percent))
+			{
+				$workorder = CreateObject('property.soworkorder');
+				foreach ($update_paid_percent as $workorder_id => $paid_percent)
+				{
+					$paid_percent = (int) $paid_percent;
+					$GLOBALS['phpgw']->db->query("UPDATE fm_workorder set paid_percent={$paid_percent} WHERE id= $workorder_id");				
+	
+					$this->db->query("SELECT type FROM fm_orders WHERE id={$workorder_id}",__LINE__,__FILE__);
+					$this->db->next_record();
+					switch ( $this->db->f('type') )
+					{
+						case 'workorder':
+							$this->db->query("SELECT project_id FROM fm_workorder WHERE id={$workorder_id}",__LINE__,__FILE__);
+							$this->db->next_record();
+							$project_id = $this->db->f('project_id');
+							$workorder->update_planned_cost($project_id);
+							break;
+					}
+				}
+			}
+			
 			$GLOBALS['phpgw']->db->transaction_commit();
 
 			return $receipt;
@@ -766,10 +725,10 @@
 			if(!isset($this->role) || !$this->role)
 			{
 				$this->role=array(
-					'is_janitor' 				=> $this->acl->check('.invoice',32),
-					'is_supervisor' 			=> $this->acl->check('.invoice',64),
-					'is_budget_responsible' 	=> $this->acl->check('.invoice',128),
-					'is_transfer' 				=> $this->acl->check('.invoice',16)
+					'is_janitor' 				=> $this->acl->check('.invoice', 32, 'property'),
+					'is_supervisor' 			=> $this->acl->check('.invoice', 64, 'property'),
+					'is_budget_responsible' 	=> $this->acl->check('.invoice', 128, 'property'),
+					'is_transfer' 				=> $this->acl->check('.invoice', 16, 'property')
 					);
 			}
 			return $this->role;
@@ -796,6 +755,7 @@
 
 		function update_period($voucher_id='',$period='')
 		{
+			$receipt = array();
 			$this->db->transaction_begin();
 
 			$this->db->query("UPDATE fm_ecobilag set periode='$period' where bilagsnr='$voucher_id'");
@@ -809,18 +769,15 @@
 
 		function increment_bilagsnr()
 		{
-
 			$this->db->query("UPDATE fm_idgenerator set value = value + 1 where name = 'Bilagsnummer'");
 			$this->db->query("select value from fm_idgenerator where name = 'Bilagsnummer'");
 			$this->db->next_record();
 			$bilagsnr = $this->db->f('value');
 			return $bilagsnr;
-
 		}
 
 		function next_bilagsnr()
 		{
-
 			$this->db->query("select value from fm_idgenerator where name = 'Bilagsnummer'");
 			$this->db->next_record();
 			$bilagsnr = $this->db->f('value')+1;
@@ -830,16 +787,16 @@
 
 		function check_vendor($vendor_id)
 		{
-
-			$this->db->query("select count(*) from fm_vendor where id='$vendor_id'");
+			$this->db->query("select count(*) as cnt from fm_vendor where id='$vendor_id'");
 			$this->db->next_record();
-			return $this->db->f(0);
+			return $this->db->f('cnt');
 		}
 
 
 		function tax_code_list($selected='')
 		{
 			$this->db->query("SELECT * FROM fm_ecomva order by id asc ");
+			$tax_code_list = array();
 			while ($this->db->next_record())
 			{
 				$tax_code_list[] = Array(
@@ -854,6 +811,7 @@
 		function get_lisfm_ecoart()
 		{
 			$this->db->query("SELECT * FROM fm_ecoart order by id asc ");
+			$art_list = array();
 			while ($this->db->next_record())
 			{
 				$art_list[] = Array(
@@ -870,20 +828,22 @@
 		function get_type_list()
 		{
 			$this->db->query("SELECT * FROM fm_ecobilag_category order by id asc ");
+			$category = array();
 			while ($this->db->next_record())
 			{
-				$art_list[] = Array(
+				$category[] = Array(
 					'id'        => $this->db->f('id'),
 					'name'       => $this->db->f('descr')
 				);
 			}
-			return $art_list;
+			return $category;
 		}
 
 	//----------
 		function select_dimb_list()
 		{
 			$this->db->query("SELECT * FROM fm_ecodimb order by id asc ");
+			$dimb_list = array();
 			while ($this->db->next_record())
 			{
 				$dimb_list[] = Array(
@@ -898,6 +858,7 @@
 		function select_dimd_list()
 		{
 			$this->db->query("SELECT * FROM fm_ecodimd order by id asc ");
+			$dimd_list = array();
 			while ($this->db->next_record())
 			{
 				$dimd_list[] = Array(
@@ -912,6 +873,7 @@
 		function select_tax_code_list()
 		{
 			$this->db->query("SELECT * FROM fm_ecomva order by id asc ");
+			$tax_code_list = array();
 			while ($this->db->next_record())
 			{
 				$tax_code_list[] = Array(
@@ -927,6 +889,7 @@
 			$sql = "SELECT id from fm_b_account_category order by id";
 			$this->db->query($sql,__LINE__,__FILE__);
 
+			$class = array();
 			while ($this->db->next_record())
 			{
 				$class[] = Array(
@@ -944,9 +907,10 @@
 
 		function read_single_voucher($bilagsnr)
 		{
-			$sql = "SELECT * from fm_ecobilag WHERE bilagsnr ='$bilagsnr'";		
+			$sql = "SELECT * from fm_ecobilag WHERE bilagsnr ='$bilagsnr'";
 			$this->db->query($sql,__LINE__,__FILE__);
 
+			$values = array();
 			while ($this->db->next_record())
 			{
 				$values[] = Array(
@@ -1062,63 +1026,63 @@
 							$sign_field = 'oppsynsmannid=';
 							$sign_id = "'$user_lid'";
 							$sign_date_field = 'oppsynsigndato=';
-							$sign_date="'" . date($this->bocommon->datetimeformat) . "'";
+							$sign_date="'" . date($this->db->datetime_format()) . "'";
 							$kommma=",";
 						elseif ($values['sign'][$n]=='sign_janitor' && $values['sign_orig'][$n]=='sign_supervisor'):
 							$blank_date = 'saksigndato= NULL';
 							$sign_field = 'oppsynsmannid=';
 							$sign_id = "'$user_lid'";
 							$sign_date_field = 'oppsynsigndato=';
-							$sign_date="'" . date($this->bocommon->datetimeformat) . "'";
+							$sign_date="'" . date($this->db->datetime_format()) . "'";
 							$kommma=",";
 						elseif ($values['sign'][$n]=='sign_janitor' && $values['sign_orig'][$n]=='sign_budget_responsible'):
 							$blank_date = 'budsjettsigndato= NULL';
 							$sign_field = 'oppsynsmannid=';
 							$sign_id = "'$user_lid'";
 							$sign_date_field = 'oppsynsigndato=';
-							$sign_date="'" . date($this->bocommon->datetimeformat) . "'";
+							$sign_date="'" . date($this->db->datetime_format()) . "'";
 							$kommma=",";
 						elseif ($values['sign'][$n]=='sign_supervisor' && !$values['sign_orig'][$n]):
 							$blank_date = '';
 							$sign_field = 'saksbehandlerid=';
 							$sign_id = "'$user_lid'";
 							$sign_date_field = 'saksigndato=';
-							$sign_date="'" . date($this->bocommon->datetimeformat) . "'";
+							$sign_date="'" . date($this->db->datetime_format()) . "'";
 							$kommma=",";
 						elseif ($values['sign'][$n]=='sign_supervisor' && $values['sign_orig'][$n]=='sign_janitor'):
 							$blank_date = 'oppsynsigndato= NULL';
 							$sign_field = 'saksbehandlerid=';
 							$sign_id = "'$user_lid'";
 							$sign_date_field = 'saksigndato=';
-							$sign_date="'" . date($this->bocommon->datetimeformat) . "'";
+							$sign_date="'" . date($this->db->datetime_format()) . "'";
 							$kommma=",";
 						elseif ($values['sign'][$n]=='sign_supervisor' && $values['sign_orig'][$n]=='sign_budget_responsible'):
 							$blank_date = 'budsjettsigndato= NULL';
 							$sign_field = 'saksbehandlerid=';
 							$sign_id = "'$user_lid'";
 							$sign_date_field = 'saksigndato=';
-							$sign_date="'" . date($this->bocommon->datetimeformat) . "'";
+							$sign_date="'" . date($this->db->datetime_format()) . "'";
 							$kommma=",";
 						elseif ($values['sign'][$n]=='sign_budget_responsible' && $values['sign_orig'][$n]=='sign_janitor'):
 							$blank_date = 'oppsynsigndato= NULL';
 							$sign_field = 'budsjettansvarligid=';
 							$sign_id = "'$user_lid'";
 							$sign_date_field = 'budsjettsigndato=';
-							$sign_date="'" . date($this->bocommon->datetimeformat) . "'";
+							$sign_date="'" . date($this->db->datetime_format()) . "'";
 							$kommma=",";
 						elseif ($values['sign'][$n]=='sign_budget_responsible' && $values['sign_orig'][$n]=='sign_supervisor'):
 							$blank_date = 'saksigndato= NULL';
 							$sign_field = 'budsjettansvarligid=';
 							$sign_id = "'$user_lid'";
 							$sign_date_field = 'budsjettsigndato=';
-							$sign_date="'" . date($this->bocommon->datetimeformat) . "'";
+							$sign_date="'" . date($this->db->datetime_format()) . "'";
 							$kommma=",";
 						elseif ($values['sign'][$n]=='sign_budget_responsible' && !$values['sign_orig'][$n]):
 							$blank_date = '';
 							$sign_field = 'budsjettansvarligid=';
 							$sign_id = "'$user_lid'";
 							$sign_date_field = 'budsjettsigndato=';
-							$sign_date="'" . date($this->bocommon->datetimeformat) . "'";
+							$sign_date="'" . date($this->db->datetime_format()) . "'";
 							$kommma=",";
 						endif;
 
@@ -1137,7 +1101,7 @@
 
 						if (!($values['num_days_orig'][$n]==$values['num_days'][$n]))
 						{
-							$payment_date = date($this->bocommon->dateformat,$values['timestamp_voucher_date'][$n]+(24*3600*$values['num_days'][$n]));
+							$payment_date = date($this->db->date_format(),$values['timestamp_voucher_date'][$n]+(24*3600*$values['num_days'][$n]));
 							$GLOBALS['phpgw']->db->query("UPDATE fm_ecobilag set forfallsdato= '$payment_date' where bilagsnr='$voucher_id'");
 						}
 
@@ -1149,14 +1113,13 @@
 							if ($this->check_for_transfer($voucher_id))
 							{
 								$transfer_id="'$user_lid',";
-								$transfer_date="'" . date($this->bocommon->datetimeformat) . "'";
+								$transfer_date="'" . date($this->db->datetime_format()) . "'";
 							}
 							else
 							{
 								$receipt['error'][] = array('msg'=>'Dette bilaget er ikkje godkjent: ' . " ".$voucher_id);
 								$local_error= true;
 							}
-
 						}
 
 						if ($values['kreditnota'][$n])
@@ -1171,35 +1134,49 @@
 
 						if (! $local_error)
 						{
-							$sql= "UPDATE fm_ecobilag set $blank_date $kommma_blank $sign_field $sign_id $kommma $sign_date_field $sign_date $kommma $transfer_sign_field $transfer_id $transfer_date_field $transfer_date ,kreditnota=$wait_for_kreditnota  where bilagsnr='$voucher_id'";
+							$sql= "UPDATE fm_ecobilag SET $blank_date $kommma_blank $sign_field $sign_id $kommma $sign_date_field $sign_date $kommma $transfer_sign_field $transfer_id $transfer_date_field $transfer_date ,kreditnota=$wait_for_kreditnota  where bilagsnr='$voucher_id'";
 							$GLOBALS['phpgw']->db->transaction_begin();
 							$GLOBALS['phpgw']->db->query($sql);
-							$GLOBALS['phpgw']->db->transaction_commit();
-
-							$receipt['message'][] = array('msg'=> lang('voucher is updated: ') . $voucher_id);
+							if($GLOBALS['phpgw']->db->transaction_commit())
+							{
+								$receipt['message'][] = array('msg'=> lang('voucher is updated: ') . $voucher_id);
+							}
 						}
 					}
 				}
 			}
 
 			$GLOBALS['phpgw']->db->query("UPDATE fm_ecobilag set utbetalingid = NULL, utbetalingsigndato = NULL WHERE budsjettsigndato IS NULL");
-			$GLOBALS['phpgw']->db->query("UPDATE fm_ecobilag set utbetalingid = NULL, utbetalingsigndato = NULL WHERE oppsynsigndato IS NULL AND saksigndato IS NULL");
+			if($this->invoice_approval == 2)
+			{
+				$GLOBALS['phpgw']->db->query("UPDATE fm_ecobilag set utbetalingid = NULL, utbetalingsigndato = NULL WHERE oppsynsigndato IS NULL AND saksigndato IS NULL");
+			}
 
 			return $receipt;
 		}
 
 		function check_for_transfer($voucher_id='')
 		{
-			$allow_transfer=False;
+			$allow_transfer=false;
 
 			$sql = "SELECT * FROM fm_ecobilag WHERE bilagsnr='$voucher_id'";
 			$this->db->limit_query($sql,0,__LINE__,__FILE__,1);
 
 			$this->db->next_record();
 
-			if ($this->db->f('budsjettsigndato') && ($this->db->f('oppsynsigndato') || $this->db->f('saksigndato')))
+			if($this->invoice_approval == 1)
 			{
-				$allow_transfer=True;
+				if ($this->db->f('budsjettsigndato'))
+				{
+					$allow_transfer=true;
+				}			
+			}
+			else
+			{
+				if ($this->db->f('budsjettsigndato') && ($this->db->f('oppsynsigndato') || $this->db->f('saksigndato')))
+				{
+					$allow_transfer=true;
+				}
 			}
 
 			return $allow_transfer;
@@ -1207,11 +1184,11 @@
 
 		function check_claim($voucher_id='')
 		{
-			$sql = "SELECT count(*) FROM fm_ecobilag $this->left_join fm_workorder on fm_ecobilag.pmwrkord_code = fm_workorder.id "
+			$sql = "SELECT count(*) as cnt FROM fm_ecobilag $this->left_join fm_workorder on fm_ecobilag.pmwrkord_code = fm_workorder.id "
 			. " WHERE bilagsnr='$voucher_id' AND fm_workorder.charge_tenant=1 AND fm_workorder.claim_issued IS NULL";
 			$this->db->query($sql,__LINE__,__FILE__);
 			$this->db->next_record();
-			return $this->db->f(0);
+			return $this->db->f('cnt');
 		}
 	}
-?>
+
