@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage agreement
- 	* @version $Id: class.sor_agreement.inc.php 18358 2007-11-27 04:43:37Z skwashd $
+ 	* @version $Id: class.sor_agreement.inc.php 4709 2010-02-02 15:18:50Z sigurd $
 	*/
 
 	/**
@@ -36,17 +36,15 @@
 	{
 		var $role;
 
-		function property_sor_agreement()
+		function __construct()
 		{
-		//	$this->currentapp	= $GLOBALS['phpgw_info']['flags']['currentapp'];
 			$this->account	= $GLOBALS['phpgw_info']['user']['account_id'];
-			$this->bocommon		= CreateObject('property.bocommon');
-			$this->db           	= $this->bocommon->new_db();
-			$this->db2           	= $this->bocommon->new_db();
+			$this->db           = & $GLOBALS['phpgw']->db;
+			$this->db2          = clone($this->db);
 
-			$this->join			= $this->bocommon->join;
-			$this->left_join	= $this->bocommon->left_join;
-			$this->like			= $this->bocommon->like;
+			$this->join			= $this->db->join;
+			$this->left_join	= $this->db->left_join;
+			$this->like			= $this->db->like;
 		}
 
 		function select_vendor_list()
@@ -81,7 +79,7 @@
 				$r_agreement_id	= (isset($data['r_agreement_id'])?$data['r_agreement_id']:'');
 				$detail			= (isset($data['detail'])?$data['detail']:'');
 				$loc1			= (isset($data['loc1'])?$data['loc1']:'');
-				
+
 			}
 
 			$choice_table = 'phpgw_cust_choice';
@@ -91,7 +89,8 @@
 			{
 				$entity_table = 'fm_r_agreement';
 				$category_table = 'fm_r_agreement_category';
-				$attribute_filter = " appname = 'property' AND location = '.r_agreement'";
+				$location_id = $GLOBALS['phpgw']->locations->get_id('property', '.r_agreement'); 
+				$attribute_filter = " location_id = {$location_id}";
 
 				$paranthesis .='(';
 				$joinmethod .= " $this->join $category_table ON ( $entity_table.category =$category_table.id))";
@@ -102,8 +101,8 @@
 				{
 					$paranthesis .='(';
 					$joinmethod .= " $this->join fm_r_agreement_item ON ( $entity_table.id =fm_r_agreement_item.agreement_id))";
-					
-				
+
+
 					$cols .= ",location_code";
 				}
 `*/
@@ -150,9 +149,10 @@
 			}
 			else
 			{
-				$allrows=True;
+				$allrows=true;
 				$entity_table = 'fm_r_agreement_item';
-				$attribute_filter = " appname = 'property' AND location = '.r_agreement.detail'";
+				$location_id = $GLOBALS['phpgw']->locations->get_id('property', '.r_agreement.detail'); 
+				$attribute_filter = " location_id = {$location_id}";
 
 				$paranthesis .='(';
 				$joinmethod .= " $this->join  fm_r_agreement_item_history ON ( $entity_table.agreement_id =fm_r_agreement_item_history.agreement_id AND $entity_table.id =fm_r_agreement_item_history.item_id))";
@@ -176,8 +176,8 @@
 				$cols_return[] 			= 'id';
 				$uicols['input_type'][]		= 'hidden';
 				$uicols['name'][]		= 'id';
-				$uicols['descr'][]			= False;
-				$uicols['statustext'][]		= False;
+				$uicols['descr'][]			= false;
+				$uicols['statustext'][]		= false;
 
 				$cols_return[] 			= 'location_code';
 				$uicols['input_type'][]		= 'text';
@@ -332,12 +332,12 @@
 				while ($this->db->next_record())
 				{
 					$filter_id[]			= $this->db->f('agreement_id');
-	
+
 				}
 
 				if(is_array($filter_id))
 				{
-					$filtermethod .= " $where $entity_table.id in (" . implode(',', $filter_id)  .")";	
+					$filtermethod .= " $where $entity_table.id in (" . implode(',', $filter_id)  .")";
 					$where= 'AND';
 				}
 			}
@@ -354,7 +354,7 @@
 				$query = preg_replace("/'/",'',$query);
 				$query = preg_replace('/"/','',$query);
 
-				$this->db->query("SELECT * FROM $attribute_table where search='1'");
+				$this->db->query("SELECT * FROM $attribute_table WHERE search=1 AND $attribute_filter");
 
 				while ($this->db->next_record())
 				{
@@ -449,10 +449,16 @@
 					}
 					else if($cols_return_extra[$i]['datatype']=='D' && $value)
 					{
-//html_print_r($value);
-
 						$r_agreement_list[$j][$cols_return_extra[$i]['name']]=date($GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat'],strtotime($value));
 					}
+					else if($cols_return_extra[$i]['datatype']=='timestamp' && $value)
+					{
+						$r_agreement_list[$j][$cols_return_extra[$i]['name']]=date($GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat'],$value);
+					}
+					else if($cols_return_extra[$i]['datatype']=='link' && $value)
+					{
+						$r_agreement_list[$j][$cols_return_extra[$i]['name']]= phpgw::safe_redirect($value);
+					}
 					else
 					{
 						$r_agreement_list[$j][$cols_return_extra[$i]['name']]=$value;
@@ -488,8 +494,8 @@
 			$cols_return[] 			= 'id';
 			$uicols['input_type'][]		= 'hidden';
 			$uicols['name'][]			= 'id';
-			$uicols['descr'][]			= False;
-			$uicols['statustext'][]		= False;
+			$uicols['descr'][]			= false;
+			$uicols['statustext'][]		= false;
 
 			$cols_return[] 			= 'cost';
 			$uicols['input_type'][]		= 'text';
@@ -587,9 +593,9 @@
 			$this->db->query("SELECT first_name,last_name FROM fm_tenant WHERE id = $id");
 			$this->db->next_record();
 			return stripslashes($this->db->f('first_name')) . ' ' . stripslashes($this->db->f('last_name'));
-		
+
 		}
-		
+
 		function read_single($r_agreement_id, $values = array())
 		{
 			$table = 'fm_r_agreement';
@@ -645,7 +651,7 @@
 				$values['cost']					= $this->db->f('cost');
 				$values['tenant_id']			= $this->db->f('tenant_id');
 				$values['rental_type_id']		= $this->db->f('rental_type_id');
-					
+
 				if ( isset($values['attributes']) && is_array($values['attributes']) )
 				{
 					foreach ( $values['attributes'] as &$attr )
@@ -671,7 +677,7 @@
 
 
 			$this->db->transaction_begin();
-			$id = $this->bocommon->next_id('fm_r_agreement');
+			$id = $this->db->next_id('fm_r_agreement');
 
 			$vals[]	= $id;
 			$vals[]	= $r_agreement['name'];
@@ -716,7 +722,7 @@
 				$cols	= "," . implode(",", $cols);
 			}
 
-			$vals	= $this->bocommon->validate_db_insert($vals);
+			$vals	= $this->db->validate_insert($vals);
 
 			$this->db->query("INSERT INTO $table (id,name,descr,entry_date,category,member_of,start_date,end_date,termination_date,customer_id,customer_name,account_id,user_id $cols) "
 				. "VALUES ($vals)",__LINE__,__FILE__);
@@ -740,7 +746,7 @@
 			$vals[] = $values['location_code'];
 			$cols[] = 'rental_type_id';
 			$vals[] = $values['rental_type_id'];
-			
+
 /*			while (is_array($values['location']) && list($input_name,$value) = each($values['location']))
 			{
 				if($value)
@@ -794,11 +800,11 @@
 			if($cols)
 			{
 				$cols	= "," . implode(",", $cols);
-				$vals	= "," . $this->bocommon->validate_db_insert($vals);
+				$vals	= "," . $this->db->validate_insert($vals);
 			}
 
 			$this->db->transaction_begin();
-			$id = $this->bocommon->next_id($table,array('agreement_id'=>$values['r_agreement_id']));
+			$id = $this->db->next_id($table,array('agreement_id'=>$values['r_agreement_id']));
 
 			$this->db->query("INSERT INTO $table (id,agreement_id,entry_date,user_id $cols) "
 				. "VALUES ($id," . $values['r_agreement_id'] ."," . time()
@@ -815,7 +821,7 @@
 			else
 			{
 				$start_date	= $values['start_date'];
-			
+
 			}
 
 			if ($values['end_date'])
@@ -885,7 +891,7 @@
 			$value_set['customer_name']= $values['customer_name'];
 			if($value_set)
 			{
-				$value_set	= ',' . $this->bocommon->validate_db_update($value_set);
+				$value_set	= ',' . $this->db->validate_update($value_set);
 			}
 
 			$this->db->query("UPDATE $table set entry_date='" . time() . "', category='"
@@ -943,11 +949,11 @@
 			$value_set['cost']	= $values['cost'];
 			$value_set['address']	= $address;
 			$value_set['rental_type_id']	= $values['rental_type_id'];
-			
-			
+
+
 			if($value_set)
 			{
-				$value_set	= ',' . $this->bocommon->validate_db_update($value_set);
+				$value_set	= ',' . $this->db->validate_update($value_set);
 			}
 
 			$this->db->query("UPDATE $table set entry_date=" . time() . "$value_set WHERE agreement_id=" . intval($values['r_agreement_id']) . ' AND id=' . intval($values['id']));
@@ -974,7 +980,7 @@
 				$this->db->query("SELECT tenant_id,to_date from fm_r_agreement_item_history WHERE agreement_id=" . intval($values['agreement_id']) . ' AND item_id=' . intval($item_id) . ' AND id=' . intval($values['id'][$item_id]));
 
 				$this->db->next_record();
-				
+
 				if(!$values['tenant_id'])
 				{
 					$values['tenant_id'] = $this->db->f('tenant_id');
@@ -983,7 +989,7 @@
 				if ($values['start_date'])
 				{
 					$start_date = $values['start_date'];
-					if($start_date < $this->db->f('to_date')) 
+					if($start_date < $this->db->f('to_date'))
 					{
 						$start_date = $this->db->f('to_date') + (3600 * 24);
 					}
@@ -992,7 +998,7 @@
 				{
 					$start_date	= $this->db->f('to_date') + (3600 * 24);
 				}
-	
+
 				if ($values['end_date'])
 				{
 					$end_date = $values['end_date'];
@@ -1083,10 +1089,10 @@
 			$vals[] = $this->db->db_addslashes($values['remark']);
 
 			$cols	= "," . implode(",", $cols);
-			$vals	= "," . $this->bocommon->validate_db_insert($vals);
+			$vals	= "," . $this->db->validate_insert($vals);
 
 			$this->db->transaction_begin();
-			$c_id = $this->bocommon->next_id($table,array('agreement_id'=>$values['r_agreement_id']));
+			$c_id = $this->db->next_id($table,array('agreement_id'=>$values['r_agreement_id']));
 
 			$this->db->query("INSERT INTO $table (id,agreement_id,entry_date,user_id $cols) "
 				. "VALUES ($c_id," . $values['r_agreement_id'] ."," . time()
@@ -1135,14 +1141,14 @@
 			$table = 'fm_r_agreement_c_history';
 
 			$this->db->transaction_begin();
-			$id = $this->bocommon->next_id($table,array('agreement_id'=>$values['r_agreement_id'],'c_id' =>$values['c_id']));
+			$id = $this->db->next_id($table,array('agreement_id'=>$values['r_agreement_id'],'c_id' =>$values['c_id']));
 
 			$this->db->query("SELECT from_date, to_date FROM $table WHERE agreement_id=" . $values['r_agreement_id'] . " AND c_id=" . $values['c_id'] . " AND id =" .($id-1),__LINE__,__FILE__);
 			$this->db->next_record();
 			if ($values['start_date'])
 			{
 				$start_date = $values['start_date'];
-				if($start_date < $this->db->f('to_date')) 
+				if($start_date < $this->db->f('to_date'))
 				{
 					$start_date = $this->db->f('to_date') + (3600 * 24);
 				}
@@ -1166,7 +1172,7 @@
 				. "VALUES (" . $values['r_agreement_id'] . "," . $values['c_id'] . "," . $id .",1," . $this->floatval($values['budget_cost']) . "," . $start_date . "," . $end_date
 				. "," . $this->account . "," . $this->floatval($values['override_fraction']) .")",__LINE__,__FILE__);
 
-			
+
 			$this->db->query("UPDATE fm_r_agreement_c_history set current_record = NULL WHERE agreement_id =" . $values['r_agreement_id'] . 'AND c_id=' . $values['c_id'] . 'AND id=' . ($id-1),__LINE__,__FILE__);
 			$receipt['r_agreement_id']= $values['r_agreement_id'];
 			$receipt['c_id']= $values['c_id'];
@@ -1186,7 +1192,7 @@
 			. " ON ( fm_r_agreement_common.agreement_id =fm_r_agreement_c_history.agreement_id "
 			. " AND fm_r_agreement_common.id =fm_r_agreement_c_history.c_id)"
 			. " WHERE  fm_r_agreement_common.agreement_id = $agreement_id AND current_record = 1 ORDER BY fm_r_agreement_c_history.c_id ASC";
-		
+
 			$this->db->query($sql,__LINE__,__FILE__);
 
 			$this->total_records = $this->db->num_rows();
@@ -1231,7 +1237,7 @@
 				);
 			}
 			return $common;
-		}	
+		}
 
 		function read_common_history($data)
 		{
@@ -1240,7 +1246,7 @@
 				$r_agreement_id	= (isset($data['r_agreement_id'])?$data['r_agreement_id']:0);
 				$c_id	= (isset($data['c_id'])?$data['c_id']:0);
 			}
-			
+
 			$table = 'fm_r_agreement_common';
 //echo $sql;
 			$sql ="SELECT b_account,budget_cost, actual_cost,fm_r_agreement_c_history.id,from_date,"
@@ -1249,7 +1255,7 @@
 			. " ON ( fm_r_agreement_common.agreement_id =fm_r_agreement_c_history.agreement_id "
 			. " AND fm_r_agreement_common.id =fm_r_agreement_c_history.c_id)"
 			. " WHERE  fm_r_agreement_common.agreement_id = $r_agreement_id AND c_id=$c_id ORDER BY fm_r_agreement_c_history.c_id ASC";
-		
+
 			$this->db->query($sql,__LINE__,__FILE__);
 
 			$this->total_records = $this->db->num_rows();
@@ -1281,4 +1287,4 @@
 			$this->db->transaction_commit();
 		}
 	}
-?>
+
