@@ -24,9 +24,11 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage agreement
- 	* @version $Id: class.sos_agreement.inc.php,v 1.29 2007/08/12 09:30:50 sigurdne Exp $
+ 	* @version $Id: class.sos_agreement.inc.php 4709 2010-02-02 15:18:50Z sigurd $
 	*/
 
+	phpgw::import_class('phpgwapi.datetime');
+
 	/**
 	 * Description
 	 * @package property
@@ -35,18 +37,18 @@
 	class property_sos_agreement
 	{
 		var $role;
+		var $uicols = array();
 
-		function property_sos_agreement()
+		function __construct()
 		{
-		//	$this->currentapp	= $GLOBALS['phpgw_info']['flags']['currentapp'];
 			$this->account	= $GLOBALS['phpgw_info']['user']['account_id'];
-			$this->bocommon		= CreateObject('property.bocommon');
-			$this->db           	= $this->bocommon->new_db();
-			$this->db2           	= $this->bocommon->new_db();
+			$this->socommon		= CreateObject('property.socommon');
+			$this->db           = & $GLOBALS['phpgw']->db;
+			$this->db2          = clone($this->db);
 
-			$this->join			= $this->bocommon->join;
-			$this->left_join	= $this->bocommon->left_join;
-			$this->like			= $this->bocommon->like;
+			$this->join			= & $this->db->join;
+			$this->left_join	= & $this->db->left_join;
+			$this->like			= & $this->db->like;
 		}
 
 		function select_vendor_list()
@@ -88,10 +90,11 @@
 			{
 				$entity_table = 'fm_s_agreement';
 				$category_table = 'fm_s_agreement_category';
-				$attribute_filter = " appname = 'property' AND location = '.s_agreement'";
+				$location_id = $GLOBALS['phpgw']->locations->get_id('property', '.s_agreement'); 
+				$attribute_filter = " location_id = {$location_id}";
 
-				$paranthesis .='(';
-				$joinmethod .= " $this->join $category_table ON ( $entity_table.category =$category_table.id))";
+				$paranthesis ='(';
+				$joinmethod = " $this->join $category_table ON ( $entity_table.category =$category_table.id))";
 				$paranthesis .='(';
 				$joinmethod .= " $this->left_join fm_vendor ON ( $entity_table.vendor_id =fm_vendor.id))";
 
@@ -136,9 +139,10 @@
 			}
 			else
 			{
-				$allrows=True;
+				$allrows=true;
 				$entity_table = 'fm_s_agreement_detail';
-				$attribute_filter = " appname = 'property' AND location = '.s_agreement.detail'";
+				$location_id = $GLOBALS['phpgw']->locations->get_id('property', '.s_agreement.detail'); 
+				$attribute_filter = " location_id = {$location_id}";
 
 				$paranthesis .='(';
 				$joinmethod .= " $this->join  fm_s_agreement_pricing ON ( $entity_table.agreement_id =fm_s_agreement_pricing.agreement_id AND $entity_table.id =fm_s_agreement_pricing.item_id))";
@@ -162,8 +166,8 @@
 				$cols_return[] 				= 'id';
 				$uicols['input_type'][]		= 'hidden';
 				$uicols['name'][]			= 'id';
-				$uicols['descr'][]			= False;
-				$uicols['statustext'][]		= False;
+				$uicols['descr'][]			= false;
+				$uicols['statustext'][]		= false;
 				$uicols['import'][]			= false;
 
 				$cols_return[] 				= 'location_code';
@@ -184,14 +188,14 @@
 				$uicols['input_type'][]		= 'text';
 				$uicols['name'][]			= 'p_entity_id';
 				$uicols['descr'][]			= 'entity_id';
-				$uicols['statustext'][]		= False;
+				$uicols['statustext'][]		= false;
 				$uicols['import'][]			= true;
 
 				$cols_return[] 				= 'p_cat_id';
 				$uicols['input_type'][]		= 'text';
 				$uicols['name'][]			= 'p_cat_id';
 				$uicols['descr'][]			= 'cat_id';
-				$uicols['statustext'][]		= False;
+				$uicols['statustext'][]		= false;
 				$uicols['import'][]			= true;
 
 				$cols_return[] 				= 'p_num';
@@ -230,15 +234,13 @@
 				$uicols['import'][]			= false;
 			}
 
-			$from .= " FROM $paranthesis $entity_table ";
-
-			$sql = "SELECT $cols $from $joinmethod";
+			$sql = "SELECT $cols FROM $paranthesis $entity_table $joinmethod";
 
 			$i	= count($uicols['name']);
 
-			$user_columns=$GLOBALS['phpgw_info']['user']['preferences']['property']['s_agreement_columns' . !!$s_agreement_id];
+			$user_columns = isset($GLOBALS['phpgw_info']['user']['preferences']['property']['s_agreement_columns' . !!$s_agreement_id]) ? $GLOBALS['phpgw_info']['user']['preferences']['property']['s_agreement_columns' . !!$s_agreement_id] :'';
 			$user_column_filter = '';
-			if (isset($user_columns) AND is_array($user_columns) AND $user_columns[0])
+			if (is_array($user_columns) && $user_columns[0])
 			{
 				$user_column_filter = " OR ($attribute_filter AND id IN (" . implode(',',$user_columns) .'))';
 			}
@@ -263,7 +265,7 @@
 			}
 
 			$this->uicols	= $uicols;
-			
+
 			if(!$s_agreement_id > 0 && $detail)
 			{
 				return;
@@ -286,6 +288,7 @@
 				$ordermethod = " order by $entity_table.id DESC";
 			}
 
+			$filtermethod = '';
 			$where= 'WHERE';
 
 /*			if ($filter=='all')
@@ -333,36 +336,37 @@
 				$filtermethod .= " $where $entity_table.member_of $this->like '%,$member_id,%' ";
 				$where= 'AND';
 			}
-	
-			if ($status)
+
+/*			if ($status)
 			{
 				$filtermethod .= " $where $entity_table.status='$status' ";
 				$where= 'AND';
 			}
+*/
 
-
+			$querymethod = '';
 			if($query)
 			{
 				$query = preg_replace("/'/",'',$query);
 				$query = preg_replace('/"/','',$query);
-
+				$query_arr = array();
 				$this->db->query("SELECT * FROM $attribute_table WHERE search='1' AND $attribute_filter");
 
 				while ($this->db->next_record())
 				{
 					if($this->db->f('datatype')=='V' || $this->db->f('datatype')=='email' || $this->db->f('datatype')=='CH')
 					{
-						$querymethod[]= "$entity_table." . $this->db->f('column_name') . " $this->like '%$query%'";
+						$query_arr[]= "$entity_table." . $this->db->f('column_name') . " $this->like '%$query%'";
 					}
 					else
 					{
-						$querymethod[]= "$entity_table." . $this->db->f('column_name') . " = '$query'";
+						$query_arr[]= "$entity_table." . $this->db->f('column_name') . " = '$query'";
 					}
 				}
 
-				if (isset($querymethod) AND is_array($querymethod))
+				if (isset($query_arr[0]))
 				{
-					$querymethod = " $where (" . implode (' OR ',$querymethod) . ')';
+					$querymethod = " $where (" . implode (' OR ',$query_arr) . ')';
 					$where = 'AND';
 				}
 			}
@@ -392,63 +396,72 @@
 				for ($i=0;$i<$n;$i++)
 				{
 					$s_agreement_list[$j][$cols_return[$i]] = stripslashes($this->db->f($cols_return[$i]));
-					$s_agreement_list[$j]['grants'] = (int)$grants[$this->db->f('user_id')];
+				//	$s_agreement_list[$j]['grants'] = (int)$grants[$this->db->f('user_id')];
 				}
 
-				for ($i=0;$i<count($cols_return_extra);$i++)
+				if(isset($cols_return_extra) && is_array($cols_return_extra))
 				{
-					$value='';
-					$value=$this->db->f($cols_return_extra[$i]['name']);
+					foreach ($cols_return_extra as $return_extra)
+					{
+						$value='';
+						$value=$this->db->f($return_extra['name']);
 
-					if(($cols_return_extra[$i]['datatype']=='R' || $cols_return_extra[$i]['datatype']=='LB') && $value)
-					{
-						$sql="SELECT value FROM $choice_table WHERE $attribute_filter AND attrib_id=" .$cols_return_extra[$i]['attrib_id']. "  AND id=" . $value;
-						$this->db2->query($sql);
-						$this->db2->next_record();
-						$s_agreement_list[$j][$cols_return_extra[$i]['name']] = $this->db2->f('value');
-					}
-					else if($cols_return_extra[$i]['datatype']=='AB' && $value)
-					{
-						$contact_data	= $contacts->read_single_entry($value,array('n_given'=>'n_given','n_family'=>'n_family','email'=>'email'));
-						$s_agreement_list[$j][$cols_return_extra[$i]['name']]	= $contact_data[0]['n_family'] . ', ' . $contact_data[0]['n_given'];
-
-					}
-					else if($cols_return_extra[$i]['datatype']=='VENDOR' && $value)
-					{
-						$sql="SELECT org_name FROM fm_vendor where id=$value";
-						$this->db2->query($sql);
-						$this->db2->next_record();
-						$s_agreement_list[$j][$cols_return_extra[$i]['name']] = $this->db2->f('org_name');
-					}
-					else if($cols_return_extra[$i]['datatype']=='CH' && $value)
-					{
-						$ch= unserialize($value);
-
-						if (isset($ch) AND is_array($ch))
+						if(($return_extra['datatype']=='R' || $return_extra['datatype']=='LB') && $value)
 						{
-							for ($k=0;$k<count($ch);$k++)
+							$sql="SELECT value FROM $choice_table WHERE $attribute_filter AND attrib_id=" .$return_extra['attrib_id']. "  AND id=" . $value;
+							$this->db2->query($sql);
+							$this->db2->next_record();
+							$s_agreement_list[$j][$return_extra['name']] = $this->db2->f('value');
+						}
+						else if($return_extra['datatype']=='AB' && $value)
+						{
+							$contact_data	= $contacts->read_single_entry($value,array('n_given'=>'n_given','n_family'=>'n_family','email'=>'email'));
+							$s_agreement_list[$j][$return_extra['name']]	= $contact_data[0]['n_family'] . ', ' . $contact_data[0]['n_given'];
+						}
+						else if($return_extra['datatype']=='VENDOR' && $value)
+						{
+							$sql="SELECT org_name FROM fm_vendor where id=$value";
+							$this->db2->query($sql);
+							$this->db2->next_record();
+							$s_agreement_list[$j][$return_extra['name']] = $this->db2->f('org_name');
+						}
+						else if($return_extra['datatype']=='CH' && $value)
+						{
+							$ch= unserialize($value);
+
+							if (isset($ch) AND is_array($ch))
 							{
-								$sql="SELECT value FROM $choice_table WHERE  $attribute_filter AND attrib_id=" .$cols_return_extra[$i]['attrib_id']. "  AND id=" . $ch[$k];
-								$this->db2->query($sql);
-								while ($this->db2->next_record())
+								for ($k=0;$k<count($ch);$k++)
 								{
-									$ch_value[]=$this->db2->f('value');
+									$sql="SELECT value FROM $choice_table WHERE  $attribute_filter AND attrib_id=" .$return_extra['attrib_id']. "  AND id=" . $ch[$k];
+									$this->db2->query($sql);
+									while ($this->db2->next_record())
+									{
+										$ch_value[]=$this->db2->f('value');
+									}
 								}
+								$s_agreement_list[$j][$return_extra['name']] = @implode(",", $ch_value);
+								unset($ch_value);
 							}
-							$s_agreement_list[$j][$cols_return_extra[$i]['name']] = @implode(",", $ch_value);
-							unset($ch_value);
+						}
+						else if($return_extra['datatype']=='D' && $value)
+						{
+							$s_agreement_list[$j][$return_extra['name']]=date($GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat'],strtotime($value));
+						}
+						else if($cols_return_extra[$i]['datatype']=='timestamp' && $value)
+						{
+							$s_agreement_list[$j][$return_extra['name']]=date($GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat'],$value);
+						}
+						else if($cols_return_extra[$i]['datatype']=='link' && $value)
+						{
+							$s_agreement_list[$j][$return_extra['name']]= phpgw::safe_redirect($value);
+						}
+						else
+						{
+							$s_agreement_list[$j][$return_extra['name']]=$value;
 						}
 					}
-					else if($cols_return_extra[$i]['datatype']=='D' && $value)
-					{
-						$s_agreement_list[$j][$cols_return_extra[$i]['name']]=date($GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat'],strtotime($value));
-					}
-					else
-					{
-						$s_agreement_list[$j][$cols_return_extra[$i]['name']]=$value;
-					}
 				}
-
 				$j++;
 			}
 //html_print_r($s_agreement_list);
@@ -476,8 +489,8 @@
 			$cols_return[] 			= 'id';
 			$uicols['input_type'][]		= 'hidden';
 			$uicols['name'][]			= 'id';
-			$uicols['descr'][]			= False;
-			$uicols['statustext'][]		= False;
+			$uicols['descr'][]			= false;
+			$uicols['statustext'][]		= false;
 
 			$cols_return[] 			= 'cost';
 			$uicols['input_type'][]		= 'text';
@@ -503,10 +516,7 @@
 			$uicols['descr'][]			= lang('date');
 			$uicols['statustext'][]		= lang('date');
 
-			$from .= " FROM $entity_table ";
-
-			$sql = "SELECT $cols $from $joinmethod";
-
+			$sql = "SELECT $cols FROM $entity_table $joinmethod";
 
 			$this->uicols	= $uicols;
 
@@ -557,11 +567,12 @@
 		{
 			$table = 'fm_s_agreement';
 
-			$this->db->query("SELECT * from $table where id='$s_agreement_id'");
+			$sql = "SELECT fm_s_agreement.* FROM $table WHERE id='$s_agreement_id'";
+			$this->db->query($sql);
 
 			if($this->db->next_record())
 			{
-				$values['id']				= (int)$this->db->f('id');
+				$values['id']				= $this->db->f('id');
 				$values['entry_date']		= $this->db->f('entry_date');
 				$values['cat_id']			= $this->db->f('category');
 				$values['member_of']		= explode(',',$this->db->f('member_of'));
@@ -582,7 +593,20 @@
 						$attr['value'] 	= $this->db->f($attr['column_name']);
 					}
 				}
+
+				$sql = "SELECT fm_s_agreement_budget.category as order_category, year, ecodimb,budget_account,budget"
+					. " FROM fm_s_agreement_budget WHERE agreement_id='$s_agreement_id' AND fm_s_agreement_budget.year =" . date('Y');
+				$this->db->query($sql);
+				$this->db->next_record();
+
+				$values['order_category']	= $this->db->f('order_category');
+				$values['year']				= $this->db->f('year');
+				$values['ecodimb']			= $this->db->f('ecodimb');
+				$values['b_account_id']		= $this->db->f('budget_account');
+				$values['budget']			= (int)$this->db->f('budget');
+				$values['year']				= $this->db->f('year');
 			}
+
 			return $values;
 		}
 
@@ -597,7 +621,7 @@
 
 			if($this->db->next_record())
 			{
-				$values['agreement_id']		= (int)$this->db->f('agreement_id');
+				$values['agreement_id']		= $this->db->f('agreement_id');
 				$values['id']				= (int)$this->db->f('id');
 				$values['entry_date']		= $this->db->f('entry_date');
 				$values['location_code']	= $this->db->f('location_code');
@@ -616,38 +640,38 @@
 			return $values;
 		}
 
-		function add($s_agreement,$values_attribute='')
+		function add($values,$values_attribute='')
 		{
-//_debug_array($s_agreement);
+//_debug_array($values);
 			$table = 'fm_s_agreement';
-			$s_agreement['name'] = $this->db->db_addslashes($s_agreement['name']);
-			$s_agreement['descr'] = $this->db->db_addslashes($s_agreement['descr']);
+			$values['name'] = $this->db->db_addslashes($values['name']);
+			$values['descr'] = $this->db->db_addslashes($values['descr']);
 
-			if($s_agreement['member_of'])
+			if($values['member_of'])
 			{
-				$s_agreement['member_of']=',' . implode(',',$s_agreement['member_of']) . ',';
+				$values['member_of']=',' . implode(',',$values['member_of']) . ',';
 			}
 
 
 			$this->db->transaction_begin();
-			$id = $this->bocommon->increment_id('workorder');
+			$id = $this->socommon->increment_id('workorder');
 
 			$vals[]	= $id;
-			$vals[]	= $s_agreement['name'];
-			$vals[]	= $s_agreement['descr'];
+			$vals[]	= $values['name'];
+			$vals[]	= $values['descr'];
 			$vals[]	= time();
-			$vals[]	= $s_agreement['cat_id'];
-			$vals[]	= $s_agreement['member_of'];
-			$vals[]	= $s_agreement['start_date'];
-			$vals[]	= $s_agreement['end_date'];
-			$vals[]	= $s_agreement['termination_date'];
-			$vals[]	= $s_agreement['vendor_id'];
-			$vals[]	= $s_agreement['b_account_id'];
+			$vals[]	= $values['cat_id'];
+			$vals[]	= $values['member_of'];
+			$vals[]	= $values['start_date'];
+			$vals[]	= $values['end_date'];
+			$vals[]	= $values['termination_date'];
+			$vals[]	= $values['vendor_id'];
+			$vals[]	= $values['b_account_id'];
 			$vals[]	= $this->account;
 
-			if(isset($s_agreement['extra']) && is_array($s_agreement['extra']))
+			if(isset($values['extra']) && is_array($values['extra']))
 			{
-				foreach ($s_agreement['extra'] as $input_name => $value)
+				foreach ($values['extra'] as $input_name => $value)
 				{
 					if(isset($value) && $value)
 					{
@@ -674,7 +698,22 @@
 				$cols	= "," . implode(",", $cols);
 			}
 
-			$vals	= $this->bocommon->validate_db_insert($vals);
+			$vals	= $this->db->validate_insert($vals);
+
+			if(isset($values['budget']) && $values['budget'])
+			{
+				$_budget = array
+				(
+					'agreement_id'		=> $values['s_agreement_id'],
+					'category'			=> $values['order_category'],
+					'year'				=> (int)$values['year'],
+					'ecodimb'			=> (int)$values['ecodimb'],
+					'budget_account'	=> $values['b_account_id'],
+					'budget'			=> $values['budget'],				
+				);
+
+				$this->update_budget($_budget);
+			}
 
 			$this->db->query("INSERT INTO $table (id,name,descr,entry_date,category,member_of,start_date,end_date,termination_date,vendor_id,account_id,user_id $cols) "
 				. "VALUES ($vals)",__LINE__,__FILE__);
@@ -760,12 +799,12 @@
 			if($cols)
 			{
 				$cols	= "," . implode(",", $cols);
-				$vals	= "," . $this->bocommon->validate_db_insert($vals);
+				$vals	= "," . $this->db->validate_insert($vals);
 			}
 
 			$this->db->transaction_begin();
 
-			$id = $this->bocommon->next_id($table,array('agreement_id'=>$values['s_agreement_id']));
+			$id = $this->db->next_id($table,array('agreement_id'=>$values['s_agreement_id']));
 
 			$this->db->query("INSERT INTO $table (id,agreement_id,entry_date,user_id $cols) "
 				. "VALUES ($id," . $values['s_agreement_id'] ."," . time()
@@ -793,7 +832,7 @@
 				$historylog	= CreateObject('property.historylog','s_agreement');
 				while (list($attrib_id,$new_value) = each($history_set))
 				{
-					$historylog->add('SO',$values['s_agreement_id'],$new_value,False, $attrib_id,false,$id);
+					$historylog->add('SO',$values['s_agreement_id'],$new_value,false, $attrib_id,false,$id);
 				}
 			}
 
@@ -803,12 +842,51 @@
 			return $receipt;
 		}
 
-		function edit($values,$values_attribute='')
+		function update_budget($data)
+		{
+			$sql = "SELECT * FROM fm_s_agreement_budget WHERE agreement_id = {$data['agreement_id']} AND year = {$data['year']}";
+			$this->db->query($sql,__LINE__,__FILE__);
+
+			if($this->db->next_record())
+			{
+				$old_category	= $this->db->f('category');
+				$old_ecodimb		= $this->db->f('ecodimb');
+				$old_budget_account	= $this->db->f('budget_account');
+				$old_budget			= $this->db->f('budget');
+				$sql = "UPDATE fm_s_agreement_budget SET"
+				 . " category = {$data['category']},"
+				 . " ecodimb = {$data['ecodimb']},"
+				 . " budget_account = '{$data['budget_account']}',"
+				 . " budget = {$data['budget']},"
+				 . ' modified_date=' . time()
+				 . " WHERE agreement_id = {$data['agreement_id']} AND year = {$data['year']}";
+				 				
+			}
+			else
+			{
+				$sql = "INSERT INTO fm_s_agreement_budget (agreement_id,year,category,ecodimb,budget_account,budget,user_id,entry_date) VALUES("
+				 . "{$data['agreement_id']},"
+				 . "{$data['year']},"
+				 . "{$data['category']},"
+				 . "{$data['ecodimb']},"
+				 . "'{$data['budget_account']}',"
+				 . "{$data['budget']},"
+				 . "{$this->account},"
+				 . time() . ')';
+			}
+
+			$this->db->query($sql,__LINE__,__FILE__);
+		
+		}
+
+		function edit($values,$values_attribute = array())
 		{
 //_debug_array($values);
 //_debug_array($values_attribute);
-			$table = 'fm_s_agreement';
 
+			$table = 'fm_s_agreement';
+			
+			$values['s_agreement_id'] = $this->db->db_addslashes($values['s_agreement_id']); // bigint
 			$values['name'] = $this->db->db_addslashes($values['name']);
 
 			if($values['member_of'])
@@ -846,14 +924,30 @@
 			$value_set['descr']	= $values['descr'];
 			if($value_set)
 			{
-				$value_set	= ',' . $this->bocommon->validate_db_update($value_set);
+				$value_set	= ',' . $this->db->validate_update($value_set);
 			}
 
+			$this->db->transaction_begin();
+			if(isset($values['budget']) && $values['budget'])
+			{
+				$_budget = array
+				(
+					'agreement_id'		=> $values['s_agreement_id'],
+					'category'			=> $values['order_category'],
+					'year'				=> (int)$values['year'],
+					'ecodimb'			=> (int)$values['ecodimb'],
+					'budget_account'	=> $values['b_account_id'],
+					'budget'			=> $values['budget'],				
+				);
+
+				$this->update_budget($_budget);
+			}
 			$this->db->query("UPDATE $table set entry_date='" . time() . "', category='"
-							. $values['cat_id'] . "', member_of='" . $values['member_of'] . "', start_date=" . intval($values['start_date']) . ", end_date=" . intval($values['end_date']) . ", termination_date=" . intval($values['termination_date']) . ", account_id=" . intval($values['b_account_id']) . "$value_set WHERE id=" . intval($values['s_agreement_id']));
+							. $values['cat_id'] . "', member_of='" . $values['member_of'] . "', start_date=" . intval($values['start_date']) . ", end_date=" . intval($values['end_date']) . ", termination_date=" . intval($values['termination_date']) . ", account_id=" . intval($values['b_account_id']) . "$value_set WHERE id='{$values['s_agreement_id']}'");
 
-			$this->db->query("UPDATE fm_s_agreement_pricing set index_date=" . intval($values['start_date']) . " WHERE id=1 AND agreement_id= " . intval($values['s_agreement_id']));
+			$this->db->query("UPDATE fm_s_agreement_pricing set index_date=" . intval($values['start_date']) . " WHERE id=1 AND agreement_id= '{$values['s_agreement_id']}'");
 
+			$this->db->transaction_commit();
 			$receipt['s_agreement_id']= $values['s_agreement_id'];
 			$receipt['message'][] = array('msg'=>lang('s_agreement %1 has been edited',$values['s_agreement_id']));
 			return $receipt;
@@ -887,14 +981,14 @@
 					}
 
 					if($entry['history'] == 1)
-					{						
+					{
 						$this->db->query("SELECT " . $entry['name'] . " from $table WHERE agreement_id= " . $values['s_agreement_id'] . " AND id=" . $values['id'],__LINE__,__FILE__);
 						$this->db->next_record();
 						$old_value = $this->db->f($entry['name']);
 						if($entry['value'] != $old_value)
 						{
 							$history_set[$entry['attrib_id']] = array('value' => $entry['value'],
-												'date'  => $this->bocommon->date_to_timestamp($entry['date']));
+												'date'  => phpgwapi_datetime::date_to_timestamp($entry['date']));
 						}
 					}
 				}
@@ -918,12 +1012,12 @@
 
 			if($value_set)
 			{
-				$value_set	= ',' . $this->bocommon->validate_db_update($value_set);
+				$value_set	= ',' . $this->db->validate_update($value_set);
 			}
 
-			$this->db->query("UPDATE $table set entry_date=" . time() . "$value_set WHERE agreement_id=" . intval($values['s_agreement_id']) . ' AND id=' . intval($values['id']));
+			$this->db->query("UPDATE $table set entry_date=" . time() . "$value_set WHERE agreement_id=" . ($values['s_agreement_id']) . ' AND id=' . intval($values['id']));
 
-			$this->db->query("UPDATE fm_s_agreement_pricing set cost = this_index *" . $this->floatval($values['cost']) . " WHERE agreement_id=" . intval($values['s_agreement_id']) . ' AND item_id=' . intval($values['id']));
+			$this->db->query("UPDATE fm_s_agreement_pricing set cost = this_index *" . $this->floatval($values['cost']) . " WHERE agreement_id=" . $values['s_agreement_id'] . ' AND item_id=' . intval($values['id']));
 
 			if (isset($history_set) AND is_array($history_set))
 			{
@@ -931,7 +1025,7 @@
 				foreach ($history_set as $attrib_id => $history)
 		//		while (list($attrib_id,$history) = each($history_set))
 				{
-					$historylog->add('SO',$values['s_agreement_id'],$history['value'],False, $attrib_id,$history['date'],$values['id']);
+					$historylog->add('SO',$values['s_agreement_id'],$history['value'],false, $attrib_id,$history['date'],$values['id']);
 				}
 			}
 
@@ -944,19 +1038,18 @@
 
 		function update($values)
 		{
-//_debug_array($values);
 			$values['new_index']=$this->floatval($values['new_index']);
 			$this->db->transaction_begin();
 
-			while (is_array($values['select']) && list($item_id,$value) = each($values['select']))
+			if(isset($values['select']) && is_array($values['select']))
 			{
-
-				$this->db->query("UPDATE fm_s_agreement_pricing set current_index = NULL WHERE agreement_id=" . intval($values['agreement_id']) . ' AND item_id=' . intval($item_id));
-
-				$this->db->query("INSERT INTO fm_s_agreement_pricing (agreement_id,item_id,id,current_index,this_index,cost,index_date,entry_date,user_id)"
-					. "VALUES (" . $values['agreement_id'] . "," . $item_id ."," . ($values['id'][$item_id]+1) .",1,'" . $values['new_index'] . "','" . ($value * $values['new_index'])  . "'," . (int)$values['date'] . "," . time()
-					. "," . $this->account . ")");
-
+				foreach ($values['select'] as $item_id => $value)
+				{
+					$this->db->query("UPDATE fm_s_agreement_pricing SET current_index = NULL WHERE agreement_id=" . $values['agreement_id'] . ' AND item_id=' . (int)$item_id);
+					$this->db->query("INSERT INTO fm_s_agreement_pricing (agreement_id,item_id,id,current_index,this_index,cost,index_date,entry_date,user_id)"
+						. "VALUES (" . $values['agreement_id'] . "," . $item_id ."," . ($values['id'][$item_id]+1) .",1,'" . $values['new_index'] . "','" . ($value * $values['new_index'])  . "'," . (int)$values['date'] . "," . time()
+						. "," . $this->account . ")");
+				}
 			}
 
 			$this->db->transaction_commit();
@@ -1005,21 +1098,24 @@
 		{
 			$table = 'fm_s_agreement';
 			$this->db->transaction_begin();
-			$this->db->query("DELETE FROM $table WHERE id=" . intval($s_agreement_id));
-			$this->db->query("DELETE FROM fm_s_agreement_detail WHERE agreement_id=" . intval($s_agreement_id));
-			$this->db->query("DELETE FROM fm_s_agreement_pricing WHERE agreement_id=" . intval($s_agreement_id));
-			$this->db->query("DELETE FROM fm_orders WHERE id=" . intval($s_agreement_id));
+			$this->db->query("DELETE FROM $table WHERE id=" . $s_agreement_id);
+			$this->db->query("DELETE FROM fm_s_agreement_detail WHERE agreement_id=" . $s_agreement_id);
+			$this->db->query("DELETE FROM fm_s_agreement_pricing WHERE agreement_id=" . $s_agreement_id);
+			$this->db->query("DELETE FROM fm_orders WHERE id=" . $s_agreement_id);
 			$this->db->transaction_commit();
 		}
 
 		function attrib_choise2id($id,$value = '')
 		{
+			$value = $this->db->db_addslashes($value);
 			$choice_table = 'phpgw_cust_choice';
-			$attribute_filter = " appname = 'property' AND location = '.s_agreement.detail'";
+			$location_id = $GLOBALS['phpgw']->locations->get_id('property', '.s_agreement.detail'); 
+			$attribute_filter = " location_id = {$location_id}";
+
 			$sql = "SELECT id FROM $choice_table WHERE $attribute_filter AND value = '$value' AND attrib_id = $id";
 			$this->db->query($sql,__LINE__,__FILE__);
 			$this->db->next_record();
-			return $this->db->f('id');					
+			return $this->db->f('id');
 		}
 
 		function request_next_id()
@@ -1029,5 +1125,50 @@
 			$next_id= $this->db->f('id')+1;
 			return $next_id;
 		}
+
+		function get_year_filter_list($agreement_id = 0)
+		{
+			$table = 'fm_s_agreement_budget';
+			$sql = "SELECT year FROM $table WHERE agreement_id = {$agreement_id} group by year ORDER BY year ASC";
+			$this->db->query($sql,__LINE__,__FILE__);
+
+			$values = array();
+
+			while ($this->db->next_record())
+			{
+				$values[]	= $this->db->f('year');
+			}
+
+			return $values;
+		}
+
+		function get_budget($agreement_id = 0)
+		{
+			$values = array();
+
+			$sql = "SELECT * FROM fm_s_agreement_budget WHERE agreement_id = {$agreement_id} ORDER BY year ASC";
+			$this->db->query($sql,__LINE__,__FILE__);
+
+			while($this->db->next_record())
+			{
+				$values[] = array
+				(
+					'agreement_id'		=> $agreement_id,
+					'year'				=> $this->db->f('year'),
+					'cat_id'			=> $this->db->f('category'),
+					'ecodimb'			=> $this->db->f('ecodimb'),
+					'budget_account'	=> $this->db->f('budget_account'),
+					'budget'			=> $this->db->f('budget'),
+					'actual_cost'		=> $this->db->f('actual_cost')
+				);
+			}
+			
+			return $values;
+		}
+
+		function delete_year_from_budget($data,$agreement_id)
+		{
+			$sql = "DELETE FROM fm_s_agreement_budget WHERE agreement_id = {$agreement_id} AND year IN(" . implode(',', $data) . ')';
+			$this->db->query($sql,__LINE__,__FILE__);
+		}
 	}
-?>
