@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage project
- 	* @version $Id: class.sotenant_claim.inc.php 18358 2007-11-27 04:43:37Z skwashd $
+ 	* @version $Id: class.sotenant_claim.inc.php 6371 2010-09-21 08:11:03Z sigurd $
 	*/
 
 	/**
@@ -34,35 +34,39 @@
 
 	class property_sotenant_claim
 	{
-		function property_sotenant_claim()
+		function __construct()
 		{
-		//	$this->currentapp	= $GLOBALS['phpgw_info']['flags']['currentapp'];
 			$this->account	= $GLOBALS['phpgw_info']['user']['account_id'];
-			$this->bocommon		= CreateObject('property.bocommon');
-			$this->db           	= $this->bocommon->new_db();
-			$this->db2           	= $this->bocommon->new_db();
-
-			$this->join			= $this->bocommon->join;
+			$this->db           = & $GLOBALS['phpgw']->db;
+			$this->join			= & $this->db->join;
+			$this->like			= & $this->db->like;
+			$this->interlink 	= CreateObject('property.interlink');
 		}
 
 		function read($data)
 		{
-			if(is_array($data))
-			{
-				$start	= (isset($data['start'])?$data['start']:0);
-				$filter	= (isset($data['filter'])?$data['filter']:'none');
-				$status	= (isset($data['status'])?$data['status']:'open');
-				$query = (isset($data['query'])?$data['query']:'');
-				$sort = (isset($data['sort'])?$data['sort']:'DESC');
-				$order = (isset($data['order'])?$data['order']:'');
-				$cat_id = (isset($data['cat_id'])?$data['cat_id']:0);
-				$allrows 	= (isset($data['allrows'])?$data['allrows']:'');
-				$project_id 	= (isset($data['project_id'])?$data['project_id']:'');
-
-			}
+			$start			= isset($data['start']) && $data['start'] ? $data['start'] : 0;
+			$user_id		= isset($data['user_id']) && $data['user_id'] ? (int)$data['user_id'] : '0';
+			$status			= isset($data['status']) && $data['status'] ? $data['status'] : 'open';
+			$query			= isset($data['query']) ? $data['query'] : '';
+			$sort			= isset($data['sort']) && $data['sort'] ? $data['sort'] : 'DESC';
+			$order			= isset($data['order']) ? $data['order'] : '';
+			$cat_id			= isset($data['cat_id']) && $data['cat_id'] ? $data['cat_id'] : 0;
+			$allrows		= isset($data['allrows']) ? $data['allrows'] : '';
+			$project_id		= isset($data['project_id']) ? $data['project_id'] : '';
+			$district_id	= isset($data['district_id']) ? (int)$data['district_id'] : 0;
 
 			if ($order)
 			{
+				switch($order)
+				{
+					case 'claim_id':
+						$order = 'fm_tenant_claim.id';
+						break;
+					case 'name':
+						$order = 'last_name';
+						break;
+				}
 				$ordermethod = " order by $order $sort";
 			}
 			else
@@ -74,7 +78,7 @@
 			$where = 'WHERE';
 			if ($cat_id > 0)
 			{
-				$filtermethod .= " $where category='$cat_id' ";
+				$filtermethod .= " $where fm_tenant_claim.category='$cat_id' ";
 				$where = 'AND';
 			}
 
@@ -84,30 +88,43 @@
 				$where = 'AND';
 			}
 
-			if ($status == 'closed'):
+			if ($status && $status != 'all')
 			{
-				$filtermethod .= " $where fm_tenant_claim.status='closed'";
+				$filtermethod .= " $where fm_tenant_claim.status='{$status}'";
 				$where = 'AND';
 			}
-			elseif($status == ''):
-			{
-				$filtermethod .= " $where fm_tenant_claim.status='open'";
-				$where = 'AND';
-			}
-			endif;
 
+			if ($user_id > 0)
+			{
+				$filtermethod .= " $where fm_tenant_claim.user_id={$user_id} ";
+				$where = 'AND';
+			}
+
+			if ($district_id > 0)
+			{
+				$filtermethod .= " $where  district_id=" .(int)$district_id;
+				$where = 'AND';
+			}
+
+			$querymethod = '';
 			if($query)
 			{
-				$query = preg_replace("/'/",'',$query);
-				$query = preg_replace('/"/','',$query);
+				$query = $this->db->db_addslashes($query);
 
-				$querymethod = " $where ( abid = '$query' or org_name LIKE '%$query%')";
+				$querymethod = " $where ( first_name $this->like '%$query%' OR last_name $this->like '%$query%' OR project_id=" . (int)$query .')';
 			}
 
-			$sql = "SELECT fm_tenant_claim.*, descr as category FROM fm_tenant_claim $this->join fm_tenant_claim_category on fm_tenant_claim.category=fm_tenant_claim_category.id $filtermethod $querymethod";
+			$sql = "SELECT fm_tenant_claim.*, fm_tenant_claim_category.descr as category, fm_tenant.last_name, fm_tenant.first_name,district_id"
+			 . " FROM fm_tenant_claim "
+			 . " $this->join fm_tenant_claim_category on fm_tenant_claim.category=fm_tenant_claim_category.id"
+			 . " $this->join fm_tenant on fm_tenant_claim.tenant_id=fm_tenant.id"
+			 . " $this->join fm_project ON fm_project.id = fm_tenant_claim.project_id"
+			 . " $this->join fm_location1 ON fm_project.loc1=fm_location1.loc1"
+			 . " $this->join fm_part_of_town ON fm_location1.part_of_town_id=fm_part_of_town.part_of_town_id"
+			 . " $filtermethod $querymethod";
 
-			$this->db2->query($sql,__LINE__,__FILE__);
-			$this->total_records = $this->db2->num_rows();
+			$this->db->query($sql,__LINE__,__FILE__);
+			$this->total_records = $this->db->num_rows();
 
 			if(!$allrows)
 			{
@@ -118,6 +135,7 @@
 				$this->db->query($sql . $ordermethod,__LINE__,__FILE__);
 			}
 
+			$claims = array();
 			while ($this->db->next_record())
 			{
 				$claims[] = array
@@ -125,10 +143,13 @@
 					'claim_id'		=> $this->db->f('id'),
 					'project_id'	=> $this->db->f('project_id'),
 					'tenant_id'		=> $this->db->f('tenant_id'),
-					'remark'		=> stripslashes($this->db->f('remark')),
+					'name'			=> $this->db->f('last_name') . ', ' . $this->db->f('first_name'),
+					'remark'		=> $this->db->f('remark',true),
 					'entry_date'	=> $this->db->f('entry_date'),
 					'category'		=> $this->db->f('category'),
-					'status'		=> $this->db->f('status')
+					'status'		=> $this->db->f('status'),
+					'user_id'		=> $this->db->f('user_id'),
+					'district_id'	=> $this->db->f('district_id'),
 				);
 			}
 			return $claims;
@@ -140,8 +161,8 @@
 			 . " $this->join fm_tenant_claim_category on fm_tenant_claim.category=fm_tenant_claim_category.id"
 			 . " WHERE project_id = $project_id";
 
-			$this->db2->query($sql,__LINE__,__FILE__);
-			$this->total_records = $this->db2->num_rows();
+			$this->db->query($sql,__LINE__,__FILE__);
+			$this->total_records = $this->db->num_rows();
 
 			$this->db->query($sql . $ordermethod,__LINE__,__FILE__);
 
@@ -159,21 +180,21 @@
 			return $claims;
 		}
 
+		//FIXME: to be removed
 		function check_claim_workorder($workorder_id)
 		{
-			$this->db->query("select * from fm_origin WHERE destination ='tenant_claim' AND origin_id='$workorder_id'",__LINE__,__FILE__);
+			$claim = $this->interlink->get_specific_relation('property', '.project.workorder', '.tenant_claim', $workorder_id, 'origin');
 
-			while ($this->db->next_record())
+			if ( $claim)
 			{
-				$claim[] = $this->db->f('destination_id');
+				return implode(",", $claim);
 			}
-
-			return @implode(",", $claim);
 		}
 
 		function read_single($id)
 		{
-			$this->db->query("select * from fm_tenant_claim where id='$id'",__LINE__,__FILE__);
+			$id = (int) $id;
+			$this->db->query("SELECT * FROM fm_tenant_claim WHERE id={$id}",__LINE__,__FILE__);
 
 			if ($this->db->next_record())
 			{
@@ -190,11 +211,11 @@
 
 			}
 
-			$this->db->query("select * from fm_origin WHERE destination ='tenant_claim' AND destination_id='$id'",__LINE__,__FILE__);
+			$target = $this->interlink->get_specific_relation('property', '.project.workorder', '.tenant_claim', $id, 'origin');
 
-			while ($this->db->next_record())
+			if ( $target)
 			{
-				$claim['workorder'][] = $this->db->f('origin_id');
+				$claim['workorder'] = $target;
 			}
 
 			return $claim;
@@ -219,7 +240,7 @@
 				$claim['status']
 				);
 
-			$values_insert	= $this->bocommon->validate_db_insert($values_insert);
+			$values_insert	= $this->db->validate_insert($values_insert);
 
 
 			$this->db->query("INSERT INTO fm_tenant_claim (project_id,tenant_id,amount,b_account_id,category,remark,user_id,entry_date,status) "
@@ -230,15 +251,18 @@
 
 			foreach ($claim['workorder'] as $workorder_id)
 			{
-				$this->db->query("INSERT INTO fm_origin (origin,origin_id,destination,destination_id,entry_date,user_id) "
-				. "VALUES ('workorder',"
-				. $workorder_id .","
-				. "'tenant_claim',"
-				. $claim_id . ","
-				. time().","
-				. $this->account .")",__LINE__,__FILE__);
+				$interlink_data = array
+				(
+					'location1_id'		=> $GLOBALS['phpgw']->locations->get_id('property', '.project.workorder'),
+					'location1_item_id' => $workorder_id,
+					'location2_id'		=> $GLOBALS['phpgw']->locations->get_id('property', '.tenant_claim'),			
+					'location2_item_id' => $claim_id,
+					'account_id'		=> $this->account
+				);
+					
+				$this->interlink->add($interlink_data,$this->db);
 
-				$this->db->query("UPDATE fm_workorder set claim_issued = 1 WHERE id=" . $workorder_id ,__LINE__,__FILE__);
+				$this->db->query("UPDATE fm_workorder SET claim_issued = 1 WHERE id=" . $workorder_id ,__LINE__,__FILE__);
 			}
 
 			$this->db->transaction_commit();
@@ -255,7 +279,6 @@
 			$claim['amount'] =  str_replace(",",".",$claim['amount']);
 
 			$value_set=array(
-				'amount'			=> $claim['amount'],
 				'tenant_id'			=> $claim['tenant_id'],
 				'b_account_id'		=> $claim['b_account_id'],
 				'amount'			=> $claim['amount'],
@@ -265,25 +288,28 @@
 				'remark'			=> $this->db->db_addslashes($claim['remark'])
 				);
 
-			$value_set	= $this->bocommon->validate_db_update($value_set);
+			$value_set	= $this->db->validate_update($value_set);
 
-			$this->db->query("UPDATE fm_tenant_claim set $value_set  WHERE id=" . intval($claim['claim_id']),__LINE__,__FILE__);
+			$this->db->query("UPDATE fm_tenant_claim set $value_set  WHERE id=" . (int)$claim['claim_id'],__LINE__,__FILE__);
 
 			$claim_id = $claim['claim_id'];
 
-			$this->db->query("DELETE FROM fm_origin WHERE destination ='tenant_claim' AND destination_id=$claim_id",__LINE__,__FILE__);
+			$this->interlink->delete_from_target('property', '.tenant_claim', $claim_id, $this->db);
 
-			$this->db->query("UPDATE fm_workorder set claim_issued = NULL WHERE id=" . $claim['project_id'] ,__LINE__,__FILE__);
+			$this->db->query("UPDATE fm_workorder set claim_issued = NULL WHERE project_id = {$claim['project_id']}" ,__LINE__,__FILE__);
 
 			foreach ($claim['workorder'] as $workorder_id)
 			{
-				$this->db->query("INSERT INTO fm_origin (origin,origin_id,destination,destination_id,entry_date,user_id) "
-				. "VALUES ('workorder',"
-				. $workorder_id .","
-				. "'tenant_claim',"
-				. $claim_id . ","
-				. time().","
-				. $this->account .")",__LINE__,__FILE__);
+				$interlink_data = array
+				(
+					'location1_id'		=> $GLOBALS['phpgw']->locations->get_id('property', '.project.workorder'),
+					'location1_item_id' => $workorder_id,
+					'location2_id'		=> $GLOBALS['phpgw']->locations->get_id('property', '.tenant_claim'),			
+					'location2_item_id' => $claim_id,
+					'account_id'		=> $this->account
+				);
+					
+				$this->interlink->add($interlink_data,$this->db);
 
 				$this->db->query("UPDATE fm_workorder set claim_issued = 1 WHERE id=" . $workorder_id ,__LINE__,__FILE__);
 			}
@@ -299,9 +325,9 @@
 		{
 			$this->db->transaction_begin();
 			$this->db->query('DELETE FROM fm_tenant_claim WHERE id=' . intval($id),__LINE__,__FILE__);
-			$this->db->query("DELETE FROM fm_origin WHERE destination ='tenant_claim' AND destination_id=$id",__LINE__,__FILE__);
+			$this->interlink->delete_from_target('property', '.tenant_claim', $id, $this->db);
 			$this->db->transaction_commit();
 
 		}
 	}
-?>
+
