@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage project
- 	* @version $Id: class.sowo_hour.inc.php 18358 2007-11-27 04:43:37Z skwashd $
+ 	* @version $Id: class.sowo_hour.inc.php 4709 2010-02-02 15:18:50Z sigurd $
 	*/
 
 	/**
@@ -34,23 +34,22 @@
 
 	class property_sowo_hour
 	{
-		function property_sowo_hour()
+		function __construct()
 		{
-		//	$this->currentapp	= $GLOBALS['phpgw_info']['flags']['currentapp'];
 			$this->account		= $GLOBALS['phpgw_info']['user']['account_id'];
-			$this->bocommon	= CreateObject('property.bocommon');
-			$this->db           	= $this->bocommon->new_db();
-			$this->db2           	= $this->bocommon->new_db();
 
-			$this->join		= $this->bocommon->join;
-			$this->left_join	= $this->bocommon->left_join;
-			$this->like		= $this->bocommon->like;
+			$this->db 			= & $GLOBALS['phpgw']->db;
+			$this->db2			= clone($this->db);
+			$this->like 		= & $this->db->like;
+			$this->join 		= & $this->db->join;
+			$this->left_join	= & $this->db->left_join;
 		}
 
 		function get_chapter_list()
 		{
 			$this->db->query("SELECT id, descr FROM fm_chapter ORDER BY id ");
 
+			$chapter_entries = array();
 			$i = 0;
 			while ($this->db->next_record())
 			{
@@ -234,7 +233,7 @@
 				time()
 				);
 
-			$values_insert	= $this->bocommon->validate_db_insert($values_insert);
+			$values_insert	= $this->db->validate_insert($values_insert);
 
 			$this->db->query("INSERT INTO fm_wo_h_deviation (workorder_id,hour_id,id,amount,descr,entry_date) VALUES ($values_insert)",__LINE__,__FILE__);
 
@@ -253,7 +252,7 @@
 				'descr'			=> $this->db->db_addslashes($values['descr'])
 				);
 
-			$value_set	= $this->bocommon->validate_db_update($value_set);
+			$value_set	= $this->db->validate_update($value_set);
 
 			$this->db->query("UPDATE fm_wo_h_deviation set $value_set WHERE workorder_id=" . $values['workorder_id'] . " AND hour_id=" . $values['hour_id'] . " AND id=" . $values['id'],__LINE__,__FILE__);
 
@@ -299,7 +298,7 @@
 				time()
 				 );
 
-			$values_insert	= $this->bocommon->validate_db_insert($values_insert);
+			$values_insert	= $this->db->validate_insert($values_insert);
 
 			$this->db->query("insert into fm_template (owner,name,descr,chapter_id,entry_date) "
 				. " values ($values_insert)",__LINE__,__FILE__);
@@ -333,7 +332,7 @@
 					$record,
 					$template_id );
 
-				$values_insert	= $this->bocommon->validate_db_insert($values_insert);
+				$values_insert	= $this->db->validate_insert($values_insert);
 
 				$this->db->query("insert into fm_template_hours (activity_id,activity_num,owner,hours_descr,unit,"
 				. "cost,quantity,billperae,ns3420_id,dim_d,grouping_id,grouping_descr,remark,tolerance,building_part,record,template_id) "
@@ -362,7 +361,7 @@
 					$hour[$i]['hours_descr'],
 					$hour[$i]['unit'],
 					$hour[$i]['cost'],
-					$hour[$i]['quantity'],
+					(int)$hour[$i]['quantity'],
 					$hour[$i]['billperae'],
 					$hour[$i]['ns3420_id'],
 					$hour[$i]['dim_d'],
@@ -373,7 +372,7 @@
 					$hour[$i]['cat_per_cent']
 					);
 
-				$values	= $this->bocommon->validate_db_insert($values);
+				$values	= $this->db->validate_insert($values);
 
 				$this->db->query("insert into fm_wo_hours (activity_id,activity_num,owner,hours_descr,unit,cost,quantity,billperae,ns3420_id,dim_d,record,entry_date,workorder_id,category,cat_per_cent) "
 				. " values ($values)",__LINE__,__FILE__);
@@ -443,7 +442,7 @@
 					$hour[$i]['cat_per_cent']
 					);
 
-				$values	= $this->bocommon->validate_db_insert($values);
+				$values	= $this->db->validate_insert($values);
 
 				$this->db->query("insert into fm_wo_hours (owner,activity_id,activity_num,hours_descr,unit,cost,quantity,billperae,ns3420_id,dim_d,"
 				. " grouping_id,grouping_descr,record,building_part,tolerance,remark,entry_date,workorder_id,category,cat_per_cent) "
@@ -520,7 +519,7 @@
 					$hour['cat_per_cent']
 					);
 
-			$values	= $this->bocommon->validate_db_insert($values);
+			$values	= $this->db->validate_insert($values);
 
 			$this->db->query("insert into fm_wo_hours (owner,hours_descr,unit,cost,quantity,billperae,ns3420_id,dim_d,"
 				. " grouping_id,grouping_descr,record,building_part,tolerance,remark,entry_date,workorder_id,category,cat_per_cent) "
@@ -661,7 +660,7 @@
 				'cat_per_cent'		=> $hour['cat_per_cent']
 				);
 
-			$value_set	= $this->bocommon->validate_db_update($value_set);
+			$value_set	= $this->db->validate_update($value_set);
 
 			$this->db->query("UPDATE fm_wo_hours set $value_set WHERE id= '" . $hour['hour_id'] ."'",__LINE__,__FILE__);
 
@@ -680,11 +679,12 @@
 			$this->db->query("UPDATE fm_vendor set email ='$to_email' where  id= '$vendor_id'",__LINE__,__FILE__);
 		}
 
-		function get_email($vendor_id)
+		function get_email($vendor_id = 0)
 		{
 			$vendor_id=(int)$vendor_id;
-
-			$this->db->query("select column_name from phpgw_cust_attribute WHERE appname='property' AND location = '.vendor' AND datatype='email'",__LINE__,__FILE__);
+			$location_id = $GLOBALS['phpgw']->locations->get_id('property', '.vendor');
+			$this->db->query("select column_name from phpgw_cust_attribute WHERE location_id = {$location_id} AND datatype='email'",__LINE__,__FILE__);
+			$email_list = array();
 			while ($this->db->next_record())
 			{
 				$this->db2->query("select " . $this->db->f('column_name') . " from fm_vendor where id=$vendor_id",__LINE__,__FILE__);
@@ -739,19 +739,19 @@
 
 			$this->db->transaction_begin();
 			$this->db->query("UPDATE fm_workorder SET calculation = '$calculation' WHERE id=$id",__LINE__,__FILE__);
-			
+
 			if($calculation > 0)
 			{
-				$config		= CreateObject('phpgwapi.config');
-				$config->read_repository();
+				$config		= CreateObject('phpgwapi.config','property');
+				$config->read();
 				$tax = 1+(($config->config_data['fm_tax'])/100);
 				$calculation = $calculation * $tax;
-				
+
 				$this->db->query("UPDATE fm_workorder SET combined_cost = '$calculation' WHERE id=$id",__LINE__,__FILE__);
 			}
-			
+
 			$this->db->transaction_commit();
 			return $receipt;
 		}
 	}
-?>
+
