@@ -24,9 +24,11 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage admin
- 	* @version $Id: class.uiXport.inc.php 18358 2007-11-27 04:43:37Z skwashd $
+ 	* @version $Id: class.uiXport.inc.php 6189 2010-07-07 10:47:32Z sigurd $
 	*/
 
+	phpgw::import_class('phpgwapi.datetime');
+
 	/**
 	 * Description
 	 * @package property
@@ -34,14 +36,14 @@
 
 	class property_uiXport
 	{
-		var $public_functions = array(
-			'import' 	=> True,
-			'export' 	=> True,
-			'rollback'	=> True
+		var $public_functions = array
+		(
+			'import' 	=> true,
+			'export' 	=> true,
+			'rollback'	=> true
 		);
 
 		var $start;
-		var $limit;
 		var $query;
 		var $sort;
 		var $order;
@@ -51,31 +53,29 @@
 		function property_uiXport()
 		{
 
-			$GLOBALS['phpgw_info']['flags']['xslt_app'] = True;
+			$GLOBALS['phpgw_info']['flags']['xslt_app'] = true;
+			$GLOBALS['phpgw_info']['flags']['menu_selection'] = 'property::invoice';
 		//	$this->currentapp		= $GLOBALS['phpgw_info']['flags']['currentapp'];
-			$this->bo       		= CreateObject('property.boXport',True);
+			$this->bo       		= CreateObject('property.boXport',true);
 			$this->invoice  		= CreateObject('property.boinvoice');
 			$this->bocommon  		= CreateObject('property.bocommon');
-			$this->menu			= CreateObject('property.menu');
 			$this->contacts			= CreateObject('property.soactor');
 			$this->contacts->role		= 'vendor';
 
-			$this->acl 			= CreateObject('phpgwapi.acl');
+			$this->acl 				= & $GLOBALS['phpgw']->acl;
 			$this->acl_location		= '.invoice';
-			$this->acl_read 		= $this->acl->check('.invoice',1);
-			$this->acl_add 			= $this->acl->check('.invoice',2);
-			$this->acl_edit 		= $this->acl->check('.invoice',4);
-			$this->acl_delete 		= $this->acl->check('.invoice',8);
-			$this->acl_manage 		= $this->acl->check('.invoice',16);
+			$this->acl_read 		= $this->acl->check('.invoice', PHPGW_ACL_READ, 'property');
+			$this->acl_add 			= $this->acl->check('.invoice', PHPGW_ACL_ADD, 'property');
+			$this->acl_edit 		= $this->acl->check('.invoice', PHPGW_ACL_EDIT, 'property');
+			$this->acl_delete 		= $this->acl->check('.invoice', PHPGW_ACL_DELETE, 'property');
+			$this->acl_manage 		= $this->acl->check('.invoice', 16, 'property');
 
 			$this->start    		= $this->bo->start;
-			$this->limit    		= $this->bo->limit;
 			$this->query    		= $this->bo->query;
 			$this->sort     		= $this->bo->sort;
 			$this->order    		= $this->bo->order;
 			$this->filter   		= $this->bo->filter;
 			$this->cat_id   		= $this->bo->cat_id;
-			$this->menu->sub		='invoice';
 		}
 
 		function import()
@@ -85,6 +85,7 @@
 				$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> 'property.uilocation.stop', 'perm'=>2, 'acl_location'=> $this->acl_location));
 			}
 
+			$GLOBALS['phpgw_info']['flags']['menu_selection'] .= '::import';
 			$receipt = $GLOBALS['phpgw']->session->appsession('session_data','import_receipt');
 			$GLOBALS['phpgw']->session->appsession('session_data','import_receipt','');
 
@@ -120,8 +121,6 @@
 				$tsvfile = phpgw::get_var('tsvfile');
 			}
 
-			$links = $this->menu->links('import_inv');
-
 			if ($cancel && $tsvfile)
 			{
 				unlink ($tsvfile);
@@ -176,26 +175,19 @@
 				}
 				if (!is_array($receipt['error']))
 				{
-
-					$dateformat = strtolower($GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat']);
-					$dateformat = str_replace(".","",$dateformat);
-					$dateformat = str_replace("-","",$dateformat);
-					$dateformat = str_replace("/","",$dateformat);
-					$y=strpos($dateformat,'y');
-					$d=strpos($dateformat,'d');
-					$m=strpos($dateformat,'m');
-
 					if($invoice_date)
 					{
-			 			$dateparts = explode('/', $invoice_date);
-			 			$sday = $dateparts[$d];
-			 			$smonth = $dateparts[$m];
-			 			$syear = $dateparts[$y];
+						$sdateparts = phpgwapi_datetime::date_array($invoice_date);
+			 			$sday = $sdateparts['day'];
+			 			$smonth = $sdateparts['month'];
+			 			$syear = $sdateparts['year'];
+			 			unset($sdateparts);
 
-			 			$dateparts = explode('/', $payment_date);
-			 			$eday = $dateparts[$d];
-			 			$emonth = $dateparts[$m];
-			 			$eyear = $dateparts[$y];
+						$edateparts = phpgwapi_datetime::date_array($payment_date);
+			 			$eday = $edateparts['day'];
+			 			$emonth = $edateparts['month'];
+			 			$eyear = $edateparts['year'];
+			 			unset($edateparts);
 					}
 
 					$old = $tsvfile;
@@ -255,6 +247,7 @@
 					}
 					else
 					{
+						$GLOBALS['phpgw_info']['flags']['noframework'] = true;
 						$this->debug_import($buffer,$invoice_common);
 						return;
 					}
@@ -270,14 +263,6 @@
 				'sub'		=> $sub
 			);
 
-			$dateformat = strtolower($GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat']);
-			$sep = '/';
-			$dlarr[strpos($dateformat,'y')] = 'yyyy';
-			$dlarr[strpos($dateformat,'m')] = 'MM';
-			$dlarr[strpos($dateformat,'d')] = 'DD';
-			ksort($dlarr);
-
-			$dateformat= (implode($sep,$dlarr));
 
 			$msgbox_data = $this->bocommon->msgbox_data($receipt);
 
@@ -287,8 +272,8 @@
 
 			$data = array
 			(
+				'menu'							=> $this->bocommon->get_menu(),
 				'msgbox_data'					=> $GLOBALS['phpgw']->common->msgbox($msgbox_data),
-				'links'						=> $links,
 
 				'img_cal'						=> $GLOBALS['phpgw']->common->image('phpgwapi','cal'),
 				'lang_datetitle'				=> lang('Select date'),
@@ -305,7 +290,7 @@
 				'value_debug'					=> $download,
 
 				'lang_import'					=> lang('Import'),
-				'lang_import_statustext'			=> lang('Klick this button to start the import'),
+				'lang_import_statustext'			=> lang('click this button to start the import'),
 
 				'lang_invoice_date'				=> lang('invoice date'),
 				'lang_payment_date'				=> lang('Payment date'),
@@ -324,9 +309,9 @@
 				'lang_num_days_statustext'			=> lang('Enter the payment date or the payment delay'),
 				'lang_payment_date_statustext'			=> lang('Enter the payment date or the payment delay'),
 				'lang_file_statustext'				=> lang('Select the file to import from'),
-				'lang_vendor_statustext'			=> lang('Select the vendor by klicking the button'),
-				'lang_vendor_name_statustext'			=> lang('Select the vendor by klicking the button'),
-				'lang_select_vendor_statustext'			=> lang('Select the vendor by klicking this button'),
+				'lang_vendor_statustext'			=> lang('Select the vendor by clicking the button'),
+				'lang_vendor_name_statustext'			=> lang('Select the vendor by clicking the button'),
+				'lang_select_vendor_statustext'			=> lang('Select the vendor by clicking this button'),
 
 
 				'value_invoice_date'				=> $invoice_date,
@@ -388,7 +373,7 @@
 				'lang_budget_responsible_statustext'		=> lang('You have to select a budget responsible for this invoice in order to make the import')
 			);
 
-			$GLOBALS['phpgw']->xslttpl->add_file(array('invoice','menu'));
+			$GLOBALS['phpgw']->xslttpl->add_file(array('invoice'));
 
 			$appname	= lang('Invoice');
 			$function_msg	= lang('Import from CSV');
@@ -406,30 +391,40 @@
 
 			$sum=0;
 
-			$import_count = count($import);
-			$table_count = count($table);
-			for ($i=0; $i<$table_count; $i++)
+			$i = 0;
+			foreach ($table as $dummy => $record)
 			{
-				for ($k=0; $k<$import_count; $k++)
+				$k=0;
+				foreach ($import as $text => $key)
 				{
-					$content[$i]['row'][$k]['value'] 	= $table[$i][$import[$header[$k]]];
-					if ($import[$header[$k]]=='belop')
+					$content[$i]['row'][$k]['value'] 	= $record[$key];
+					$content[$i]['row'][$k]['align'] 	= 'center';
+					if ($key=='belop')
 					{
 						$content[$i]['row'][$k]['align'] 	= 'right';
-						$sum=$sum+$table[$i][$import[$header[$k]]];
-						$content[$i]['row'][$k]['value'] 	= number_format($table[$i][$import[$header[$k]]], 2, ',', '');
+						$sum=$sum+$record[$key];
+						$content[$i]['row'][$k]['value'] 	= number_format($record[$key], 2, ',', '');
 					}
+					else if ($key=='stedsnavn')
+					{
+						$content[$i]['row'][$k]['align'] 	= 'left';
+					}
+
+					$k++;
 				}
+				$i++;
 			}
 
-			for ($k=0; $k<count($header); $k++)
+			foreach ($import as $text => $key)
 			{
-				$table_header[$k]['header'] 	= $header[$k];
-				$table_header[$k]['width'] 		= '5%';
-				$table_header[$k]['align'] 		= 'center';
+				$table_header[] = array
+				(
+					'header'	=> $text,
+					'width' 	=> '5%',
+					'align' 	=> 'center'
+				);
 			}
 
-
 			$link_data_add = array
 			(
 				'menuaction'	=> 'property.uiXport.import',
@@ -439,7 +434,7 @@
 			$link_data_cancel = array
 			(
 				'menuaction'	=> 'property.uiXport.import',
-				'cancel'	=> True
+				'cancel'	=> true
 
 			);
 
@@ -449,48 +444,45 @@
 
 			$table_add[] = array
 			(
-				'lang_add'		=> lang('Import'),
-				'lang_add_statustext'	=> lang('Import this invoice'),
-				'add_action'		=> $GLOBALS['phpgw']->link('/index.php',$link_data_add),
-				'lang_cancel'		=> lang('cancel'),
-				'lang_cancel_statustext'=> lang('Do not import this invoice'),
-				'cancel_action'		=> $GLOBALS['phpgw']->link('/index.php',$link_data_cancel)
+				'lang_add'					=> lang('Import'),
+				'lang_add_statustext'		=> lang('Import this invoice'),
+				'add_action'				=> $GLOBALS['phpgw']->link('/index.php',$link_data_add),
+				'lang_cancel'				=> lang('cancel'),
+				'lang_cancel_statustext'	=> lang('Do not import this invoice'),
+				'cancel_action'				=> $GLOBALS['phpgw']->link('/index.php',$link_data_cancel)
 
 			);
 
-			$vendor	= $this->contacts->read_single(array('actor_id'=>$table[0]['spvend_code']));
-			if(is_array($vendor))
+			$vendor	= $this->contacts->read_single($invoice_common['vendor_id'], array('attributes'=>array(array('column_name' => 'org_name'))));
+
+			foreach($vendor['attributes'] as $attribute)
 			{
-				foreach($vendor['attributes'] as $attribute)
+				if($attribute['column_name']=='org_name')
 				{
-					if($attribute['name']=='org_name')
-					{
-						$vendor_name=$attribute['value'];
-						break;
-					}
+					$vendor_name = $attribute['value'];
+					break;
 				}
 			}
 
 			$data = array
 			(
-				'artid'							=> $table[0]['artid'],
+				'artid'							=> $invoice_common['art'],
 				'lang_type'						=> lang('Type'),
-				'artid'							=> $table[0]['artid'],
 				'lang_bilagsnr'					=> lang('bilagsnr'),
-				'bilagsnr'						=> $table[0]['bilagsnr'],
+				'bilagsnr'						=> $invoice_common['bilagsnr'],
 				'lang_vendor'					=> lang('Vendor'),
 				'vendor_name'					=> $vendor_name,
-				'spvend_code'					=> $table[0]['spvend_code'],
+				'spvend_code'					=> $invoice_common['vendor_id'],
 				'lang_fakturadato'				=> lang('invoice date'),
-				'fakturadato'					=> $table[0]['fakturadato'],
+				'fakturadato'					=> $invoice_common['invoice_date'],
 				'lang_forfallsdato'				=> lang('Payment date'),
 				'forfallsdato'					=> $table[0]['forfallsdato'],
 				'lang_janitor'					=> lang('Janitor'),
-				'oppsynsmannid'					=> $table[0]['oppsynsmannid'],
+				'oppsynsmannid'					=> $invoice_common['janitor'],
 				'lang_supervisor'				=> lang('Supervisor'),
-				'saksbehandlerid'				=> $table[0]['saksbehandlerid'],
+				'saksbehandlerid'				=> $invoice_common['supervisor'],
 				'lang_budget_responsible'		=> lang('Budget Responsible'),
-				'budsjettansvarligid'			=> $table[0]['budsjettansvarligid'],
+				'budsjettansvarligid'			=> $invoice_common['budget_responsible'],
 				'lang_sum'						=> lang('Sum'),
 				'sum'							=> number_format($sum, 2, ',', ''),
 				'table_header'					=> $table_header,
@@ -517,13 +509,13 @@
 				$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> 'property.uilocation.stop', 'perm'=>16, 'acl_location'=> $this->acl_location));
 			}
 
-			$GLOBALS['phpgw']->xslttpl->add_file(array('invoice','menu',
+			$GLOBALS['phpgw_info']['flags']['menu_selection'] .= '::export';
+			$GLOBALS['phpgw']->xslttpl->add_file(array('invoice',
 										'search_field'));
 
 			$values 	= phpgw::get_var('values');
 			$date 	= phpgw::get_var('date');
-
-			$links = $this->menu->links('export_inv');
+			$receipt = array();
 
 			if($values['submit'])
 			{
@@ -537,10 +529,10 @@
 					$receipt = $this->bo->export(array('conv_type'=>$values['conv_type'],'download'=>$values['download'],'force_period_year'=>$values['force_period_year']));
 					if(!$values['download'])
 					{
-						$GLOBALS['phpgw_info']['flags'][noheader] = True;
-						$GLOBALS['phpgw_info']['flags'][nofooter] = True;
-						$GLOBALS['phpgw_info']['flags']['xslt_app'] = False;
-						$GLOBALS['phpgw_info']['flags']['noframework'] = True;
+						$GLOBALS['phpgw_info']['flags'][noheader] = true;
+						$GLOBALS['phpgw_info']['flags'][nofooter] = true;
+						$GLOBALS['phpgw_info']['flags']['xslt_app'] = false;
+						$GLOBALS['phpgw_info']['flags']['noframework'] = true;
 						echo '<pre>' . $receipt['message'][0]['msg'] . '</pre>';
 						echo '&nbsp<a href="'.$GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uiXport.export')) . '">' . lang('Back') . '</a>';
 					}
@@ -555,42 +547,33 @@
 
 			$link_data = array
 			(
-				'menuaction'		=> 'property.uiXport.export',
-				'invoice_id'		=> $invoice_id,
-				'sub'			=> $sub);
+				'menuaction'		=> 'property.uiXport.export'
+			);
 
 			$msgbox_data = $this->bocommon->msgbox_data($receipt);
 
-			$force_period_year[0]['id'] = date(Y);
-			$force_period_year[1]['id'] = date(Y) -1;
-
-
 			$data = array
 			(
+				'menu'						=> $this->bocommon->get_menu(),
 				'msgbox_data'				=> $GLOBALS['phpgw']->common->msgbox($msgbox_data),
-				'force_period_year'			=> $force_period_year,
-				'lang_force_period_year'		=> lang('Force year for period'),
-				'lang_force_period_year_statustext'	=> lang('Force year for period'),
-				'lang_select_year'			=> lang('select year'),
-				'links'					=> $links,
+				'lang_export_statustext'	=> lang('click this button to start the export'),
 				'lang_select_conv'			=> lang('Select conversion'),
-				'conv_list'				=> $this->bo->select_export_conv($values['conv_type']),
+				'conv_list'					=> $this->bo->select_export_conv($values['conv_type']),
 				'select_conv'				=> 'values[conv_type]',
-				'lang_conv_statustext'			=> lang('Select conversion'),
+				'lang_conv_statustext'		=> lang('Select conversion'),
 
-				'lang_rollback_file'			=> lang('Roll back'),
-				'link_rollback_file'			=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uiXport.rollback')),
+				'lang_rollback_file'		=> lang('Roll back'),
+				'link_rollback_file'		=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uiXport.rollback')),
 
-				'lang_export_to_file'			=> lang('Export to file'),
+				'lang_export_to_file'		=> lang('Export to file'),
 				'value_debug'				=> $values['debug'],
-				'lang_debug_statustext'			=> lang('Uncheck to debug the result'),
+				'lang_debug_statustext'		=> lang('Uncheck to debug the result'),
 
 				'lang_submit'				=> lang('Submit'),
 				'lang_cancel'				=> lang('Cancel'),
 
-				'message'				=> $message,
 				'form_action'				=> $GLOBALS['phpgw']->link('/index.php',$link_data),
-				'lang_save'				=> lang('save')
+				'lang_save'					=> lang('save')
 			);
 
 //_debug_array($data);
@@ -600,7 +583,6 @@
 			$GLOBALS['phpgw_info']['flags']['app_header'] = lang('property') . ' - ' . $appname . ': ' . $function_msg;
 
 			$GLOBALS['phpgw']->xslttpl->set_var('phpgw',array('export' => $data));
-		//	$GLOBALS['phpgw']->xslttpl->pp();
 		}
 
 		function rollback()
@@ -610,15 +592,13 @@
 				$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> 'property.uilocation.stop', 'perm'=>16, 'acl_location'=> $this->acl_location));
 			}
 
-			$GLOBALS['phpgw']->xslttpl->add_file(array('invoice','menu',
+			$GLOBALS['phpgw']->xslttpl->add_file(array('invoice',
 										'search_field'));
 
 			$values 	= phpgw::get_var('values');
 			$date 	= phpgw::get_var('date');
 //_debug_array($values);
 
-			$links = $this->menu->links('export_inv');
-
 			if($values['submit'])
 			{
 				if (!$values['conv_type'])
@@ -643,15 +623,6 @@
 
 			$link_data = array('menuaction'	=> 'property.uiXport.rollback');
 
-			$dateformat = strtolower($GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat']);
-			$sep = '/';
-			$dlarr[strpos($dateformat,'y')] = 'yyyy';
-			$dlarr[strpos($dateformat,'m')] = 'MM';
-			$dlarr[strpos($dateformat,'d')] = 'DD';
-			ksort($dlarr);
-
-			$dateformat= (implode($sep,$dlarr));
-
 //_debug_array($receipt);
 			$jscal = CreateObject('phpgwapi.jscalendar');
 			$jscal->add_listener('date');
@@ -661,7 +632,6 @@
 			$data = array
 			(
 				'msgbox_data'				=> $GLOBALS['phpgw']->common->msgbox($msgbox_data),
-				'links'					=> $links,
 
 				'img_cal'					=> $GLOBALS['phpgw']->common->image('phpgwapi','cal'),
 				'lang_datetitle'			=> lang('Select date'),
@@ -703,4 +673,4 @@
 		//	$GLOBALS['phpgw']->xslttpl->pp();
 		}
 	}
-?>
+
