@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage admin
- 	* @version $Id: class.uiadmin.inc.php 18358 2007-11-27 04:43:37Z skwashd $
+ 	* @version $Id: class.uiadmin.inc.php 5148 2010-04-08 13:42:11Z sigurd $
 	*/
 
 	/**
@@ -48,15 +48,16 @@
 
 		var $public_functions = array
 		(
-			'list_acl'		=> True,
-			'aclprefs'		=> True,
-			'edit_id'		=> True,
-			'contact_info'	=> True
+			'list_acl'		=> true,
+			'aclprefs'		=> true,
+			'edit_id'		=> true,
+			'contact_info'	=> true
 		);
 
 		function property_uiadmin()
 		{
-			$GLOBALS['phpgw_info']['flags']['xslt_app'] = True;
+			$GLOBALS['phpgw_info']['flags']['xslt_app'] = true;
+			$GLOBALS['phpgw_info']['flags']['menu_selection'] = 'admin::property';
 		//	$this->currentapp			= $GLOBALS['phpgw_info']['flags']['currentapp'];
 			$this->nextmatchs			= CreateObject('phpgwapi.nextmatchs');
 			$this->account				= $GLOBALS['phpgw_info']['user']['account_id'];
@@ -65,13 +66,13 @@
 			$this->bopreferences		= createObject('preferences.boadmin_acl',true);
 			$this->bocommon				= CreateObject('property.bocommon');
 
-			$this->acl 					= CreateObject('phpgwapi.acl');
+			$this->acl 					= & $GLOBALS['phpgw']->acl;
 			$this->acl_location			= '.admin';
-			$this->acl_read 			= $this->acl->check($this->acl_location,1);
-			$this->acl_add 				= $this->acl->check($this->acl_location,2);
-			$this->acl_edit 			= $this->acl->check($this->acl_location,4);
-			$this->acl_delete 			= $this->acl->check($this->acl_location,8);
-			$this->acl_manage 			= $this->acl->check($this->acl_location,16);
+			$this->acl_read 			= $this->acl->check($this->acl_location, PHPGW_ACL_READ, 'property');
+			$this->acl_add 				= $this->acl->check($this->acl_location, PHPGW_ACL_ADD, 'property');
+			$this->acl_edit 			= $this->acl->check($this->acl_location, PHPGW_ACL_EDIT, 'property');
+			$this->acl_delete 			= $this->acl->check($this->acl_location, PHPGW_ACL_DELETE, 'property');
+			$this->acl_manage 			= $this->acl->check($this->acl_location, 16, 'property');
 
 	//		$this->acl_app			= $this->bo->acl_app;
 			$this->start			= $this->bo->start;
@@ -107,6 +108,12 @@
 
 		function aclprefs()
 		{
+			if (!isset($GLOBALS['phpgw_info']['user']['apps']['preferences']))
+			{
+				$this->bocommon->no_access();
+				return;
+			}
+
 			$GLOBALS['phpgw']->xslttpl->add_file(array('admin','nextmatchs',
 										'search_field'));
 
@@ -234,7 +241,7 @@
 			}
 
 			$msgbox_data = (isset($receipt)?$this->bocommon->msgbox_data($receipt):'');
-	
+
 			$num_records = 0;
 			if(isset($user_list) && is_array($user_list))
 			{
@@ -244,7 +251,7 @@
 			{
 				$num_records = $num_records + count($group_list);
 			}
-			
+
 			$data = array
 			(
 				'msgbox_data'					=> $GLOBALS['phpgw']->common->msgbox($msgbox_data),
@@ -271,7 +278,7 @@
 				'cat_list'						=> $this->bo->select_category_list('filter',$this->cat_id),
 				'select_action'					=> $GLOBALS['phpgw']->link('/index.php',$link_data),
 				'cat_id'						=> $this->cat_id,
-				'permission'					=> False,
+				'permission'					=> false,
 				'grant'							=> 1,
 
 				'lang_searchfield_statustext'	=> lang('Enter the search string. To show all entries, empty this field and press the SUBMIT button again'),
@@ -284,18 +291,20 @@
 				'lang_no_location'				=> lang('No location'),
 				'lang_location_statustext'		=> lang('Select submodule'),
 				'select_name_location'			=> 'module',
-				'location_list'					=> $this->bopreferences->select_location('filter',$this->location,True),
+				'location_list'					=> $this->bopreferences->select_location('filter',$this->location,true),
 
 				'is_admin'						=> $GLOBALS['phpgw_info']['user']['apps']['admin'],
 				'lang_group_statustext'			=> lang('Select the granting group. To do not use a granting group select NO GRANTING GROUP'),
 				'select_group_name'				=> 'granting_group',
 				'lang_no_group'					=> lang('No granting group'),
 				'group_list'					=> $this->bocommon->get_group_list('filter',$this->granting_group,$start=-1,$sort='ASC',$order='account_firstname',$query='',$offset=-1),
+				'lang_enable_inheritance'       => lang('enable inheritance'), 
+                'lang_enable_inheritance_statustext'        => lang('rights are inherited down the hierarchy')
 			);
 
 			$appname	= lang('preferences');
 			$function_msg	= lang('set grants');
-			$owner_name = $GLOBALS['phpgw']->accounts->id2name($GLOBALS['phpgw']->accounts->account_id);		// get owner name for title
+			$owner_name = $GLOBALS['phpgw']->accounts->id2name($this->account);		// get owner name for title
 
 			$GLOBALS['phpgw_info']['flags']['app_header'] = lang('property') . ' - ' . $appname . ': ' . $function_msg . ': ' . $owner_name;
 			$GLOBALS['phpgw']->xslttpl->set_var('phpgw',array('list_permission' => $data));
@@ -306,6 +315,13 @@
 
 		function list_acl()
 		{
+			$GLOBALS['phpgw_info']['flags']['menu_selection'] .= '::permissions';
+
+			if (!isset($GLOBALS['phpgw_info']['user']['apps']['admin'])) //this one is different
+			{
+				$this->bocommon->no_access();
+				return;
+			}
 
 			$GLOBALS['phpgw']->xslttpl->add_file(array('admin','nextmatchs',
 										'search_field'));
@@ -321,6 +337,7 @@
 				$receipt	= $this->bo->set_permission($values,$r_processed,false,$initials);
 			}
 
+			$num_records = 0;
 			if ($this->location)
 			{
 				if($this->cat_id=='accounts')
@@ -330,6 +347,7 @@
 
 				if (isSet($user_list) AND is_array($user_list))
 				{
+					$num_records = count($user_list);
 					foreach($user_list as $user)
 					{
 						$processed[] = $user['account_id'];
@@ -387,6 +405,7 @@
 
 				if (isSet($group_list) AND is_array($group_list))
 				{
+					$num_records = count($group_list);
 					foreach($group_list as $group)
 					{
 						$processed[] = $group['account_id'];
@@ -525,8 +544,8 @@
 				'processed'						=> (isset($processed)?$processed:''),
 				'location'						=> $this->location,
 
-				'num_records'					=> (isset($user_list)?count($user_list):''),
-				'all_records'					=> (isset($this->bo->total_records)?$this->bo->total_records:''),
+				'num_records'					=> $num_records,
+				'all_records'					=> isset($this->bo->total_records) && $this->bo->total_records ? $this->bo->total_records : 0,
 				'link_url'						=> $GLOBALS['phpgw']->link('/index.php',$link_data),
 				'img_path'						=> $GLOBALS['phpgw']->common->get_image_path('phpgwapi','default'),
 
@@ -553,7 +572,9 @@
 				'lang_no_location'				=> lang('No location'),
 				'lang_location_statustext'		=> lang('Select submodule'),
 				'select_name_location'			=> 'module',
-				'location_list'					=> $this->bopreferences->select_location('filter',$this->location,False)
+				'location_list'					=> $this->bopreferences->select_location('filter',$this->location,false),
+				'lang_enable_inheritance'       => lang('enable inheritance'), 
+                'lang_enable_inheritance_statustext'        => lang('rights are inherited down the hierarchy')
 			);
 
 			$appname	= lang('permission');
@@ -567,6 +588,13 @@
 
 		function edit_id()
 		{
+			$GLOBALS['phpgw_info']['flags']['menu_selection'] .= '::id_control';
+
+			if (!$this->acl_edit)
+			{
+				$this->bocommon->no_access();
+				return;
+			}
 
 			$GLOBALS['phpgw']->xslttpl->add_file(array('admin'));
 
@@ -630,14 +658,23 @@
 
 		function contact_info()
 		{
+			$GLOBALS['phpgw_info']['flags']['menu_selection'] .= '::user_contact';
+
+			if (!$this->acl_edit)
+			{
+				$this->bocommon->no_access();
+				return;
+			}
+
+			$user_id	= phpgw::get_var('user_id', 'int');
+
 			$GLOBALS['phpgw']->xslttpl->add_file(array('admin'));
 
 			$values		= phpgw::get_var('values');
 
 			if ($values['save'])
 			{
-				$GLOBALS['phpgw']->preferences->account_id=$this->filter;
-				$GLOBALS['phpgw']->preferences->read_repository();
+				$GLOBALS['phpgw']->preferences->set_account_id($user_id, true);
 
 				if ($values['old_email'] != $values['email'])
 				{
@@ -659,18 +696,63 @@
 					$GLOBALS['phpgw']->preferences->add('property',"default_vendor_category",$values['default_vendor_category'],'user');
 					$receipt['message'][] = array('msg' => lang('default vendor category is updated'));
 				}
+				if ($values['old_default_tts_category'] != $values['default_tts_category'])
+				{
+					$GLOBALS['phpgw']->preferences->add('property',"tts_category",$values['default_tts_category'],'user');
+					$receipt['message'][] = array('msg' => lang('default ticket category is updated'));
+				}
+				if ($values['old_assigntodefault'] != $values['assigntodefault'])
+				{
+					$GLOBALS['phpgw']->preferences->add('property',"assigntodefault",$values['assigntodefault'],'user');
+					$receipt['message'][] = array('msg' => lang('default ticket assigned to is updated'));
+				}
+				if ($values['old_groupdefault'] != $values['groupdefault'])
+				{
+					$GLOBALS['phpgw']->preferences->add('property',"groupdefault",$values['groupdefault'],'user');
+					$receipt['message'][] = array('msg' => lang('default ticket group is updated'));
+				}
 				$GLOBALS['phpgw']->preferences->save_repository();
 			}
 
-			if($this->filter)
+			if($user_id)
 			{
-				$prefs = $this->bocommon->create_preferences('property',$this->filter);
+				$prefs = $this->bocommon->create_preferences('property',$user_id);
 			}
 
-			$cats		= CreateObject('phpgwapi.categories');
-			$cats->app_name = 'fm_vendor';
+			$cats		= CreateObject('phpgwapi.categories', -1, 'property', '.vendor');
 
-			$cat_data	= $cats->formatted_xslt_list(array('selected' => $prefs['default_vendor_category'],'globals' => True, 'link_data' =>array()));
+			$cat_data	= $cats->formatted_xslt_list(array('selected' => $prefs['default_vendor_category'],'globals' => true, 'link_data' =>array()));
+
+			$cats->set_appname('property','.ticket');
+
+			$cat_data_tts	= $cats->formatted_xslt_list(array('selected' => $prefs['tts_category'],'globals' => true, 'link_data' =>array()));
+
+			$acc = & $GLOBALS['phpgw']->accounts;
+			$group_list = $acc->get_list('groups',-1,'ASC');
+			foreach ( $group_list as $entry )
+			{
+				$groups_tts[] = array
+				(
+					'id'	=> $entry->id,
+					'name'	=> $entry->lid,
+					'selected' => $entry->id == $prefs['groupdefault']
+				);
+			}
+
+			$account_list = $acc->get_list('accounts',-1,'ASC','account_lastname');
+
+			foreach ( $account_list as $entry )
+			{
+				if($entry->enabled == true)
+				{
+					$accounts_tts[] = array
+					(
+						'id'	=> $entry->id,
+						'name'	=> $entry->__toString(),
+						'selected' => $entry->id == $prefs['assigntodefault']
+					);
+				}
+			}
 
 			$msgbox_data = $this->bocommon->msgbox_data($receipt);
 
@@ -698,7 +780,7 @@
 
 				'lang_approval_from'			=> lang('Approval from'),
 				'value_old_approval_from'		=> $prefs['approval_from'],
-				'approval_from'					=> $this->bocommon->get_user_list('select',$prefs['approval_from'],$extra=False,$default=False,$start=-1,$sort='ASC',$order='account_lastname',$query='',$offset=-1),
+				'approval_from'					=> $this->bocommon->get_user_list('select',$prefs['approval_from'],$extra=false,$default=false,$start=-1,$sort='ASC',$order='account_lastname',$query='',$offset=-1),
 
 				'select_user_name'				=> 'approval_from',
 				'lang_approval_from_statustext'	=> lang('Select the users supervisor'),
@@ -706,16 +788,29 @@
 				'lang_default_vendor_category'	=> lang('default vendor category'),
 				'value_old_default_vendor_category'	=> $prefs['default_vendor_category'],
 				'vendor_category'				=> $cat_data['cat_list'],
+
+				'lang_default_tts_category'		=> lang('default ticket categories'),
+				'value_old_default_tts_category'	=> $prefs['tts_category'],
+				'tts_category'					=> $cat_data_tts['cat_list'],
+
 				'select_user_name'				=> 'approval_from',
 				'lang_default_vendor_category_statustext'=> lang('Select default vendor category'),
 				'lang_no_cat'					=> lang('No category'),
 
 
 				'lang_user_statustext'			=> lang('Select the user to edit email'),
-				'select_user_name'				=> 'filter',
+				'select_user_name'				=> 'user_id',
 				'lang_no_user'					=> lang('No user'),
-				'value_user_id'					=> $this->filter,
-				'user_list'						=> $this->bocommon->get_user_list('filter',$this->filter,$extra=False,$default=False,$start=-1,$sort='ASC',$order='account_lastname',$query='',$offset=-1),
+				'value_user_id'					=> $user_id,
+				'user_list'						=> $this->bocommon->get_user_list('filter',$user_id,$extra=false,$default=false,$start=-1,$sort='ASC',$order='account_lastname',$query='',$offset=-1, true),
+				'group_list_tts'				=> $groups_tts,
+				'account_list_tts'				=> $accounts_tts,
+				'lang_group_select'				=> lang('Default group TTS'),
+				'lang_account_select'			=> lang('Default assign to TTS'),
+				'value_old_assigntodefault'		=> $prefs['assigntodefault'],
+				'value_old_groupdefault'		=> $prefs['groupdefault'],
+				'lang_no_assigntodefault'		=> lang('no user'),
+				'lang_no_groupdefault'			=> lang('no group'),
 			);
 
 			$appname	= lang('User contact info');
@@ -727,4 +822,4 @@
 			$this->save_sessiondata();
 		}
 	}
-?>
+
