@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage ifc
- 	* @version $Id: class.uiifc.inc.php 18358 2007-11-27 04:43:37Z skwashd $
+ 	* @version $Id: class.uiifc.inc.php 1046 2008-05-26 19:51:07Z sigurd $
 	*/
 
 	/**
@@ -44,30 +44,29 @@
 
 		var $public_functions = array
 		(
-			'index'		=> True,
-			'view'		=> True,
-			'edit'		=> True,
-			'import'	=> True,
-			'delete'	=> True,
+			'index'		=> true,
+			'view'		=> true,
+			'edit'		=> true,
+			'import'	=> true,
+			'delete'	=> true,
 			'no_access'	=> true
 		);
 
 		function uiifc()
 		{
-			$GLOBALS['phpgw_info']['flags']['xslt_app'] = True;
+			$GLOBALS['phpgw_info']['flags']['xslt_app'] = true;
+			$GLOBALS['phpgw_info']['flags']['menu_selection'] = 'property::ifc';
 		//	$this->currentapp		= $GLOBALS['phpgw_info']['flags']['currentapp'];
 			$this->cats				= CreateObject('phpgwapi.categories');
 			$this->nextmatchs		= CreateObject('phpgwapi.nextmatchs');
 			$this->account			= $GLOBALS['phpgw_info']['user']['account_id'];
 			$this->bo				= CreateObject('property.boifc',true);
-			$this->menu				= CreateObject('property.menu');
-			$this->menu->sub		='ifc';
 			$this->acl 				= & $GLOBALS['phpgw']->acl;
 			$this->acl_location 	= '.ifc';
-			$this->acl_read 			= $this->acl->check($this->acl_location,PHPGW_ACL_READ);
-			$this->acl_add 				= $this->acl->check($this->acl_location,PHPGW_ACL_ADD);
-			$this->acl_edit 			= $this->acl->check($this->acl_location,PHPGW_ACL_EDIT);
-			$this->acl_delete 			= $this->acl->check($this->acl_location,PHPGW_ACL_DELETE);
+			$this->acl_read 			= $this->acl->check($this->acl_location, PHPGW_ACL_READ, 'property');
+			$this->acl_add 				= $this->acl->check($this->acl_location, PHPGW_ACL_ADD, 'property');
+			$this->acl_edit 			= $this->acl->check($this->acl_location, PHPGW_ACL_EDIT, 'property');
+			$this->acl_delete 			= $this->acl->check($this->acl_location, PHPGW_ACL_DELETE, 'property');
 
 			$this->start			= $this->bo->start;
 			$this->query			= $this->bo->query;
@@ -94,22 +93,19 @@
 		function index()
 		{
 			$output	= phpgw::get_var('output');
-			
+
 			if(!$output)
 			{
 				$output = 'html';
 			}
-			
-			$this->menu->sub = 'alternative';
-			$links = $this->menu->links();
+
 			if(!$this->acl_read)
 			{
-				$this->no_access($links);
+				$this->no_access();
 				return;
 			}
 
-			$GLOBALS['phpgw']->xslttpl->add_file(array('ifc','nextmatchs','menu',
-										'search_field'));
+			$GLOBALS['phpgw']->xslttpl->add_file(array('ifc','nextmatchs','search_field'));
 
 			$ifc_info = $this->bo->read();
 
@@ -244,10 +240,9 @@
 			$data = array
 			(
 				'msgbox_data'							=> $GLOBALS['phpgw']->common->msgbox($msgbox_data),
-				'links'									=> $links,
-				'cat_filter'							=> $this->cats->formatted_xslt_list(array('select_name' => 'cat_id','selected' => $this->cat_id,'globals' => True,'link_data' => $link_data)),
+				'cat_filter'							=> $this->cats->formatted_xslt_list(array('select_name' => 'cat_id','selected' => $this->cat_id,'globals' => true,'link_data' => $link_data)),
 				'filter_data'							=> $this->nextmatchs->xslt_filter(array('filter' => $this->filter,'link_data' => $link_data)),
-				'allow_allrows'							=> True,
+				'allow_allrows'							=> true,
 				'allrows'								=> $this->allrows,
 				'start_record'							=> $this->start,
 				'record_limit'							=> $record_limit,
@@ -268,7 +263,7 @@
 			$function_msg= lang('list ifc values');
 
 			$GLOBALS['phpgw_info']['flags']['app_header'] = lang('property'). ': ' . $function_msg;
-			
+
 			if($output == 'wml')
 			{
 				$GLOBALS['phpgw']->xslttpl->set_output('wml');
@@ -279,15 +274,16 @@
 
 		function import()
 		{
+			$GLOBALS['phpgw_info']['flags']['menu_selection'] .= '::import';
 			$acl_location = '.ifc.import';
-			if(!$this->acl->check($acl_location,PHPGW_ACL_ADD))
+			if(!$this->acl->check($acl_location,PHPGW_ACL_ADD, 'property'))
 			{
 //				$this->no_access();
 //				return;
 			}
 
 			$bolocation		= CreateObject('property.bolocation');
-			
+
 			$GLOBALS['phpgw']->xslttpl->add_file(array('ifc'));
 			$values		= phpgw::get_var('values');
 
@@ -304,7 +300,7 @@
 					{
 						$ifcfile = phpgw::get_var('tsvfile');
 					}
-				
+
 					if(!isset($receipt['error']) || !$receipt['error'])
 					{
 					//	$values['ifc_id']	= $ifc_id;
@@ -327,13 +323,13 @@
 					}
 					$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> 'property.uiifc.index'));
 				}
-			}				
+			}
 
 			$location_data=$bolocation->initiate_ui_location(array(
 						'values'	=> (isset($values['location_data'])?$values['location_data']:''),
 						'type_id'	=> -1, // calculated from location_types
-						'no_link'	=> False, // disable lookup links for location type less than type_id
-						'tenant'	=> False,
+						'no_link'	=> false, // disable lookup links for location type less than type_id
+						'tenant'	=> false,
 						'lookup_type'	=> 'form',
 						'lookup_entity'	=> false,
 						'entity_data'	=> (isset($values['p'])?$values['p']:'')
@@ -353,7 +349,7 @@
 				'import_url'					=> $GLOBALS['phpgw']->link('/index.php',$link_data),
 				'location_data'					=> $location_data,
 				'lang_file'						=> lang('file'),
-				'lang_file_statustext'			=> lang('choose file to import'),				
+				'lang_file_statustext'			=> lang('choose file to import'),
 
 				'lang_save'						=> lang('save'),
 				'lang_cancel'					=> lang('cancel'),
@@ -382,7 +378,7 @@
 			}
 
 			$output	= phpgw::get_var('output');
-			
+
 			if(!$output)
 			{
 				$output = 'html';
@@ -408,7 +404,7 @@
 			{
 				if(!$this->acl_edit)
 				{
-					$this->no_access($links);
+					$this->no_access();
 					return;
 				}
 
@@ -416,9 +412,9 @@
 				{
 					while (is_array($insert_record['extra']) && list($key,$column) = each($insert_record['extra']))
 					{
-						if($_POST[$key])
+						if(isset($_POST[$key]) && $_POST[$key])
 						{
-							$values['extra'][$column]	= $_POST[$key];
+							$values['extra'][$column]	= phpgw::get_var($key, 'string', 'POST');
 						}
 					}
 				}
@@ -450,7 +446,7 @@
 					{
 						foreach ($values_attribute as $attribute )
 						{
-							if($attribute['allow_null'] != 'True' && !$attribute['value'])
+							if($attribute['allow_null'] != 'true' && !$attribute['value'])
 							{
 								$receipt['error'][]=array('msg'=>lang('Please enter value for attribute %1', $attribute['input_text']));
 							}
@@ -681,9 +677,9 @@
 			$GLOBALS['phpgw']->xslttpl->set_var('phpgw',array('delete' => $data));
 		}
 
-		function no_access($links = '')
+		function no_access()
 		{
-			$GLOBALS['phpgw']->xslttpl->add_file(array('no_access','menu'));
+			$GLOBALS['phpgw']->xslttpl->add_file(array('no_access'));
 
 			$receipt['error'][]=array('msg'=>lang('NO ACCESS'));
 
@@ -692,7 +688,6 @@
 			$data = array
 			(
 				'msgbox_data'	=> $GLOBALS['phpgw']->common->msgbox($msgbox_data),
-				'links'			=> $links,
 			);
 
 			$appname	= lang('No access');
