@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage agreement
- 	* @version $Id: class.uir_agreement.inc.php 18358 2007-11-27 04:43:37Z skwashd $
+ 	* @version $Id: class.uir_agreement.inc.php 5148 2010-04-08 13:42:11Z sigurd $
 	*/
 
 	/**
@@ -32,6 +32,8 @@
 	 * @package property
 	 */
 
+	phpgw::import_class('phpgwapi.yui');
+
 	class property_uir_agreement
 	{
 		var $grants;
@@ -44,42 +46,41 @@
 
 		var $public_functions = array
 		(
-			'index'  			=> True,
-			'view'   			=> True,
-			'edit'   			=> True,
-			'delete' 			=> True,
-			'columns'			=> True,
-			'edit_item'			=> True,
-			'view_item'			=> True,
-			'view_file'			=> True,
-			'excel'				=> True,
-			'edit_common'		=> True,
-			'delete_common_h'	=> True
+			'index'  			=> true,
+			'view'   			=> true,
+			'edit'   			=> true,
+			'delete' 			=> true,
+			'columns'			=> true,
+			'edit_item'			=> true,
+			'view_item'			=> true,
+			'view_file'			=> true,
+			'download'				=> true,
+			'edit_common'		=> true,
+			'delete_common_h'	=> true
 		);
 
 		function property_uir_agreement()
 		{
-			$GLOBALS['phpgw_info']['flags']['xslt_app'] = True;
+			$GLOBALS['phpgw_info']['flags']['xslt_app'] = true;
+			$GLOBALS['phpgw_info']['flags']['menu_selection'] = 'property::agreement::rental';
 			$this->nextmatchs		= CreateObject('phpgwapi.nextmatchs');
 			$this->account			= $GLOBALS['phpgw_info']['user']['account_id'];
 
-			$this->bo				= CreateObject('property.bor_agreement',True);
+			$this->bo				= CreateObject('property.bor_agreement',true);
 			$this->bocommon			= CreateObject('property.bocommon');
-			$this->menu				= CreateObject('property.menu');
 
 			$this->role				= $this->bo->role;
 
-			$this->cats				= CreateObject('phpgwapi.categories');
-			$this->cats->app_name	= 'fm_tenant';
+			$this->cats				= CreateObject('phpgwapi.categories', -1, 'property', '.tenant');
 
-			$this->acl				= CreateObject('phpgwapi.acl');
+			$this->acl				= & $GLOBALS['phpgw']->acl;
 			$this->acl_location		= '.r_agreement';
 
-			$this->acl_read 		= $this->acl->check($this->acl_location,1);
-			$this->acl_add			= $this->acl->check($this->acl_location,2);
-			$this->acl_edit			= $this->acl->check($this->acl_location,4);
-			$this->acl_delete		= $this->acl->check($this->acl_location,8);
-			$this->acl_manage		= $this->acl->check($this->acl_location,16);
+			$this->acl_read 		= $this->acl->check($this->acl_location, PHPGW_ACL_READ, 'property');
+			$this->acl_add			= $this->acl->check($this->acl_location, PHPGW_ACL_ADD, 'property');
+			$this->acl_edit			= $this->acl->check($this->acl_location, PHPGW_ACL_EDIT, 'property');
+			$this->acl_delete		= $this->acl->check($this->acl_location, PHPGW_ACL_DELETE, 'property');
+			$this->acl_manage		= $this->acl->check($this->acl_location, 16, 'property');
 
 			$this->start			= $this->bo->start;
 			$this->query			= $this->bo->query;
@@ -90,9 +91,7 @@
 			$this->customer_id		= $this->bo->customer_id;
 			$this->allrows			= $this->bo->allrows;
 			$this->member_id		= $this->bo->member_id;
-			$this->fakebase 		= $this->bo->fakebase;
 			$this->loc1 			= $this->bo->loc1;
-
 		}
 
 		function save_sessiondata()
@@ -118,7 +117,7 @@
 
 			$GLOBALS['phpgw']->xslttpl->add_file(array('columns'));
 
-			$GLOBALS['phpgw_info']['flags']['noframework'] = True;
+			$GLOBALS['phpgw_info']['flags']['noframework'] = true;
 
 			$values = phpgw::get_var('values');
 
@@ -126,7 +125,7 @@
 			{
 
 				$GLOBALS['phpgw']->preferences->account_id=$this->account;
-				$GLOBALS['phpgw']->preferences->read_repository();
+				$GLOBALS['phpgw']->preferences->read();
 				$GLOBALS['phpgw']->preferences->add('property','r_agreement_columns',$values['columns'],'user');
 				$GLOBALS['phpgw']->preferences->save_repository();
 
@@ -146,7 +145,7 @@
 			$data = array
 			(
 				'msgbox_data' 	=> $GLOBALS['phpgw']->common->msgbox($msgbox_data),
-				'column_list'	=> $this->bo->column_list($values['columns'],$allrows=True),
+				'column_list'	=> $this->bo->column_list($values['columns'],$allrows=true),
 				'function_msg'	=> $function_msg,
 				'form_action'	=> $GLOBALS['phpgw']->link('/index.php',$link_data),
 				'lang_columns'	=> lang('columns'),
@@ -167,61 +166,23 @@
 				$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> 'property.uilocation.stop', 'perm'=>1, 'acl_location'=> $this->acl_location));
 			}
 
-			$GLOBALS['phpgw_info']['flags'][noheader] = True;
-			$GLOBALS['phpgw_info']['flags'][nofooter] = True;
-			$GLOBALS['phpgw_info']['flags']['xslt_app'] = False;
-
-			$file_name	= urldecode(phpgw::get_var('file_name'));
-			$id 		= phpgw::get_var('id', 'int');
-
-			$file = $this->fakebase. SEP . 'rental_agreement' . SEP . $id . SEP . $file_name;
-
-			if($this->bo->vfs->file_exists(array(
-				'string' => $file,
-				'relatives' => Array(RELATIVE_NONE)
-				)))
-			{
-				$ls_array = $this->bo->vfs->ls (array (
-						'string'		=>  $file,
-						'relatives' 	=> Array(RELATIVE_NONE),
-						'checksubdirs'	=> False,
-						'nofiles'		=> True
-					)
-				);
-
-				$this->bo->vfs->override_acl = 1;
-
-				$document= $this->bo->vfs->read(array(
-					'string' => $file,
-					'relatives' => Array(RELATIVE_NONE)));
-
-				$this->bo->vfs->override_acl = 0;
-
-				$browser = CreateObject('phpgwapi.browser');
-				$browser->content_header($ls_array[0]['name'],$ls_array[0]['mime_type'],$ls_array[0]['size']);
-
-				echo $document;
-			}
+			$bofiles	= CreateObject('property.bofiles');
+			$bofiles->view_file('rental_agreement');
 		}
 
 		function index()
 		{
-			$this->menu->sub	= 'agreement';
-
 			if(!$this->acl_read)
 			{
 				$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> 'property.uilocation.stop', 'perm'=>1, 'acl_location'=> $this->acl_location));
 			}
 
 			$GLOBALS['phpgw']->xslttpl->add_file(array('r_agreement',
-										'menu',
 										'receipt',
 										'search_field_grouped',
 										'nextmatchs',
 										));
 
-			$links = $this->menu->links('r_agreement');
-
 			$receipt = $GLOBALS['phpgw']->session->appsession('session_data','r_agreement_receipt');
 			$GLOBALS['phpgw']->session->appsession('session_data','r_agreement_receipt','');
 
@@ -363,19 +324,19 @@
 				'role'		=> $this->role
 			);
 
-			$member_of_data	= $this->cats->formatted_xslt_list(array('selected' => $this->member_id,'globals' => True,link_data => $link_data));
+			$member_of_data	= $this->cats->formatted_xslt_list(array('selected' => $this->member_id,'globals' => true,link_data => $link_data));
 
 			$GLOBALS['phpgw']->js->validate_file('overlib','overlib','property');
 
 //_debug_array($member_of_data);
 			$data = array
 			(
+				'menu'							=> $this->bocommon->get_menu(),
 				'lang_columns'					=> lang('columns'),
 				'link_columns'					=> $GLOBALS['phpgw']->link('/index.php',$link_columns),
 				'lang_columns_help'				=> lang('Choose columns'),
 				'msgbox_data'					=> $GLOBALS['phpgw']->common->msgbox($msgbox_data),
-				'links'							=> $links,
- 				'allow_allrows'					=> True,
+ 				'allow_allrows'					=> true,
 				'allrows'						=> $this->allrows,
 				'start_record'					=> $this->start,
 				'record_limit'					=> $record_limit,
@@ -409,10 +370,10 @@
 				'table_add'						=> $table_add,
 
 				'tenant_link'					=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uilookup.tenant')),
-				'lang_select_tenant_statustext'	=> lang('Select the customer by klicking this link'),
+				'lang_select_tenant_statustext'	=> lang('Select the customer by clicking this link'),
 				'lang_tenant'					=> lang('customer'),
 				'property_link'					=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uilocation.index', 'lookup'=>1, 'type_id'=>1, 'lookup_name'=>0)),
-				'lang_select_property_statustext'=> lang('Select the property by klicking this link'),
+				'lang_select_property_statustext'=> lang('Select the property by clicking this link'),
 				'lang_property_statustext'		=> lang('Search by property'),
 				'lang_property'					=> lang('property'),
 				'customer_id'					=> $this->customer_id,
@@ -523,12 +484,13 @@
 
 		function edit()
 		{
-			$id	= phpgw::get_var('id', 'int');
-			$values		= phpgw::get_var('values');
+			$id				= phpgw::get_var('id', 'int');
+			$values			= phpgw::get_var('values');
 			$delete_item	= phpgw::get_var('delete_item', 'bool');
-			$item_id	= phpgw::get_var('item_id', 'int', 'GET');
+			$item_id		= phpgw::get_var('item_id', 'int', 'GET');
+			$active_tab		= phpgw::get_var('tab', 'string', 'REQUEST', 'general');
 
-			$config		= CreateObject('phpgwapi.config','property');
+			$config			= CreateObject('phpgwapi.config','property');
 			$boalarm		= CreateObject('property.boalarm');
 
 			if($delete_item && $id && $item_id)
@@ -547,7 +509,7 @@
 			}
 
 
-			$GLOBALS['phpgw']->xslttpl->add_file(array('r_agreement','attributes_form'));
+			$GLOBALS['phpgw']->xslttpl->add_file(array('r_agreement', 'attributes_form', 'files'));
 
 			if (is_array($values))
 			{
@@ -570,7 +532,7 @@
 					{
 						$values['customer_name'] = $first_name . ' ' . $values['customer_name'];
 					}
-										
+
 					$values['b_account_id']		= phpgw::get_var('b_account_id', 'int', 'POST');
 					$values['b_account_name']	= phpgw::get_var('b_account_name', 'string', 'POST');
 
@@ -595,12 +557,18 @@
 						$values['r_agreement_id']=$this->bo->request_next_id();
 					}
 
+					$bofiles	= CreateObject('property.bofiles');
+					if(isset($id) && $id && isset($values['file_action']) && is_array($values['file_action']))
+					{
+						$bofiles->delete_file("/rental_agreement/{$id}/", $values);
+					}
+
 					if(isset($_FILES['file']['name']) && $_FILES['file']['name'])
 					{
 						$values['file_name']=str_replace (' ','_',$_FILES['file']['name']);
-						$to_file = $this->fakebase. SEP . 'rental_agreement' . SEP . $values['r_agreement_id'] . SEP . $values['file_name'];
+						$to_file = "{$bofiles->fakebase}/rental_agreement/{$values['r_agreement_id']}/{$values['file_name']}";
 
-						if(!$values['document_name_orig'] && $this->bo->vfs->file_exists(array(
+						if(!$values['document_name_orig'] && $bofiles->vfs->file_exists(array(
 								'string' => $to_file,
 								'relatives' => Array(RELATIVE_NONE)
 							)))
@@ -609,28 +577,27 @@
 						}
 					}
 
-
 					if(!$receipt['error'])
 					{
 //						$values['r_agreement_id']	= $id;
-						$receipt	= $this->bo->create_home_dir($receipt);
+
 						$receipt = $this->bo->save($values,$values_attribute,$action);
 						$id = $receipt['r_agreement_id'];
 						$this->cat_id = ($values['cat_id']?$values['cat_id']:$this->cat_id);
 
 						if($values['file_name'])
 						{
-							$this->bo->create_document_dir($id);
-							$this->bo->vfs->override_acl = 1;
+							$bofiles->create_document_dir("rental_agreement/{$id}");
+							$bofiles->vfs->override_acl = 1;
 
-							if(!$this->bo->vfs->cp (array (
+							if(!$bofiles->vfs->cp (array (
 								'from'	=> $_FILES['file']['tmp_name'],
 								'to'	=> $to_file,
 								'relatives'	=> array (RELATIVE_NONE|VFS_REAL, RELATIVE_ALL))))
 							{
 								$receipt['error'][]=array('msg'=>lang('Failed to upload file !'));
 							}
-							$this->bo->vfs->override_acl = 0;
+							$bofiles->vfs->override_acl = 0;
 						}
 
 
@@ -705,21 +672,25 @@
 			$jscal->add_listener('values_start_date');
 			$jscal->add_listener('values_end_date');
 			$jscal->add_listener('values_termination_date');
-			
+
 			if ($id)
-			{
-				$jscal->add_listener('values_date');
+			{		
 				$this->cat_id = ($r_agreement['cat_id']?$r_agreement['cat_id']:$this->cat_id);
 				$this->member_id = ($r_agreement['member_of']?$r_agreement['member_of']:$this->member_id);
 				$list = $this->bo->read_details($id);
 
+				if($list)
+				{
+					$jscal->add_listener('values_date');
+				}
+
 				$uicols		= $this->bo->uicols;
 				$list		= $this->list_content($list,$uicols);
 				$content	= $list['content'];
 				$table_header=$list['table_header'];
 				for ($i=0; $i<count($list['content'][0]['row']); $i++)
 				{
-					$set_column[]=True;
+					$set_column[]=true;
 				}
 
 				if ($content)
@@ -777,7 +748,7 @@
 							'text_edit'					=> $text_edit,
 							'text_delete'				=> $text_delete
 						);
-						
+
 						unset($link_edit);
 						unset($link_delete);
 						unset($text_edit);
@@ -836,37 +807,10 @@
 						'account_id'=> $account_id
 						));
 
-			$dateformat = strtolower($GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat']);
-			$sep = '/';
-			$dlarr[strpos($dateformat,'y')] = 'yyyy';
-			$dlarr[strpos($dateformat,'m')] = 'MM';
-			$dlarr[strpos($dateformat,'d')] = 'DD';
-			ksort($dlarr);
-
-			$dateformat= (implode($sep,$dlarr));
-
-			switch(substr($dateformat,0,1))
-			{
-				case 'M':
-					$dateformat_validate= "javascript:vDateType='1'";
-					$onKeyUp	= "DateFormat(this,this.value,event,false,'1')";
-					$onBlur		= "DateFormat(this,this.value,event,true,'1')";
-					break;
-				case 'y':
-					$dateformat_validate="javascript:vDateType='2'";
-					$onKeyUp	= "DateFormat(this,this.value,event,false,'2')";
-					$onBlur		= "DateFormat(this,this.value,event,true,'2')";
-					break;
-				case 'D':
-					$dateformat_validate="javascript:vDateType='3'";
-					$onKeyUp	= "DateFormat(this,this.value,event,false,'3')";
-					$onBlur		= "DateFormat(this,this.value,event,true,'3')";
-					break;
-			}
 
 			$msgbox_data = $this->bocommon->msgbox_data($receipt);
 
-			$member_of_data	= $this->cats->formatted_xslt_list(array('selected' => $this->member_id,'globals' => True,link_data => array()));
+			$member_of_data	= $this->cats->formatted_xslt_list(array('selected' => $this->member_id,'globals' => true,link_data => array()));
 
 			$table_add_space[] = array
 			(
@@ -896,7 +840,7 @@
 				'id'		=>$id
 			);
 
-			$config->read_repository();
+			$config->read();
 			$link_to_files = $config->config_data['files_url'];
 
 			$j	= count($r_agreement['files']);
@@ -905,9 +849,9 @@
 				$r_agreement['files'][$i]['file_name']=urlencode($r_agreement['files'][$i]['name']);
 			}
 
-			$link_excel = array
+			$link_download = array
 			(
-				'menuaction'	=> 'property.uir_agreement.excel',
+				'menuaction'	=> 'property.uir_agreement.download',
 				'id'		=>$id
 			);
 
@@ -915,24 +859,65 @@
 			$GLOBALS['phpgw']->js->validate_file('core','check','property');
 			$GLOBALS['phpgw']->js->validate_file('dateformat','dateformat','property');
 
+			if (isset($r_agreement['attributes']) && is_array($r_agreement['attributes']))
+			{
+
+		/*		foreach ($values['attributes'] as & $attribute)
+				{
+					if($attribute['history'] == true)
+					{
+						$link_history_data = array
+						(
+							'menuaction'	=> 'property.uis_agreement.attrib_history',
+							'attrib_id'	=> $attribute['id'],
+							'id'		=> $id,
+							'edit'		=> true
+						);
+
+						$attribute['link_history'] = $GLOBALS['phpgw']->link('/index.php',$link_history_data);
+					}
+				}
+		*/
+
+				phpgwapi_yui::tabview_setup('edit_tabview');
+				$tabs['general']	= array('label' => lang('general'), 'link' => '#general');
+
+				$location = $this->acl_location;
+				$attributes_groups = $this->bo->get_attribute_groups($location, $r_agreement['attributes']);
+
+				$attributes = array();
+				foreach ($attributes_groups as $group)
+				{
+					if(isset($group['attributes']))
+					{
+						$attributes[] = $group;
+					}
+				}
+				unset($attributes_groups);
+				unset($r_agreement['attributes']);
+				
+				$tabs['details']	= array('label' => lang('details'), 'link' => '#details');
+			}
+
+
 			$data = array
 			(
 
 				'alarm_data'					=> $alarm_data,
 				'lang_alarm'					=> lang('Alarm'),
-				'lang_excel'					=> 'excel',
-				'link_excel'					=> $GLOBALS['phpgw']->link('/index.php',$link_excel),
-				'lang_excel_help'				=> lang('Download table to MS Excel'),
+				'lang_download'					=> 'download',
+				'link_download'					=> $GLOBALS['phpgw']->link('/index.php',$link_download),
+				'lang_download_help'				=> lang('Download table to your browser'),
 
-				'fileupload'					=> True,
+				'fileupload'					=> true,
 				'link_view_file'				=> $GLOBALS['phpgw']->link('/index.php',$link_file_data),
 				'link_to_files'					=> $link_to_files,
 				'files'							=> $r_agreement['files'],
 				'lang_files'					=> lang('files'),
 				'lang_filename'					=> lang('Filename'),
-				'lang_delete_file'				=> lang('Delete file'),
-				'lang_view_file_statustext'		=> lang('Klick to view file'),
-				'lang_delete_file_statustext'	=> lang('Check to delete file'),
+				'lang_file_action'				=> lang('Delete file'),
+				'lang_view_file_statustext'		=> lang('click to view file'),
+				'lang_file_action_statustext'	=> lang('Check to delete file'),
 				'lang_upload_file'				=> lang('Upload file'),
 				'lang_file_statustext'			=> lang('Select file to upload'),
 
@@ -957,17 +942,10 @@
 				'member_of_name'				=> 'member_id',
 				'member_of_list'				=> $member_of_data['cat_list'],
 
-				'lang_dateformat' 				=> lang(strtolower($dateformat)),
-				'dateformat_validate'			=> $dateformat_validate,
-				'onKeyUp'						=> $onKeyUp,
-				'onBlur'						=> $onBlur,
-				'lang_attributes'				=> lang('Attributes'),
-				'attributes_header'				=> $attributes_header,
-				'attributes_values'				=> $r_agreement['attributes'],
+				'attributes_group'				=> $attributes,
 				'lookup_functions'				=> $r_agreement['lookup_functions'],
-				'dateformat'					=> $dateformat,
-
 				'img_cal'						=> $GLOBALS['phpgw']->common->image('phpgwapi','cal'),
+
 				'lang_datetitle'				=> lang('Select date'),
 
 				'lang_start_date_statustext'	=> lang('Select the estimated end date for the Project'),
@@ -981,7 +959,7 @@
 				'lang_termination_date_statustext'	=> lang('Select the estimated termination date'),
 				'lang_termination_date'			=> lang('termination date'),
 				'value_termination_date'		=> $r_agreement['termination_date'],
-				
+
 				'tenant_data'					=> $tenant_data,
 				'b_account_data'				=> $b_account_data,
 				'lang_name'						=> lang('name'),
@@ -1008,21 +986,21 @@
 				'values_common'					=> $content_common,
 				'table_header_common'			=> $table_header_common,
 				'textareacols'					=> isset($GLOBALS['phpgw_info']['user']['preferences']['property']['textareacols']) && $GLOBALS['phpgw_info']['user']['preferences']['property']['textareacols'] ? $GLOBALS['phpgw_info']['user']['preferences']['property']['textareacols'] : 40,
-				'textarearows'					=> isset($GLOBALS['phpgw_info']['user']['preferences']['property']['textarearows']) && $GLOBALS['phpgw_info']['user']['preferences']['property']['textarearows'] ? $GLOBALS['phpgw_info']['user']['preferences']['property']['textarearows'] : 6
+				'textarearows'					=> isset($GLOBALS['phpgw_info']['user']['preferences']['property']['textarearows']) && $GLOBALS['phpgw_info']['user']['preferences']['property']['textarearows'] ? $GLOBALS['phpgw_info']['user']['preferences']['property']['textarearows'] : 6,
+				'tabs'							=> phpgwapi_yui::tabview_generate($tabs, $active_tab)				
 			);
 
 			$GLOBALS['phpgw_info']['flags']['app_header'] = lang('rental agreement') . ': ' . ($id?lang('edit') . ' ' . lang($this->role):lang('add') . ' ' . lang($this->role));
 
 			$GLOBALS['phpgw']->xslttpl->set_var('phpgw',array('edit' => $data));
-		//	$GLOBALS['phpgw']->xslttpl->pp();
 		}
 
-		function excel()
+		function download()
 		{
 			$id	= phpgw::get_var('id', 'int');
 			$list = $this->bo->read_details($id);
 			$uicols		= $this->bo->uicols;
-			$this->bocommon->excel($list,$uicols['name'],$uicols['descr'],$uicols['input_type']);
+			$this->bocommon->download($list,$uicols['name'],$uicols['descr'],$uicols['input_type']);
 		}
 
 		function edit_item()
@@ -1120,7 +1098,7 @@
 				}
 				elseif (!$values['save'] && !$values['apply'] && !$values['update']):
 				{
-					$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> 'property.uir_agreement.edit', 'id'=> $r_agreement_id));
+					$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> 'property.uir_agreement.edit', 'id'=> $r_agreement_id, 'tab' => 'details'));
 				}
 				endif;
 			}
@@ -1139,41 +1117,13 @@
 			);
 
 
-			$dateformat = strtolower($GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat']);
-			$sep = '/';
-			$dlarr[strpos($dateformat,'y')] = 'yyyy';
-			$dlarr[strpos($dateformat,'m')] = 'MM';
-			$dlarr[strpos($dateformat,'d')] = 'DD';
-			ksort($dlarr);
-
-			$dateformat= (implode($sep,$dlarr));
-
-			switch(substr($dateformat,0,1))
-			{
-				case 'M':
-					$dateformat_validate= "javascript:vDateType='1'";
-					$onKeyUp	= "DateFormat(this,this.value,event,false,'1')";
-					$onBlur		= "DateFormat(this,this.value,event,true,'1')";
-					break;
-				case 'y':
-					$dateformat_validate="javascript:vDateType='2'";
-					$onKeyUp	= "DateFormat(this,this.value,event,false,'2')";
-					$onBlur		= "DateFormat(this,this.value,event,true,'2')";
-					break;
-				case 'D':
-					$dateformat_validate="javascript:vDateType='3'";
-					$onKeyUp	= "DateFormat(this,this.value,event,false,'3')";
-					$onBlur		= "DateFormat(this,this.value,event,true,'3')";
-					break;
-			}
-
 			$jscal = CreateObject('phpgwapi.jscalendar');
 			$jscal->add_listener('values_start_date');
 			$jscal->add_listener('values_end_date');
-			
+
 			$msgbox_data = $this->bocommon->msgbox_data($receipt);
 
-	//		$member_of_data	= $this->cats->formatted_xslt_list(array('selected' => $this->member_id,'globals' => True,link_data => array()));
+	//		$member_of_data	= $this->cats->formatted_xslt_list(array('selected' => $this->member_id,'globals' => true,link_data => array()));
 
 			$table_add[] = array
 			(
@@ -1193,19 +1143,19 @@
 			}
 			else
 			{
-				$lookup_type='form';			
+				$lookup_type='form';
 				$main_form_name = 'form';
 				$update_form_name = 'form2';
 			}
 
 			$uicols		= $this->bo->uicols;
-			$list		= $this->list_content($list,$uicols,$edit_item=True);
+			$list		= $this->list_content($list,$uicols,$edit_item=true);
 			$content	= $list['content'];
 			$table_header=$list['table_header'];
 
 			for ($i=0; $i<count($list['content'][0]['row']); $i++)
 			{
-				$set_column[]=True;
+				$set_column[]=true;
 			}
 //_debug_array($list);
 			$tenant_data=$this->bocommon->initiate_ui_tenant_lookup(array(
@@ -1237,15 +1187,14 @@
 			$location_data=$bolocation->initiate_ui_location(array(
 						'values'		=> $values['location_data'],
 						'type_id'		=> -1, // calculated from location_types
-						'no_link'		=> False, // disable lookup links for location type less than type_id
-						'tenant'		=> False,
+						'no_link'		=> false, // disable lookup links for location type less than type_id
+						'tenant'		=> false,
 						'lookup_type'	=> $lookup_type,
-						'lookup_entity'	=> False, // $this->bocommon->get_lookup_entity('r_agreement'),
-						'entity_data'	=> False,//$values['p']
+						'lookup_entity'	=> false, // $this->bocommon->get_lookup_entity('r_agreement'),
+						'entity_data'	=> false,//$values['p']
 						));
 
 			$GLOBALS['phpgw']->js->validate_file('core','check','property');
-			$GLOBALS['phpgw']->js->validate_file('dateformat','dateformat','property');
 
 			$data = array
 			(
@@ -1262,15 +1211,8 @@
 				'lang_cancel_statustext'			=> lang('Leave the rental agreement untouched and return back to the list'),
 				'lang_save_statustext'				=> lang('Save the rental agreement and return back to the list'),
 
-				'lang_dateformat' 					=> lang(strtolower($dateformat)),
-				'dateformat_validate'				=> $dateformat_validate,
-				'onKeyUp'							=> $onKeyUp,
-				'onBlur'							=> $onBlur,
-				'lang_attributes'					=> lang('Attributes'),
-				'attributes_header'					=> $attributes_header,
 				'attributes_values'					=> $values['attributes'],
 				'lookup_functions'					=> $values['lookup_functions'],
-				'dateformat'						=> $dateformat,
 
 				'img_cal'							=> $GLOBALS['phpgw']->common->image('phpgwapi','cal'),
 				'lang_datetitle'					=> lang('Select date'),
@@ -1351,7 +1293,7 @@
 			}
 
 			$uicols		= $this->bo->uicols;
-			$list		= $this->list_content($list,$uicols,$edit_item=True);
+			$list		= $this->list_content($list,$uicols,$edit_item=true);
 			$content	= $list['content'];
 			$table_header=$list['table_header'];
 
@@ -1360,8 +1302,8 @@
 			$location_data=$bolocation->initiate_ui_location(array(
 						'values'		=> $values['location_data'],
 						'type_id'		=> -1, // calculated from location_types
-						'no_link'		=> False, // disable lookup links for location type less than type_id
-						'tenant'		=> False,
+						'no_link'		=> false, // disable lookup links for location type less than type_id
+						'tenant'		=> false,
 						'lookup_type'	=> $lookup_type,
 						'lookup_entity'	=> $this->bocommon->get_lookup_entity('r_agreement'),
 						'entity_data'	=> $values['p']
@@ -1463,7 +1405,7 @@
 			$r_agreement_id	= phpgw::get_var('id', 'int');
 			$config		= CreateObject('phpgwapi.config','property');
 
-			$GLOBALS['phpgw']->xslttpl->add_file(array('r_agreement','attributes_view'));
+			$GLOBALS['phpgw']->xslttpl->add_file(array('r_agreement', 'attributes_view', 'files'));
 
 
 			$r_agreement = $this->bo->read_single(array('r_agreement_id'=>$r_agreement_id));
@@ -1477,7 +1419,7 @@
 				$total_records = count($list);
 
 				$uicols		= $this->bo->uicols;
-				$list		= $this->list_content($list,$uicols,$edit_item=False,$view_only=True);
+				$list		= $this->list_content($list,$uicols,$edit_item=false,$view_only=true);
 				$content	= $list['content'];
 				$table_header=$list['table_header'];
 			}
@@ -1528,7 +1470,7 @@
 
 			$dateformat= (implode($sep,$dlarr));
 
-			$member_of_data	= $this->cats->formatted_xslt_list(array('selected' => $this->member_id,'globals' => True,link_data => array()));
+			$member_of_data	= $this->cats->formatted_xslt_list(array('selected' => $this->member_id,'globals' => true,link_data => array()));
 
 			$link_file_data = array
 			(
@@ -1537,7 +1479,7 @@
 			);
 
 
-			$config->read_repository();
+			$config->read();
 			$link_to_files = $config->config_data['files_url'];
 
 			$j	= count($r_agreement['files']);
@@ -1558,7 +1500,7 @@
 				'files'								=> $r_agreement['files'],
 				'lang_files'						=> lang('files'),
 				'lang_filename'						=> lang('Filename'),
-				'lang_view_file_statustext'			=> lang('Klick to view file'),
+				'lang_view_file_statustext'			=> lang('click to view file'),
 
 				'edit_url'							=> $GLOBALS['phpgw']->link('/index.php',$link_data),
 				'lang_id'							=> lang('ID'),
@@ -1607,7 +1549,7 @@
 		//	$GLOBALS['phpgw']->xslttpl->pp();
 		}
 
-	
+
 		function edit_common()
 		{
 			$r_agreement_id	= phpgw::get_var('r_agreement_id', 'int');
@@ -1640,7 +1582,7 @@
 						if ($values['save'])
 						{
 							$GLOBALS['phpgw']->session->appsession('session_data','r_agreement_receipt',$receipt);
-							$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> 'property.uir_agreement.edit', 'id'=> $r_agreement_id));
+							$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> 'property.uir_agreement.edit', 'id'=> $r_agreement_id, 'tab' => 'details'));
 						}
 					}
 				}
@@ -1665,7 +1607,7 @@
 				}
 				elseif (!$values['save'] && !$values['apply'] && !$values['update']):
 				{
-					$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> 'property.uir_agreement.edit', 'id'=> $r_agreement_id));
+					$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> 'property.uir_agreement.edit', 'id'=> $r_agreement_id, 'tab' => 'details'));
 				}
 				endif;
 			}
@@ -1673,7 +1615,7 @@
 			$r_agreement = $this->bo->read_single(array('r_agreement_id'=>$r_agreement_id));
 
 			$default_next_date = date($GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat'],$this->bocommon->date_to_timestamp($r_agreement['start_date']));
-			
+
 			if($c_id)
 			{
 				$values = $this->bo->read_single_common(array('r_agreement_id'=>$r_agreement_id,'c_id'=>$c_id));
@@ -1718,7 +1660,7 @@
 							'text_edit'					=> $text_edit,
 							'text_delete'				=> $text_delete
 						);
-						
+
 						unset($link_edit);
 						unset($link_delete);
 						unset($text_edit);
@@ -1893,4 +1835,4 @@
 			$GLOBALS['phpgw']->xslttpl->set_var('phpgw',array('delete' => $data));
 		}
 	}
-?>
+
