@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage project
- 	* @version $Id: class.uitenant_claim.inc.php 18358 2007-11-27 04:43:37Z skwashd $
+ 	* @version $Id: class.uitenant_claim.inc.php 6369 2010-09-21 07:52:05Z sigurd $
 	*/
 
 	/**
@@ -32,6 +32,7 @@
 	 * @package property
 	 */
 
+	phpgw::import_class('phpgwapi.yui');
 
 	class property_uitenant_claim
 	{
@@ -45,41 +46,39 @@
 
 		var $public_functions = array
 		(
-			'index'  => True,
-			'check'  => True,
-			'view'   => True,
-			'edit'   => True,
-			'delete' => True
+			'index'  => true,
+			'check'  => true,
+			'view'   => true,
+			'edit'   => true,
+			'delete' => true
 		);
 
 		function property_uitenant_claim()
 		{
-			$GLOBALS['phpgw_info']['flags']['xslt_app'] = True;
-		//	$this->currentapp	= $GLOBALS['phpgw_info']['flags']['currentapp'];
-			$this->nextmatchs	= CreateObject('phpgwapi.nextmatchs');
+			$GLOBALS['phpgw_info']['flags']['xslt_app'] = true;
+			$GLOBALS['phpgw_info']['flags']['menu_selection'] = 'property::invoice::claim';
 			$this->account		= $GLOBALS['phpgw_info']['user']['account_id'];
 
-			$this->bo		= CreateObject('property.botenant_claim',True);
+			$this->bo		= CreateObject('property.botenant_claim',true);
 			$this->bocommon		= CreateObject('property.bocommon');
-			$this->menu		= CreateObject('property.menu');
-
-			$this->acl		= CreateObject('phpgwapi.acl');
+			$this->acl			= & $GLOBALS['phpgw']->acl;
 			$this->acl_location	= '.tenant_claim';
 
-			$this->acl_read 	= $this->acl->check($this->acl_location,1);
-			$this->acl_add		= $this->acl->check($this->acl_location,2);
-			$this->acl_edit		= $this->acl->check($this->acl_location,4);
-			$this->acl_delete	= $this->acl->check($this->acl_location,8);
-			$this->acl_manage	= $this->acl->check($this->acl_location,16);
+			$this->acl_read 	= $this->acl->check($this->acl_location, PHPGW_ACL_READ, 'property');
+			$this->acl_add		= $this->acl->check($this->acl_location, PHPGW_ACL_ADD, 'property');
+			$this->acl_edit		= $this->acl->check($this->acl_location, PHPGW_ACL_EDIT, 'property');
+			$this->acl_delete	= $this->acl->check($this->acl_location, PHPGW_ACL_DELETE, 'property');
+			$this->acl_manage	= $this->acl->check($this->acl_location, 16, 'property');
 
 			$this->start		= $this->bo->start;
 			$this->query		= $this->bo->query;
 			$this->sort		= $this->bo->sort;
 			$this->order		= $this->bo->order;
-			$this->filter		= $this->bo->filter;
+			$this->user_id		= $this->bo->user_id;
 			$this->status		= $this->bo->status;
 			$this->cat_id		= $this->bo->cat_id;
 			$this->allrows		= $this->bo->allrows;
+			$this->project_id	= $this->bo->project_id;
 		}
 
 		function save_sessiondata()
@@ -90,7 +89,8 @@
 				'query'			=> $this->query,
 				'sort'			=> $this->sort,
 				'order'			=> $this->order,
-				'filter'		=> $this->filter,
+				'user_id'		=> $this->user_id,
+				'district_id'	=> $this->district_id,
 				'status'		=> $this->status,
 				'cat_id'		=> $this->cat_id,
 				'allrows'		=> $this->allrows
@@ -101,7 +101,6 @@
 		function index($project_id='')
 		{
 			$GLOBALS['phpgw']->xslttpl->add_file(array('tenant_claim',
-										'menu',
 										'receipt',
 										'search_field',
 										'nextmatchs'));
@@ -111,196 +110,428 @@
 				$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> 'property.uilocation.stop', 'perm'=>1, 'acl_location'=> $this->acl_location));
 			}
 
-
-			$this->menu->sub	= 'project';
-			$links = $this->menu->links('tenant_claim');
-
 			$receipt = $GLOBALS['phpgw']->session->appsession('session_data','tenant_claim_receipt');
 			$GLOBALS['phpgw']->session->appsession('session_data','tenant_claim_receipt','');
 
+			$datatable = array();
+
+			if( phpgw::get_var('phpgw_return_as') != 'json' )
+			{
+				$datatable['menu']					= $this->bocommon->get_menu();
+	    		$datatable['config']['base_url'] = $GLOBALS['phpgw']->link('/index.php', array
+	    		(
+	    			'menuaction'			=> 'property.uitenant_claim.index',
+	    			'query'            		=> $this->query,
+ 	                'cat_id'				=> $this->cat_id,
+ 	                'order'					=> $this->order,
+					'user_id'				=> $this->user_id,
+					'district_id'			=> $this->district_id
+   				));
+
+				$datatable['config']['base_java_url'] = "menuaction:'property.uitenant_claim.index',"
+	    											."sort: '{$this->sort}',"
+ 	                        						."order: '{$this->order}',"
+ 	                        						."status: '{$this->status}',"
+ 	                        						."project_id: '{$this->project_id}',"
+ 	                        						."user_id: '{$this->user_id}',"
+ 	                        						."district_id: '{$this->district_id}',"
+ 	                        						."query: '{$this->query}'";
+
+				$datatable['config']['allow_allrows'] = true;
+
+				$link_data = array
+				(
+					'menuaction'	=> 'property.uitenant_claim.index',
+					'sort'		=> $this->sort,
+					'order'		=> $this->order,
+					'cat_id'	=> $this->cat_id,
+					'user_id'	=> $this->user_id,
+					'status_id'	=> $this->status_id,
+					'project_id'=> $this->project_id,
+					'query'		=> $this->query
+				);
+
+				$values_combo_box[0] = $this->bocommon->select_category_list(array('format'=>'filter','selected' => $this->cat_id,'type' =>'tenant_claim','order'=>'descr'));
+				$default_value = array ('id'=>'','name'=> lang('no category'));
+				array_unshift ($values_combo_box[0],$default_value);
+
+				$values_combo_box[1]  = $this->bocommon->select_district_list('filter',$this->district_id);
+				$default_value = array ('id'=>'','name'=>lang('no district'));
+				array_unshift ($values_combo_box[1],$default_value);
+
+				$values_combo_box[2]  = $this->bo->get_status_list(array('format' => 'filter', 'selected' => $this->status,'default' => 'open'));
+				$default_value = array ('id'=>'','name'=>lang('open'));
+				array_unshift ($values_combo_box[2],$default_value);
+
+				$values_combo_box[3]  = $this->bocommon->get_user_list_right2('filter',2,$this->filter,$this->acl_location);
+				array_unshift ($values_combo_box[3],array('id'=>$GLOBALS['phpgw_info']['user']['account_id'],'name'=>lang('mine tickets')));
+				$default_value = array ('id'=>'','name'=>lang('no user'));
+				array_unshift ($values_combo_box[3],$default_value);
+
+				$datatable['actions']['form'] = array(
+				array(
+					'action'	=> $GLOBALS['phpgw']->link('/index.php',
+							array(
+								'menuaction' 		=> 'property.uitenant_claim.index',
+								'query'            		=> $this->query,
+ 	                			'cat_id'				=> $this->cat_id
+							)
+						),
+					'fields'	=> array(
+	                                    'field' => array(
+				                                        array( //boton 	CATEGORY
+				                                            'id' => 'btn_cat_id',
+				                                            'name' => 'cat_id',
+				                                            'value'	=> lang('Category'),
+				                                            'type' => 'button',
+				                                            'style' => 'filter',
+				                                            'tab_index' => 1
+
+				                                        ),
+									array
+										( //boton 	STATUS
+										'id' => 'btn_district_id',
+										'name' => 'district_id',
+										'value'	=> lang('District'),
+										'type' => 'button',
+										'style' => 'filter',
+											'tab_index' => 2
+									),
+				                                        array( //boton 	STATUS
+				                                            'id' => 'btn_status_id',
+				                                            'name' => 'status_id',
+				                                            'value'	=> lang('Status'),
+				                                            'type' => 'button',
+				                                            'style' => 'filter',
+				                                            'tab_index' => 3
+				                                        ),
+									array
+									( //boton 	USER
+										'id' => 'sel_user_id',
+										'name' => 'user_id',
+										'value'	=> lang('User'),
+										'type' => 'select',
+										'style' => 'filter',
+										'values' => $values_combo_box[3],
+										'onchange'=> 'onChangeSelect();',
+										'tab_index' => 4
+									),
+				                                        array(
+							                                'type'	=> 'button',
+							                            	'id'	=> 'btn_new',
+							                                'value'	=> lang('add'),
+							                                'tab_index' => 7
+							                            ),
+				                                        array( //boton     SEARCH
+				                                            'id' => 'btn_search',
+				                                            'name' => 'search',
+				                                            'value'    => lang('search'),
+				                                            'type' => 'button',
+				                                            'tab_index' => 6
+				                                        ),
+				   										array( // TEXT INPUT
+				                                            'name'     => 'query',
+				                                            'id'     => 'txt_query',
+				                                            'value'    => '',//$query,
+				                                            'type' => 'text',
+				                                            'onkeypress' => 'return pulsar(event)',
+				                                            'size'    => 28,
+				                                            'tab_index' => 5
+				                                        ),
+			                           				),
+			                       		'hidden_value' => array
+			                       						  (
+						                                        array
+						                                        ( //div values  combo_box_0
+								                                	'id' => 'values_combo_box_0',
+								                                    'value'	=> $this->bocommon->select2String($values_combo_box[0])
+								                                ),
+									array
+									( //div values  combo_box_1
+										'id' => 'values_combo_box_1',
+										'value'	=> $this->bocommon->select2String($values_combo_box[1])
+									),
+								                                array
+								                                ( //div values  combo_box_2
+								                                	'id' => 'values_combo_box_2',
+								                                    'value'	=> $this->bocommon->select2String($values_combo_box[2])
+								                                ),
+									array
+									( //div values  combo_box_3
+										'id' => 'values_combo_box_3',
+										'value'	=> $this->bocommon->select2String($values_combo_box[3])
+									),
+
+			                       						  )
+										)
+					 )
+				);
+
+			}
+
+
 			$claim_list = $this->bo->read(array('project_id' => $project_id));
 
-			while (is_array($claim_list) && list(,$claim) = each($claim_list))
+			$uicols = array();
+			$uicols['name'][0]['name'] = 'claim id';
+			$uicols['name'][0]['value'] = 'claim_id';
+
+			$uicols['name'][1]['name'] = 'district_id';
+			$uicols['name'][1]['value'] = 'district_id';
+
+			$uicols['name'][2]['name'] = 'Project';
+			$uicols['name'][2]['value'] = 'project_id';
+
+			$uicols['name'][3]['name'] = 'name';
+			$uicols['name'][3]['value'] = 'name';
+
+			$uicols['name'][4]['name'] = 'time created';
+			$uicols['name'][4]['value'] = 'entry_date';
+
+			$uicols['name'][5]['name'] = 'user';
+			$uicols['name'][5]['value'] = 'user';
+
+			$uicols['name'][6]['name'] = 'category';
+			$uicols['name'][6]['value'] = 'category';
+
+			$uicols['name'][7]['name'] = 'Status';
+			$uicols['name'][7]['value'] = 'status';
+
+			$uicols['name'][8]['name'] = 'tenant_id';
+			$uicols['name'][8]['value'] = 'tenant_id';
+
+			$count_uicols_name = count($uicols['name']);
+
+			$j = 0;
+			if (isset($claim_list) AND is_array($claim_list))
 			{
-				if($claim['tenant_id'])
+				foreach($claim_list as $claim_entry)
 				{
-					$tenant= $this->bocommon->read_single_tenant($claim['tenant_id']);
-					$name = $tenant['last_name'] . ', ' . $tenant['first_name'];
+					for ($k=0;$k<$count_uicols_name;$k++)
+					{
+						$datatable['rows']['row'][$j]['column'][$k]['name']		= $uicols['name'][$k]['value'];
+						$datatable['rows']['row'][$j]['column'][$k]['value']	= $claim_entry[$uicols['name'][$k]['value']];
+
+					}
+					$j++;
+				}
+			}
+
+			$parameters = array
+			(
+				'parameter' => array
+				(
+					array
+					(
+						'name'		=> 'claim_id',
+						'source'	=> 'claim_id'
+					),
+				)
+			);
+
+			if($this->acl_read)
+			{
+				$datatable['rowactions']['action'][] = array
+				(
+					'my_name' 		=> 'view',
+					'statustext' 	=> lang('view the claim'),
+					'text'			=> lang('view'),
+					'action'		=> $GLOBALS['phpgw']->link('/index.php',array
+					(
+						'menuaction'	=> 'property.uitenant_claim.view'
+					)
+				),
+				'parameters'	=> $parameters
+				);
+			}
+
+			if ($this->acl_edit)
+			{
+				$datatable['rowactions']['action'][] = array
+				(
+					'my_name' 			=> 'edit',
+					'statustext' 		=> lang('edit the claim'),
+					'text'				=> lang('edit'),
+					'action'			=> $GLOBALS['phpgw']->link('/index.php',array
+					(
+						'menuaction'	=> 'property.uitenant_claim.edit'
+					)
+				),
+				'parameters'	=> $parameters
+				);
+			}
+
+			if ($this->acl_delete)
+			{
+				$datatable['rowactions']['action'][] = array
+				(
+					'my_name' 			=> 'delete',
+					'statustext' 		=> lang('delete the claim'),
+					'text'				=> lang('delete'),
+					'confirm_msg'		=> lang('do you really want to delete this entry'),
+					'action'			=> $GLOBALS['phpgw']->link('/index.php',array
+					(
+						'menuaction'	=> 'property.uitenant_claim.delete'
+					)
+				),
+				'parameters'	=> $parameters
+				);
+			}
+			$datatable['rowactions']['action'][] = array(
+					'my_name' 		=> 'add',
+					'text' 			=> lang('add'),
+					'action'		=> $GLOBALS['phpgw']->link('/index.php',array
+					(
+						'menuaction'	=> 'property.uiproject.index',
+						'lookup'		=>	1,
+						'from'			=>  'tenant_claim'
+					)));
+
+			unset($parameters);
+
+			for ($i=0;$i<$count_uicols_name;$i++)
+			{
+				if($uicols['input_type'][$i]!='hidden')
+				{
+					$datatable['headers']['header'][$i]['formatter'] 		= ($uicols['formatter'][$i]==''?  '""' : $uicols['formatter'][$i]);
+					$datatable['headers']['header'][$i]['name'] 			= $uicols['name'][$i]['value'];
+					$datatable['headers']['header'][$i]['text'] 			= lang($uicols['name'][$i]['name']);
+					$datatable['headers']['header'][$i]['visible'] 			= true;
+					$datatable['headers']['header'][$i]['sortable']			= false;
 				}
 
-				$content[] = array
-				(
-					'claim_id'				=> $claim['claim_id'],
-					'project_id'				=> $claim['project_id'],
-					'status'				=> lang($claim['status']),
-					'name'					=> $name,
-					'entry_date'				=> $claim['entry_date'],
-					'category'				=> $claim['category'],
-					'link_view'				=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uitenant_claim.view', 'claim_id'=> $claim['claim_id'])),
-					'link_edit'				=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uitenant_claim.edit', 'claim_id'=> $claim['claim_id'])),
-					'link_delete'				=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uitenant_claim.delete', 'claim_id'=> $claim['claim_id'])),
-					'lang_view_statustext'			=> lang('view the claim'),
-					'lang_edit_statustext'			=> lang('edit the claim'),
-					'lang_delete_statustext'		=> lang('delete the claim'),
-					'text_view'				=> lang('view'),
-					'text_edit'				=> lang('edit'),
-					'text_delete'				=> lang('delete')
-				);
-				unset ($tenant);
-				unset ($name);
+				if($uicols['name'][$i]['value']=='claim_id'
+					|| $uicols['name'][$i]['value']=='project_id'
+					|| $uicols['name'][$i]['value']=='name'
+					|| $uicols['name'][$i]['value']=='district_id'
+					|| $uicols['name'][$i]['value']=='entry_date'
+				)
+				{
+					$datatable['headers']['header'][$i]['sortable']		= true;
+					$datatable['headers']['header'][$i]['sort_field']   = $uicols['name'][$i]['value'];
+				}
+
+				if($uicols['name'][$i]['value']=='category')
+				{
+					$datatable['headers']['header'][$i]['sortable']		= true;
+					$datatable['headers']['header'][$i]['sort_field']   = 'descr';
+				}
+
+				if($uicols['name'][$i]['value']=='tenant_id')
+				{
+					$datatable['headers']['header'][$i]['visible'] 		= false;
+					$datatable['headers']['header'][$i]['format'] 		= 'hidden';
+				}
 			}
 
-			$table_header = array
-			(
-				'lang_project'		=> lang('Project'),
-				'lang_name'		=> lang('name'),
-				'lang_status'		=> lang('Status'),
-				'lang_time_created'	=> lang('time created'),
-				'lang_view'		=> lang('view'),
-				'lang_edit'		=> lang('edit'),
-				'lang_delete'		=> lang('delete'),
-				'lang_claim_id'		=> lang('claim id'),
-				'sort_project'		=> $this->nextmatchs->show_sort_order(array
-										(
-											'sort'	=> $this->sort,
-											'var'	=> 'project_id',
-											'order'	=> $this->order,
-											'extra'	=> array('menuaction' => 'property.uitenant_claim.index',
-																	'cat_id'	=> $this->cat_id,
-																	'query'		=>$this->query,
-																	'status'	=>$this->status,
-																	'allrows'	=>$this->allrows)
-										)),
-				'sort_name'		=> $this->nextmatchs->show_sort_order(array
-										(
-											'sort'	=> $this->sort,
-											'var'	=> 'org_name',
-											'order'	=> $this->order,
-											'extra'	=> array('menuaction' => 'property.uitenant_claim.index',
-																	'cat_id'	=> $this->cat_id,
-																	'query'		=>$this->query,
-																	'status'	=>$this->status,
-																	'allrows'	=>$this->allrows)
-										)),
-				'sort_claim_id'		=> $this->nextmatchs->show_sort_order(array
-										(
-											'sort'	=> $this->sort,
-											'var'	=> 'claim_id',
-											'order'	=> $this->order,
-											'extra'	=> array('menuaction' => 'property.uitenant_claim.index',
-																	'cat_id'	=> $this->cat_id,
-																	'query'		=>$this->query,
-																	'status'	=>$this->status,
-																	'allrows'	=>$this->allrows)
-										)),
-				'sort_time_created'	=> $this->nextmatchs->show_sort_order(array
-										(
-											'sort'	=> $this->sort,
-											'var'	=> 'entry_date',
-											'order'	=> $this->order,
-											'extra'	=> array('menuaction' => 'property.uitenant_claim.index',
-																	'cat_id'	=>$this->cat_id,
-																	'query'		=>$this->query,
-																	'status'	=>$this->status,
-																	'allrows'	=>$this->allrows)
-										)),
-				'sort_category'		=> $this->nextmatchs->show_sort_order(array
-										(
-											'sort'	=> $this->sort,
-											'var'	=> 'descr',
-											'order'	=> $this->order,
-											'extra'	=> array('menuaction' => 'property.uitenant_claim.index',
-																	'cat_id'	=>$this->cat_id,
-																	'query'		=>$this->query,
-																	'status'	=>$this->status,
-																	'allrows'	=>$this->allrows)
-										)),
-				'lang_category'		=> lang('category')
-			);
+			//path for property.js
+			$datatable['property_js'] = $GLOBALS['phpgw_info']['server']['webserver_url']."/property/js/yahoo/property.js";
 
-			if ($project_id)
+			// Pagination and sort values
+			$datatable['pagination']['records_start'] 	= (int)$this->bo->start;
+			$datatable['pagination']['records_limit'] 	= $GLOBALS['phpgw_info']['user']['preferences']['common']['maxmatchs'];
+			$datatable['pagination']['records_returned']= count($claim_list);
+			$datatable['pagination']['records_total'] 	= $this->bo->total_records;
+
+
+			$appname					= lang('Tenant claim');
+			$function_msg				= lang('list claim');
+
+			if ( (phpgw::get_var("start")== "") && (phpgw::get_var("order",'string')== ""))
 			{
-				$lang_add = lang('add another');
-				$add_action	= $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uitenant_claim.edit', 'project_id'=> $project_id));
+				$datatable['sorting']['order'] 			= 'claim_id'; // name key Column in myColumnDef
+				$datatable['sorting']['sort'] 			= 'desc'; // ASC / DESC
 			}
 			else
 			{
-				$lang_add = lang('add');
-				$add_action	= $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uiproject.index', 'lookup'=>true, 'from'=>'tenant_claim'));
-
+				$datatable['sorting']['order']			= phpgw::get_var('order', 'string'); // name of column of Database
+				$datatable['sorting']['sort'] 			= phpgw::get_var('sort', 'string'); // ASC / DESC
 			}
 
-			$table_add = array
-			(
-				'lang_add'		=> $lang_add,
-				'lang_add_statustext'	=> lang('add a claim'),
-				'add_action'		=> $add_action
-			);
+			phpgwapi_yui::load_widget('dragdrop');
+		  	phpgwapi_yui::load_widget('datatable');
+		  	phpgwapi_yui::load_widget('menu');
+		  	phpgwapi_yui::load_widget('connection');
+		  	phpgwapi_yui::load_widget('loader');
+			phpgwapi_yui::load_widget('tabview');
+			phpgwapi_yui::load_widget('paginator');
+			phpgwapi_yui::load_widget('animation');
 
-			$link_data = array
-			(
-				'menuaction'	=> 'property.uitenant_claim.index',
-				'sort'		=> $this->sort,
-				'order'		=> $this->order,
-				'cat_id'	=> $this->cat_id,
-				'filter'	=> $this->filter,
-				'status'	=> $this->status,
-				'query'		=> $this->query
-			);
+		  	//-- BEGIN----------------------------- JSON CODE ------------------------------
+    		//values for Pagination
+	    		$json = array
+	    		(
+	    			'recordsReturned' 	=> $datatable['pagination']['records_returned'],
+    				'totalRecords' 		=> (int)$datatable['pagination']['records_total'],
+	    			'startIndex' 		=> $datatable['pagination']['records_start'],
+					'sort'				=> $datatable['sorting']['order'],
+	    			'dir'				=> $datatable['sorting']['sort'],
+					'records'			=> array()
+	    		);
 
-			if(!$this->allrows)
-			{
-				$record_limit	= $GLOBALS['phpgw_info']['user']['preferences']['common']['maxmatchs'];
-			}
-			else
-			{
-				$record_limit	= $this->bo->total_records;
-			}
+				// values for datatable
+	    		if(isset($datatable['rows']['row']) && is_array($datatable['rows']['row'])){
+	    			foreach( $datatable['rows']['row'] as $row )
+	    			{
+		    			$json_row = array();
+		    			foreach( $row['column'] as $column)
+		    			{
+		    				if(isset($column['format']) && $column['format']== "link" && $column['java_link']==true)
+		    				{
+		    					$json_row[$column['name']] = "<a href='#' id='".$column['link']."' onclick='javascript:filter_data(this.id);'>" .$column['value']."</a>";
+		    				}
+		    				elseif(isset($column['format']) && $column['format']== "link")
+		    				{
+		    				  $json_row[$column['name']] = "<a href='".$column['link']."'>" .$column['value']."</a>";
+		    				}else
+		    				{
+		    				  $json_row[$column['name']] = $column['value'];
+		    				}
+		    			}
+		    			$json['records'][] = $json_row;
+	    			}
+	    		}
 
-			$msgbox_data = $this->bocommon->msgbox_data($receipt);
+				// right in datatable
+				if(isset($datatable['rowactions']['action']) && is_array($datatable['rowactions']['action']))
+				{
+					$json ['rights'] = $datatable['rowactions']['action'];
+				}
 
-			$data = array
-			(
-				'msgbox_data'				=> $GLOBALS['phpgw']->common->msgbox($msgbox_data),
-				'links'					=> $links,
- 				'allow_allrows'				=> true,
-				'allrows'				=> $this->allrows,
-				'start_record'				=> $this->start,
-				'record_limit'				=> $record_limit,
-				'num_records'				=> count($claim_list),
- 				'all_records'				=> $this->bo->total_records,
-				'link_url'				=> $GLOBALS['phpgw']->link('/index.php',$link_data),
-				'img_path'				=> $GLOBALS['phpgw']->common->get_image_path('phpgwapi','default'),
-				'lang_no_cat'				=> lang('no category'),
-				'lang_cat_statustext'			=> lang('Select the category the claim belongs to. To do not use a category select NO CATEGORY'),
-				'select_name'				=> 'cat_id',
-				'cat_list'				=> $this->bocommon->select_category_list(array('format'=>'filter','selected' => $this->cat_id,'type' =>'tenant_claim','order'=>'descr')),
+				if( phpgw::get_var('phpgw_return_as') == 'json' )
+				{
+		    		return $json;
+				}
 
-				'select_action'				=> $GLOBALS['phpgw']->link('/index.php',$link_data),
-				'filter_list'				=> $this->nextmatchs->xslt_filter(array('filter' => $this->filter)),
-				'lang_filter_statustext'		=> lang('Select the filter. To show all entries select SHOW ALL'),
 
-				'status_name'				=> 'status',
-				'status_list'				=> $this->bo->get_status_list(array('format' => 'filter', 'selected' => $this->status,'default' => 'open')),
-				'lang_no_status'			=> lang('Open'),
-				'lang_filter_statustext'		=> lang('Select the filter. To show all entries select SHOW ALL'),
+			$datatable['json_data'] = json_encode($json);
+			//-------------------- JSON CODE ----------------------
 
-				'lang_searchfield_statustext'		=> lang('Enter the search string. To show all entries, empty this field and press the SUBMIT button again'),
-				'lang_searchbutton_statustext'		=> lang('Submit the search string'),
-				'query'					=> $this->query,
-				'lang_search'				=> lang('search'),
-				'table_header'				=> $table_header,
-				'values'				=> $content,
-				'table_add'				=> $table_add
-			);
+			$template_vars = array();
+			$template_vars['datatable'] = $datatable;
+			$GLOBALS['phpgw']->xslttpl->add_file(array('datatable'));
+	      	$GLOBALS['phpgw']->xslttpl->set_var('phpgw', $template_vars);
+
+	      	if ( !isset($GLOBALS['phpgw']->css) || !is_object($GLOBALS['phpgw']->css) )
+	      	{
+	        	$GLOBALS['phpgw']->css = createObject('phpgwapi.css');
+	      	}
+
+	      	$GLOBALS['phpgw']->css->validate_file('datatable');
+		  	$GLOBALS['phpgw']->css->validate_file('property');
+		  	$GLOBALS['phpgw']->css->add_external_file('property/templates/base/css/property.css');
+			$GLOBALS['phpgw']->css->add_external_file('phpgwapi/js/yahoo/datatable/assets/skins/sam/datatable.css');
+			$GLOBALS['phpgw']->css->add_external_file('phpgwapi/js/yahoo/paginator/assets/skins/sam/paginator.css');
+			$GLOBALS['phpgw']->css->add_external_file('phpgwapi/js/yahoo/container/assets/skins/sam/container.css');
+
+			$GLOBALS['phpgw_info']['flags']['app_header'] = lang('property') . ' - ' . $appname . ': ' . $function_msg;
+
+			$GLOBALS['phpgw']->js->validate_file( 'yahoo', 'tenant_claim.index', 'property' );
 			$this->save_sessiondata();
-			$GLOBALS['phpgw_info']['flags']['app_header'] = lang('Tenant claim') . ': ' . lang('list claim');
-
-			$GLOBALS['phpgw']->xslttpl->set_var('phpgw',array('list' => $data));
-		//	$GLOBALS['phpgw']->xslttpl->pp();
 		}
 
 
+
 		function check()
 		{
 			$project_id	= phpgw::get_var('project_id', 'int');
@@ -336,6 +567,7 @@
 			$claim_id = phpgw::get_var('claim_id', 'int');
 
 			$values	 = phpgw::get_var('values');
+			//_debug_array($values);die;
 			$values['project_id']		= phpgw::get_var('project_id', 'int');
 			$values['b_account_id']		= phpgw::get_var('b_account_id', 'int', 'POST');
 			$values['b_account_name']	= phpgw::get_var('b_account_name', 'string', 'POST');
@@ -399,7 +631,24 @@
 
 			$project_values	= $this->boproject->read_single($values['project_id']);
 
-//_debug_array($project_values);
+			$soinvoice	= CreateObject('property.soinvoice');
+			
+			foreach ($project_values['workorder_budget'] as &$workorder)
+			{
+				$vouchers = $soinvoice->read_invoice(array('paid'=>'1','workorder_id' => $workorder['workorder_id'], 'user_lid' => 'all'));
+				if(isset($vouchers[0]['voucher_id']))
+				{
+					$workorder['voucher_id'] = $vouchers[0]['voucher_id'];
+				}
+				else
+				{
+					$vouchers = $soinvoice->read_invoice(array('workorder_id' => $workorder['workorder_id'], 'user_lid' => 'all'));
+					$workorder['voucher_id'] = isset($vouchers[0]['voucher_id']) ? $vouchers[0]['voucher_id'] : '';
+				}
+			}
+
+
+//_debug_array($project_values);die();
 
 			$table_header_workorder[] = array
 			(
@@ -416,7 +665,7 @@
 			$location_data=$bolocation->initiate_ui_location(array(
 						'values'	=> $project_values['location_data'],
 						'type_id'	=> count(explode('-',$project_values['location_data']['location_code'])),
-						'no_link'	=> False, // disable lookup links for location type less than type_id
+						'no_link'	=> false, // disable lookup links for location type less than type_id
 						'tenant'	=> $project_values['location_data']['tenant_id'],
 						'lookup_type'	=> 'view',
 						'lookup_entity'	=> $this->bocommon->get_lookup_entity('project'),
@@ -458,13 +707,13 @@
 					{
 						if($project_values['workorder_budget'][$i]['workorder_id'] == $workorder_id)
 						{
-							$project_values['workorder_budget'][$i]['selected'] = True;
+							$project_values['workorder_budget'][$i]['selected'] = true;
 						}
 					}
 				}
 			}
 
-
+/*
 			for ($i=0;$i<count($project_values['workorder_budget']);$i++)
 			{
 				$claimed= $this->bo->check_claim_workorder($project_values['workorder_budget'][$i]['workorder_id']);
@@ -475,7 +724,7 @@
 				}
 			}
 
-
+*/
 
 			$this->cat_id = ($values['cat_id']?$values['cat_id']:$this->cat_id);
 			$b_account_data=$this->bocommon->initiate_ui_budget_account_lookup(array(
@@ -489,8 +738,60 @@
 				'project_id' 	=> $values['project_id']
 			);
 
+			$cats				= CreateObject('phpgwapi.categories', -1,  'property', '.project');
+			$cats->supress_info	= true;
+
+			$cat_list_project	= $cats->return_array('',0,false,'','','',false);
+			$cat_list_project	= $this->bocommon->select_list($project_values['cat_id'],$cat_list_project);
+
 			$msgbox_data = $this->bocommon->msgbox_data($receipt);
 
+
+			for($d=0;$d<count($project_values['workorder_budget']);$d++)
+			{
+				if($project_values['workorder_budget'][$d]['charge_tenant']==1)
+				{
+					$project_values['workorder_budget'][$d]['charge_tenant']='x';
+				}
+
+				if($project_values['workorder_budget'][$d]['selected']==1)
+				{
+					$project_values['workorder_budget'][$d]['selected']='<input type="checkbox" name="values[workorder][]" checked value="'.$project_values['workorder_budget'][$d]['workorder_id'].'">';
+				}
+				else
+				{
+					$project_values['workorder_budget'][$d]['selected']='<input type="checkbox" name="values[workorder][]" value="'.$project_values['workorder_budget'][$d]['workorder_id'].'">';
+				}
+			}
+
+			//---datatable0 settings---------------------------------------------------
+
+			$datavalues[0] = array
+			(
+				'name'			=> "0",
+				'values' 		=> json_encode($project_values['workorder_budget']),
+				'total_records'	=> count($project_values['workorder_budget']),
+				'edit_action'	=> json_encode($GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uiworkorder.edit'))),
+				'is_paginator'	=> 1,
+				'footer'		=> 0
+			);
+
+//_debug_array($project_values['workorder_budget']);die();
+
+			$myColumnDefs[0] = array
+       		(
+       			'name'			=> "0",
+       			'values'		=>	json_encode(array(	array('key' => 'workorder_id',	'label'=>'Workorder',	'sortable'=>true,'resizeable'=>true,'formatter'=>'YAHOO.widget.DataTable.formatLink'),
+									       				array('key' => 'budget',	'label'=>'Budget',	'sortable'=>true,'resizeable'=>true),
+									       				array('key' => 'calculation',	'label'=>'Calculation',	'sortable'=>true,'resizeable'=>true),
+		       				       						array('key' => 'vendor_name','label'=>'Vendor','sortable'=>true,'resizeable'=>true),
+		       				       						array('key' => 'charge_tenant','label'=>'Charge tenant','sortable'=>true,'resizeable'=>true),
+		       				       						array('key' => 'status','label'=>'Status','sortable'=>true,'resizeable'=>true),
+		       				       						array('key' => 'actual_cost','label'=>lang('actual cost'),'sortable'=>true,'resizeable'=>true),
+		       				       						array('key' => 'voucher_id','label'=>lang('voucher'),'sortable'=>true,'resizeable'=>true),
+		       				       						array('key' => 'selected','label'=>'select',	'sortable'=>false,'resizeable'=>false)))
+			);
+
 			$data = array
 			(
 				'table_header_workorder'		=> $table_header_workorder,
@@ -499,6 +800,12 @@
 				'lang_start_date'			=> lang('Project start date'),
 				'value_start_date'			=> $project_values['start_date'],
 
+				'property_js'							=> json_encode($GLOBALS['phpgw_info']['server']['webserver_url']."/property/js/yahoo/property2.js"),
+				'base_java_url'							=> json_encode(array(menuaction => "property.uitenant_claim.edit",claim_id=>$claim_id)),
+				'datatable'								=> $datavalues,
+				'myColumnDefs'							=> $myColumnDefs,
+				//'myButtons'								=> $myButtons,
+
 				'lang_end_date'				=> lang('Project end date'),
 				'value_end_date'			=> $project_values['end_date'],
 
@@ -539,7 +846,7 @@
 				'lang_sum'				=> lang('Sum'),
 				'select_user_name'			=> 'project_values[coordinator]',
 				'lang_no_user'				=> lang('Select coordinator'),
-				'user_list'				=> $this->bocommon->get_user_list('select',$project_values['coordinator'],$extra=False,$default=False,$start=-1,$sort='ASC',$order='account_lastname',$query='',$offset=-1),
+				'user_list'				=> $this->bocommon->get_user_list('select',$project_values['coordinator'],$extra=false,$default=false,$start=-1,$sort='ASC',$order='account_lastname',$query='',$offset=-1),
 
 				'status_list'				=> $this->boproject->select_status_list('select',$project_values['status']),
 				'lang_no_status'			=> lang('Select status'),
@@ -554,10 +861,8 @@
 
 				'lang_select_workorder_statustext'	=> lang('Include the workorder to this claim'),
 
-				'cat_list_project'			=> $this->bocommon->select_category_list(array('format'=>'select','selected' => $project_values['cat_id'],'type' =>'project','order'=>'descr')),
-
+				'cat_list_project'					=> $cat_list_project,
 //------------------
-
 				'lang_status'				=> lang('Status'),
 				'lang_status_statustext'		=> lang('Select status'),
 				'status_list'				=> $this->bo->get_status_list(array('format' => 'select', 'selected' => $values['status'],'default' => 'open')),
@@ -600,6 +905,27 @@
 			$GLOBALS['phpgw_info']['flags']['app_header'] = lang('Tenant claim') . ': ' . ($claim_id?lang('edit claim'):lang('add claim'));
 
 			$GLOBALS['phpgw']->xslttpl->set_var('phpgw',array('edit' => $data));
+
+			//_debug_array($data);die;
+
+			//---datatable settings--------------------
+			phpgwapi_yui::load_widget('dragdrop');
+		  	phpgwapi_yui::load_widget('datatable');
+		  	phpgwapi_yui::load_widget('menu');
+		  	phpgwapi_yui::load_widget('connection');
+		  	phpgwapi_yui::load_widget('loader');
+			phpgwapi_yui::load_widget('tabview');
+			phpgwapi_yui::load_widget('paginator');
+			phpgwapi_yui::load_widget('animation');
+
+			$GLOBALS['phpgw']->css->validate_file('datatable');
+		  	$GLOBALS['phpgw']->css->validate_file('property');
+		  	$GLOBALS['phpgw']->css->add_external_file('property/templates/base/css/property.css');
+			$GLOBALS['phpgw']->css->add_external_file('phpgwapi/js/yahoo/datatable/assets/skins/sam/datatable.css');
+			$GLOBALS['phpgw']->css->add_external_file('phpgwapi/js/yahoo/paginator/assets/skins/sam/paginator.css');
+			$GLOBALS['phpgw']->css->add_external_file('phpgwapi/js/yahoo/container/assets/skins/sam/container.css');
+			$GLOBALS['phpgw']->js->validate_file( 'yahoo', 'uitenant.edit', 'property' );
+			//-----------------------datatable settings---
 		//	$GLOBALS['phpgw']->xslttpl->pp();
 		}
 
@@ -612,22 +938,21 @@
 				$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> 'property.uilocation.stop', 'perm'=>8, 'acl_location'=> $this->acl_location));
 			}
 
-
 			$claim_id	= phpgw::get_var('claim_id', 'int');
 			$delete		= phpgw::get_var('delete', 'bool', 'POST');
 			$confirm	= phpgw::get_var('confirm', 'bool', 'POST');
 
+			if( phpgw::get_var('phpgw_return_as') == 'json' )
+			{
+				$this->bo->delete($claim_id);
+				return "claim_id ".$claim_id." ".lang("has been deleted");
+			}
+
 			$link_data = array
 			(
 				'menuaction' => 'property.uitenant_claim.index'
 			);
 
-			if (phpgw::get_var('confirm', 'bool', 'POST'))
-			{
-				$this->bo->delete($claim_id);
-				$GLOBALS['phpgw']->redirect_link('/index.php',$link_data);
-			}
-
 			$GLOBALS['phpgw']->xslttpl->add_file(array('app_delete'));
 
 			$data = array
@@ -680,7 +1005,7 @@
 			$location_data=$bolocation->initiate_ui_location(array(
 						'values'	=> $project_values['location_data'],
 						'type_id'	=> count(explode('-',$project_values['location_data']['location_code'])),
-						'no_link'	=> False, // disable lookup links for location type less than type_id
+						'no_link'	=> false, // disable lookup links for location type less than type_id
 						'tenant'	=> $project_values['location_data']['tenant_id'],
 						'lookup_type'	=> 'view',
 						'lookup_entity'	=> $this->bocommon->get_lookup_entity('project'),
@@ -722,13 +1047,13 @@
 					{
 						if($project_values['workorder_budget'][$i]['workorder_id'] == $workorder_id)
 						{
-							$project_values['workorder_budget'][$i]['selected'] = True;
+							$project_values['workorder_budget'][$i]['selected'] = true;
 						}
 					}
 				}
 			}
 
-
+/*
 			for ($i=0;$i<count($project_values['workorder_budget']);$i++)
 			{
 				$claimed= $this->bo->check_claim_workorder($project_values['workorder_budget'][$i]['workorder_id']);
@@ -739,7 +1064,7 @@
 				}
 			}
 
-
+*/
 
 			$b_account_data=$this->bocommon->initiate_ui_budget_account_lookup(array(
 						'b_account_id'		=> $values['b_account_id'],
@@ -749,6 +1074,12 @@
 
 			$msgbox_data = $this->bocommon->msgbox_data($receipt);
 
+			$cats				= CreateObject('phpgwapi.categories', -1,  'property', '.project');
+			$cats->supress_info	= true;
+
+			$cat_list_project	= $cats->return_array('',0,false,'','','',false);
+			$cat_list_project	= $this->bocommon->select_list($project_values['cat_id'],$cat_list_project);
+
 			$data = array
 			(
 				'table_header_workorder'		=> $table_header_workorder,
@@ -796,7 +1127,7 @@
 				'lang_sum'				=> lang('Sum'),
 				'select_user_name'			=> 'project_values[coordinator]',
 				'lang_no_user'				=> lang('Select coordinator'),
-				'user_list'				=> $this->bocommon->get_user_list('select',$project_values['coordinator'],$extra=False,$default=False,$start=-1,$sort='ASC',$order='account_lastname',$query='',$offset=-1),
+				'user_list'				=> $this->bocommon->get_user_list('select',$project_values['coordinator'],$extra=false,$default=false,$start=-1,$sort='ASC',$order='account_lastname',$query='',$offset=-1),
 
 				'status_list'				=> $this->boproject->select_status_list('select',$project_values['status']),
 				'lang_no_status'			=> lang('Select status'),
@@ -809,7 +1140,7 @@
 
 				'b_account_data'			=> $b_account_data,
 
-				'cat_list_project'			=> $this->bocommon->select_category_list(array('format'=>'select','selected' => $project_values['cat_id'],'type' =>'project','order'=>'descr')),
+				'cat_list_project'			=> $cat_list_project,
 
 //------------------
 
@@ -842,10 +1173,10 @@
 				'value_date'				=> $GLOBALS['phpgw']->common->show_date($tenant_claim['entry_date'])
 
 			);
-			$GLOBALS['phpgw_info']['flags']['app_header'] = lang('Tenant claim') . ': ' . ($claim_id?lang('edit claim'):lang('add claim'));
+			$GLOBALS['phpgw_info']['flags']['app_header'] = lang('Tenant claim') . '::' . lang('view claim');
 
 			$GLOBALS['phpgw']->xslttpl->set_var('phpgw',array('view' => $data));
 		//	$GLOBALS['phpgw']->xslttpl->pp();
 		}
 	}
-?>
+
