@@ -25,7 +25,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage admin
- 	* @version $Id: cron.php,v 1.2 2007/10/07 21:25:22 sigurdne Exp $
+ 	* @version $Id$
 	*/
 
 	/**
@@ -38,11 +38,9 @@
 
 	$_GET['domain'] = isset($_SERVER['argv'][1]) ? $_SERVER['argv'][1] : 'default';
 
-
 	if(!$function = $_SERVER['argv'][2])
-
 	{
-		echo date('Y/m/d H:i:s ') . " Nothing to execute\n";
+		echo "Nothing to execute\n";
 		return;
 	}
 
@@ -50,15 +48,27 @@
 
 	$GLOBALS['phpgw_info']['flags'] = array(
 		'currentapp' => 'login',
-		'noapi'      => True		// this stops header.inc.php to include phpgwapi/inc/function.inc.php
+		'noapi'      => true		// this stops header.inc.php to include phpgwapi/inc/function.inc.php
 	);
 	include($path_to_phpgroupware.'/header.inc.php');
 	unset($GLOBALS['phpgw_info']['flags']['noapi']);
 
-	$db_type = $GLOBALS['phpgw_domain'][$_GET['domain']]['db_type'];
+//	$db_type = $GLOBALS['phpgw_domain'][$_GET['domain']]['db_type'];
 
 	$GLOBALS['phpgw_info']['server']['sessions_type'] = 'db';
 
+	$_domain_info = isset($GLOBALS['phpgw_domain'][$_GET['domain']]) ? $GLOBALS['phpgw_domain'][$_GET['domain']] : '';
+	if(!$_domain_info)
+	{
+		echo "not a valid domain\n";
+		die();
+	}
+	else
+	{
+		$GLOBALS['phpgw_domain'] = array();
+		$GLOBALS['phpgw_domain'][$_GET['domain']] = $_domain_info;
+	}
+
 	include(PHPGW_API_INC.'/functions.inc.php');
 
 	$data = array('function' => $function,'enabled'=>1);
@@ -77,6 +87,9 @@
 		$destroy_session = true;
 	}
 
+	$GLOBALS['phpgw_info']['user']['apps']['admin'] = true;
+	$GLOBALS['phpgw_info']['user']['domain'] = $_GET['domain'];
+
 	$num = ExecMethod('property.custom_functions.index',$data);
 	// echo date('Y/m/d H:i:s ').$_GET['domain'].': '.($num ? "$num job(s) executed" : 'Nothing to execute')."\n";
 
@@ -85,4 +98,4 @@
 		$GLOBALS['phpgw']->session->destroy($GLOBALS['phpgw']->session->sessionid, true);
 	}
 
-	$GLOBALS['phpgw']->common->phpgw_exit();	
+	$GLOBALS['phpgw']->common->phpgw_exit();
