@@ -3,18 +3,18 @@
 	* phpGroupWare - property: a Facilities Management System.
 	*
 	* @author Sigurd Nes <sigurdne@online.no>
-	* @copyright Copyright (C) 2003-2005 Free Software Foundation, Inc. http://www.fsf.org/
+	* @copyright Copyright (C) 2003-2009 Free Software Foundation, Inc. http://www.fsf.org/
 	* @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage setup
- 	* @version $Id: setup.inc.php,v 1.61 2007/10/13 10:02:54 sigurdne Exp $
+ 	* @version $Id: setup.inc.php 6383 2010-09-23 10:20:10Z sigurd $
 	*/
 
-	$setup_info['property']['name']		= 'property';
-	$setup_info['property']['version']	= '0.9.17.541';
+	$setup_info['property']['name']			= 'property';
+	$setup_info['property']['version']		= '0.9.17.594';
 	$setup_info['property']['app_order']	= 8;
-	$setup_info['property']['enable']	= 1;
+	$setup_info['property']['enable']		= 1;
 	$setup_info['property']['app_group']	= 'office';
 
 	$setup_info['property']['author'] = array
@@ -79,17 +79,18 @@
 		'fm_vendor',
 		'fm_vendor_category',
 		'fm_district',
-		'fm_location1',
+		'fm_locations',
 		'fm_location1_category',
+		'fm_location1',
 		'fm_location1_history',
-		'fm_location2',
 		'fm_location2_category',
+		'fm_location2',
 		'fm_location2_history',
-		'fm_location3',
 		'fm_location3_category',
+		'fm_location3',
 		'fm_location3_history',
-		'fm_location4',
 		'fm_location4_category',
+		'fm_location4',
 		'fm_location4_history',
 		'fm_location_type',
 		'fm_location_config',
@@ -97,7 +98,6 @@
 		'fm_b_account',
 		'fm_b_account_category',
 		'fm_workorder',
-		'fm_workorder_category',
 		'fm_workorder_history',
 		'fm_workorder_status',
 		'fm_activities',
@@ -114,17 +114,18 @@
 		'fm_request_condition_type',
 		'fm_request_condition',
 		'fm_request_status',
-		'fm_request_category',
 		'fm_request_history',
 		'fm_template',
 		'fm_template_hours',
 		'fm_chapter',
 		'fm_ns3420',
+		'fm_project_status',
 		'fm_project',
 		'fm_projectbranch',
+		'fm_project_group',
 		'fm_project_history',
+		'fm_tts_status',
 		'fm_tts_tickets',
-		'fm_tts_category',
 		'fm_tts_history',
 		'fm_tts_views',
 		'fm_ecoart',
@@ -138,12 +139,15 @@
 		'fm_ecologg',
 		'fm_ecomva',
 		'fm_ecouser',
+		'fm_event',
+		'fm_event_action',
+		'fm_event_exception',
+		'fm_event_schedule',
 		'fm_investment',
 		'fm_investment_value',
 		'fm_event_receipt',
 		'fm_idgenerator',
 		'fm_document',
-		'fm_document_category',
 		'fm_document_history',
 		'fm_document_status',
 		'fm_standard_unit',
@@ -162,14 +166,16 @@
 		'fm_custom',
 		'fm_custom_cols',
 		'fm_orders',
+		'fm_order_dim1',
+		'fm_order_template',
 		'fm_s_agreement',
+		'fm_s_agreement_budget',
 		'fm_s_agreement_category',
 		'fm_s_agreement_detail',
 		'fm_s_agreement_pricing',
 		'fm_s_agreement_history',
 		'fm_async_method',
 		'fm_cron_log',
-		'fm_origin',
 		'fm_tenant_claim',
 		'fm_tenant_claim_category',
 		'fm_r_agreement',
@@ -182,21 +188,34 @@
 		'fm_budget',
 		'fm_budget_period',
 		'fm_budget_cost',
+		'fm_responsibility',
+		'fm_responsibility_contact',
+		'fm_action_pending',
+		'fm_action_pending_category',
+		'fm_jasper',
+		'fm_jasper_input_type',
+		'fm_jasper_format_type',
+		'fm_jasper_input'
 	);
 
 	/* The hooks this app includes, needed for hooks registration */
 	$setup_info['property']['hooks'] = array
 	(
-		'add_def_pref',
-		'deleteaccount',
 		'manual',
 		'settings',
-		'preferences',
-		'admin',
 		'help',
-		'sidebox_menu',
-		'menu'	=> 'property.menu.get_menu'
-
+		'menu'			=> 'property.menu.get_menu',
+		'cat_add'		=> 'property.cat_hooks.cat_add',
+		'cat_delete'	=> 'property.cat_hooks.cat_delete',
+		'cat_edit'		=> 'property.cat_hooks.cat_edit',
+		'config',
+		'home',
+		'addaccount'	=> 'property.hook_helper.clear_userlist',
+		'editaccount'	=> 'property.hook_helper.clear_userlist',
+		'deleteaccount'	=> 'property.hook_helper.clear_userlist',
+		'addgroup'		=> 'property.hook_helper.clear_userlist',
+		'deletegroup'	=> 'property.hook_helper.clear_userlist',
+		'editgroup'		=> 'property.hook_helper.clear_userlist'
 	);
 
 	/* Dependencies for this app to work */
