@@ -5,10 +5,9 @@
 	* @copyright Copyright (C) 2000-2005 Free Software Foundation, Inc. http://www.fsf.org/
 	* @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 	* @package setup
-	* @version $Id: applications.php 18358 2007-11-27 04:43:37Z skwashd $
+	* @version $Id: applications.php 6327 2010-09-11 14:04:15Z sigurd $
 	*/
 
-	$DEBUG = (isset($_POST['debug']) && $_POST['debug']) || (isset($_GET['debug']) && $_GET['debug']);
 	/*
 	 TODO: We allow a user to hose their setup here, need to make use
 	 of dependencies so they are warned that they are pulling the rug
@@ -24,19 +23,23 @@
 		'noapi'			=> true
 	);
 	
+
 	/**
 	 * Include setup functions
 	 */
 	include ('./inc/functions.inc.php');
 
-	if ( isset($_POST['cancel']) && $_POST['cancel'] )
+	if ( phpgw::get_var('cancel', 'bool', 'POST') )
 	{
-		Header("Location: index.php");
+		Header('Location: index.php');
 		exit;
 	}
 
 	@set_time_limit(0);
 
+	$DEBUG = phpgw::get_var('debug', 'bool');
+
+
 	// Check header and authentication
 	if (!$GLOBALS['phpgw_setup']->auth('Config'))
 	{
@@ -49,7 +52,8 @@
 
 	$tpl_root = $GLOBALS['phpgw_setup']->html->setup_tpl_dir('setup');
 	$setup_tpl = CreateObject('phpgwapi.Template',$tpl_root);
-	$setup_tpl->set_file(array(
+	$setup_tpl->set_file(array
+	(
 		'T_head' => 'head.tpl',
 		'T_footer' => 'footer.tpl',
 		'T_alert_msg' => 'msg_alert_msg.tpl',
@@ -72,8 +76,6 @@
 	$setup_tpl->set_block('T_setup_main','footer','footer');
 	$setup_tpl->set_var('lang_cookies_must_be_enabled', lang('<b>NOTE:</b> You must have cookies enabled to use setup and header admin!') );
 
-	$bg_class = array('row_on', 'row_off');
-
 	/**
 	 * Parse dependencies
 	 * 
@@ -135,69 +137,79 @@
 		$install = phpgw::get_var('install', 'string', 'POST');
 		$upgrade = phpgw::get_var('upgrade', 'string', 'POST');
 
+		if( !isset($GLOBALS['phpgw_setup']->oProc) || !$GLOBALS['phpgw_setup']->oProc )
+		{
+			$GLOBALS['phpgw_setup']->process->init_process();
+		}
+
 		if(!empty($remove) && is_array($remove))
 		{
+			$GLOBALS['phpgw_setup']->oProc->m_odb->transaction_begin();
 			foreach($remove as $appname => $key)
 			{
-				echo '<h3>' . lang('Processing: %1', $appname) . "</h3>\n<ul>";
-				$terror = array();
-				$terror[] = $setup_info[$appname];
+				echo '<h3>' . lang('Processing: %1', lang($appname)) . "</h3>\n<ul>";
+				$terror = array( $setup_info[$appname] );
 
 				if ( isset($setup_info[$appname]['tables'])
 					&& $setup_info[$appname]['tables'] )
 				{
-					$GLOBALS['phpgw_setup']->process->droptables($terror,$DEBUG);
-					echo "<li>{$setup_info[$appname]['name']} " . lang('tables dropped') . ".</li>\n";
+					$GLOBALS['phpgw_setup']->process->droptables($terror, $DEBUG);
+					echo '<li>' . lang('%1 tables dropped', lang($appname)) . ".</li>\n";
 				}
 
-				$GLOBALS['phpgw_setup']->deregister_app($setup_info[$appname]['name']);
-				echo "<li>{$setup_info[$appname]['name']} " . lang('deregistered') . ".</li>\n";
+				$GLOBALS['phpgw_setup']->deregister_app($appname);
+				echo '<li>' . lang('%1 deregistered', lang($appname)) . ".</li>\n";
 
 				if (isset($setup_info[$appname]['hooks'])
 					&& $setup_info[$appname]['hooks'] )
 				{
-					$GLOBALS['phpgw_setup']->deregister_hooks($setup_info[$appname]['name']);
-					echo "<li>{$setup_info[$appname]['name']} " . lang('hooks deregistered') . ".</li>\n";
+					$GLOBALS['phpgw_setup']->deregister_hooks($appname);
+					echo '<li>' . lang('%1 hooks deregistered', lang($appname)) . ".</li>\n";
 				}
 
-				$terror = $GLOBALS['phpgw_setup']->process->drop_langs($terror,$DEBUG);
-				echo "<li>{$setup_info[$appname]['name']} " . lang('Translations removed') . ".</li>\n</ul>\n";
+				$terror = $GLOBALS['phpgw_setup']->process->drop_langs($terror, $DEBUG);
+				echo '<li>' . lang('%1 translations removed', $appname) . ".</li>\n</ul>\n";
 			}
+			$GLOBALS['phpgw_setup']->oProc->m_odb->transaction_commit();
 		}
 
 		if(!empty($install) && is_array($install))
 		{
+			$GLOBALS['phpgw_setup']->oProc->m_odb->transaction_begin();
 			foreach($install as $appname => $key)
 			{
-				echo '<h3>' . lang('Processing: %1', $appname) . "</h3>\n<ul>";
-				$terror = array();
-				$terror[] = $setup_info[$appname];
+				echo '<h3>' . lang('Processing: %1', lang($appname)) . "</h3>\n<ul>";
+				$terror = array($setup_info[$appname]);
 
 				if ( isset($setup_info[$appname]['tables'])
 					&& is_array($setup_info[$appname]['tables']) )
 				{
 					$terror = $GLOBALS['phpgw_setup']->process->current($terror,$DEBUG);
-					$terror = $GLOBALS['phpgw_setup']->process->default_records($terror,$DEBUG);
 					echo "<li>{$setup_info[$appname]['name']} "
 						. lang('tables installed, unless there are errors printed above') . ".</h3>\n";
+					$terror = $GLOBALS['phpgw_setup']->process->default_records($terror,$DEBUG);
+					echo '<li>' . lang('%1 default values processed', lang($appname)) . ".</li>\n";
 				}
 				else
 				{
-					if ($GLOBALS['phpgw_setup']->app_registered($setup_info[$appname]['name']))
+					if ($GLOBALS['phpgw_setup']->app_registered($appname))
 					{
-						$GLOBALS['phpgw_setup']->update_app($setup_info[$appname]['name']);
+						$GLOBALS['phpgw_setup']->update_app($appname);
 					}
 					else
 					{
-						$GLOBALS['phpgw_setup']->register_app($setup_info[$appname]['name']);
-					}
-					echo "<li>{$setup_info[$appname]['name']} " . lang('registered') . ".</li>\n";
+						$GLOBALS['phpgw_setup']->register_app($appname);
+						echo '<li>' . lang('%1 registered', lang($appname)) . ".</li>\n";
 
+						// Default values has be processed - even for apps without tables - after register for locations::add to work
+						$terror = $GLOBALS['phpgw_setup']->process->default_records($terror,$DEBUG);
+						echo '<li>' . lang('%1 default values processed', lang($appname)) . ".</li>\n";
+					}
 					if ( isset($setup_info[$appname]['hooks'])
 						&& is_array($setup_info[$appname]['hooks']) )
 					{
-						$GLOBALS['phpgw_setup']->register_hooks($setup_info[$appname]['name']);
-						echo "<li>{$setup_info[$appname]['name']} " . lang('hooks registered') . ".</li>\n";
+						$GLOBALS['phpgw_setup']->register_hooks($appname);
+						echo '<li>' . lang('%1 hooks registered', lang($appname)) . ".</li>\n";
 					}
 				}
 				$force_en = False;
@@ -206,31 +218,34 @@
 					$force_en = true;
 				}
 				$terror = $GLOBALS['phpgw_setup']->process->add_langs($terror,$DEBUG,$force_en);
-				echo "<li>{$setup_info[$appname]['name']} " . lang('Translations added') . ".</li>\n</ul>\n";
+				echo '<li>' . lang('%1 translations added', lang($appname)) . ".</li>\n</ul>\n";
 			}
+			$GLOBALS['phpgw_setup']->oProc->m_odb->transaction_commit();
 		}
 
 		if(!empty($upgrade) && is_array($upgrade))
 		{
 			foreach($upgrade as $appname => $key)
 			{
-				echo '<h3>' . lang('Processing: %1', $appname) . "</h3>\n<ul>";
+				echo '<h3>' . lang('Processing: %1', lang($appname)) . "</h3>\n<ul>";
 				$terror = array();
 				$terror[] = $setup_info[$appname];
 
 				$GLOBALS['phpgw_setup']->process->upgrade($terror,$DEBUG);
 				if ($setup_info[$appname]['tables'])
 				{
-					echo "<li>{$setup_info[$appname]['name']} " . lang('tables upgraded') . ".</li>";
+					echo '<li>' . lang('%1 tables upgraded', lang($appname)) . ".</li>";
 					// The process_upgrade() function also handles registration
 				}
 				else
 				{
-					echo "<li>{$setup_info[$appname]['name']} " . lang('upgraded') . ".</li>";
+					echo '<li>' . lang('%1 upgraded', lang($appname)) . ".</li>";
 				}
 
-				$terror = $GLOBALS['phpgw_setup']->process->upgrade_langs($terror,$DEBUG);
-				echo "<li>{$setup_info[$appname]['name']} " . lang('Translations upgraded') . ".</li>\n</ul>\n";
+			// Sigurd sep 2010: very slow - run 'Manage Languages' from setup instead. 
+			//	$terror = $GLOBALS['phpgw_setup']->process->upgrade_langs($terror,$DEBUG);
+			//	echo '<li>' . lang('%1 translations upgraded', lang($appname)) . ".</li>\n</ul>\n";
+			echo "<li>To updgrade languages - run <b>'Manage Languages'</b> from setup</li>\n</ul>\n";
 			}
 		}
 
@@ -248,56 +263,54 @@
 	if($detail)
 	{
 		ksort($setup_info[$detail]);
-		$setup_tpl->set_var('description','<a href="applications.php?debug='.$DEBUG.'">' . lang('Go back') . '</a>');
+		$name = lang($setup_info[$detail]['name']);
+		$setup_tpl->set_var('description', "<h2>{$name}</h2>\n<ul>\n");
 		$setup_tpl->pparse('out','header');
-
-		
-		$name = ($setup_info[$detail]['title'] ? $setup_info[$detail]['title'] 
-			 : lang($setup_info[$detail]['name']));
-		$setup_tpl->set_var('name',lang('application'));
-		$setup_tpl->set_var('details', $name);
-		$setup_tpl->set_var('bg_class', 'th');
 		$setup_tpl->pparse('out','detail');
 	
 		$i = 1;
 		foreach($setup_info[$detail] as $key => $val)
 		{
-			if($key != 'title' && $key != 'name')
+			switch ($key)
 			{
-				$i = $i % 2;
+				// ignore these ones
+				case 'application':
+				case 'app_group':
+				case 'app_order':
+				case 'enable':
+				case 'name':
+				case 'title':
+				case '':
+					continue 2; //switch is a looping structure in php - see php.net/continue - skwashd jan08
 
-				if ($key == 'tables')
-				{
+				case 'tables':
 					$tblcnt = count($setup_info[$detail][$key]);
 					if(is_array($val))
 					{
-						$key = '<br/><a href="sqltoarray.php?appname=' . $detail . '&amp;submit=True">' . $key . '(' . $tblcnt . ')</a>:<br/>';
-						$val = implode(',<br/>',$val) .'<br/>';
+						$key = '<a href="sqltoarray.php?appname=' . $detail . '&amp;submit=True">' . $key . '(' . $tblcnt . ')</a>';
+						$val = implode(',<br>', $val);
 					}
-				}
-				
-				if ($key == 'hooks')
-				{
-					$val = implode(',',$val);
-				}
-				
-				if ($key == 'depends')
-				{
-					$val = parsedep($val);
-				}
-				
-				if (is_array($val))
-				{
-					$val = implode(',',$val);
-				}
+					break;
 
-				$setup_tpl->set_var('bg_class', $bg_class[$i]);
-				$setup_tpl->set_var('name',$key);
-				$setup_tpl->set_var('details',$val);
-				$setup_tpl->pparse('out','detail');
+				case 'depends':
+					$val = parsedep($val);
+					break;
+
+				case 'hooks':
+				default:
+					if (is_array($val))
+					{
+						$val = implode(', ', $val);
+					}
 			}
+
+			$i = $i % 2;
+			$setup_tpl->set_var('name', $key);
+			$setup_tpl->set_var('details', $val);
+			$setup_tpl->pparse('out','detail');
 			++$i;
 		}
+		$setup_tpl->set_var('footer_text', "</ul>\n<a href=\"applications.php?debug={$DEBUG}\">" . lang('Go back') . '</a>');
 		$setup_tpl->pparse('out','footer');
 		exit;
 	}
@@ -431,7 +444,6 @@
 		$setup_tpl->set_var('remove_all',lang('Remove All'));
 		$setup_tpl->set_var('lang_debug',lang('enable debug messages'));
 		$setup_tpl->set_var('debug','<input type="checkbox" name="debug" value="True"' .($DEBUG ? ' checked' : '') . '>');
-		$setup_tpl->set_var('bg_class',$bg_class[0]);
 
 		$setup_tpl->pparse('out','app_header');
 
@@ -440,25 +452,26 @@
 		{
 			if( isset($value['name']) && $value['name'] != 'phpgwapi' && $value['name'] != 'notifywindow')
 			{
-				$i = ++$i % 2;
+				++$i;
+				$row = $i % 2 ? 'off' : 'on';
 				$value['title'] = !isset($value['title']) || !strlen($value['title']) ? str_replace('*', '', lang($value['name'])) : $value['title'];
 				$setup_tpl->set_var('apptitle',$value['title']);
 				$setup_tpl->set_var('currentver', isset($value['currentver']) ? $value['currentver'] : '');
 				$setup_tpl->set_var('version',$value['version']);
-				$setup_tpl->set_var('bg_class', $bg_class[$i]);
+				$setup_tpl->set_var('bg_class',  "row_{$row}");
 				$setup_tpl->set_var('row_remove', '');
                         
 				switch($value['status'])
 				{
 					case 'C':
-						$setup_tpl->set_var('row_remove', 'row_remove_' . ($i ? 'off' : 'on') );
+						$setup_tpl->set_var('row_remove', "row_remove_{$row}");
 						$setup_tpl->set_var('remove','<input type="checkbox" name="remove[' . $value['name'] . ']" />');
 						$setup_tpl->set_var('upgrade','&nbsp;');
 						if (!$GLOBALS['phpgw_setup']->detection->check_app_tables($value['name']))
 						{
 							// App installed and enabled, but some tables are missing
 							$setup_tpl->set_var('instimg','stock_database.png');
-							$setup_tpl->set_var('bg_class','row_err_table_' . ( $i % 1 ? 'off' : 'on') );
+							$setup_tpl->set_var('bg_class', "row_err_table_{$row}");
 							$setup_tpl->set_var('instalt',lang('Not Completed'));
 							$setup_tpl->set_var('resolution','<a href="applications.php?resolve=' . $value['name'] . '&amp;badinstall=True">' . lang('Potential Problem') . '</a>');
 							$status = lang('Requires reinstall or manual repair') . ' - ' . $value['status'];
@@ -481,7 +494,7 @@
 								{
 									$notables = '&amp;notables=True';
 								}
-								$setup_tpl->set_var('bg_class','row_err_gen_' . ( $i % 1 ? 'off' : 'on') );
+								$setup_tpl->set_var('bg_class', "row_err_gen_{$row}");
 								$setup_tpl->set_var('resolution',
 									'<a href="applications.php?resolve=' . $value['name'] .  $notables . '">' . lang('Possible Reasons') . '</a>'
 								);
@@ -494,12 +507,12 @@
 						$setup_tpl->set_var('instalt',lang('Not Completed'));
 						if ( !isset($value['currentver']) || !$value['currentver'] )
 						{
-							$setup_tpl->set_var('bg_class','row_install_' . ( $i % 1 ? 'off' : 'on') );
+							$setup_tpl->set_var('bg_class', "row_install_{$row}");
 							$status = "[{$value['status']}] " . lang('Please install');
 							if ( isset($value['tables']) && is_array($value['tables']) && $GLOBALS['phpgw_setup']->detection->check_app_tables($value['name'],True))
 							{
 								// Some tables missing
-								$setup_tpl->set_var('bg_class', 'row_err_gen_' . ( $i % 1 ? 'off' : 'on') );
+								$setup_tpl->set_var('bg_class', "row_err_gen_{$row}");
 								$setup_tpl->set_var('instimg','stock_database.png');
 								$setup_tpl->set_var('row_remove', 'row_remove_' . ($i ? 'off' : 'on') );
 								$setup_tpl->set_var('remove','<input type="checkbox" name="remove[' . $value['name'] . ']" />');
@@ -510,14 +523,14 @@
 							{
 								$setup_tpl->set_var('remove','&nbsp;');
 								$setup_tpl->set_var('resolution','');
-								$status = "[{$value['status']}] " . lang('Requires upgrade');
+								$status = "[{$value['status']}] " . lang('Available to install');
 							}
 							$setup_tpl->set_var('install','<input type="checkbox" name="install[' . $value['name'] . ']" />');
 							$setup_tpl->set_var('upgrade','&nbsp;');
 						}
 						else
 						{
-							$setup_tpl->set_var('bg_class','row_upgrade_' . ( $i % 1 ? 'off' : 'on') );
+							$setup_tpl->set_var('bg_class', "row_upgrade_{$row}");
 							$setup_tpl->set_var('install','&nbsp;');
 							// TODO display some info about breakage if you mess with this app
 							$setup_tpl->set_var('upgrade','<input type="checkbox" name="upgrade[' . $value['name'] . ']">');
@@ -538,7 +551,7 @@
 						$status = "[{$value['status']}] " . lang('Version Mismatch');
 						break;
 					case 'D':
-						$setup_tpl->set_var('bg_class', 'row_err_gen_' . ( $i % 1 ? 'off' : 'on') );
+						$setup_tpl->set_var('bg_class', "row_err_gen_{$row}");
 						$depstring = parsedep($value['depends']);
 						$setup_tpl->set_var('instimg', 'stock_no.png');
 						$setup_tpl->set_var('instalt',lang('Dependency Failure'));
@@ -549,7 +562,7 @@
 						$status = "[{$value['status']}] " . lang('Dependency Failure') . $depstring;
 						break;
 					case 'P':
-						$setup_tpl->set_var('bg_class', 'row_err_gen_' . ( $i % 1 ? 'off' : 'on') );
+						$setup_tpl->set_var('bg_class', "row_err_gen_{$row}");
 						$depstring = parsedep($value['depends']);
 						$setup_tpl->set_var('instimg', 'stock_no.png');
 						$setup_tpl->set_var('instalt',lang('Post-install Dependency Failure'));
@@ -582,4 +595,3 @@
 		$setup_tpl->pparse('out','footer');
 		$GLOBALS['phpgw_setup']->html->show_footer();
 	}
-?>
