@@ -15,25 +15,7 @@
   *  option) any later version.                                              *
   \**************************************************************************/
 
-  /* $Id: functions.inc.php 18358 2007-11-27 04:43:37Z skwashd $ */
-
-	// PHP5 compat fix
-	if (version_compare(phpversion(), '5.0') < 0)
-	{
-		eval('
-			function clone($obj)
-			{
-				if ( method_exists($obj, "__clone") )
-				{
-					$new_obj = $obj;
-					$new_obj->__clone();
-					return $new_obj;
-				}
-				return $obj;
-			}
-		');
-	}
-
+  /* $Id: functions.inc.php 6048 2010-06-12 15:28:01Z sigurd $ */
 
 	/**
 	* phpGroupWare Information level "error"
@@ -44,33 +26,35 @@
 	* phpGroupWare debug level "error"
 	*/
 	define('PHPGW_E_DEBUG', -1024);
-	
+
 	if ( file_exists('../header.inc.php') )
 	{
 		require_once('../header.inc.php');
 	}
 
-	if (!function_exists('html_entity_decode'))//html_entity_decode() is only available in PHP4.3+
+	if ( !function_exists('filter_var') || !function_exists('json_encode') ) // filter_var() and json_encode are only available in PHP 5.2+
 	{
-		die('<h1>You appear to be using PHP ' . PHP_VERSION . " phpGroupWare requires 4.3.0 or later <br>\n"
+		die('<h1>You appear to be using PHP ' . PHP_VERSION . " phpGroupWare requires 5.2.0 or later <br>\n"
 			. 'Please contact your System Administrator</h1>');
 	}
 
 	/*  If we included the header.inc.php, but it is somehow broken, cover ourselves... */
-	if ( !defined('PHPGW_SERVER_ROOT') && !defined('PHPGW_INCLUDE_ROOT') )
+	if ( !defined('PHPGW_SERVER_ROOT') )
 	{
 		define('PHPGW_SERVER_ROOT', realpath('..') );
-		define('PHPGW_INCLUDE_ROOT', realpath('..') );
 	}
 
-	define('SEP', DIRECTORY_SEPARATOR);
-
-	if ( is_dir(PHPGW_INCLUDE_ROOT . SEP . 'phpgwapi') && is_dir(PHPGW_INCLUDE_ROOT . SEP . 'phpgwapi' . SEP . 'inc')
-		&& is_file(PHPGW_INCLUDE_ROOT . SEP . 'phpgwapi' .  SEP . 'inc' . SEP . 'common_functions.inc.php') )
+	if ( !defined('PHPGW_INCLUDE_ROOT') )
 	{
-		require_once(PHPGW_INCLUDE_ROOT . SEP . 'phpgwapi' .  SEP . 'inc' . SEP . 'common_functions.inc.php');
+		define('PHPGW_INCLUDE_ROOT', PHPGW_SERVER_ROOT);
+	}
+
+	if ( is_dir(PHPGW_INCLUDE_ROOT . '/phpgwapi') && is_dir(PHPGW_INCLUDE_ROOT . '/phpgwapi/inc')
+		&& is_file(PHPGW_INCLUDE_ROOT . '/phpgwapi/inc/common_functions.inc.php') )
+	{
+		require_once(PHPGW_INCLUDE_ROOT . '/phpgwapi/inc/common_functions.inc.php');
 		$GLOBALS['phpgw'] = createObject('phpgwapi.phpgw');
-		require_once(PHPGW_INCLUDE_ROOT . SEP . 'phpgwapi' . SEP . 'inc' . SEP . 'log_functions.inc.php');
+		require_once(PHPGW_INCLUDE_ROOT . '/phpgwapi/inc/log_functions.inc.php');
 	}
 	else
 	{
@@ -79,23 +63,29 @@
 			. ' target="_blank">download phpGroupWare</a> and try again');
 	}
 
+	// Make sure we have an install id - I don't like this, but it works :( skwashd mar2008
+	if ( !isset($GLOBALS['phpgw_info']['server']['install_id']) )
+	{
+		$GLOBALS['phpgw_info']['server']['install_id'] = sha1($_SERVER['HTTP_HOST']);
+	}
+
 	/**
-	* Translate a phrase
-	*
-	* @param string $key phrase to translate (note: %n are replaces with $mn)
-	* @param string $m1 substitution string
-	* @param string $m1 substitution string
-	* @param string $m2 substitution string
-	* @param string $m3 substitution string
-	* @param string $m4 substitution string
-	* @param string $m5 substitution string
-	* @param string $m6 substitution string
-	* @param string $m7 substitution string
-	* @param string $m8 substitution string
-	* @param string $m9 substitution string
-	* @param string $m10 substitution string
-	* @returns string translated phrase
-	*/
+	 * Translate a phrase
+	 *
+	 * @param string $key phrase to translate (note: %n are replaces with $mn)
+	 * @param string $m1 substitution string
+	 * @param string $m1 substitution string
+	 * @param string $m2 substitution string
+	 * @param string $m3 substitution string
+	 * @param string $m4 substitution string
+	 * @param string $m5 substitution string
+	 * @param string $m6 substitution string
+	 * @param string $m7 substitution string
+	 * @param string $m8 substitution string
+	 * @param string $m9 substitution string
+	 * @param string $m10 substitution string
+	 * @returns string translated phrase
+	 */
 	function lang($key,$m1='',$m2='',$m3='',$m4='',$m5='',$m6='',$m7='',$m8='',$m9='',$m10='')
 	{
 		if(is_array($m1))
@@ -117,7 +107,7 @@
 	/**
 	* cleans up a backtrace array and converts it to a string
 	*
-	* @internal this is such an ugly piece of code due to a reference to the error context 
+	* @internal this is such an ugly piece of code due to a reference to the error context
 	* being in the backtrace and the error context can not be edited - see php.net/set_error_handler
 	* @param array $bt php backtrace
 	* @return string the formatted backtrace, empty if the user is not an admin
@@ -215,11 +205,11 @@
 	* phpGroupWare generic error handler
 	*
 	* @link http://php.net/set_error_handler
-	* 
+	*
 	*/
 	function phpgw_handle_error($error_level, $error_msg, $error_file, $error_line, $error_context = array())
 	{
-		if ( error_reporting() == 0 ) // 0 == @function() so we ignore it, as the dev requested 
+		if ( error_reporting() == 0 ) // 0 == @function() so we ignore it, as the dev requested
 		{
 			return true;
 		}
@@ -266,9 +256,10 @@
 				break;
 			case E_NOTICE:
 			case E_USER_NOTICE:
+			case E_STRICT:
 				$log_args['severity'] = 'N';
 				$log->notice($log_args);
-				echo "\n<br>" . lang('ERROR Notice: %1 in %2 at line %3', $error_msg, $error_file, $error_line) . "<br>\n"; //this will be commented in the final version
+			//	echo "\n<br>" . lang('ERROR Notice: %1 in %2 at line %3', $error_msg, $error_file, $error_line) . "<br>\n"; //this will be commented in the final version
 			//No default, we just ignore it, for now
 		}
 	}
@@ -314,8 +305,7 @@
 	*/
 	function lang_select($onChange = '')
 	{
-		$ConfigLang = phpgw::get_var('ConfigLang');
-
+		$ConfigLang = phpgw::get_var('ConfigLang', 'string', 'POST');
 		$select = '<select name="ConfigLang"' . ($onChange ? ' onChange="this.form.submit();"' : '') . '>' . "\n";
 		$languages = get_langs();
 		while(list($null,$data) = each($languages))
@@ -349,5 +339,18 @@
 
 	$GLOBALS['phpgw_info']['server']['app_images'] = 'templates/base/images';
 
+	if($_POST['setting']['enable_mcrypt'] == 'True')
+	{
+		$GLOBALS['phpgw_info']['server']['mcrypt_enabled'] = true;
+		$_iv  = $_POST['setting']['mcrypt_iv'];
+		$_key = $_POST['setting']['setup_mcrypt_key'];
+	}
+	else
+	{
+		$_iv  = $GLOBALS['phpgw_info']['server']['mcrypt_iv'];
+		$_key = $GLOBALS['phpgw_info']['server']['setup_mcrypt_key'];	
+	}
+
+	$GLOBALS['phpgw']->crypto->init(array($_key, $_iv));
+
 	$GLOBALS['phpgw_setup'] = CreateObject('phpgwapi.setup', True, True);
-?>
