@@ -5,7 +5,7 @@
 	* @copyright Portions Copyright (C) 2000-2005 Free Software Foundation, Inc. http://www.fsf.org/
 	* @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 	* @package setup
-	* @version $Id: index.php 18358 2007-11-27 04:43:37Z skwashd $
+	* @version $Id: index.php 6048 2010-06-12 15:28:01Z sigurd $
 	*/
 
 	/*
@@ -69,6 +69,7 @@
 	}
 	elseif (!$GLOBALS['phpgw_setup']->auth('Config'))
 	{
+		$_POST['ConfigLang'] = isset($GLOBALS['phpgw_info']['server']['default_lang']) ? $GLOBALS['phpgw_info']['server']['default_lang'] : '';
 		$GLOBALS['phpgw_setup']->html->show_header(lang('Please login'),True);
 		$GLOBALS['phpgw_setup']->html->login_form();
 		$GLOBALS['phpgw_setup']->html->show_footer();
@@ -180,10 +181,12 @@
 			switch ($phpgw_domain[$GLOBALS['ConfigDomain']]['db_type'])
 			{
 				case 'mysql':
-					$setup_tpl->set_var('instr',lang('mysqlinstr'));
+					$setup_tpl->set_var('instr',lang('mysqlinstr %1', $phpgw_domain[$GLOBALS['ConfigDomain']]['db_name']));
+					$setup_tpl->set_var('db_root','root');
 					break;
 				case 'postgres':
-					$setup_tpl->set_var('instr',lang('pgsqlinstr'));
+					$setup_tpl->set_var('instr',lang('pgsqlinstr %1', $phpgw_domain[$GLOBALS['ConfigDomain']]['db_name']));
+					$setup_tpl->set_var('db_root','postgres');
 					break;
 			}
 			$setup_tpl->parse('V_db_stage_1','B_db_stage_1');
@@ -246,7 +249,14 @@
 			switch ($GLOBALS['phpgw_info']['setup']['currentver']['phpgwapi'])
 			{
 				case 'dbcreate':
-					$GLOBALS['phpgw_setup']->db->create_database($_POST['db_root'], $_POST['db_pass']);
+					try
+					{
+						$GLOBALS['phpgw_setup']->db->create_database($_POST['db_root'], $_POST['db_pass']);
+					}
+					catch (Exception $e)
+					{
+						$setup_tpl->set_var('status',$e->getMessage());
+					}
 					break;
 				case 'drop':
 					$setup_info = $GLOBALS['phpgw_setup']->detection->get_versions($setup_info);
@@ -258,7 +268,7 @@
 
 					// Only process phpgwapi, admin and preferences.
 					$setup_info = $GLOBALS['phpgw_setup']->detection->base_install($setup_info);
-					$setup_info = $GLOBALS['phpgw_setup']->process->pass($setup_info,'new',$GLOBALS['DEBUG'],True);
+					$setup_info = $GLOBALS['phpgw_setup']->process->pass($setup_info, 'new', false, true);
 					$GLOBALS['included'] = True;
 					include_once('lang.php');
 					$GLOBALS['phpgw_info']['setup']['currentver']['phpgwapi'] = 'oldversion';
@@ -327,16 +337,16 @@
 			);
 			$GLOBALS['phpgw_setup']->db->query("select config_value FROM phpgw_config WHERE config_name='auth_type'");
 			$GLOBALS['phpgw_setup']->db->next_record();
-			if ($GLOBALS['phpgw_setup']->db->f(0) == 'ldap')
+			if ($GLOBALS['phpgw_setup']->db->f('config_value') == 'ldap')
 			{
 				$GLOBALS['phpgw_setup']->db->query("select config_value FROM phpgw_config WHERE config_name='ldap_host'");
 				$GLOBALS['phpgw_setup']->db->next_record();
-				if ($GLOBALS['phpgw_setup']->db->f(0) != '')
+				if ($GLOBALS['phpgw_setup']->db->f('config_value') != '')
 				{
 					$btn_config_ldap = $GLOBALS['phpgw_setup']->html->make_frm_btn_simple(
 						lang('LDAP account import/export'),
 						'POST','ldap.php',
-						'submit',lang('Configure Now'),
+						'submit',lang('Configure LDAP accounts'),
 						''
 					);
 				}
@@ -346,14 +356,14 @@
 				}
 				$GLOBALS['phpgw_setup']->db->query("select config_value FROM phpgw_config WHERE config_name='webserver_url'");
 				$GLOBALS['phpgw_setup']->db->next_record();
-				if ($GLOBALS['phpgw_setup']->db->f(0))
+				if ($GLOBALS['phpgw_setup']->db->f('config_value'))
 				{
 					/* NOTE: we assume here ldap doesn't delete accounts */
 					$link_make_accts = $GLOBALS['phpgw_setup']->html->make_href_link_simple(
-						'<br />',
-						'setup_demo.php',
-						lang('Click Here'),
-						lang('to setup an admin account and (optionally) 3 demo accounts.')
+						'<br>',
+						'accounts.php',
+						lang('Setup an Admininstrator account'),
+						lang('and optional demo accounts.')
 					);
 				}
 				else
@@ -365,15 +375,15 @@
 			{
 				$btn_config_ldap = '';
 				/* detect whether anything will be deleted before alerting */
-				$phpgw_setup->db->query("select config_value FROM phpgw_config WHERE config_name='account_repository'");
+				$phpgw_setup->db->query("SELECT config_value FROM phpgw_config WHERE config_name = 'account_repository'");
 				$phpgw_setup->db->next_record();
-				$account_repository = $phpgw_setup->db->f(0);
-				$account_creation_notice = lang('to setup an admin account and (optionally) 3 demo accounts.');
+				$account_repository = $phpgw_setup->db->f('config_value');
+				$account_creation_notice = lang('and optional demo accounts.');
 				if ($account_repository == 'sql')
 				{
-					$phpgw_setup->db->query("select count(*) from phpgw_accounts");
+					$phpgw_setup->db->query("select count(*) as cnt from phpgw_accounts");
 					$phpgw_setup->db->next_record();
-					$number_of_accounts = (int) $phpgw_setup->db->f(0);
+					$number_of_accounts = (int) $phpgw_setup->db->f('cnt');
 					if ($number_of_accounts>0)
 					{
 						$account_creation_notice .= lang('<br /><b>This will delete all existing accounts.</b>');
@@ -381,9 +391,9 @@
 				}
 
  				$link_make_accts = $GLOBALS['phpgw_setup']->html->make_href_link_simple(
- 					'<br />',
- 					'setup_demo.php',
- 					lang('Click Here'),
+ 					'<br>',
+ 					'accounts.php',
+ 					lang('Setup an Admininstrator account'),
 					$account_creation_notice
  				);
 			}
@@ -481,4 +491,3 @@
 	);
 	$setup_tpl->pparse('out','T_setup_main');
 	$GLOBALS['phpgw_setup']->html->show_footer();
-?>
