@@ -8,7 +8,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package sms
 	* @subpackage sms
- 	* @version $Id: class.sms.inc.php 18203 2007-08-13 12:45:07Z sigurdne $
+ 	* @version $Id: class.sms.inc.php 6257 2010-08-22 14:40:02Z sigurd $
 	*/
 
 	/**
@@ -19,32 +19,43 @@
 
 //	_debug_array ($GLOBALS['phpgw_info']['sms_config']);
 
-	$apps_path['base']	= PHPGW_SERVER_ROOT . SEP . 'sms';
-	$apps_path['libs']	= $apps_path['base'] . SEP . 'lib';
-	$apps_path['plug']	= $apps_path['base'] . SEP . 'inc' . SEP . 'plugin';
-	$apps_path['inc']	= $apps_path['base'] . SEP . 'inc';
-	
+	$apps_path['base']	= PHPGW_SERVER_ROOT . '/sms';
+	$apps_path['libs']	= $apps_path['base'] . '/lib';
+	$apps_path['plug']	= $apps_path['base'] . '/inc/plugin';
+	$apps_path['inc']	= $apps_path['base'] . '/inc';
+
 	// SMS command security parameter
-	$feat_command_path['bin']	= $apps_path['base']."/bin";
+	$feat_command_path['bin']	= "{$apps_path['base']}/bin/{$GLOBALS['phpgw_info']['user']['domain']}";
 	$GLOBALS['phpgw_info']['sms_config']['common']['apps_path'] = $apps_path;
 	$GLOBALS['phpgw_info']['sms_config']['common']['feat_command_path'] = $feat_command_path;
 
-	if(!isset($GLOBALS['phpgw_info']['sms_config']['common']['gateway_module']) || !$GLOBALS['phpgw_info']['sms_config']['common']['gateway_module'])
+	if(!isset($GLOBALS['phpgw_info']['sms_config']['common']['gateway_module_get']) || !$GLOBALS['phpgw_info']['sms_config']['common']['gateway_module_get'])
 	{
 		$path_to_sms = dirname(__FILE__);
 
-		include_once($path_to_sms . SEP . 'config.php');
+		require $path_to_sms . '/config.php';
 	}
 
-	if (file_exists($apps_path['inc'] . SEP . 'plugin' . SEP . 'gateway' . SEP . $GLOBALS['phpgw_info']['sms_config']['common']['gateway_module']. "/fn.php"))
+	if($GLOBALS['phpgw_info']['sms_config']['common']['gateway_module_get'] && !$GLOBALS['phpgw_info']['sms_config']['common']['gateway_module_send'])
 	{
-		include_once($apps_path['inc'] . SEP . 'plugin' . SEP . 'gateway' . SEP. $GLOBALS['phpgw_info']['sms_config']['common']['gateway_module']. "/fn.php");
+		$GLOBALS['phpgw_info']['sms_config']['common']['gateway_module_send'] = $GLOBALS['phpgw_info']['sms_config']['common']['gateway_module_get'];
+	}
+
+	if (file_exists("{$apps_path['inc']}/plugin/gateway/{$GLOBALS['phpgw_info']['sms_config']['common']['gateway_module_get']}/get.php")
+	 && file_exists("{$apps_path['inc']}/plugin/gateway/{$GLOBALS['phpgw_info']['sms_config']['common']['gateway_module_send']}/send.php"))
+	{
+		require "{$apps_path['inc']}/plugin/gateway/{$GLOBALS['phpgw_info']['sms_config']['common']['gateway_module_get']}/get.php";
+		require "{$apps_path['inc']}/plugin/gateway/{$GLOBALS['phpgw_info']['sms_config']['common']['gateway_module_send']}/send.php";
 	}
 	else
 	{
-		if (!$GLOBALS['phpgw_info']['sms_config']['common']['gateway_module'])
+		if ($GLOBALS['phpgw_info']['sms_config']['common']['gateway_module_get'] && !file_exists("{$apps_path['inc']}/plugin/gateway/{$GLOBALS['phpgw_info']['sms_config']['common']['gateway_module_get']}/get.php"))
 		{
-			die ("ERROR: Gateway module '" . $GLOBALS['phpgw_info']['sms_config']['common']['gateway_module'] . "' does not exists - please contact system administrator");
+			die ("ERROR: Gateway get module '" . $GLOBALS['phpgw_info']['sms_config']['common']['gateway_module_get'] . "' does not exists - please contact system administrator");
+		}
+		else if ($GLOBALS['phpgw_info']['sms_config']['common']['gateway_module_send'] && !file_exists("{$apps_path['inc']}/plugin/gateway/{$GLOBALS['phpgw_info']['sms_config']['common']['gateway_module_send']}/send.php"))
+		{
+			die ("ERROR: Gateway send module '" . $GLOBALS['phpgw_info']['sms_config']['common']['gateway_module_send'] . "' does not exists - please contact system administrator");
 		}
 		else
 		{
@@ -52,22 +63,23 @@
 		}
 	}
 
-	class sms_sms_
+	class sms_sms__
 	{
 		var $apps_path;
-		
-		function sms_sms_()
-		{	
+
+		function __construct()
+		{
 			$this->apps_config = $GLOBALS['phpgw_info']['sms_config']['common']['apps_config'];
 			$this->apps_path = $GLOBALS['phpgw_info']['sms_config']['common']['apps_path'];
 			$this->feat_command_path = $GLOBALS['phpgw_info']['sms_config']['common']['feat_command_path'];
-			$this->gateway_module = $GLOBALS['phpgw_info']['sms_config']['common']['gateway_module'];
+			$this->gateway_module_get = $GLOBALS['phpgw_info']['sms_config']['common']['gateway_module_get'];
+			$this->gateway_module_send = $GLOBALS['phpgw_info']['sms_config']['common']['gateway_module_send'];
 			$this->gateway_number = $GLOBALS['phpgw_info']['sms_config']['common']['gateway_number'];
 			$this->web_title = $GLOBALS['phpgw_info']['sms_config']['common']['web_title'];
 			$this->email_service = $GLOBALS['phpgw_info']['sms_config']['common']['email_service'];
 			$this->email_footer = $GLOBALS['phpgw_info']['sms_config']['common']['email_footer'];
 			$this->reserved_codes = $GLOBALS['phpgw_info']['sms_config']['reserved_codes'];
-			
+
 
 			$dateformat		= $GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat'];
 			$request['start_date']			= $GLOBALS['phpgw']->common->show_date($request['start_date'],$dateformat);
@@ -112,7 +124,7 @@
 		{
 			return date($this->datetimeformat, time());
 		}
-		
+
 		function gpcode2gpid($uid,$gp_code)
 		{
 			if ($uid && $gp_code)
@@ -127,29 +139,29 @@
 
 		function username2mobile($username)
 		{
-			
+
 		//	$GLOBALS['phpgw']->preferences->account_id = $this->account;
-		//	$GLOBALS['phpgw']->preferences->read_repository();
+		//	$GLOBALS['phpgw']->preferences->read();
 			$mobile = $GLOBALS['phpgw_info']['user']['preferences']['sms']['cellphone'];
 			return $mobile;
 		}
-		
+
 		function username2sender($username)
-		{			
+		{
 			if($GLOBALS['phpgw_info']['user']['preferences']['sms']['signature'])
 			{
 				$sender = ' - ' . $GLOBALS['phpgw_info']['user']['preferences']['sms']['signature'];
 			}
 			return $sender;
 		}
-				
+
 		function username2name($username)
 		{
 			$name = $GLOBALS['phpgw_info']['user']['fullname'];
 			return $name;
 		}
-		
-		
+
+
 		function sendmail($mail_from,$mail_to,$subject="",$mail_body="")
 		{
 			if (!is_object($GLOBALS['phpgw']->send))
@@ -158,15 +170,15 @@
 			}
 
 			$rcpt = $GLOBALS['phpgw']->send->msg('email',$mail_to, $subject, stripslashes($mail_body), '', $cc, $bcc, $mail_from, $from_name, 'plain');
-			
+
 			return $rcpt;
 		}
-		
-		
+
+
 		function websend2pv($username,$sms_to,$message,$sms_type="text",$unicode="0")
 		{
 			$datetime_now = $this->datetime_now();
-			$gateway_module = $this->gateway_module; 
+			$gateway_module_send = $this->gateway_module_send;
 			$uid = $this->account;
 
 			$mobile_sender = $this->username2mobile($username);
@@ -200,16 +212,16 @@
 				$c_sms_to = str_replace("\'","",$array_sms_to[$i]);
 				$c_sms_to = str_replace("\"","",$array_sms_to[$i]);
 				$message = $this->db->db_addslashes($message);
-			
-				$db_query = "INSERT INTO phpgw_sms_tblSMSOutgoing 
-					(uid,p_gateway,p_src,p_dst,p_footer,p_msg,p_datetime,p_sms_type,unicode) 
-					VALUES ('$uid','$gateway_module','$mobile_sender','$c_sms_to','$sms_sender','$message','$datetime_now','$sms_type','$unicode')";
-		
+
+				$db_query = "INSERT INTO phpgw_sms_tblsmsoutgoing
+					(uid,p_gateway,p_src,p_dst,p_footer,p_msg,p_datetime,p_sms_type,unicode)
+					VALUES ('$uid','$gateway_module_send','$mobile_sender','$c_sms_to','$sms_sender','$message','$datetime_now','$sms_type','$unicode')";
+
 				$GLOBALS['phpgw']->db->transaction_begin();
 				$GLOBALS['phpgw']->db->query($db_query,__LINE__,__FILE__);
-				$smslog_id = $GLOBALS['phpgw']->db->get_last_insert_id('phpgw_sms_tblSMSOutgoing','smslog_id');
+				$smslog_id = $GLOBALS['phpgw']->db->get_last_insert_id('phpgw_sms_tblsmsoutgoing','smslog_id');
 				$GLOBALS['phpgw']->db->transaction_commit();
-		
+
 				$gp_code = "PV";
 				$to[$i] = $c_sms_to;
 				$ok[$i] = 0;
@@ -223,11 +235,11 @@
 			}
 			return array($ok,$to);
 		}
-		
+
 		function websend2group($username,$gp_code,$message,$sms_type="text")
 		{
 			$datetime_now = $this->datetime_now();
-			$gateway_module = $this->gateway_module;
+			$gateway_module_send = $this->gateway_module_send;
 			$uid = $GLOBALS['phpgw']->accounts->name2id($username);
 			$mobile_sender = $this->username2mobile($username);
 			$max_length = 160;
@@ -253,10 +265,10 @@
 				$c_gp_code = strtoupper($array_gp_code[$i]);
 				$gpid = gpcode2gpid($uid,$c_gp_code);
 				$db_query = "SELECT * FROM phpgw_sms_tblUserPhonebook WHERE gpid='$gpid'";
-				$db_result = dba_query($db_query);
-				while ($db_row = dba_fetch_array($db_result))
+				$db_result = $this->db->query($db_query);
+				while($this->db->next_record())
 				{
-					$p_num = $db_row[p_num];
+					$p_num = $this->db->f('p_num');
 					$sms_to = $p_num;
 					$sms_msg = $message;
 					$sms_msg = str_replace("\r","",$sms_msg);
@@ -270,11 +282,12 @@
 					$sms_to = str_replace("\"","",$sms_to);
 					$the_msg = "$sms_to\n$sms_msg";
 					$db_query1 = "
-					INSERT INTO phpgw_sms_tblSMSOutgoing 
-					(uid,p_gateway,p_src,p_dst,p_footer,p_msg,p_datetime,p_gpid,p_sms_type) 
-					VALUES ('$uid','$gateway_module','$mobile_sender','$sms_to','$sms_sender','$message','$datetime_now','$gpid','$sms_type')
+					INSERT INTO phpgw_sms_tblsmsoutgoing
+					(uid,p_gateway,p_src,p_dst,p_footer,p_msg,p_datetime,p_gpid,p_sms_type)
+					VALUES ('$uid','$gateway_module_send','$mobile_sender','$sms_to','$sms_sender','$message','$datetime_now','$gpid','$sms_type')
 					";
-					$smslog_id = @dba_insert_id($db_query1);
+					$this->db2->query($db_query1);
+					$smslog_id = $this->db2->get_last_insert_id('phpgw_sms_tblsmsoutgoing');
 					$to[$j] = $sms_to;
 					$ok[$j] = 0;
 					if ($smslog_id)
@@ -289,7 +302,7 @@
 			}
 			return array($ok,$to);
 		}
-		
+
 		function send2group($mobile_sender,$gp_code,$message)
 		{
 			$datetime_now = $this->datetime_now();
@@ -297,25 +310,25 @@
 			if ($mobile_sender && $gp_code && $message)
 			{
 				$db_query = "SELECT uid,username,sender FROM phpgw_sms_tblUser WHERE mobile='$mobile_sender'";
-				$db_result = dba_query($db_query);
-				$db_row = dba_fetch_array($db_result);
-				$uid = $db_row[uid];
-				$username = $db_row[username];
-				$sms_sender = $db_row[sender];
+				$this->db->query($db_query);
+				$this->db->next_record();
+				$uid = $this->db->f('uid');
+				$username = $this->db->f('username');
+				$sms_sender = $this->db->f('sender');
 				if ($uid && $username)
 				{
 					$gp_code = strtoupper($gp_code);
 					$db_query = "SELECT * FROM phpgw_sms_tblUserGroupPhonebook WHERE uid='$uid' AND gp_code='$gp_code'";
-					$db_result = dba_query($db_query);		
-					$db_row = dba_fetch_array($db_result);
-					$gpid = $db_row[gpid];
+					$this->db->query($db_query);
+					$this->db->next_record();
+					$gpid = $this->db->f('gpid');
 					if ($gpid && $message)
 					{
 						$db_query = "SELECT * FROM phpgw_sms_tblUserPhonebook WHERE gpid='$gpid' AND uid='$uid'";
-						$db_result = dba_query($db_query);
-						while ($db_row = dba_fetch_array($db_result))
+						$this->db->query($db_query);
+						while ($this->db->next_record())
 						{
-							$p_num = $db_row[p_num];
+							$p_num = $this->db->f('p_num');
 							$sms_to = $p_num;
 							$max_length = 160 - strlen($sms_sender) - 3;
 							if (strlen($message)>$max_length)
@@ -335,9 +348,10 @@
 							$sms_to = str_replace("\"","",$sms_to);
 							$send_code = md5(mktime().$sms_to);
 							$db_query1 = "
-							INSERT INTO phpgw_sms_tblSMSOutgoing (uid,p_src,p_dst,p_footer,p_msg,p_datetime,p_gpid) 
+							INSERT INTO phpgw_sms_tblsmsoutgoing (uid,p_src,p_dst,p_footer,p_msg,p_datetime,p_gpid)
 							VALUES ('$uid','$mobile_sender','$sms_to','$sms_sender','$message','$datetime_now','$gpid')";
-							$smslog_id = @dba_insert_id($db_query1);
+							$this->db2->query($db_query1);
+							$smslog_id = $this->db2->get_last_insert_id('phpgw_sms_tblsmsoutgoing');
 							$sms_id = "$gp_code.$uid.$smslog_id";
 							if ($smslog_id)
 							{
@@ -352,13 +366,13 @@
 			}
 			return $ok;
 		}
-		
+
 		function insertsmstodb($sms_datetime,$sms_sender,$target_code,$message)
 		{
 			$email_footer = $this->email_footer;
 			$email_service = $this->email_service;
 			$web_title = $this->web_title;
-			$gateway_module = $this->gateway_module;
+			$gateway_module_get = $this->gateway_module_get;
 
 			$ok = false;
 			if ($sms_sender && $target_code && $message)
@@ -366,13 +380,13 @@
 			// masked sender sets here
 				$masked_sender = substr_replace($sms_sender,'xxxx',-4);
 				$sql = "
-					INSERT INTO phpgw_sms_tblsmsincoming 
-					(in_gateway,in_sender,in_masked,in_code,in_msg,in_datetime) 
-					VALUES ('$gateway_module','$sms_sender','$masked_sender','$target_code','$message','$sms_datetime')
+					INSERT INTO phpgw_sms_tblsmsincoming
+					(in_gateway,in_sender,in_masked,in_code,in_msg,in_datetime)
+					VALUES ('$gateway_module_get','$sms_sender','$masked_sender','$target_code','$message','$sms_datetime')
 					";
 				$this->db->query($sql,__LINE__,__FILE__);
 
-				if ($cek_ok = $this->db->get_last_insert_id(phpgw_sms_tblsmsincoming,'in_id'))
+				if ($cek_ok = $this->db->get_last_insert_id('phpgw_sms_tblsmsincoming','in_id'))
 				{
 					$db_query1 = "SELECT board_forward_email FROM phpgw_sms_featboard WHERE board_code='$target_code'";
 					$this->db->query($db_query1,__LINE__,__FILE__);
@@ -394,7 +408,7 @@
 			}
 			return $ok;
 		}
-		
+
 		function insertsmstoinbox($sms_datetime,$sms_sender,$target_user,$message)
 		{
 			$email_footer = $this->email_footer;
@@ -407,7 +421,7 @@
 			//	$db_query = "SELECT uid,email,mobile FROM phpgw_sms_tblUser WHERE username='$target_user'";
 				$uid = $GLOBALS['phpgw']->accounts->name2id($target_user);
 			//	$GLOBALS['phpgw']->preferences->account_id = $uid;
-			//	$GLOBALS['phpgw']->preferences->read_repository();
+			//	$GLOBALS['phpgw']->preferences->read();
 				$mobile = $GLOBALS['phpgw_info']['user']['preferences']['sms']['cellphone'];
 				$email = $GLOBALS['phpgw_info']['user']['preferences']['email']['address'];
 
@@ -415,7 +429,7 @@
 				{
 					$db_query = "
 					INSERT INTO phpgw_sms_tbluserinbox
-					(in_sender,in_uid,in_msg,in_datetime) 
+					(in_sender,in_uid,in_msg,in_datetime)
 					VALUES ('$sms_sender','$uid','$message','$sms_datetime')
 					";
 
@@ -440,18 +454,18 @@
 			}
 			return $ok;
 		}
-		
+
 		function getsmsinbox()
 		{
 			$this->gw_set_incoming_action();
 		}
-		
+
 		function getsmsstatus()
 		{
-			$gateway_module = $this->gateway_module;
-			$db_query = "SELECT * FROM phpgw_sms_tblsmsoutgoing WHERE p_status='0' AND p_gateway='$gateway_module'";
+			$gateway_module_send = $this->gateway_module_send;
+			$db_query = "SELECT * FROM phpgw_sms_tblsmsoutgoing WHERE p_status='0' AND p_gateway='$gateway_module_send'";
 			$this->db->query($db_query,__LINE__,__FILE__);
-			
+
 			while ($this->db->next_record())
 			{
 				$gpid = "";
@@ -470,7 +484,7 @@
 			}
 		//	$this->gw_set_delivery_status($gp_code,$uid,$smslog_id,$p_datetime,$p_update);
 		}
-		
+
 /*		function execgwcustomcmd()
 		{
 			if (function_exists("gw_customcmd"))
@@ -478,27 +492,27 @@
 				gw_customcmd();
 			}
 		}
-		
+
 		function execcommoncustomcmd($DAEMON_COUNTER = '')
 		{
 			@include $this->apps_path[inc]."/admin/commoncustomcmd.php";
 		}
-		
+
 */		function setsmsdeliverystatus($smslog_id,$uid,$p_status)
 		{
 			$datetime_now = $this->datetime_now();
 			$ok = false;
-			$db_query = "UPDATE phpgw_sms_tblSMSOutgoing SET p_update='$datetime_now',p_status='$p_status' WHERE smslog_id='$smslog_id' AND uid='$uid'";
+			$db_query = "UPDATE phpgw_sms_tblsmsoutgoing SET p_update='$datetime_now',p_status='$p_status' WHERE smslog_id='$smslog_id' AND uid='$uid'";
 			$this->db->transaction_begin();
 			$this->db->query($db_query,__LINE__,__FILE__);
-			
+
 			if ($this->db->transaction_commit())
 			{
 				$ok = true;
 			}
 			return $ok;
 		}
-		
+
 		function checkavailablecode($code)
 		{
 			$reserved_codes = $this->reserved_codes;
@@ -513,7 +527,7 @@
 			}
 			if ($reserved)
 			{
-				$ok = false;	
+				$ok = false;
 			}
 			else
 			{
@@ -555,7 +569,7 @@
 			}
 				return $ok;
 		}
-		
+
 		// part of SMS board
 		function outputtorss($code,$line="10")
 		{
@@ -566,7 +580,7 @@
 			{
 				$line = "10";
 			};
-			
+
 			$format_output = "RSS0.91";
 			$rss = new UniversalFeedCreator();
 			$db_query1 = "SELECT * FROM phpgw_sms_tblsmsincoming WHERE in_code='$code' ORDER BY in_datetime DESC LIMIT 0,$line";
@@ -581,12 +595,12 @@
 				$items->description = $description;
 				$items->comments = $datetime;
 				$items->date = strtotime($datetime);
-				$rss->addItem($items);		
+				$rss->addItem($items);
 			}
 			$feeds = $rss->createFeed($format_output);
 			return $feeds;
 		}
-		
+
 		// part of SMS board
 		function outputtohtml($code,$line="10",$pref_bodybgcolor="#E0D0C0",$pref_oddbgcolor="#EEDDCC",$pref_evenbgcolor="#FFEEDD")
 		{
@@ -632,7 +646,7 @@
 				return $content;
 			}
 		}
-		
+
 		// part of SMS command
 		function execcommand($sms_datetime,$sms_sender,$command_code,$command_param)
 		{
@@ -640,13 +654,13 @@
 			$ok = false;
 			$sql = "SELECT command_exec,command_type FROM phpgw_sms_featcommand WHERE command_code='$command_code'";
 			$this->db->query($sql,__LINE__,__FILE__);
-			$this->db->next_record();	
+			$this->db->next_record();
 			$command_exec = $this->db->f('command_exec');
 			$command_type = $this->db->f('command_type');
 
 			if($command_type == 'php')
 			{
-				include(PHPGW_SERVER_ROOT . SEP . 'sms' . SEP . 'bin'  . SEP .  basename($command_exec));
+				include(PHPGW_SERVER_ROOT . "/sms/bin/{$GLOBALS['phpgw_info']['user']['domain']}/" .  basename($command_exec));
 			}
 			else
 			{
@@ -658,7 +672,7 @@
 			}
 			$sql = "
 			INSERT INTO phpgw_sms_featcommand_log
-			(sms_sender,command_log_datetime,command_log_code,command_log_exec,command_log_param,command_log_success) 
+			(sms_sender,command_log_datetime,command_log_code,command_log_exec,command_log_param,command_log_success)
 			VALUES
 			('$sms_sender','$datetime_now','$command_code','$command_exec','$command_param','" . (int)!!$command_output . "')
 			";
@@ -673,7 +687,7 @@
 			}
 			return $ok;
 		}
-		
+
 		// part of SMS custom
 		function processcustom($sms_datetime,$sms_sender,$custom_code,$custom_param)
 		{
@@ -681,25 +695,25 @@
 			$ok = false;
 			$sql = "SELECT custom_url FROM phpgw_sms_featcustom WHERE custom_code='$custom_code'";
 			$this->db->query($sql,__LINE__,__FILE__);
-			$this->db->next_record();	
+			$this->db->next_record();
 			$custom_url = $this->db->f('custom_url');
 			$custom_url = str_replace("##SMSDATETIME##",urlencode($sms_datetime),$custom_url);
 			$custom_url = str_replace("##SMSSENDER##",urlencode($sms_sender),$custom_url);
 			$custom_url = str_replace("##CUSTOMCODE##",urlencode($custom_code),$custom_url);
 			$custom_url = str_replace("##CUSTOMPARAM##",urlencode($custom_param),$custom_url);
 			$url = parse_url($custom_url);
-			if (!$url['port']) 
+			if (!$url['port'])
 			{
 				$url['port'] = 80;
 			}
 			$connection = fsockopen($url['host'],$url['port'],&$error_number,&$error_description,60);
-			if($connection) 
+			if($connection)
 			{
 				socket_set_blocking($connection, false);
 				fputs($connection, "GET $custom_url HTTP/1.0\r\n\r\n");
 				$sql = "
 				INSERT INTO phpgw_sms_featcustom_log
-				(sms_sender,custom_log_datetime,custom_log_code,custom_log_url) 
+				(sms_sender,custom_log_datetime,custom_log_code,custom_log_url)
 				VALUES
 				('$sms_sender','$datetime_now','$custom_code','$custom_url')
 				";
@@ -714,7 +728,7 @@
 			}
 			return $ok;
 		}
-		
+
 		// part of SMS autoreply
 		function processautoreply($sms_datetime,$sms_sender,$autoreply_code,$autoreply_param)
 		{
@@ -733,17 +747,17 @@
 				$autoreply_scenario_param_list .= "autoreply_scenario_param$i='".$autoreply_part[$i]."' AND ";
 			}
 			$sql = "
-			SELECT autoreply_scenario_result FROM phpgw_sms_featautoreply_scenario 
+			SELECT autoreply_scenario_result FROM phpgw_sms_featautoreply_scenario
 			WHERE $autoreply_scenario_param_list 1=1
 			";
 			$this->db->query($sql,__LINE__,__FILE__);
-			$this->db->next_record();	
-			
+			$this->db->next_record();
+
 			if ($autoreply_scenario_result = $this->db->f('autoreply_scenario_result'))
 			{
 				$sql = "
 				INSERT INTO phpgw_sms_featautoreply_log
-				(sms_sender,autoreply_log_datetime,autoreply_log_code,autoreply_log_request) 
+				(sms_sender,autoreply_log_datetime,autoreply_log_code,autoreply_log_request)
 				VALUES
 				('$sms_sender','$datetime_now','$autoreply_code','$autoreply_request')
 				";
@@ -761,7 +775,7 @@
 				$ok = false;
 				$sql = "SELECT uid FROM phpgw_sms_featautoreply WHERE autoreply_code='$autoreply_code'";
 				$this->db->query($sql,__LINE__,__FILE__);
-				$this->db->next_record();	
+				$this->db->next_record();
 
 				$c_uid = $this->db->f('uid');
 				$c_username = $GLOBALS['phpgw']->accounts->id2name($c_uid);
@@ -773,7 +787,7 @@
 			}
 			return $ok;
 		}
-		
+
 		// part of SMS poll
 		function savepoll($sms_sender,$target_poll,$target_choice)
 		{
@@ -784,28 +798,28 @@
 			{
 				$sql = "SELECT poll_id,poll_enable FROM phpgw_sms_featpoll WHERE poll_code='$target_poll'";
 				$this->db->query($sql,__LINE__,__FILE__);
-				$this->db->next_record();	
+				$this->db->next_record();
 
 				$poll_id = $this->db->f('poll_id');
 				$poll_enable = $this->db->f('poll_enable');
 				$sql = "SELECT choice_id FROM phpgw_sms_featpoll_choice WHERE choice_code='$target_choice' AND poll_id='$poll_id'";
 				$this->db->query($sql,__LINE__,__FILE__);
-				$this->db->next_record();	
+				$this->db->next_record();
 				$choice_id = $this->db->f('choice_id');
 				if ($poll_id && $choice_id)
 				{
 					$sql = "SELECT result_id FROM phpgw_sms_featpoll_result WHERE poll_sender='$sms_sender' AND poll_id='$poll_id'";
 					$this->db->query($sql,__LINE__,__FILE__);
-					
+
 					if($this->db->num_rows()>0)
 					{
-						$already_vote = True;
+						$already_vote = true;
 					}
 					if ((!$already_vote) && $poll_enable)
 					{
 						$sql = "
-							INSERT INTO phpgw_sms_featpoll_result 
-							(poll_id,choice_id,poll_sender) 
+							INSERT INTO phpgw_sms_featpoll_result
+							(poll_id,choice_id,poll_sender)
 							VALUES ('$poll_id','$choice_id','$sms_sender')
 							";
 						$this->db->query($sql,__LINE__,__FILE__);
@@ -813,13 +827,15 @@
 					$ok = true;
 				}
 			}
-			return $ok;	
+			return $ok;
 		}
-		
+
 		// check incoming SMS for available codes
 		// and sets the action
 		function setsmsincomingaction($sms_datetime,$sms_sender,$target_code,$message)
 		{
+			$message = utf8_encode($message);
+			$target_code = utf8_encode($target_code);
 			$ok = false;
 			switch ($target_code)
 			{
@@ -912,4 +928,4 @@
 			return $ok;
 		}
 	}
-?>
+
