@@ -8,7 +8,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package sms
 	* @subpackage autoreply
- 	* @version $Id: class.uiautoreply.inc.php 18358 2007-11-27 04:43:37Z skwashd $
+ 	* @version $Id: class.uiautoreply.inc.php 6257 2010-08-22 14:40:02Z sigurd $
 	*/
 
 	/**
@@ -19,37 +19,36 @@
 	class sms_uiautoreply
 	{
 		var $public_functions = array(
-			'index'			=> True,
-			'add'			=> True,
-			'add_yes'		=> True,
-			'add_scenario'		=> True,
-			'add_scenario_yes'	=> True,
-			'edit_scenario'		=> True,
-			'edit_scenario_yes'	=> True,
-			'manage'		=> True,
-			'delete'		=> True,
+			'index'			=> true,
+			'add'			=> true,
+			'add_yes'		=> true,
+			'add_scenario'		=> true,
+			'add_scenario_yes'	=> true,
+			'edit_scenario'		=> true,
+			'edit_scenario_yes'	=> true,
+			'manage'		=> true,
+			'delete'		=> true,
 			'delete_scenario'	=> true
 			);
 
-		function sms_uiautoreply()
+		function __construct()
 		{
-		//	$this->currentapp			= $GLOBALS['phpgw_info']['flags']['currentapp'];
 			$this->nextmatchs			= CreateObject('phpgwapi.nextmatchs');
 			$this->account				= $GLOBALS['phpgw_info']['user']['account_id'];
-			$this->bo				= CreateObject('sms.boautoreply',true);
+			$this->bo					= CreateObject('sms.boautoreply',true);
 			$this->bocommon				= CreateObject('sms.bocommon');
-			$this->menu				= CreateObject('sms.menu');
-			$this->sms				= CreateObject('sms.sms');
-			$this->acl				= CreateObject('phpgwapi.acl');
-			$this->acl_location 			= '.autoreply';
+			$this->sms					= CreateObject('sms.sms');
+			$this->acl 					= & $GLOBALS['phpgw']->acl;
+			$this->acl_location 		= '.autoreply';
 			$this->menu->sub			= '.autoreply';
 			$this->start				= $this->bo->start;
 			$this->query				= $this->bo->query;
-			$this->sort				= $this->bo->sort;
+			$this->sort					= $this->bo->sort;
 			$this->order				= $this->bo->order;
 			$this->allrows				= $this->bo->allrows;
-			
+
 			$this->db 		= clone($GLOBALS['phpgw']->db);
+			$GLOBALS['phpgw_info']['flags']['menu_selection'] .= 'sms::autoreply';
 		}
 
 		function save_sessiondata()
@@ -64,19 +63,17 @@
 			$this->bo->save_sessiondata($data);
 		}
 
-
 		function index()
 		{
-			$GLOBALS['phpgw_info']['flags']['xslt_app'] = True;
-			$links = $this->menu->links();
-			if(!$this->acl->check($this->acl_location, PHPGW_ACL_READ))
+			$GLOBALS['phpgw_info']['flags']['xslt_app'] = true;
+			if(!$this->acl->check($this->acl_location, PHPGW_ACL_READ, 'sms'))
 			{
 
-				$this->bocommon->no_access($links);
+				$this->bocommon->no_access();
 				return;
 			}
-			
-			$GLOBALS['phpgw']->xslttpl->add_file(array('autoreply','nextmatchs','menu',
+
+			$GLOBALS['phpgw']->xslttpl->add_file(array('autoreply','nextmatchs',
 										'search_field'));
 
 			$receipt = $GLOBALS['phpgw']->session->appsession('session_data','sms_reply_receipt');
@@ -85,9 +82,8 @@
 
 			$autoreply_info = $this->bo->read();
 
-			while (is_array($autoreply_info) && list(,$entry) = each($autoreply_info))
+			foreach ($autoreply_info as $entry)
 			{
-
 				if($this->bocommon->check_perms($entry['grants'], PHPGW_ACL_DELETE))
 				{
 					$link_delete		= $GLOBALS['phpgw']->link('/index.php', array('menuaction'=> 'sms.uiautoreply.delete', 'autoreply_id'=> $entry['id']));
@@ -109,7 +105,7 @@
 					'text_delete'				=> $text_delete,
 					'lang_delete_text'			=> $lang_delete_text,
 				);
-	
+
 				unset ($link_delete);
 				unset ($text_delete);
 				unset ($lang_delete_text);
@@ -155,7 +151,7 @@
 				'query'		=> $this->query
 			);
 
-//			if($this->acl->check($this->acl_location, PHPGW_ACL_ADD))
+//			if($this->acl->check($this->acl_location, PHPGW_ACL_ADD, 'sms'))
 			{
 				$table_add[] = array
 				(
@@ -165,30 +161,30 @@
 				);
 			}
 
-			$msgbox_data = $this->bocommon->msgbox_data($receipt);
+			$msgbox_data = $GLOBALS['phpgw']->common->msgbox_data($receipt);
 
 			$data = array
 			(
-				'msgbox_data'					=> $GLOBALS['phpgw']->common->msgbox($msgbox_data),
-				'links'						=> $links,
-				'allow_allrows'					=> True,
-				'allrows'					=> $this->allrows,
-				'start_record'					=> $this->start,
-				'record_limit'					=> $record_limit,
-				'num_records'					=> count($autoreply_info),
-				'all_records'					=> $this->bo->total_records,
-				'link_url'					=> $GLOBALS['phpgw']->link('/index.php',$link_data),
-				'img_path'					=> $GLOBALS['phpgw']->common->get_image_path('phpgwapi','default'),
-				'lang_searchfield_statustext'			=> lang('Enter the search string. To show all entries, empty this field and press the SUBMIT button again'),
-				'lang_searchbutton_statustext'			=> lang('Submit the search string'),
-				'query'						=> $this->query,
-				'lang_search'					=> lang('search'),
-				'table_header'					=> $table_header,
-				'table_add'					=> $table_add,
-				'values'					=> $content
+				'msgbox_data'						=> $GLOBALS['phpgw']->common->msgbox($msgbox_data),
+				'menu'								=> execMethod('sms.menu.links'),
+				'allow_allrows'						=> true,
+				'allrows'							=> $this->allrows,
+				'start_record'						=> $this->start,
+				'record_limit'						=> $record_limit,
+				'num_records'						=> count($autoreply_info),
+				'all_records'						=> $this->bo->total_records,
+				'link_url'							=> $GLOBALS['phpgw']->link('/index.php',$link_data),
+				'img_path'							=> $GLOBALS['phpgw']->common->get_image_path('phpgwapi','default'),
+				'lang_searchfield_statustext'		=> lang('Enter the search string. To show all entries, empty this field and press the SUBMIT button again'),
+				'lang_searchbutton_statustext'		=> lang('Submit the search string'),
+				'query'								=> $this->query,
+				'lang_search'						=> lang('search'),
+				'table_header'						=> $table_header,
+				'table_add'							=> $table_add,
+				'values'							=> $content
 			);
 
-			$appname					= lang('autoreplies');
+			$appname						= lang('autoreplies');
 			$function_msg					= lang('list SMS autoreplies');
 
 			$GLOBALS['phpgw_info']['flags']['app_header'] = lang('sms') . ' - ' . $appname . ': ' . $function_msg;
@@ -198,16 +194,14 @@
 
 		function add()
 		{
-		
-			if(!$this->acl->check($this->acl_location, PHPGW_ACL_ADD))
+			if(!$this->acl->check($this->acl_location, PHPGW_ACL_ADD, 'sms'))
 			{
-				$links = $this->menu->links();
-				$GLOBALS['phpgw_info']['flags']['xslt_app'] = True;
-				$this->bocommon->no_access($links);
+				$GLOBALS['phpgw_info']['flags']['xslt_app'] = true;
+				$this->bocommon->no_access();
 				return;
 			}
-			
-			
+
+
 			$GLOBALS['phpgw_info']['flags']['app_header'] = lang('SMS').' - '.lang('Add SMS autoreply');
 			$GLOBALS['phpgw']->common->phpgw_header();
 
@@ -225,7 +219,7 @@
 				'menuaction'	=> 'sms.uiautoreply.add_yes',
 				'autoreply_id'	=> $autoreply_id
 				);
-				
+
 			$add_url = $GLOBALS['phpgw']->link('/index.php',$add_data);
 
 
@@ -254,12 +248,11 @@
 
 		function add_yes()
 		{
-		
-			if(!$this->acl->check($this->acl_location, PHPGW_ACL_ADD))
+
+			if(!$this->acl->check($this->acl_location, PHPGW_ACL_ADD, 'sms'))
 			{
-				$links = $this->menu->links();
-				$GLOBALS['phpgw_info']['flags']['xslt_app'] = True;
-				$this->bocommon->no_access($links);
+				$GLOBALS['phpgw_info']['flags']['xslt_app'] = true;
+				$this->bocommon->no_access();
 				return;
 			}
 
@@ -272,36 +265,36 @@
 			{
 			    if ($this->sms->checkavailablecode($add_autoreply_code))
 			    {
-				$sql = "INSERT INTO phpgw_sms_featautoreply (uid,autoreply_code) VALUES ('$uid','$add_autoreply_code')";
-				$this->db->transaction_begin();
+					$sql = "INSERT INTO phpgw_sms_featautoreply (uid,autoreply_code) VALUES ('$uid','$add_autoreply_code')";
+					$this->db->transaction_begin();
 
-				$this->db->query($sql,__LINE__,__FILE__);
+					$this->db->query($sql,__LINE__,__FILE__);
 
-				$new_uid = $this->db->get_last_insert_id(phpgw_sms_featautoreply,'autoreply_id');
+					$new_uid = $this->db->get_last_insert_id(phpgw_sms_featautoreply,'autoreply_id');
 
-				$this->db->transaction_commit();
-					
-				if ($new_uid)
-				{
-					$receipt['message'][]=array('msg'=>lang('SMS autoreply code %1 has been added', $add_autoreply_code));
-					$GLOBALS['phpgw']->session->appsession('session_data','sms_reply_receipt',$receipt);
-					$target = 'index';
-				}
-				else
-				{
-					$error_string = lang('Fail to add SMS autoreply code') . ' ' . $add_autoreply_code;
-				}
+					$this->db->transaction_commit();
+
+					if ($new_uid)
+					{
+						$receipt['message'][]=array('msg'=>lang('SMS autoreply code %1 has been added', $add_autoreply_code));
+						$GLOBALS['phpgw']->session->appsession('session_data','sms_reply_receipt',$receipt);
+						$target = 'index';
+					}
+					else
+					{
+						$error_string = lang('Fail to add SMS autoreply code') . ' ' . $add_autoreply_code;
+					}
 			    }
 			    else
 			    {
-				$error_string = lang('SMS code %1 already exists, reserved or use by other feature!',$add_autoreply_code);
+					$error_string = lang('SMS code %1 already exists, reserved or use by other feature!',$add_autoreply_code);
 			    }
 			}
 			else
 			{
 				$error_string = lang('You must fill all fields!');
 			}
-			
+
 			$add_data = array(
 				'menuaction'	=> 'sms.uiautoreply.' . $target,
 				'err'		=> urlencode($error_string)
@@ -313,16 +306,15 @@
 
 		function add_scenario()
 		{
-		
-			if(!$this->acl->check($this->acl_location, PHPGW_ACL_ADD))
+
+			if(!$this->acl->check($this->acl_location, PHPGW_ACL_ADD, 'sms'))
 			{
-				$links = $this->menu->links();
-				$GLOBALS['phpgw_info']['flags']['xslt_app'] = True;
-				$this->bocommon->no_access($links);
+				$GLOBALS['phpgw_info']['flags']['xslt_app'] = true;
+				$this->bocommon->no_access();
 				return;
 			}
-			
-			
+
+
 			$GLOBALS['phpgw_info']['flags']['app_header'] = lang('SMS').' - '.lang('Add SMS autoreply scenario');
 			$GLOBALS['phpgw']->common->phpgw_header();
 
@@ -350,7 +342,7 @@
 				'menuaction'	=> 'sms.uiautoreply.add_scenario_yes',
 				'autoreply_id'	=> $autoreply_id
 				);
-				
+
 			$add_url = $GLOBALS['phpgw']->link('/index.php',$add_data);
 
 
@@ -363,7 +355,7 @@
 			for ($i=1;$i<=7;$i++)
 			{
 			    ${"add_autoreply_scenario_param".$i} = strtoupper(get_var("add_autoreply_scenario_param$i",array('POST','GET')));
-			    $content .= "<p>SMS autoreply scenario param $i: <input type=text size=20 maxlength=20 name=add_autoreply_scenario_param$i value=\"".${"add_autoreply_scenario_param".$i}."\">\n";			    
+			    $content .= "<p>SMS autoreply scenario param $i: <input type=text size=20 maxlength=20 name=add_autoreply_scenario_param$i value=\"".${"add_autoreply_scenario_param".$i}."\">\n";
 			}
 
 			$content .= "
@@ -375,7 +367,7 @@
 			$done_data = array(
 				'menuaction'	=> 'sms.uiautoreply.manage',
 				'autoreply_id'	=> $autoreply_id);
-				
+
 			$done_url = $GLOBALS['phpgw']->link('/index.php',$done_data);
 
 			$content .= "
@@ -388,12 +380,11 @@
 
 		function add_scenario_yes()
 		{
-		
-			if(!$this->acl->check($this->acl_location, PHPGW_ACL_ADD))
+
+			if(!$this->acl->check($this->acl_location, PHPGW_ACL_ADD, 'sms'))
 			{
-				$links = $this->menu->links();
-				$GLOBALS['phpgw_info']['flags']['xslt_app'] = True;
-				$this->bocommon->no_access($links);
+				$GLOBALS['phpgw_info']['flags']['xslt_app'] = true;
+				$this->bocommon->no_access();
 				return;
 			}
 
@@ -401,7 +392,7 @@
 			$add_autoreply_scenario_result	= phpgw::get_var('add_autoreply_scenario_result');
 
 			$ok = 0;
-			
+
 			for ($i=1;$i<=7;$i++)
 			{
 			    ${"add_autoreply_scenario_param".$i} = strtoupper(get_var("add_autoreply_scenario_param$i",array('POST','GET')));
@@ -422,14 +413,14 @@
 				$autoreply_scenario_code_param_entry .= "'".${"add_autoreply_scenario_param".$i}."',";
 			    }
 			    $sql = "
-				INSERT INTO phpgw_sms_featautoreply_scenario 
+				INSERT INTO phpgw_sms_featautoreply_scenario
 				(autoreply_id,".$autoreply_scenario_param_list."autoreply_scenario_result) VALUES ('$autoreply_id',$autoreply_scenario_code_param_entry'$add_autoreply_scenario_result')";
-			    
+
 				$this->db->transaction_begin();
 				$this->db->query($sql,__LINE__,__FILE__);
 				$new_uid = $this->db->get_last_insert_id(phpgw_sms_featautoreply_scenario,'autoreply_scenario_id');
 				$this->db->transaction_commit();
-					
+
 				if ($new_uid)
 			    {
 					$error_string = "SMS autoreply scenario has been added";
@@ -444,7 +435,7 @@
 			    $error_string = "You must fill at least one field and the scenario result!";
 			}
 			$target = 'add_scenario';
-			
+
 			$add_data = array(
 				'menuaction'			=> 'sms.uiautoreply.' . $target,
 				'autoreply_id' 			=> $autoreply_id,
@@ -463,16 +454,15 @@
 
 		function edit_scenario()
 		{
-		
-			if(!$this->acl->check($this->acl_location, PHPGW_ACL_EDIT))
+
+			if(!$this->acl->check($this->acl_location, PHPGW_ACL_EDIT, 'sms'))
 			{
-				$links = $this->menu->links();
-				$GLOBALS['phpgw_info']['flags']['xslt_app'] = True;
-				$this->bocommon->no_access($links);
+				$GLOBALS['phpgw_info']['flags']['xslt_app'] = true;
+				$this->bocommon->no_access();
 				return;
 			}
-			
-			
+
+
 			$GLOBALS['phpgw_info']['flags']['app_header'] = lang('SMS').' - '.lang('Edit SMS autoreply scenario');
 			$GLOBALS['phpgw']->common->phpgw_header();
 
@@ -501,7 +491,7 @@
 				'autoreply_id'		=> $autoreply_id,
 				'autoreply_scenario_id'	=> $autoreply_scenario_id
 				);
-				
+
 			$edit_url = $GLOBALS['phpgw']->link('/index.php',$edit_data);
 
 
@@ -531,7 +521,7 @@
 			$done_data = array(
 				'menuaction'	=> 'sms.uiautoreply.manage',
 				'autoreply_id'	=> $autoreply_id);
-				
+
 			$done_url = $GLOBALS['phpgw']->link('/index.php',$done_data);
 
 			$content .= "
@@ -546,19 +536,18 @@
 
 		function edit_scenario_yes()
 		{
-		
-			if(!$this->acl->check($this->acl_location, PHPGW_ACL_EDIT))
+
+			if(!$this->acl->check($this->acl_location, PHPGW_ACL_EDIT, 'sms'))
 			{
-				$links = $this->menu->links();
-				$GLOBALS['phpgw_info']['flags']['xslt_app'] = True;
-				$this->bocommon->no_access($links);
+				$GLOBALS['phpgw_info']['flags']['xslt_app'] = true;
+				$this->bocommon->no_access();
 				return;
 			}
 
 			$autoreply_scenario_id	= phpgw::get_var('autoreply_scenario_id');
 			$autoreply_id	= phpgw::get_var('autoreply_id');
 			$edit_autoreply_scenario_result	= get_var('edit_autoreply_scenario_result',array('POST','GET'));
-			
+
 			for ($i=1;$i<=7;$i++)
 			{
 			    ${"edit_autoreply_scenario_param".$i} = strtoupper(get_var("edit_autoreply_scenario_param$i",array('POST','GET')));
@@ -575,8 +564,8 @@
 					$autoreply_scenario_param_list .= "autoreply_scenario_param$i='".${"edit_autoreply_scenario_param".$i}."',";
 			    }
 			    $sql = "
-				UPDATE phpgw_sms_featautoreply_scenario 
-				SET ".$autoreply_scenario_param_list."autoreply_scenario_result='$edit_autoreply_scenario_result' 
+				UPDATE phpgw_sms_featautoreply_scenario
+				SET ".$autoreply_scenario_param_list."autoreply_scenario_result='$edit_autoreply_scenario_result'
 				WHERE autoreply_id='$autoreply_id' AND autoreply_scenario_id='$autoreply_scenario_id'
 			    ";
 
@@ -600,7 +589,7 @@
 			}
 
 			$target = 'edit_scenario';
-			
+
 			$add_data = array(
 				'menuaction'				=> 'sms.uiautoreply.' . $target,
 				'autoreply_id' 				=> $autoreply_id,
@@ -620,15 +609,14 @@
 
 
 		function manage()
-		{		
-			if(!$this->acl->check($this->acl_location, 16))
+		{
+			if(!$this->acl->check($this->acl_location, 16, 'sms'))
 			{
-				$links = $this->menu->links();
-				$GLOBALS['phpgw_info']['flags']['xslt_app'] = True;
-				$this->bocommon->no_access($links);
+				$GLOBALS['phpgw_info']['flags']['xslt_app'] = true;
+				$this->bocommon->no_access();
 				return;
 			}
-					
+
 			$GLOBALS['phpgw_info']['flags']['app_header'] = lang('SMS').' - '.lang('Manage SMS autoreply');
 			$GLOBALS['phpgw']->common->phpgw_header();
 
@@ -637,14 +625,14 @@
 
 			$autoreply_id	= phpgw::get_var('autoreply_id');
 			$err	= urldecode(phpgw::get_var('err'));
-	
+
 /*			if (!$this->acl->check('run', PHPGW_ACL_READ,'admin'))
 			{
 			    $query_user_only = "AND uid='$uid'";
 			}
 */
 			$sql = "SELECT * FROM phpgw_sms_featautoreply WHERE autoreply_id='$autoreply_id' $query_user_only";
-	
+
 			$this->db->query($sql,__LINE__,__FILE__);
 			$this->db->next_record();
 
@@ -659,7 +647,7 @@
 				'menuaction'	=> 'sms.uiautoreply.add_scenario',
 				'autoreply_id'	=> $autoreply_id
 				);
-				
+
 			$add_url = $GLOBALS['phpgw']->link('/index.php',$add_data);
 
 			$content .= "
@@ -681,7 +669,7 @@
 			    $owner = $GLOBALS['phpgw']->accounts->id2name($o_uid);
 			    $list_of_param = "";
 			    for ($i=1;$i<=7;$i++)
-			    { 
+			    {
 					$list_of_param .= $this->db->f("autoreply_scenario_param$i")."&nbsp;";
 			    }
 
@@ -697,7 +685,7 @@
 
 			$done_data = array(
 				'menuaction'	=> 'sms.uiautoreply.index');
-				
+
 			$done_url = $GLOBALS['phpgw']->link('/index.php',$done_data);
 
 			$content .= "
@@ -706,16 +694,15 @@
 			    <p>
 			";
 			echo $content;
-		
+
 		}
 
 		function delete()
 		{
-			$GLOBALS['phpgw_info']['flags']['xslt_app'] = True;
-			if(!$this->acl->check($this->acl_location, PHPGW_ACL_DELETE))
+			$GLOBALS['phpgw_info']['flags']['xslt_app'] = true;
+			if(!$this->acl->check($this->acl_location, PHPGW_ACL_DELETE, 'sms'))
 			{
-				$links = $this->menu->links();
-				$this->bocommon->no_access($links);
+				$this->bocommon->no_access();
 				return;
 			}
 
@@ -730,7 +717,6 @@
 
 			if (phpgw::get_var('confirm', 'bool', 'POST'))
 			{
-			//	$this->bo->delete_type($autoreply_id);
 
 				$sql = "SELECT autoreply_code FROM phpgw_sms_featautoreply WHERE autoreply_id='$autoreply_id'";
 				$this->db->query($sql,__LINE__,__FILE__);
@@ -755,14 +741,14 @@
 	    				}
 	    				$this->db->transaction_commit();
 				}
-					
+
 				$link_data['err'] = urlencode($error_string);
 				$GLOBALS['phpgw']->session->appsession('session_data','sms_reply_receipt',$receipt);
 				$GLOBALS['phpgw']->redirect_link('/index.php',$link_data);
 			}
 
 
-			
+
 			$GLOBALS['phpgw']->xslttpl->add_file(array('app_delete'));
 
 			$data = array
@@ -785,11 +771,10 @@
 
 		function delete_scenario()
 		{
-			$GLOBALS['phpgw_info']['flags']['xslt_app'] = True;
-			if(!$this->acl->check($this->acl_location, PHPGW_ACL_DELETE))
+			$GLOBALS['phpgw_info']['flags']['xslt_app'] = true;
+			if(!$this->acl->check($this->acl_location, PHPGW_ACL_DELETE, 'sms'))
 			{
-				$links = $this->menu->links();
-				$this->bocommon->no_access($links);
+				$this->bocommon->no_access();
 				return;
 			}
 
@@ -852,6 +837,4 @@
 			$GLOBALS['phpgw_info']['flags']['app_header'] = lang('sms') . ' - ' . $appname . ': ' . $function_msg;
 			$GLOBALS['phpgw']->xslttpl->set_var('phpgw',array('delete' => $data));
 		}
-
 	}
-?>
