@@ -8,7 +8,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package sms
 	* @subpackage command
- 	* @version $Id: class.uicommand.inc.php 18358 2007-11-27 04:43:37Z skwashd $
+ 	* @version $Id: class.uicommand.inc.php 6257 2010-08-22 14:40:02Z sigurd $
 	*/
 
 	/**
@@ -19,36 +19,32 @@
 	class sms_uicommand
 	{
 		var $public_functions = array(
-			'index'			=> True,
-			'log'			=> True,
-			'edit'			=> True,
-			'edit_command'		=> True,
-			'delete'		=> True,
+			'index'			=> true,
+			'log'			=> true,
+			'redirect'		=> true,
+			'edit'			=> true,
+			'edit_command'	=> true,
+			'delete'		=> true,
 			);
 
-
-		function sms_uicommand()
+		function __construct()
 		{
-
-		//	$this->currentapp			= $GLOBALS['phpgw_info']['flags']['currentapp'];
-			$this->nextmatchs			= CreateObject('phpgwapi.nextmatchs');
-			$this->account				= $GLOBALS['phpgw_info']['user']['account_id'];
+			$this->nextmatchs		= CreateObject('phpgwapi.nextmatchs');
+			$this->account			= $GLOBALS['phpgw_info']['user']['account_id'];
 			$this->bo				= CreateObject('sms.bocommand');
-			$this->bocommon				= CreateObject('sms.bocommon');
-			$this->menu				= CreateObject('sms.menu');
+			$this->bocommon			= CreateObject('sms.bocommon');
 			$this->sms				= CreateObject('sms.sms');
-			$this->acl				= CreateObject('phpgwapi.acl');
-			$this->acl_location 			= '.command';
-			$this->menu->sub			=$this->acl_location;
-			$this->cat_id				= $this->bo->cat_id;
-			$this->start				= $this->bo->start;
-			$this->query				= $this->bo->query;
+			$this->acl 				= & $GLOBALS['phpgw']->acl;
+			$this->acl_location 	= '.command';
+			$this->cat_id			= $this->bo->cat_id;
+			$this->start			= $this->bo->start;
+			$this->query			= $this->bo->query;
 			$this->sort				= $this->bo->sort;
-			$this->order				= $this->bo->order;
-			$this->allrows				= $this->bo->allrows;
-			
+			$this->order			= $this->bo->order;
+			$this->allrows			= $this->bo->allrows;
+
 			$this->db 				= clone($GLOBALS['phpgw']->db);
-			$this->db2 				= clone($GLOBALS['phpgw']->db);
+			$GLOBALS['phpgw_info']['flags']['menu_selection'] = 'sms::command';
 		}
 
 		function save_sessiondata()
@@ -66,16 +62,15 @@
 
 		function index()
 		{
-			$links = $this->menu->links($this->acl_location . '.list');
-			$GLOBALS['phpgw_info']['flags']['xslt_app'] = True;
+			$GLOBALS['phpgw_info']['flags']['xslt_app'] = true;
 
-			if(!$this->acl->check($this->acl_location, PHPGW_ACL_READ))
+			if(!$this->acl->check($this->acl_location, PHPGW_ACL_READ, 'sms'))
 			{
-				$this->bocommon->no_access($links);
+				$this->bocommon->no_access();
 				return;
 			}
 
-			$GLOBALS['phpgw']->xslttpl->add_file(array('command','nextmatchs','menu',
+			$GLOBALS['phpgw']->xslttpl->add_file(array('command','nextmatchs',
 										'search_field'));
 
 			$receipt = $GLOBALS['phpgw']->session->appsession('session_data','sms_command_receipt');
@@ -84,9 +79,8 @@
 
 			$command_info = $this->bo->read();
 
-			while (is_array($command_info) && list(,$entry) = each($command_info))
+			foreach ($command_info as $entry)
 			{
-
 				if($this->bocommon->check_perms($entry['grants'], PHPGW_ACL_DELETE))
 				{
 					$link_delete		= $GLOBALS['phpgw']->link('/index.php', array('menuaction'=> 'sms.uicommand.delete', 'command_id'=> $entry['id']));
@@ -109,7 +103,7 @@
 					'text_delete'				=> $text_delete,
 					'lang_delete_text'			=> $lang_delete_text,
 				);
-	
+
 				unset ($link_delete);
 				unset ($text_delete);
 				unset ($lang_delete_text);
@@ -156,7 +150,7 @@
 				'query'		=> $this->query
 			);
 
-//			if($this->acl->check($this->acl_location, PHPGW_ACL_ADD))
+//			if($this->acl->check($this->acl_location, PHPGW_ACL_ADD, 'sms'))
 			{
 				$table_add[] = array
 				(
@@ -166,27 +160,27 @@
 				);
 			}
 
-			$msgbox_data = $this->bocommon->msgbox_data($receipt);
+			$msgbox_data = $GLOBALS['phpgw']->common->msgbox_data($receipt);
 
 			$data = array
 			(
-				'msgbox_data'					=> $GLOBALS['phpgw']->common->msgbox($msgbox_data),
-				'links'						=> $links,
-				'allow_allrows'					=> True,
-				'allrows'					=> $this->allrows,
-				'start_record'					=> $this->start,
-				'record_limit'					=> $record_limit,
-				'num_records'					=> count($command_info),
-				'all_records'					=> $this->bo->total_records,
-				'link_url'					=> $GLOBALS['phpgw']->link('/index.php',$link_data),
-				'img_path'					=> $GLOBALS['phpgw']->common->get_image_path('phpgwapi','default'),
-				'lang_searchfield_statustext'			=> lang('Enter the search string. To show all entries, empty this field and press the SUBMIT button again'),
-				'lang_searchbutton_statustext'			=> lang('Submit the search string'),
-				'query'						=> $this->query,
-				'lang_search'					=> lang('search'),
-				'table_header'					=> $table_header,
-				'table_add'					=> $table_add,
-				'values'					=> $content
+				'msgbox_data'						=> $GLOBALS['phpgw']->common->msgbox($msgbox_data),
+				'menu'								=> execMethod('sms.menu.links'),
+				'allow_allrows'						=> true,
+				'allrows'							=> $this->allrows,
+				'start_record'						=> $this->start,
+				'record_limit'						=> $record_limit,
+				'num_records'						=> count($command_info),
+				'all_records'						=> $this->bo->total_records,
+				'link_url'							=> $GLOBALS['phpgw']->link('/index.php',$link_data),
+				'img_path'							=> $GLOBALS['phpgw']->common->get_image_path('phpgwapi','default'),
+				'lang_searchfield_statustext'		=> lang('Enter the search string. To show all entries, empty this field and press the SUBMIT button again'),
+				'lang_searchbutton_statustext'		=> lang('Submit the search string'),
+				'query'								=> $this->query,
+				'lang_search'						=> lang('search'),
+				'table_header'						=> $table_header,
+				'table_add'							=> $table_add,
+				'values'							=> $content
 			);
 
 			$appname	= lang('commands');
@@ -199,23 +193,22 @@
 
 		function edit_command()
 		{
-			$GLOBALS['phpgw_info']['flags']['xslt_app'] = True;
+			$GLOBALS['phpgw_info']['flags']['xslt_app'] = true;
 
-			$links = $this->menu->links();
 			$command_id	= phpgw::get_var('command_id', 'int');
 			if($command_id)
 			{
-				if(!$this->acl->check($this->acl_location, PHPGW_ACL_EDIT))
+				if(!$this->acl->check($this->acl_location, PHPGW_ACL_EDIT, 'sms'))
 				{
-					$this->bocommon->no_access($links);
+					$this->bocommon->no_access();
 					return;
 				}
 			}
 			else
 			{
-				if(!$this->acl->check($this->acl_location, PHPGW_ACL_ADD))
+				if(!$this->acl->check($this->acl_location, PHPGW_ACL_ADD, 'sms'))
 				{
-					$this->bocommon->no_access($links);
+					$this->bocommon->no_access();
 					return;
 				}
 			}
@@ -242,7 +235,7 @@
 					{
 						$receipt['error'][]=array('msg'=>lang('Please select a command type !'));
 					}
-					
+
 					if(!$values['exec'])
 					{
 						$receipt['error'][]=array('msg'=>lang('Please enter a command exec !'));
@@ -261,7 +254,7 @@
 							unset($values['code']);
 						}
 					}
-					
+
 					if(!$receipt['error'])
 					{
 						$receipt = $this->bo->save_command($values,$action);
@@ -302,42 +295,38 @@
 				'command_id'	=> $command_id
 			);
 
-			$msgbox_data = $this->bocommon->msgbox_data($receipt);
+			$msgbox_data = $GLOBALS['phpgw']->common->msgbox_data($receipt);
 
 			$data = array
 			(
 
-				'value_code'			=> $values['code'],
-				'value_descr'			=> $values['descr'],
-				'lang_code'			=> lang('SMS command code'),
-				'lang_descr'			=> lang('descr'),
-				'lang_help1'			=> lang('Pass these parameter to command URL field:'),
-				'lang_help2'			=> lang('##SMSDATETIME## replaced by SMS incoming date/time'),
-				'lang_help3'			=> lang('##SMSSENDER## replaced by sender number'),
-				'lang_help4'			=> lang('##COMMANDCODE## replaced by command code'),
-				'lang_help5'			=> lang('##COMMANDPARAM## replaced by command parameter passed to server from SMS'),
-				'lang_binary_path'		=> lang('SMS command binary path'),
-				'value_binary_path'		=> PHPGW_SERVER_ROOT . SEP . 'sms' . SEP . 'bin',
-
-				'lang_type'			=> lang('command type'),				
-				'type_list'			=> $this->bo->select_type_list($values['type']),
-				'lang_no_type'			=> lang('no exec type'),
+				'value_code'					=> $values['code'],
+				'value_descr'					=> $values['descr'],
+				'lang_code'						=> lang('SMS command code'),
+				'lang_descr'					=> lang('descr'),
+				'lang_help1'					=> lang('Pass these parameter to command URL field:'),
+				'lang_help2'					=> lang('##SMSDATETIME## replaced by SMS incoming date/time'),
+				'lang_help3'					=> lang('##SMSSENDER## replaced by sender number'),
+				'lang_help4'					=> lang('##COMMANDCODE## replaced by command code'),
+				'lang_help5'					=> lang('##COMMANDPARAM## replaced by command parameter passed to server from SMS'),
+				'lang_binary_path'				=> lang('SMS command binary path'),
+				'value_binary_path'				=> PHPGW_SERVER_ROOT . "/sms/bin/{$GLOBALS['phpgw_info']['user']['domain']}",
+				'lang_type'						=> lang('command type'),
+				'type_list'						=> $this->bo->select_type_list($values['type']),
+				'lang_no_type'					=> lang('no exec type'),
 				'lang_lang_type_status_text'	=> lang('input type'),
-
-
-				'value_exec'			=> $values['exec'],
-				'lang_exec'			=> lang('SMS command exec'),
-
-				'msgbox_data'			=> $GLOBALS['phpgw']->common->msgbox($msgbox_data),
-				'form_action'			=> $GLOBALS['phpgw']->link('/index.php',$link_data),
-				'lang_id'			=> lang('ID'),
-				'lang_save'			=> lang('save'),
-				'lang_cancel'			=> lang('cancel'),
-				'value_id'			=> $command_id,
-				'lang_done_status_text'		=> lang('Back to the list'),
-				'lang_save_status_text'		=> lang('Save the values'),
-				'lang_apply'			=> lang('apply'),
-				'lang_apply_status_text'	=> lang('Apply the values'),
+				'value_exec'					=> $values['exec'],
+				'lang_exec'						=> lang('SMS command exec'),
+				'msgbox_data'					=> $GLOBALS['phpgw']->common->msgbox($msgbox_data),
+				'form_action'					=> $GLOBALS['phpgw']->link('/index.php',$link_data),
+				'lang_id'						=> lang('ID'),
+				'lang_save'						=> lang('save'),
+				'lang_cancel'					=> lang('cancel'),
+				'value_id'						=> $command_id,
+				'lang_done_status_text'			=> lang('Back to the list'),
+				'lang_save_status_text'			=> lang('Save the values'),
+				'lang_apply'					=> lang('apply'),
+				'lang_apply_status_text'		=> lang('Apply the values'),
 			);
 
 			$appname	= lang('command');
@@ -346,25 +335,43 @@
 			$GLOBALS['phpgw']->xslttpl->set_var('phpgw',array('edit_command' => $data));
 		}
 
+		function redirect()
+		{
+			$code		= phpgw::get_var('code');
+			$param		= urldecode(phpgw::get_var('param'));
+
+			if(is_file(PHPGW_SERVER_ROOT . "/sms/bin/{$GLOBALS['phpgw_info']['user']['domain']}/config_" . strtoupper(basename($code)) . '_log'))
+			{
+				include(PHPGW_SERVER_ROOT . "/sms/bin/{$GLOBALS['phpgw_info']['user']['domain']}/config_" . strtoupper(basename($code)) . '_log');
+
+				$GLOBALS['phpgw']->redirect_link('/index.php',$link_data);
+			}
+			else
+			{
+				$GLOBALS['phpgw_info']['flags']['xslt_app'] = true;
+				$GLOBALS['phpgw_info']['flags']['menu_selection'] .= '::log';
+				$this->bocommon->no_access(lang('target not configured'));
+			}
+
+		}
 		function log()
 		{
-			$links = $this->menu->links($this->acl_location . '.log');
-			$GLOBALS['phpgw_info']['flags']['xslt_app'] = True;
+			$GLOBALS['phpgw_info']['flags']['menu_selection'] .= '::log';
+			$GLOBALS['phpgw_info']['flags']['xslt_app'] = true;
 
-			if(!$this->acl->check($this->acl_location, PHPGW_ACL_READ))
+			if(!$this->acl->check($this->acl_location, PHPGW_ACL_READ, 'sms'))
 			{
-				$this->bocommon->no_access($links);
+				$this->bocommon->no_access();
 				return;
 			}
 
-			$GLOBALS['phpgw']->xslttpl->add_file(array('command','nextmatchs','menu',
+			$GLOBALS['phpgw']->xslttpl->add_file(array('command','nextmatchs',
 										'search_field'));
 
 			$command_info = $this->bo->read_log();
 
-			while (is_array($command_info) && list(,$entry) = each($command_info))
+			foreach ($command_info as $entry)
 			{
-
 				if($this->bocommon->check_perms($entry['grants'], PHPGW_ACL_DELETE))
 				{
 					$link_delete		= $GLOBALS['phpgw']->link('/index.php', array('menuaction'=> 'sms.uicommand.delete', 'command_id'=> $entry['id']));
@@ -374,17 +381,18 @@
 
 				$content[] = array
 				(
-					'id'			=> $entry['id'],
-					'sender'		=> $entry['sender'],
-					'success'		=> $entry['success'],
-					'datetime'		=> $entry['datetime'],
-					'code'			=> $entry['code'],
-					'param'			=> $entry['param'],
+					'id'				=> $entry['id'],
+					'sender'			=> $entry['sender'],
+					'success'			=> $entry['success'],
+					'datetime'			=> $entry['datetime'],
+					'code'				=> $entry['code'],
+					'link_redirect'		=> $entry['success'] == 1 ? $GLOBALS['phpgw']->link('/index.php', array('menuaction'=> 'sms.uicommand.redirect','code' => $entry['code'], 'param'=> urlencode($entry['param']))) : '',
+					'param'				=> $entry['param'],
 					'link_delete'		=> $link_delete,
 					'text_delete'		=> $text_delete,
 					'lang_delete_text'	=> $lang_delete_text,
 				);
-	
+
 				unset ($link_delete);
 				unset ($text_delete);
 				unset ($lang_delete_text);
@@ -425,8 +433,8 @@
 														'allrows'	=> $this->allrows)
 										)),
 
-				'lang_id'		=> lang('id'),
-				'lang_code'		=> lang('code'),
+				'lang_id'			=> lang('id'),
+				'lang_code'			=> lang('code'),
 				'lang_sender'		=> lang('sender'),
 				'lang_success'		=> lang('success'),
 				'lang_datetime'		=> lang('datetime'),
@@ -452,30 +460,30 @@
 				'query'		=> $this->query
 			);
 
-			$msgbox_data = $this->bocommon->msgbox_data($receipt);
+			$msgbox_data = $GLOBALS['phpgw']->common->msgbox_data($receipt);
 
 			$data = array
 			(
 				'msgbox_data'					=> $GLOBALS['phpgw']->common->msgbox($msgbox_data),
-				'links'						=> $links,
-				'allow_allrows'					=> True,
-				'allrows'					=> $this->allrows,
+				'menu'							=> execMethod('sms.menu.links'),
+				'allow_allrows'					=> true,
+				'allrows'						=> $this->allrows,
 				'start_record'					=> $this->start,
 				'record_limit'					=> $record_limit,
 				'num_records'					=> count($command_info),
 				'all_records'					=> $this->bo->total_records,
-				'link_url'					=> $GLOBALS['phpgw']->link('/index.php',$link_data),
-				'img_path'					=> $GLOBALS['phpgw']->common->get_image_path('phpgwapi','default'),
-				'lang_searchfield_statustext'			=> lang('Enter the search string. To show all entries, empty this field and press the SUBMIT button again'),
-				'lang_searchbutton_statustext'			=> lang('Submit the search string'),
-				'query'						=> $this->query,
+				'link_url'						=> $GLOBALS['phpgw']->link('/index.php',$link_data),
+				'img_path'						=> $GLOBALS['phpgw']->common->get_image_path('phpgwapi','default'),
+				'lang_searchfield_statustext'	=> lang('Enter the search string. To show all entries, empty this field and press the SUBMIT button again'),
+				'lang_searchbutton_statustext'	=> lang('Submit the search string'),
+				'query'							=> $this->query,
 				'lang_search'					=> lang('search'),
 				'table_header_log'				=> $table_header,
 				'values_log'					=> $content,
 				'lang_no_cat'					=> lang('no category'),
-				'lang_cat_statustext'				=> lang('Select the category the location belongs to. To do not use a category select NO CATEGORY'),
+				'lang_cat_statustext'			=> lang('Select the category the location belongs to. To do not use a category select NO CATEGORY'),
 				'select_name'					=> 'cat_id',
-				'cat_list'					=> $this->bo->get_category_list(array('format'=>'filter','selected' => $this->cat_id)),
+				'cat_list'						=> $this->bo->get_category_list(array('format'=>'filter','selected' => $this->cat_id)),
 				'select_action'					=> $GLOBALS['phpgw']->link('/index.php',$link_data),
 			);
 
@@ -490,11 +498,10 @@
 
 		function delete()
 		{
-			$GLOBALS['phpgw_info']['flags']['xslt_app'] = True;
-			if(!$this->acl->check($this->acl_location, PHPGW_ACL_DELETE))
+			$GLOBALS['phpgw_info']['flags']['xslt_app'] = true;
+			if(!$this->acl->check($this->acl_location, PHPGW_ACL_DELETE, 'sms'))
 			{
-				$links = $this->menu->links();
-				$this->bocommon->no_access($links);
+				$this->bocommon->no_access();
 				return;
 			}
 
@@ -508,8 +515,6 @@
 
 			if (phpgw::get_var('confirm', 'bool', 'POST'))
 			{
-			//	$this->bo->delete_type($command_id);
-
 				$sql = "SELECT command_code FROM phpgw_sms_featcommand WHERE command_id='$command_id'";
 				$this->db->query($sql,__LINE__,__FILE__);
 				$this->db->next_record();
@@ -528,12 +533,12 @@
 					else
 					{
 						$error_string = "Fail to delete SMS command code `$command_code`";
-					
+
 					}
 
 	    			$this->db->transaction_commit();
 				}
-					
+
 				$link_data['err'] = urlencode($error_string);
 
 				$GLOBALS['phpgw']->redirect_link('/index.php',$link_data);
@@ -546,10 +551,10 @@
 				'done_action'			=> $GLOBALS['phpgw']->link('/index.php',$link_data),
 				'delete_action'			=> $GLOBALS['phpgw']->link('/index.php', array('menuaction'=> 'sms.uicommand.delete', 'command_id'=> $command_id)),
 				'lang_confirm_msg'		=> lang('do you really want to delete this entry'),
-				'lang_yes'			=> lang('yes'),
-				'lang_yes_statustext'		=> lang('Delete the entry'),
-				'lang_no_statustext'		=> lang('Back to the list'),
-				'lang_no'			=> lang('no')
+				'lang_yes'				=> lang('yes'),
+				'lang_yes_statustext'	=> lang('Delete the entry'),
+				'lang_no_statustext'	=> lang('Back to the list'),
+				'lang_no'				=> lang('no')
 			);
 
 			$function_msg	= lang('delete SMS command code');
@@ -558,4 +563,3 @@
 			$GLOBALS['phpgw']->xslttpl->set_var('phpgw',array('delete' => $data));
 		}
 	}
-?>
