@@ -8,7 +8,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package sms
 	* @subpackage polls
- 	* @version $Id: class.uipoll.inc.php 18358 2007-11-27 04:43:37Z skwashd $
+ 	* @version $Id: class.uipoll.inc.php 6257 2010-08-22 14:40:02Z sigurd $
 	*/
 
 	/**
@@ -19,40 +19,38 @@
 	class sms_uipoll
 	{
 		var $public_functions = array(
-			'index'			=> True,
-			'add'			=> True,
-			'add_yes'		=> True,
-			'add_choice'		=> True,
-			'view'			=> True,
-			'edit'			=> True,
-			'edit_yes'		=> True,
-			'delete_choice'		=> True,
-			'delete'		=> True,
-			'status'		=> True,
+			'index'			=> true,
+			'add'			=> true,
+			'add_yes'		=> true,
+			'add_choice'	=> true,
+			'view'			=> true,
+			'edit'			=> true,
+			'edit_yes'		=> true,
+			'delete_choice'	=> true,
+			'delete'		=> true,
+			'status'		=> true,
 			);
 
 
 		function sms_uipoll()
 		{
-
-		//	$this->currentapp			= $GLOBALS['phpgw_info']['flags']['currentapp'];
 			$this->nextmatchs			= CreateObject('phpgwapi.nextmatchs');
 			$this->account				= $GLOBALS['phpgw_info']['user']['account_id'];
-			$this->bo				= CreateObject('sms.bopoll',true);
+			$this->bo					= CreateObject('sms.bopoll',true);
 			$this->bocommon				= CreateObject('sms.bocommon');
-			$this->menu				= CreateObject('sms.menu');
-			$this->sms				= CreateObject('sms.sms');
-			$this->acl				= CreateObject('phpgwapi.acl');
-			$this->acl_location 			= '.poll';
+			$this->sms					= CreateObject('sms.sms');
+			$this->acl 					= & $GLOBALS['phpgw']->acl;
+			$this->acl_location 		= '.poll';
 			$this->menu->sub			= $this->acl_location;
 			$this->start				= $this->bo->start;
 			$this->query				= $this->bo->query;
-			$this->sort				= $this->bo->sort;
+			$this->sort					= $this->bo->sort;
 			$this->order				= $this->bo->order;
 			$this->allrows				= $this->bo->allrows;
-			
-			$this->db 				= clone($GLOBALS['phpgw']->db);
-			$this->db2 				= clone($GLOBALS['phpgw']->db);
+
+			$this->db 					= & $GLOBALS['phpgw']->db;
+			$this->db2 					= clone($this->db);
+			$GLOBALS['phpgw_info']['flags']['menu_selection'] = 'sms::poll';
 		}
 
 		function save_sessiondata()
@@ -70,18 +68,15 @@
 
 		function index()
 		{
+			$GLOBALS['phpgw_info']['flags']['xslt_app'] = true;
 
-			$links = $this->menu->links();
-			$GLOBALS['phpgw_info']['flags']['xslt_app'] = True;
-
-			if(!$this->acl->check($this->acl_location, PHPGW_ACL_READ))
+			if(!$this->acl->check($this->acl_location, PHPGW_ACL_READ, 'sms'))
 			{
-				$this->bocommon->no_access($links);
+				$this->bocommon->no_access();
 				return;
 			}
-			
 
-			$GLOBALS['phpgw']->xslttpl->add_file(array('poll','nextmatchs','menu',
+			$GLOBALS['phpgw']->xslttpl->add_file(array('poll','nextmatchs',
 										'search_field'));
 
 			$receipt = $GLOBALS['phpgw']->session->appsession('session_data','sms_poll_receipt');
@@ -90,7 +85,7 @@
 
 			$poll_info = $this->bo->read();
 
-			while (is_array($poll_info) && list(,$entry) = each($poll_info))
+			foreach ($poll_info as $entry)
 			{
 				if($this->bocommon->check_perms($entry['grants'], PHPGW_ACL_DELETE))
 				{
@@ -107,24 +102,24 @@
 				{
 					$status = lang('disabled');
 				}
-				
+
 				$content[] = array
 				(
-					'code'					=> $entry['code'],
-					'title'					=> $entry['title'],
-					'status'				=> $status,
-					'user'					=> $GLOBALS['phpgw']->accounts->id2name($entry['uid']),
-					'link_edit'				=> $GLOBALS['phpgw']->link('/index.php', array('menuaction'=> 'sms.uipoll.edit', 'poll_id'=> $entry['id'])),
+					'code'						=> $entry['code'],
+					'title'						=> $entry['title'],
+					'status'					=> $status,
+					'user'						=> $GLOBALS['phpgw']->accounts->id2name($entry['uid']),
+					'link_edit'					=> $GLOBALS['phpgw']->link('/index.php', array('menuaction'=> 'sms.uipoll.edit', 'poll_id'=> $entry['id'])),
 					'link_delete'				=> $link_delete,
-					'link_view'				=> $GLOBALS['phpgw']->link('/index.php', array('menuaction'=> 'sms.uipoll.view', 'poll_id'=> $entry['id'])),
-					'lang_view_config_text'			=> lang('view the config'),
-					'lang_edit_config_text'			=> lang('manage the poll code'),
-					'text_view'				=> lang('view'),
-					'text_edit'				=> lang('edit'),
+					'link_view'					=> $GLOBALS['phpgw']->link('/index.php', array('menuaction'=> 'sms.uipoll.view', 'poll_id'=> $entry['id'])),
+					'lang_view_config_text'		=> lang('view the config'),
+					'lang_edit_config_text'		=> lang('manage the poll code'),
+					'text_view'					=> lang('view'),
+					'text_edit'					=> lang('edit'),
 					'text_delete'				=> $text_delete,
 					'lang_delete_text'			=> $lang_delete_text,
 				);
-	
+
 				unset ($link_delete);
 				unset ($text_delete);
 				unset ($lang_delete_text);
@@ -165,14 +160,14 @@
 			$link_data = array
 			(
 				'menuaction'	=> 'sms.uipoll.index',
-				'sort'		=> $this->sort,
-				'order'		=> $this->order,
-				'cat_id'	=> $this->cat_id,
-				'filter'	=> $this->filter,
-				'query'		=> $this->query
+				'sort'			=> $this->sort,
+				'order'			=> $this->order,
+				'cat_id'		=> $this->cat_id,
+				'filter'		=> $this->filter,
+				'query'			=> $this->query
 			);
 
-//			if($this->acl->check($this->acl_location, PHPGW_ACL_ADD))
+//			if($this->acl->check($this->acl_location, PHPGW_ACL_ADD, 'sms'))
 			{
 				$table_add[] = array
 				(
@@ -182,27 +177,27 @@
 				);
 			}
 
-			$msgbox_data = $this->bocommon->msgbox_data($receipt);
+			$msgbox_data = $GLOBALS['phpgw']->common->msgbox_data($receipt);
 
 			$data = array
 			(
 				'msgbox_data'					=> $GLOBALS['phpgw']->common->msgbox($msgbox_data),
-				'links'						=> $links,
-				'allow_allrows'					=> True,
-				'allrows'					=> $this->allrows,
+				'menu'							=> execMethod('sms.menu.links'),
+				'allow_allrows'					=> true,
+				'allrows'						=> $this->allrows,
 				'start_record'					=> $this->start,
 				'record_limit'					=> $record_limit,
 				'num_records'					=> count($poll_info),
 				'all_records'					=> $this->bo->total_records,
-				'link_url'					=> $GLOBALS['phpgw']->link('/index.php',$link_data),
-				'img_path'					=> $GLOBALS['phpgw']->common->get_image_path('phpgwapi','default'),
-				'lang_searchfield_statustext'			=> lang('Enter the search string. To show all entries, empty this field and press the SUBMIT button again'),
-				'lang_searchbutton_statustext'			=> lang('Submit the search string'),
-				'query'						=> $this->query,
+				'link_url'						=> $GLOBALS['phpgw']->link('/index.php',$link_data),
+				'img_path'						=> $GLOBALS['phpgw']->common->get_image_path('phpgwapi','default'),
+				'lang_searchfield_statustext'	=> lang('Enter the search string. To show all entries, empty this field and press the SUBMIT button again'),
+				'lang_searchbutton_statustext'	=> lang('Submit the search string'),
+				'query'							=> $this->query,
 				'lang_search'					=> lang('search'),
 				'table_header'					=> $table_header,
-				'table_add'					=> $table_add,
-				'values'					=> $content
+				'table_add'						=> $table_add,
+				'values'						=> $content
 			);
 
 			$appname		= lang('polls');
@@ -215,16 +210,13 @@
 
 		function add()
 		{
-		
-			if(!$this->acl->check($this->acl_location, PHPGW_ACL_READ))
+			if(!$this->acl->check($this->acl_location, PHPGW_ACL_READ, 'sms'))
 			{
-				$links = $this->menu->links();
-				$GLOBALS['phpgw_info']['flags']['xslt_app'] = True;
-				$this->bocommon->no_access($links);
+				$GLOBALS['phpgw_info']['flags']['xslt_app'] = true;
+				$this->bocommon->no_access();
 				return;
 			}
-			
-			
+
 			$GLOBALS['phpgw_info']['flags']['app_header'] = lang('SMS').' - '.lang('Add SMS poll');
 			$GLOBALS['phpgw']->common->phpgw_header();
 
@@ -241,7 +233,7 @@
 				'menuaction'	=> 'sms.uipoll.add_yes',
 				'autoreply_id'	=> $autoreply_id
 				);
-				
+
 			$add_url = $GLOBALS['phpgw']->link('/index.php',$add_data);
 
 
@@ -270,12 +262,10 @@
 
 		function add_yes()
 		{
-		
-			if(!$this->acl->check($this->acl_location, PHPGW_ACL_READ))
+			if(!$this->acl->check($this->acl_location, PHPGW_ACL_READ, 'sms'))
 			{
-				$links = $this->menu->links();
-				$GLOBALS['phpgw_info']['flags']['xslt_app'] = True;
-				$this->bocommon->no_access($links);
+				$GLOBALS['phpgw_info']['flags']['xslt_app'] = true;
+				$this->bocommon->no_access();
 				return;
 			}
 
@@ -300,7 +290,7 @@
 					$new_uid = $this->db->get_last_insert_id(phpgw_sms_featpoll,'poll_id');
 
 					$this->db->transaction_commit();
-					
+
 					if ($new_uid)
 					{
 					    $error_string = "SMS poll with code `$poll_code` has been added";
@@ -325,16 +315,12 @@
 			$GLOBALS['phpgw']->redirect_link('/index.php',$add_data);
 		}
 
-
-
 		function add_choice()
 		{
-		
-			if(!$this->acl->check($this->acl_location, PHPGW_ACL_READ))
+			if(!$this->acl->check($this->acl_location, PHPGW_ACL_READ, 'sms'))
 			{
-				$links = $this->menu->links();
-				$GLOBALS['phpgw_info']['flags']['xslt_app'] = True;
-				$this->bocommon->no_access($links);
+				$GLOBALS['phpgw_info']['flags']['xslt_app'] = true;
+				$this->bocommon->no_access();
 				return;
 			}
 
@@ -348,11 +334,11 @@
 			{
 				$sql = "SELECT choice_id FROM phpgw_sms_featpoll_choice WHERE poll_id='$poll_id' AND choice_code='$choice_code'";
 				$this->db->query($sql,__LINE__,__FILE__);
-	    
+
 					if (!$this->db->next_record())
 	    			{
 						$sql = "
-		    				INSERT INTO phpgw_sms_featpoll_choice 
+		    				INSERT INTO phpgw_sms_featpoll_choice
 		    				(poll_id,choice_title,choice_code)
 		    				VALUES ('$poll_id','$choice_title','$choice_code')
 							";
@@ -376,7 +362,7 @@
 			}
 			else
 			{
-				$error_string = "You must fill all fields!";	    
+				$error_string = "You must fill all fields!";
 			}
 
 			$add_data = array(
@@ -390,12 +376,10 @@
 
 		function status()
 		{
-		
-			if(!$this->acl->check($this->acl_location, PHPGW_ACL_READ))
+			if(!$this->acl->check($this->acl_location, PHPGW_ACL_READ, 'sms'))
 			{
-				$links = $this->menu->links();
-				$GLOBALS['phpgw_info']['flags']['xslt_app'] = True;
-				$this->bocommon->no_access($links);
+				$GLOBALS['phpgw_info']['flags']['xslt_app'] = true;
+				$this->bocommon->no_access();
 				return;
 			}
 
@@ -407,13 +391,13 @@
 			$this->db->transaction_begin();
 
 			$this->db->query($sql,__LINE__,__FILE__);
-	    
+
 			if ($this->db->affected_rows()>0)
 			{
 			    $error_string = "This poll status has been changed!";
 			}
 			$this->db->transaction_commit();
-	
+
 			$add_data = array(
 				'menuaction'	=> 'sms.uipoll.edit',
 				'poll_id' => $poll_id,
@@ -423,20 +407,15 @@
 			$GLOBALS['phpgw']->redirect_link('/index.php',$add_data);
 		}
 
-
-
 		function edit()
 		{
-		
-			if(!$this->acl->check($this->acl_location, PHPGW_ACL_READ))
+			if(!$this->acl->check($this->acl_location, PHPGW_ACL_READ, 'sms'))
 			{
-				$links = $this->menu->links();
-				$GLOBALS['phpgw_info']['flags']['xslt_app'] = True;
-				$this->bocommon->no_access($links);
+				$GLOBALS['phpgw_info']['flags']['xslt_app'] = true;
+				$this->bocommon->no_access();
 				return;
 			}
-			
-			
+
 			$GLOBALS['phpgw_info']['flags']['app_header'] = lang('SMS').' - '.lang('Edit SMS poll');
 			$GLOBALS['phpgw']->common->phpgw_header();
 
@@ -464,7 +443,7 @@
 				'poll_id' => $poll_id,
 				'poll_code' => $poll_code,
 				);
-				
+
 			$edit_url = $GLOBALS['phpgw']->link('/index.php',$edit_data);
 
 			$content .= "
@@ -497,7 +476,7 @@
 				'menuaction'	=> 'sms.uipoll.add_choice',
 				'poll_id'	=> $poll_id,
 				);
-			
+
 			$add_url = $GLOBALS['phpgw']->link('/index.php',$add_data);
 
 
@@ -509,7 +488,7 @@
 			<p><input type=submit class=button value=\"Add Choice\">
 			</form>
 			<br>";
-			
+
 			echo $content;
 
 			$enable_data = array('menuaction'	=> 'sms.uipoll.status',
@@ -527,7 +506,7 @@
 			$sql = "SELECT poll_enable FROM phpgw_sms_featpoll WHERE poll_id='$poll_id'";
 			$this->db->query($sql,__LINE__,__FILE__);
 			$this->db->next_record();
-	
+
 			$poll_status = "<font color=red><b>Disable</b></font>";
 			if ($this->db->f('poll_enable'))
 			{
@@ -536,7 +515,7 @@
 			}
 			else
 			{
-			    $action = "<p>- <a href=\"$enable_url\">I want to <b>enable</b> this poll</a>";			
+			    $action = "<p>- <a href=\"$enable_url\">I want to <b>enable</b> this poll</a>";
 			}
 
 			$content = "
@@ -544,7 +523,7 @@
 			    <p>
 			    <p>Current status: $poll_status
 			    <p>What do you want to do ?
-			    $action			    
+			    $action
 			    <br>
 			    ";
 
@@ -561,12 +540,10 @@
 
 		function edit_yes()
 		{
-		
-			if(!$this->acl->check($this->acl_location, PHPGW_ACL_READ))
+			if(!$this->acl->check($this->acl_location, PHPGW_ACL_READ, 'sms'))
 			{
-				$links = $this->menu->links();
-				$GLOBALS['phpgw_info']['flags']['xslt_app'] = True;
-				$this->bocommon->no_access($links);
+				$GLOBALS['phpgw_info']['flags']['xslt_app'] = true;
+				$this->bocommon->no_access();
 				return;
 			}
 
@@ -579,10 +556,10 @@
 
 			if ($poll_id && $poll_title && $poll_code)
 			{
-			    
+
 					$sql = "UPDATE phpgw_sms_featpoll SET poll_title='$poll_title',poll_code='$poll_code'
 							WHERE poll_id='$poll_id'";
-					
+
 					$this->db->transaction_begin();
 
 					$this->db->query($sql,__LINE__,__FILE__);
@@ -608,14 +585,12 @@
 
 		function view()
 		{
-			if(!$this->acl->check($this->acl_location, PHPGW_ACL_READ))
+			if(!$this->acl->check($this->acl_location, PHPGW_ACL_READ, 'sms'))
 			{
-				$links = $this->menu->links();
-				$GLOBALS['phpgw_info']['flags']['xslt_app'] = True;
-				$this->bocommon->no_access($links);
+				$GLOBALS['phpgw_info']['flags']['xslt_app'] = true;
+				$this->bocommon->no_access();
 				return;
 			}
-			
 
 			$poll_id	= phpgw::get_var('poll_id', 'int');
 
@@ -624,8 +599,8 @@
 			$this->db->next_record();
 
 			$poll_title = $this->db->f('poll_title');
-			
-			
+
+
 			$GLOBALS['phpgw_info']['flags']['app_header'] = lang('SMS').' - '.lang('view poll') . ': ' . $poll_title;
 			$GLOBALS['phpgw']->common->phpgw_header();
 
@@ -639,7 +614,7 @@
 			{
 			    $mult = $_GET[mult];
 			    $bodybgcolor = $_GET[bodybgcolor];
-			    if (!isset($mult)) 
+			    if (!isset($mult))
 			    {
 				$mult = "2";
 			    }
@@ -658,36 +633,36 @@
 				$this->db->query($sql,__LINE__,__FILE__);
 			    while ($this->db->next_record())
 			    {
-				$choice_id = $this->db->f('choice_id');
-				$choice_title = $this->db->f('choice_title');
-				$choice_code = $this->db->f('choice_code');
-				$sql2 = "SELECT result_id FROM phpgw_sms_featpoll_result WHERE poll_id='$poll_id' AND choice_id='$choice_id'";
-				$this->db2->query($sql2,__LINE__,__FILE__);
-				$choice_voted = $this->db2->num_rows();
-				if ($total_voters)
-				{
-				    $percentage = round(($choice_voted/$total_voters)*100);
-				}
-				else
-				{
-				    $percentage = "0";
-				}
+					$choice_id = $this->db->f('choice_id');
+					$choice_title = $this->db->f('choice_title');
+					$choice_code = $this->db->f('choice_code');
+					$sql2 = "SELECT result_id FROM phpgw_sms_featpoll_result WHERE poll_id='$poll_id' AND choice_id='$choice_id'";
+					$this->db->query($sql2,__LINE__,__FILE__);
+					$choice_voted = $this->db->num_rows();
+					if ($total_voters)
+					{
+					    $percentage = round(($choice_voted/$total_voters)*100);
+					}
+					else
+					{
+					    $percentage = "0";
+					}
 
-				$bar_img = $GLOBALS['phpgw_info']['server']['webserver_url'] . '/sms/templates/base/images/bar.png';
+					$bar_img = $GLOBALS['phpgw_info']['server']['webserver_url'] . '/sms/templates/base/images/bar.png';
 
-				$content .= "
+					$content .= "
 				    <tr>
-					<td width=90% nowrap class=box_text valign=middle align=left>
-					    <font size=-2>[ <b>$choice_code</b> ] $choice_title</font>
-					</td>
-					<td width=10% nowrap class=box_text valign=middle align=right>
-					    <font size=-2>$percentage%, $choice_voted</font>
-					</td>
-				    </tr>
-				    <tr>
-					<td width=100% nowrap class=box_text valign=middle align=left colspan=2>
-					    <img src=\"$bar_img\" height=\"12\" width=\"".($mult*$percentage)."\" alt=\"".($percentage)."% ($choice_voted)\"></font><br>
-					</td>
+						<td width=90% nowrap class=box_text valign=middle align=left>
+						    <font size=-2>[ <b>$choice_code</b> ] $choice_title</font>
+							</td>
+						<td width=10% nowrap class=box_text valign=middle align=right>
+						    <font size=-2>$percentage%, $choice_voted</font>
+						</td>
+					    </tr>
+					    <tr>
+						<td width=100% nowrap class=box_text valign=middle align=left colspan=2>
+						    <img src=\"$bar_img\" height=\"12\" width=\"".($mult*$percentage)."\" alt=\"".($percentage)."% ($choice_voted)\"></font><br>
+						</td>
 				    </tr>
 				";
 			    }
@@ -696,9 +671,11 @@
 				</table>
 			    ";
 
-				$done_data = array(
-				'menuaction'	=> 'sms.uipoll.index');
-				
+				$done_data = array
+				(
+					'menuaction'	=> 'sms.uipoll.index'
+				);
+
 				$done_url = $GLOBALS['phpgw']->link('/index.php',$done_data);
 
 				$content .= "
@@ -713,11 +690,10 @@
 
 		function delete()
 		{
-			$GLOBALS['phpgw_info']['flags']['xslt_app'] = True;
-			if(!$this->acl->check($this->acl_location, PHPGW_ACL_READ))
+			$GLOBALS['phpgw_info']['flags']['xslt_app'] = true;
+			if(!$this->acl->check($this->acl_location, PHPGW_ACL_READ, 'sms'))
 			{
-				$links = $this->menu->links();
-				$this->bocommon->no_access($links);
+				$this->bocommon->no_access();
 				return;
 			}
 
@@ -748,7 +724,7 @@
 					if ($this->db->affected_rows())
 	    			{
 						$sql = "DELETE FROM phpgw_sms_tblsmsincoming WHERE in_code='$poll_title'";
-						$this->db->query($sql,__LINE__,__FILE__);	
+						$this->db->query($sql,__LINE__,__FILE__);
 						$error_string = "SMS poll `$poll_title` with all its messages has been deleted!";
 					}
 					else
@@ -757,7 +733,7 @@
 	    			}
 	    			$this->db->transaction_commit();
 				}
-					
+
 				$link_data['err'] = urlencode($error_string);
 
 				$GLOBALS['phpgw']->redirect_link('/index.php',$link_data);
@@ -786,11 +762,10 @@
 
 		function delete_choice()
 		{
-			$GLOBALS['phpgw_info']['flags']['xslt_app'] = True;
-			if(!$this->acl->check($this->acl_location, PHPGW_ACL_READ))
+			$GLOBALS['phpgw_info']['flags']['xslt_app'] = true;
+			if(!$this->acl->check($this->acl_location, PHPGW_ACL_READ, 'sms'))
 			{
-				$links = $this->menu->links();
-				$this->bocommon->no_access($links);
+				$this->bocommon->no_access();
 				return;
 			}
 
@@ -823,13 +798,13 @@
 					if ($this->db->affected_rows())
 	    			{
 						$sql = "DELETE FROM phpgw_sms_featpoll_result WHERE poll_id='$poll_id' AND choice_id='$choice_id'";
-						$this->db->query($sql,__LINE__,__FILE__);	
+						$this->db->query($sql,__LINE__,__FILE__);
 						$error_string = "SMS poll choice with code `$choice_code` and all its voters has been deleted!";
 					}
 
 	    			$this->db->transaction_commit();
 				}
-					
+
 				$link_data['err'] = urlencode($error_string);
 
 				$GLOBALS['phpgw']->redirect_link('/index.php',$link_data);
@@ -839,20 +814,19 @@
 
 			$data = array
 			(
-				'done_action'			=> $GLOBALS['phpgw']->link('/index.php',$link_data),
-				'delete_action'			=> $GLOBALS['phpgw']->link('/index.php', array('menuaction'=> 'sms.uipoll.delete_choice', 'poll_id'=> $poll_id, 'choice_id'=> $choice_id)),
-				'lang_confirm_msg'		=> lang('do you really want to delete this entry'),
-				'lang_yes'			=> lang('yes'),
+				'done_action'				=> $GLOBALS['phpgw']->link('/index.php',$link_data),
+				'delete_action'				=> $GLOBALS['phpgw']->link('/index.php', array('menuaction'=> 'sms.uipoll.delete_choice', 'poll_id'=> $poll_id, 'choice_id'=> $choice_id)),
+				'lang_confirm_msg'			=> lang('do you really want to delete this entry'),
+				'lang_yes'					=> lang('yes'),
 				'lang_yes_statustext'		=> lang('Delete the entry'),
 				'lang_no_statustext'		=> lang('Back to the list'),
-				'lang_no'			=> lang('no')
+				'lang_no'					=> lang('no')
 			);
 
-			$appname		= lang('sms');
+			$appname			= lang('sms');
 			$function_msg		= lang('delete poll choice');
 
 			$GLOBALS['phpgw_info']['flags']['app_header'] = lang('sms') . ' - ' . $appname . ': ' . $function_msg;
 			$GLOBALS['phpgw']->xslttpl->set_var('phpgw',array('delete' => $data));
 		}
 	}
-?>
